<?php
defined( 'ABSPATH' ) || exit;

$templates['hero-1'] = array();
$templates['hero-1']['name'] = esc_html__( 'Hero', 'total' ) . ' 1';
$templates['hero-1']['category'] = 'hero';
$templates['hero-1']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627246953324{padding-top: 15% !important;padding-bottom: 15% !important;background-color: #222222 !important;}"][vc_column][vcex_heading text="Best in the Industry" color="rgba(255,255,255,0.6)" text_align="center" font_size=".9em" font_weight="semibold" text_transform="uppercase" letter_spacing="1px"][vcex_spacing size="10px"][vcex_heading text="Meet Company X, the All-In-One Service for Designers &amp; Freelancers" align="center" color="#ffffff" text_align="center" tag="h2" font_size="d:35px|pl:30px" font_weight="bold" width="700px"][vcex_spacing size="20px"][vc_column_text text_align="center" color="rgba(255,255,255,0.5)" width="500px" align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec egestas hendrerit felis quis convallis. Sed erat ex, finibus non.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

$templates['hero-2'] = array();
$templates['hero-2']['name'] = esc_html__( 'Hero', 'total' ) . ' 2';
$templates['hero-2']['category'] = 'hero';
$templates['hero-2']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627247001753{padding-top: 15% !important;padding-bottom: 15% !important;background-color: #222222 !important;}"][vc_column][vcex_heading text="Best in the Industry" color="rgba(255,255,255,0.6)" text_align="center" font_size=".9em" font_weight="semibold" text_transform="uppercase" letter_spacing="1px"][vcex_spacing size="10px"][vcex_heading text="Meet Company X, the All-In-One Service for Designers &amp; Freelancers" align="center" color="#ffffff" text_align="center" tag="h2" font_size="d:35px|pl:30px" font_weight="bold" width="700px"][vcex_spacing size="20px"][vcex_button align="center" color="white" border_radius="0px" border="0px" font_padding="top:12px|right:25px|bottom:12px|left:25px" font_weight="700" text_transform="uppercase" letter_spacing="1px" font_size="12px"]Get Started[/vcex_button][/vc_column][/vc_row]
CONTENT;

$templates['hero-3'] = array();
$templates['hero-3']['name'] = esc_html__( 'Hero', 'total' ) . ' 3';
$templates['hero-3']['category'] = 'hero';
$templates['hero-3']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627247023160{padding-top: 10% !important;padding-bottom: 10% !important;background-color: #222222 !important;}"][vc_column width="2/3"][vcex_heading text="Best in the Industry" color="rgba(255,255,255,0.6)" font_size=".9em" font_weight="semibold" text_transform="uppercase" letter_spacing="1px"][vcex_spacing size="10px"][vcex_heading text="Meet Company X, the All-In-One Service for Designers &amp; Freelancers" color="#ffffff" tag="h2" font_size="d:35px|pl:30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text color="rgba(255,255,255,0.5)"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec egestas hendrerit felis quis convallis. Sed erat ex, finibus non tellus in, molestie tempor enim. Maecenas eu orci nec ante suscipit bibendum.[/vc_column_text][vcex_spacing][vcex_button color="white" border_radius="0px" border="0px" font_padding="top:12px|right:25px|bottom:12px|left:25px" font_weight="700" text_transform="uppercase" letter_spacing="1px" font_size="12px"]Get Started[/vcex_button][/vc_column][vc_column width="1/3"][/vc_column][/vc_row]
CONTENT;

$templates['hero-4'] = array();
$templates['hero-4']['name'] = esc_html__( 'Hero', 'total' ) . ' 4';
$templates['hero-4']['category'] = 'hero';
$templates['hero-4']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627072369697{padding-top: 10% !important;padding-bottom: 10% !important;background-color: #222222 !important;}"][vc_column width="2/3"][vcex_heading text="Best in the Industry" color="rgba(255,255,255,0.6)" font_size=".9em" font_weight="semibold" text_transform="uppercase" letter_spacing="1px"][vcex_spacing size="10px"][vcex_heading text="Meet Company X, the All-In-One Service for Designers &amp; Freelancers" color="#ffffff" tag="h2" font_size="d:35px|pl:30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text color="rgba(255,255,255,0.5)"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec egestas hendrerit felis quis convallis. Sed erat ex, finibus non tellus in, molestie tempor enim. Maecenas eu orci nec ante suscipit bibendum.[/vc_column_text][vcex_spacing][vcex_multi_buttons buttons="%5B%7B%22text%22%3A%22LEARN%20MORE%22%2C%22link%22%3A%22url%3A%23%22%2C%22style%22%3A%22flat%22%2C%22local_scroll%22%3A%22false%22%2C%22download_attribute%22%3A%22false%22%2C%22css_animation%22%3A%22none%22%7D%2C%7B%22text%22%3A%22GET%20STARTED%22%2C%22link%22%3A%22url%3A%23%22%2C%22style%22%3A%22outline%22%2C%22color%22%3A%22white%22%2C%22local_scroll%22%3A%22false%22%2C%22download_attribute%22%3A%22false%22%2C%22css_animation%22%3A%22none%22%7D%5D" align="left" font_weight="700" padding="top:12px|right:30px|bottom:12px|left:30px" border_radius="0px" border_width="2px" letter_spacing="1px" spacing="20px" font_size=".92em"][/vc_column][vc_column width="1/3"][/vc_column][/vc_row]
CONTENT;

$templates['hero-5'] = array();
$templates['hero-5']['name'] = esc_html__( 'Hero', 'total' ) . ' 5';
$templates['hero-5']['category'] = 'hero';
$templates['hero-5']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" wpex_shape_divider_bottom="waves" css=".vc_custom_1625950372960{padding-top: 10% !important;padding-bottom: 18% !important;background-color: #222222 !important;}" wpex_shape_divider_bottom_height="50" wpex_shape_divider_bottom_visibility="hidden-phone"][vc_column width="2/3"][vcex_heading text="Limited Time Sale" add_css_to_inner="true" color="#ffffff" font_size="11px" font_weight="600" text_transform="uppercase" background_color="accent" css=".vc_custom_1627072862241{padding-top: 5px !important;padding-right: 10px !important;padding-bottom: 5px !important;padding-left: 10px !important;}"][vcex_spacing size="10px"][vcex_heading text="Meet Company X, the All-In-One Service for Designers &amp; Freelancers" color="#ffffff" tag="h2" font_size="d:35px|pl:30px" font_weight="bold"][vcex_divider_dots align="left" color="#ffffff" margin="top:15px|bottom:15px"][vc_column_text color="rgba(255,255,255,0.5)"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec egestas hendrerit felis quis convallis. Sed erat ex, finibus non tellus in, molestie tempor enim. Maecenas eu orci nec ante suscipit bibendum.[/vc_column_text][vcex_spacing][vcex_multi_buttons buttons="%5B%7B%22text%22%3A%22LEARN%20MORE%22%2C%22link%22%3A%22url%3A%23%22%2C%22style%22%3A%22flat%22%2C%22local_scroll%22%3A%22false%22%2C%22download_attribute%22%3A%22false%22%2C%22css_animation%22%3A%22none%22%7D%2C%7B%22text%22%3A%22GET%20STARTED%22%2C%22link%22%3A%22url%3A%23%22%2C%22style%22%3A%22outline%22%2C%22color%22%3A%22white%22%2C%22local_scroll%22%3A%22false%22%2C%22download_attribute%22%3A%22false%22%2C%22css_animation%22%3A%22none%22%7D%5D" align="left" font_weight="700" padding="top:12px|right:30px|bottom:12px|left:30px" border_radius="0px" border_width="2px" letter_spacing="1px" spacing="20px" font_size=".92em"][/vc_column][vc_column width="1/3"][/vc_column][/vc_row]
CONTENT;

$templates['hero-6'] = array();
$templates['hero-6']['name'] = esc_html__( 'Hero', 'total' ) . ' 6';
$templates['hero-6']['category'] = 'hero';
$templates['hero-6']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" column_spacing="60" css=".vc_custom_1627073006101{padding-top: 60px !important;padding-bottom: 20px !important;background-color: #222222 !important;}"][vc_column width="1/2"][vcex_image source="external" external_image="{$ph_square}"][/vc_column][vc_column width="1/2"][vcex_heading text="Meet Company X, the All-In-One Service for Designers &amp; Freelancers" color="#ffffff" tag="h2" font_size="30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text color="rgba(255,255,255,0.5)"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec egestas hendrerit felis quis convallis. Sed erat ex, finibus non tellus in, molestie tempor enim. Maecenas eu orci nec ante suscipit bibendum.[/vc_column_text][vcex_spacing][vcex_button color="white" border_radius="0px" border="0px" font_padding="top:12px|right:25px|bottom:12px|left:25px" font_weight="bold" text_transform="uppercase" letter_spacing="1px" font_size=".92em"]Get Started[/vcex_button][/vc_column][/vc_row]
CONTENT;

$templates['hero-7'] = array();
$templates['hero-7']['name'] = esc_html__( 'Hero', 'total' ) . ' 7';
$templates['hero-7']['category'] = 'hero';
$templates['hero-7']['content'] = <<<CONTENT
[vc_row content_placement="middle" css=".vc_custom_1627333682124{margin-top: 40px !important;}"][vc_column width="3/5"][vcex_heading text="Hi there," font_weight="bold" font_size="18px" tag="span" line_height="1"][vcex_heading text="I am Mark" font_weight="900" font_size="d:85px|tp:70px|pl:60px|pp:50px" tag="h2" line_height="1.2"][vcex_heading text="Freelance developer during the day`{`br`}`&amp; crime fighter at night." font_weight="semibold" font_size="d:30px|pl:25px" tag="div" line_height="1.2"][vcex_spacing size="35px"][vcex_button font_size="18px" border_radius="0px" custom_background="#f22150" font_padding="top:10px|right:30px|bottom:10px|left:30px"]Learn more[/vcex_button][/vc_column][vc_column width="2/5"][vcex_image source="external" external_image="{$ph_square}"][/vc_column][/vc_row]
CONTENT;

$templates['hero-8'] = array();
$templates['hero-8']['name'] = esc_html__( 'Hero', 'total' ) . ' 8';
$templates['hero-8']['category'] = 'hero';
$templates['hero-8']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627334818773{padding-top: 60px !important;padding-bottom: 65px !important;}"][vc_column][vcex_heading text="Make your dreams come true" align="center" tag="h2" font_size="d:60px|pl:45px" font_weight="900" text_align="center" width="700px" font_family="Merriweather" color="#251757" line_height="1.2"][vcex_spacing size="20px"][vc_column_text width="700px" align="center" text_align="center" font_size="18px" color="#9b98a9"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci.[/vc_column_text][vcex_spacing size="40px"][vcex_button custom_background="#6559ff" font_weight="500" font_size="16px" border_radius="15px" font_padding="top:15px|right:30px|bottom:15px|left:30px" align="center" custom_hover_background="#857bff"]Let's get started[/vcex_button][/vc_column][/vc_row]
CONTENT;

$templates['hero-9'] = array();
$templates['hero-9']['name'] = esc_html__( 'Hero', 'total' ) . ' 9';
$templates['hero-9']['category'] = 'hero';
$templates['hero-9']['content'] = <<<CONTENT
[vc_row column_spacing="50" css=".vc_custom_1627335173714{margin-top: 50px !important;}"][vc_column width="1/2"][vcex_heading text="Meet Crowdfund" font_weight="bolder" font_size="50px" font_family="Inter"][vcex_spacing size="20px"][vc_column_text color="#222222" font_size="16px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros.[/vc_column_text][vcex_spacing size="40px"][vcex_flex_container flex_grow="true" flex_wrap="true" flex_direction="row" gap="15px"][vcex_button font_size="14px" font_weight="bold" font_padding="top:15px|right:25px|bottom:15px|left:25px" border_radius="4px" custom_background="#222222" custom_color="#d1be7f"]Let's Get Started[/vcex_button][vcex_button onclick="lightbox" url="https://www.youtube.com/watch?v=UKI93s1yVDo" font_size="14px" font_weight="bold" font_padding="top:15px|right:25px|bottom:15px|left:25px" border_radius="4px" custom_background="#fff3cb" custom_color="#222222" icon_left="ticon ticon-play"]Watch Video Tour[/vcex_button][/vcex_flex_container][/vc_column][vc_column width="1/2"][vcex_image source="external" external_image="{$ph_landscape}"][/vc_column][/vc_row]
CONTENT;

$templates['hero-10'] = array();
$templates['hero-10']['name'] = esc_html__( 'Hero', 'total' ) . ' 10';
$templates['hero-10']['category'] = 'hero';
$templates['hero-10']['content'] = <<<CONTENT
[vc_row css=".vc_custom_1627348203578{margin-top: 40px !important;}"][vc_column width="3/5"][vcex_heading text="#E-8_JTVCc3BhbiUyMGNsYXNzJTNEJTIyd3BleC1mb250LWV4dHJhYm9sZCUyMiU1REV2ZXJ5dGhpbmclNUIlMkZzcGFuJTVEJTIweW91JTIwbmVlZCUyMHRvJTIwYnVpbGQlMjBhJTIwZ3JlYXQlMjAlMjYlMjBmYXN0JTIwJTVCc3BhbiUyMGNsYXNzJTNEJTIyd3BleC1mb250LWV4dHJhYm9sZCUyMiU1RFdlYnNpdGUlNUIlMkZzcGFuJTVELg==" font_size="45px" font_weight="500" tag="h2"][vcex_spacing size="25px"][vc_zigzag color="black" align="left" el_width="10"][vcex_spacing size="20px"][vc_column_text color="#000000" font_size="18px"]If you are looking to create an awesome, responsive and mobile friendly website, look no further![/vc_column_text][vcex_spacing size="35px"][vcex_newsletter_form bottom_margin="20px" input_align="left" fullwidth_mobile="true" gap="15px" placeholder_text="your-email@example.com" submit_text="Try for Free" submit_bg="#ffde06" input_width="550px" submit_weight="bold" input_border_color="#bdbdbd" input_border_radius="8px" submit_border_radius="8px" input_color="#000000" input_font_size="16px" submit_text_transform="none" submit_font_size="14px" submit_color="#333333"][vcex_list_item icon="ticon ticon-check" icon_spacing="5px" font_color="#000000" font_size="14px" font_weight="semibold"]Trusted by over 50,000 websites.[/vcex_list_item][/vc_column][vc_column width="2/5"][/vc_column][/vc_row]
CONTENT;

$templates['hero-11'] = array();
$templates['hero-11']['name'] = esc_html__( 'Hero', 'total' ) . ' 11';
$templates['hero-11']['category'] = 'hero';
$templates['hero-11']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627348246314{padding-top: 60px !important;padding-bottom: 60px !important;}"][vc_column][vcex_image source="external" align="center" external_image="{$ph_square}" width="120px" border_radius="50%"][vcex_spacing][vcex_heading text="Hi, I'm Jessica" tag="h2" text_align="center" font_weight="semibold" font_size="25px"][vcex_spacing size="10px"][vcex_heading text="Building apps, products, brands and modern websites." align="center" tag="h2" text_align="center" font_weight="bold" font_size="60px" line_height="1.2" width="800px" font_family="Poppins"][vcex_spacing size="35px"][vc_column_text color="#000000" font_size="18px" width="700px" align="center" text_align="center"]Product Designer and Visual Developer based in sunny California. I specialize in UI/UX Design, Mobile-First Web Design and Visual Development.[/vc_column_text][vcex_spacing size="50px"][vcex_button custom_background="#000000" border_radius="9999px" font_size="14px" text_transform="uppercase" font_weight="normal" font_padding="top:20px|right:40px|bottom:20px|left:40px" align="center"]Connect With me[/vcex_button][/vc_column][/vc_row]
CONTENT;

$templates['hero-12'] = array();
$templates['hero-12']['name'] = esc_html__( 'Hero', 'total' ) . ' 12';
$templates['hero-12']['category'] = 'hero';
$templates['hero-12']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627362980294{padding-top: 10% !important;background-color: #f6f7fb !important;}"][vc_column][vcex_heading text="A simple and smart tool to that will help grow your business" align="center" tag="h2" font_size="d:40px|pl:35px" font_weight="bold" text_align="center" font_family="Inter" color="#2c3959" line_height="1.2" width="700px"][vcex_spacing size="20px"][vc_column_text width="600px" align="center" text_align="center" font_size="18px" color="rgba(0,0,0,0.5)"]The best platform for collective reviews, user-generated content and site metrics designed to increase site conversions.[/vc_column_text][vcex_spacing][vcex_flex_container align_items="strech" justify_content="center" flex_wrap="true" flex_direction="row"][vcex_button bottom_margin="15px" custom_background="#0255ff" font_weight="semibold" font_size="14px" border_radius="9999px" font_padding="top:15px|right:30px|bottom:15px|left:30px" align="center" custom_hover_background="#3577ff"]Start 14-Day Free Trial[/vcex_button][vcex_button bottom_margin="15px" shadow="shadow-md" custom_background="#ffffff" font_weight="500" font_size="14px" border_radius="9999px" font_padding="top:15px|right:30px|bottom:15px|left:30px" align="center" custom_color="#0255ff" icon_right="ticon ticon-angle-right"]Learn more[/vcex_button][/vcex_flex_container][vc_column_text text_align="center" color="#9b98a9" font_size=".9em"]No credit card required. Plans start at $0/month.[/vc_column_text][vcex_spacing size="40px"][vcex_image source="external" align="center" external_image="{$ph_landscape}" width="800px"][/vc_column][/vc_row]
CONTENT;

$templates['hero-13'] = array();
$templates['hero-13']['name'] = esc_html__( 'Hero', 'total' ) . ' 13';
$templates['hero-13']['category'] = 'hero';
$templates['hero-13']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" column_spacing="60" css=".vc_custom_1633376619322{padding-top: 80px !important;padding-bottom: 40px !important;background-color: #000000 !important;}"][vc_column width="1/2"][vc_column_text font_size="16px" color="rgba(255,255,255,0.5)"]Design Websites Faster[/vc_column_text][vcex_spacing size="20px"][vcex_heading text="The Ultimate Product for Building Fast &amp; Responsive Sites Compared To Ordinary Frameworks." color="#ffffff" tag="h2" font_size="30px" font_weight="normal"][vcex_spacing size="50px"][vcex_button color="white" border_radius="9999px" border="0px" font_padding="top:15px|right:40px|bottom:15px|left:40px" font_weight="semibold" font_size="1em"]Get Started[/vcex_button][/vc_column][vc_column width="1/2"][vcex_flex_container flex_direction="row" gap="30px"][vcex_image source="external" external_image="{$ph_portrait}" css=".vc_custom_1633376598454{margin-top: 60px !important;}"][vcex_image source="external" external_image="{$ph_portrait}"][/vcex_flex_container][/vc_column][/vc_row]
CONTENT;

$templates['hero-14'] = array();
$templates['hero-14']['name'] = esc_html__( 'Hero', 'total' ) . ' 14';
$templates['hero-14']['category'] = 'hero';
$templates['hero-14']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1633377752259{padding-top: 15% !important;padding-bottom: 15% !important;background-color: #0061ff !important;}"][vc_column][vcex_heading text="Complete Package" align="center" tag="h2" font_size="d:40px|pl:35px" font_weight="900" text_align="center" font_family="Inter" color="#ffffff" line_height="1.2" width="700px"][vcex_spacing size="20px"][vc_column_text width="600px" align="center" text_align="center" font_size="16px" color="#ffffff"]The best platform for collective reviews, user-generated content and site metrics designed to increase site conversions.[/vc_column_text][vcex_spacing size="40px"][vcex_flex_container align_items="strech" justify_content="center" flex_wrap="true" flex_direction="row" gap="15px"][vcex_button bottom_margin="15px" custom_background="#ffffff" font_weight="semibold" font_size="14px" border_radius="4px" font_padding="top:12px|right:40px|bottom:12px|left:40px" custom_hover_color="accent" custom_color="#000000"]View Features[/vcex_button][vcex_button onclick="lightbox" url="https://www.youtube.com/watch?v=UKI93s1yVDo" bottom_margin="15px" icon_type="fontawesome" font_weight="semibold" font_size="14px" border_radius="4px" font_padding="top:12px|right:40px|bottom:12px|left:40px" icon_left_fontawesome="fas fa-play" style="minimal-border" custom_hover_background="rgba(255,255,255,0.1)" color="white" custom_hover_color="#ffffff"]Promo Video[/vcex_button][/vcex_flex_container][vcex_spacing size="10px"][vc_column_text text_align="center" color="rgba(255,255,255,0.7)" font_size="11px"]Create websites faster and smarter with the Total framework.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

$templates['hero-15'] = array();
$templates['hero-15']['name'] = esc_html__( 'Hero', 'total' ) . ' 15';
$templates['hero-15']['category'] = 'hero';
$templates['hero-15']['content'] = <<<CONTENT
[vc_row content_placement="middle" equal_height="yes" css=".vc_custom_1633380719894{margin-top: 50px !important;}"][vc_column width="1/2"][vcex_heading text="Build Complex Layouts Easier &amp; Faster" font_weight="bolder" font_size="36px" tag="h2"][vcex_spacing size="20px"][vc_column_text color="#222222" font_size="14px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros.[/vc_column_text][vcex_spacing size="35px"][vcex_button font_size="12px" font_weight="bold" font_padding="top:15px|right:30px|bottom:15px|left:30px" custom_background="#0145ff" custom_hover_background="#235eff"]Learn more[/vcex_button][vcex_spacing][/vc_column][vc_column width="1/2"][vcex_image source="external" external_image="{ph_square}"][/vc_column][/vc_row]
CONTENT;

$templates['hero-16'] = array();
$templates['hero-16']['name'] = esc_html__( 'Hero', 'total' ) . ' 16';
$templates['hero-16']['category'] = 'hero';
$templates['hero-16']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" column_spacing="60" css=".vc_custom_1633379210231{padding-top: 60px !important;padding-bottom: 20px !important;background-color: #e8edec !important;}"][vc_column width="1/2"][vcex_animated_text strings="%5B%7B%22text%22%3A%22Website%22%7D%2C%7B%22text%22%3A%22Startup%22%7D%2C%7B%22text%22%3A%22Company%22%7D%5D" type_cursor="true" back_delay="1000" animated_font_weight="500" static_text="true" static_before="A better framework for your" font_size="d:48px|pl:42px|pp:36px" font_weight="300" speed="40" back_speed="40" start_delay="1000" tag="h2"][vcex_spacing size="40px"][vc_column_text color="rgba(30,21,23,0.9)" font_size="18px" el_class="wpex-antialiased"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec egestas hendrerit felis quis convallis. Sed erat ex, finibus non tellus in molestie.[/vc_column_text][vcex_spacing size="40px"][vcex_button icon_type="fontawesome" color="white" border_radius="9999px" border="0px" font_padding="top:20px|right:40px|bottom:20px|left:40px" font_weight="normal" font_size="16px" custom_background="#18473d" custom_color="#ffffff" icon_right_padding="20px" icon_right_fontawesome="fas fa-arrow-right" icon_right_transform="5px" custom_hover_background="#216053"]Get Started[/vcex_button][/vc_column][vc_column width="1/2"][vcex_grid_container columns="2" columns_lg=""][vcex_image source="external" external_image="{$ph_square}"][vcex_image source="external" external_image="{$ph_square}"][vcex_image source="external" external_image="{$ph_square}"][vcex_image source="external" external_image="{$ph_square}"][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['hero-17'] = array();
$templates['hero-17']['name'] = esc_html__( 'Hero', 'total' ) . ' 17';
$templates['hero-17']['category'] = 'hero';
$templates['hero-17']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" column_spacing="60" css=".vc_custom_1633389855754{padding-top: 80px !important;padding-bottom: 20px !important;background-color: #e4e9f5 !important;}"][vc_column width="1/2"][vcex_heading text="Take your business growth up to a new level" font_weight="semibold" font_size="3em" font_family="Inter" color="#111827" tag="h2"][vcex_spacing][vc_column_text color="#6b7280" font_weight="500" font_size="14px" el_class="wpex-antialiased"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros.[/vc_column_text][vcex_spacing size="40px"][vcex_flex_container flex_wrap="true" flex_direction="row" gap="15px"][vcex_button font_size=".9em" font_weight="semibold" border_radius="4px" custom_background="#05b4ff" custom_color="#ffffff" custom_hover_background="#009ee2" text_transform="uppercase" letter_spacing="1px" font_padding="top:15px|right:25px|bottom:15px|left:25px"]Get Started[/vcex_button][vcex_button font_size=".9em" font_weight="semibold" border_radius="4px" custom_background="#ffffff" custom_color="#000000" text_transform="uppercase" letter_spacing="1px" font_padding="top:15px|right:25px|bottom:15px|left:25px" custom_hover_color="#009ee2"]Learn More[/vcex_button][/vcex_flex_container][vcex_divider color="#cfd4e0" margin="top:60px|bottom:40px"][vc_column_text color="#111827"]If you have any questions you can always <a href="#">contact</a> our support team which are available 24/7 and will reply asap.[/vc_column_text][/vc_column][vc_column width="1/2"][vcex_image source="external" external_image="{ph_square}"][/vc_column][/vc_row]
CONTENT;

$templates['hero-18'] = array();
$templates['hero-18']['name'] = esc_html__( 'Hero', 'total' ) . ' 18';
$templates['hero-18']['category'] = 'hero';
$templates['hero-18']['content'] = <<<CONTENT
[vc_row content_placement="middle" equal_height="yes" css=".vc_custom_1633380719894{margin-top: 50px !important;}"][vc_column width="1/2"][vcex_list_item bottom_margin="10px" icon="ticon ticon-circle" color="#b40309" font_weight="500" font_color="#777777"]Donations Save Lives[/vcex_list_item][vcex_heading text="Giving help to those who need it." font_weight="bold" font_size="45px" font_family="Noto Serif" color="#333333" tag="h2"][vcex_spacing size="20px"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros.[/vc_column_text][vcex_spacing size="40px"][vcex_button font_size="11px" font_weight="semibold" font_padding="top:15px|right:30px|bottom:15px|left:30px" custom_background="#b40309" custom_hover_background="#a30308" border_radius="9999px" text_transform="uppercase" letter_spacing="1px"]Make a donation[/vcex_button][vcex_spacing][/vc_column][vc_column width="1/2"][vcex_image source="external" align="center" overlay_style="" external_image="{$ph_square}" border_radius="9999px" width="400"][/vc_column][/vc_row]
CONTENT;

$templates['hero-19'] = array();
$templates['hero-19']['name'] = esc_html__( 'Hero', 'total' ) . ' 19';
$templates['hero-19']['category'] = 'hero';
$templates['hero-19']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" column_spacing="60" remove_bottom_col_margin="true" css=".vc_custom_1633737138529{padding-top: 80px !important;background-color: #1a40ca !important;}"][vc_column width="1/2"][vcex_heading text="Ready to grow your business &amp; find success?" font_weight="bold" font_size="35px" font_family="Inter" color="#ffffff" tag="h2"][vcex_spacing size="15px"][vc_column_text color="rgba(255,255,255,0.81)" font_weight="500" el_class="wpex-antialiased"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros.[/vc_column_text][vcex_spacing size="45px"][vcex_flex_container flex_wrap="true" flex_direction="row" gap="15px"][vcex_button font_weight="500" border_radius="8px" text_transform="uppercase" letter_spacing="1px" font_padding="top:15px|right:35px|bottom:15px|left:35px" font_size=".8em" custom_background="#12c9e9" custom_color="#ffffff" custom_hover_background="#2ed2ef"]Get Your Quote[/vcex_button][vcex_button font_weight="500" border_radius="8px" text_transform="uppercase" letter_spacing="1px" font_padding="top:15px|right:35px|bottom:15px|left:35px" style="minimal-border" color="white" font_size=".8em"]Learn More[/vcex_button][/vcex_flex_container][vcex_spacing][vcex_bullets icon_type="ticons" icon="ticon ticon-check-circle" gap="40px" alignment="horizontal" icon_color="#12c9e9" color="#ffffff"]<ul><li>1 month Free Trial</li><li>24/7 Customer support</li></ul>[/vcex_bullets][vcex_spacing size="40px"][/vc_column][vc_column width="1/2"][vcex_image source="external" align="center" shadow="shadow" external_image="{$ph_square}" css=".vc_custom_1633736790702{margin-bottom: -40px !important;}" border_radius="20px"][/vc_column][/vc_row]
CONTENT;

$templates['hero-20'] = array();
$templates['hero-20']['name'] = esc_html__( 'Hero', 'total' ) . ' 20';
$templates['hero-20']['category'] = 'hero';
$templates['hero-20']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1633737351256{padding-top: 18% !important;padding-bottom: 18% !important;background-color: #e6f4f2 !important;}"][vc_column][vcex_spacing size="10px"][vcex_heading text="Professional Spa Treatments for Your Hair and Nails" align="center" tag="h2" text_align="center" font_weight="semibold" font_size="d:45px|pl:30px" line_height="1.2" width="800px" font_family="Montserrat" color="#0d1712"][vcex_spacing size="40px"][vcex_flex_container justify_content="center" flex_wrap="true" flex_direction="row" gap="15px"][vcex_button custom_background="#538c70" font_weight="semibold" font_padding="top:15px|right:35px|bottom:15px|left:35px" font_size="1em" custom_hover_background="#60a181" border_radius="4px"]View Collection[/vcex_button][vcex_button download_attribute="true" font_weight="semibold" font_padding="top:15px|right:35px|bottom:15px|left:35px" font_size="1em" style="minimal-border" border="1px solid #538c70" border_radius="4px" custom_hover_background="rgba(83,140,112,0.1)" custom_color="#538c70"]Download Brochure[/vcex_button][/vcex_flex_container][/vc_column][/vc_row]
CONTENT;

$templates['hero-21'] = array();
$templates['hero-21']['name'] = esc_html__( 'Hero', 'total' ) . ' 21';
$templates['hero-21']['category'] = 'hero';
$templates['hero-21']['content'] = <<<CONTENT
[vc_row content_placement="middle" equal_height="yes" css=".vc_custom_1633380719894{margin-top: 50px !important;}"][vc_column width="1/2"][vcex_heading text="#E-8_TG9jYWwlMjBQbHVtYmluZyUyMCUyNiUyMEFpciUyMENvbmRpdGlvbmluZyUyMCU1QnNwYW4lMjBjbGFzcyUzRCUyMndwZXgtdGV4dC1hY2NlbnQlMjIlNURTZXJ2aWNlcyU1QiUyRnNwYW4lNUQ=" font_weight="bold" font_size="42px" tag="h2" color="#546181"][vcex_spacing size="25px"][vc_column_text color="#3f4a67" font_size="16px"]Highly rated and trusted plumbing and AC repair services with fast turn arounds and professional care.[/vc_column_text][vcex_spacing size="40px"][vcex_button icon_type="fontawesome" font_size="16px" font_weight="normal" font_padding="top:15px|right:30px|bottom:15px|left:30px" custom_background="#3859f1" custom_hover_background="#4866f2" icon_right_fontawesome="fas fa-angle-double-right"]Request a Quote[/vcex_button][vcex_spacing size="35px"][vcex_list_item bottom_margin="15px" flex_align="center" icon_type="fontawesome" icon_fontawesome="far fa-check-circle" font_size="15px" font_color="#3f4a67" color="#8599cd" icon_size="1.2em"]5 star Yelp rating[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon_type="fontawesome" icon_fontawesome="far fa-check-circle" font_size="15px" font_color="#3f4a67" color="#8599cd" icon_size="1.2em"]24hr weekday availability[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon_type="fontawesome" icon_fontawesome="far fa-check-circle" font_size="15px" font_color="#3f4a67" color="#8599cd" icon_size="1.2em"]100% satisfaction guarantee[/vcex_list_item][/vc_column][vc_column width="1/2"][vcex_image source="external" external_image="{ph_square}"][/vc_column][/vc_row]
CONTENT;
// IMPORTANT - Space required to prevent HEREDOC errors.
?>