<?php
/**
 * Togglebar dismiss button.
 *
 * @package Total WordPress theme
 * @subpackage Partials
 * @version 5.4.5
 */

?>

<div class="toggle-bar-dismiss wpex-absolute wpex-z-5 wpex-top-50 wpex-right-0 wpex-mr-5 wpex-md-mr-30 -wpex-translate-y-50"><button role="button" class="toggle-bar-dismiss__button wpex-flex wpex-items-center" aria-controls="toggle-bar-wrap" aria-label="<?php esc_html_e( 'Close', 'total' ); ?>"><?php wpex_svg( 'material/close', 24 ); ?></button></div>