<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Media
$html .= $this->get_media( array(
	'class' => 'wpex-mb-10',
) );

// Title
$html .= $this->get_title( array(
	'class' => 'wpex-heading wpex-text-lg wpex-mb-5',
) );

// Author
$html .= $this->get_author( array(
	'class' => 'wpex-text-3 wpex-child-inherit-color',
	'link_class' => 'wpex-no-underline',
	'prefix' => esc_html( 'By', 'total' ) . ' ',
) );

return $html;