<?php
namespace TotalTheme\Filters;

defined( 'ABSPATH' ) || exit;

/**
 * Hooks into "redirect_canonical".
 *
 * @package TotalTheme
 * @subpackage Filters
 * @version 5.4
 */
final class Redirect_Canonical {

	/**
	 * Callback method.
	 */
	public static function callback( $redirect_url ) {
		if ( is_singular() && is_paged() ) {
			$redirect_url = false; // fix for pagination not working on singular posts.
		}

		return $redirect_url;
	}

}