<?php
use TotalTheme\Header\Core as Header;

/**
 * Site header
 *
 * @package TotalTheme
 * @subpackage Partials
 * @version 5.4.3
 */

defined( 'ABSPATH' ) || exit;

?>

<?php wpex_hook_header_before(); ?>

<?php if ( ! wpex_theme_do_location( 'header' ) ) : ?>

	<header id="site-header" <?php Header::wrapper_class(); ?><?php wpex_schema_markup( 'header' ); ?><?php wpex_aria_landmark( 'header' ); ?>>

		<?php wpex_hook_header_top(); ?>

		<div id="site-header-inner" <?php Header::inner_class(); ?>><?php

			wpex_hook_header_inner();

		?></div>

		<?php wpex_hook_header_bottom(); ?>

	</header>

<?php endif; ?>

<?php wpex_hook_header_after(); ?>