.wpex-term-settings-postbox{margin-top:30px}.wpex-term-settings-postbox h2{font-size:14px;padding:8px 12px;margin:0;line-height:1.4}.wpex-term-settings-postbox .form-table th{padding:8px 30px 8px 0}.wpex-term-settings-postbox .form-table td{padding:8px 0}.wpex-term-settings-postbox .form-table tr:not(:first-child){border-top:1px solid #eee}.wpex-term-settings-postbox .inside{margin-top:0;margin-bottom:0;padding-top:4px;padding-bottom:4px}.wpex-term-settings-postbox .form-table{padding:0;margin:0}.wpex-term-settings-postbox select{min-width:50%}
