<?php
namespace TotalThemeCore\WPBakery\Iconpicker;

defined( 'ABSPATH' ) || exit;

final class Ticons {

	public static function get_icons( $icons ) {
		$ticons = array(
			array( 'ticon ticon-handshake-o' => 'Handshake Outlined' ),
			array( 'ticon ticon-envelope-open' => 'Envelope Open(email, e-mail, letter, support, mail, message, notification)' ),
			array( 'ticon ticon-envelope-open-o' => 'Envelope Open Outlined(email, e-mail, letter, support, mail, message, notification)' ),
			array( 'ticon ticon-linode' => 'Linode' ),
			array( 'ticon ticon-address-book' => 'Address Book' ),
			array( 'ticon ticon-address-book-o' => 'Address Book Outlined' ),
			array( 'ticon ticon-address-card' => 'Address Card(vcard)' ),
			array( 'ticon ticon-address-card-o' => 'Address Card Outlined(vcard-o)' ),
			array( 'ticon ticon-user-circle' => 'User Circle' ),
			array( 'ticon ticon-user-circle-o' => 'User Circle Outlined' ),
			array( 'ticon ticon-user-o' => 'User Outlined' ),
			array( 'ticon ticon-id-badge' => 'Identification Badge' ),
			array( 'ticon ticon-id-card' => 'Identification Card(drivers-license)' ),
			array( 'ticon ticon-id-card-o' => 'Identification Card Outlined(drivers-license-o)' ),
			array( 'ticon ticon-quora' => 'Quora' ),
			array( 'ticon ticon-free-code-camp' => 'Free Code Camp' ),
			array( 'ticon ticon-telegram' => 'Telegram' ),
			array( 'ticon ticon-thermometer-full' => 'Thermometer Full(thermometer-4, thermometer)' ),
			array( 'ticon ticon-thermometer-three-quarters' => 'Thermometer 3/4 Full(thermometer-3)' ),
			array( 'ticon ticon-thermometer-half' => 'Thermometer 1/2 Full(thermometer-2)' ),
			array( 'ticon ticon-thermometer-quarter' => 'Thermometer 1/4 Full(thermometer-1)' ),
			array( 'ticon ticon-thermometer-empty' => 'Thermometer Empty(thermometer-0)' ),
			array( 'ticon ticon-shower' => 'Shower' ),
			array( 'ticon ticon-bath' => 'Bath(bathtub, s15)' ),
			array( 'ticon ticon-podcast' => 'Podcast' ),
			array( 'ticon ticon-window-maximize' => 'Window Maximize' ),
			array( 'ticon ticon-window-minimize' => 'Window Minimize' ),
			array( 'ticon ticon-window-restore' => 'Window Restore' ),
			array( 'ticon ticon-window-close' => 'Window Close(times-rectangle)' ),
			array( 'ticon ticon-window-close-o' => 'Window Close Outline(times-rectangle-o)' ),
			array( 'ticon ticon-bandcamp' => 'Bandcamp' ),
			array( 'ticon ticon-grav' => 'Grav' ),
			array( 'ticon ticon-etsy' => 'Etsy' ),
			array( 'ticon ticon-imdb' => 'IMDB' ),
			array( 'ticon ticon-ravelry' => 'Ravelry' ),
			array( 'ticon ticon-eercast' => 'Eercast' ),
			array( 'ticon ticon-microchip' => 'Microchip' ),
			array( 'ticon ticon-snowflake-o' => 'Snowflake Outlined' ),
			array( 'ticon ticon-superpowers' => 'Superpowers' ),
			array( 'ticon ticon-wpexplorer' => 'WPExplorer' ),
			array( 'ticon ticon-meetup' => 'Meetup' ),
			array( 'ticon ticon-glass' => 'Glass(martini, drink, bar, alcohol, liquor)' ),
			array( 'ticon ticon-music' => 'Music(note, sound)' ),
			array( 'ticon ticon-search' => 'Search(magnify, zoom, enlarge, bigger)' ),
			array( 'ticon ticon-envelope-o' => 'Envelope Outlined(email, e-mail, letter, support, mail, message, notification)' ),
			array( 'ticon ticon-heart' => 'Heart(love, like, favorite)' ),
			array( 'ticon ticon-star' => 'Star(award, achievement, night, rating, score, favorite)' ),
			array( 'ticon ticon-star-o' => 'Star Outlined(award, achievement, night, rating, score, favorite)' ),
			array( 'ticon ticon-user' => 'User(person, man, head, profile)' ),
			array( 'ticon ticon-film' => 'Film(movie)' ),
			array( 'ticon ticon-check' => 'Check(checkmark, done, todo, agree, accept, confirm, tick, ok)' ),
			array( 'ticon ticon-times' => 'Times(close, exit, x, cross)(remove, close)' ),
			array( 'ticon ticon-search-plus' => 'Search Plus(magnify, zoom, enlarge, bigger)' ),
			array( 'ticon ticon-search-minus' => 'Search Minus(magnify, minify, zoom, smaller)' ),
			array( 'ticon ticon-power-off' => 'Power Off(on)' ),
			array( 'ticon ticon-signal' => 'signal(graph, bars)' ),
			array( 'ticon ticon-cog' => 'cog(settings)(gear)' ),
			array( 'ticon ticon-trash-o' => 'Trash Outlined(garbage, delete, remove, trash, hide)' ),
			array( 'ticon ticon-home' => 'home(main, house)' ),
			array( 'ticon ticon-clock-o' => 'Clock Outlined(watch, timer, late, timestamp)' ),
			array( 'ticon ticon-road' => 'road(street)' ),
			array( 'ticon ticon-download' => 'Download(import)' ),
			array( 'ticon ticon-inbox' => 'inbox' ),
			array( 'ticon ticon-refresh' => 'refresh(reload, sync)' ),
			array( 'ticon ticon-lock' => 'lock(protect, admin, security)' ),
			array( 'ticon ticon-flag' => 'flag(report, notification, notify)' ),
			array( 'ticon ticon-headphones' => 'headphones(sound, listen, music, audio)' ),
			array( 'ticon ticon-volume-off' => 'volume-off(audio, mute, sound, music)' ),
			array( 'ticon ticon-volume-down' => 'volume-down(audio, lower, quieter, sound, music)' ),
			array( 'ticon ticon-volume-up' => 'volume-up(audio, higher, louder, sound, music)' ),
			array( 'ticon ticon-qrcode' => 'qrcode(scan)' ),
			array( 'ticon ticon-barcode' => 'barcode(scan)' ),
			array( 'ticon ticon-tag' => 'tag(label)' ),
			array( 'ticon ticon-tags' => 'tags(labels)' ),
			array( 'ticon ticon-book' => 'book(read, documentation)' ),
			array( 'ticon ticon-bookmark' => 'bookmark(save)' ),
			array( 'ticon ticon-print' => 'print' ),
			array( 'ticon ticon-camera' => 'camera(photo, picture, record)' ),
			array( 'ticon ticon-video-camera' => 'Video Camera(film, movie, record)' ),
			array( 'ticon ticon-picture-o' => 'Picture Outlined(photo, image)' ),
			array( 'ticon ticon-pencil' => 'pencil(write, edit, update)' ),
			array( 'ticon ticon-map-marker' => 'map-marker(map, pin, location, coordinates, localize, address, travel, where, place)' ),
			array( 'ticon ticon-adjust' => 'adjust(contrast)' ),
			array( 'ticon ticon-tint' => 'tint(raindrop, waterdrop, drop, droplet)' ),
			array( 'ticon ticon-pencil-square-o' => 'Pencil Square Outlined(write, edit, update)(edit)' ),
			array( 'ticon ticon-share-square-o' => 'Share Square Outlined(social, send, arrow)' ),
			array( 'ticon ticon-check-square-o' => 'Check Square Outlined(todo, done, agree, accept, confirm, ok)' ),
			array( 'ticon ticon-arrows' => 'Arrows(move, reorder, resize)' ),
			array( 'ticon ticon-plus-circle' => 'Plus Circle(add, new, create, expand)' ),
			array( 'ticon ticon-minus-circle' => 'Minus Circle(delete, remove, trash, hide)' ),
			array( 'ticon ticon-times-circle' => 'Times Circle(close, exit, x)' ),
			array( 'ticon ticon-check-circle' => 'Check Circle(todo, done, agree, accept, confirm, ok)' ),
			array( 'ticon ticon-question-circle' => 'Question Circle(help, information, unknown, support)' ),
			array( 'ticon ticon-info-circle' => 'Info Circle(help, information, more, details)' ),
			array( 'ticon ticon-crosshairs' => 'Crosshairs(picker)' ),
			array( 'ticon ticon-times-circle-o' => 'Times Circle Outlined(close, exit, x)' ),
			array( 'ticon ticon-check-circle-o' => 'Check Circle Outlined(todo, done, agree, accept, confirm, ok)' ),
			array( 'ticon ticon-ban' => 'ban(delete, remove, trash, hide, block, stop, abort, cancel)' ),
			array( 'ticon ticon-share' => 'Share(mail-forward)' ),
			array( 'ticon ticon-plus' => 'plus(add, new, create, expand)' ),
			array( 'ticon ticon-minus' => 'minus(hide, minify, delete, remove, trash, hide, collapse)' ),
			array( 'ticon ticon-asterisk' => 'asterisk(details)' ),
			array( 'ticon ticon-exclamation-circle' => 'Exclamation Circle(warning, error, problem, notification, alert)' ),
			array( 'ticon ticon-gift' => 'gift(present)' ),
			array( 'ticon ticon-leaf' => 'leaf(eco, nature, plant)' ),
			array( 'ticon ticon-fire' => 'fire(flame, hot, popular)' ),
			array( 'ticon ticon-eye' => 'Eye(show, visible, views)' ),
			array( 'ticon ticon-eye-slash' => 'Eye Slash(toggle, show, hide, visible, visiblity, views)' ),
			array( 'ticon ticon-exclamation-triangle' => 'Exclamation Triangle(warning, error, problem, notification, alert)(warning)' ),
			array( 'ticon ticon-plane' => 'plane(travel, trip, location, destination, airplane, fly, mode)' ),
			array( 'ticon ticon-calendar' => 'calendar(date, time, when, event)' ),
			array( 'ticon ticon-random' => 'random(sort, shuffle)' ),
			array( 'ticon ticon-comment' => 'comment(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
			array( 'ticon ticon-magnet' => 'magnet' ),
			array( 'ticon ticon-retweet' => 'retweet(refresh, reload, share)' ),
			array( 'ticon ticon-shopping-cart' => 'shopping-cart(checkout, buy, purchase, payment)' ),
			array( 'ticon ticon-folder' => 'Folder' ),
			array( 'ticon ticon-folder-open' => 'Folder Open' ),
			array( 'ticon ticon-arrows-v' => 'Arrows Vertical(resize)' ),
			array( 'ticon ticon-arrows-h' => 'Arrows Horizontal(resize)' ),
			array( 'ticon ticon-bar-chart' => 'Bar Chart(graph, analytics, statistics)(bar-chart-o)' ),
			array( 'ticon ticon-camera-retro' => 'camera-retro(photo, picture, record)' ),
			array( 'ticon ticon-key' => 'key(unlock, password)' ),
			array( 'ticon ticon-cogs' => 'cogs(settings)(gears)' ),
			array( 'ticon ticon-comments' => 'comments(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
			array( 'ticon ticon-thumbs-o-up' => 'Thumbs Up Outlined(like, approve, favorite, agree, hand)' ),
			array( 'ticon ticon-thumbs-o-down' => 'Thumbs Down Outlined(dislike, disapprove, disagree, hand)' ),
			array( 'ticon ticon-star-half' => 'star-half(award, achievement, rating, score)' ),
			array( 'ticon ticon-heart-o' => 'Heart Outlined(love, like, favorite)' ),
			array( 'ticon ticon-sign-out' => 'Sign Out(log out, logout, leave, exit, arrow)' ),
			array( 'ticon ticon-thumb-tack' => 'Thumb Tack(marker, pin, location, coordinates)' ),
			array( 'ticon ticon-external-link' => 'External Link(open, new)' ),
			array( 'ticon ticon-sign-in' => 'Sign In(enter, join, log in, login, sign up, sign in, signin, signup, arrow)' ),
			array( 'ticon ticon-trophy' => 'trophy(award, achievement, cup, winner, game)' ),
			array( 'ticon ticon-upload' => 'Upload(import)' ),
			array( 'ticon ticon-lemon-o' => 'Lemon Outlined(food)' ),
			array( 'ticon ticon-phone' => 'Phone(call, voice, number, support, earphone, telephone)' ),
			array( 'ticon ticon-square-o' => 'Square Outlined(block, square, box)' ),
			array( 'ticon ticon-bookmark-o' => 'Bookmark Outlined(save)' ),
			array( 'ticon ticon-phone-square' => 'Phone Square(call, voice, number, support, telephone)' ),
			array( 'ticon ticon-unlock' => 'unlock(protect, admin, password, lock)' ),
			array( 'ticon ticon-credit-card' => 'credit-card(money, buy, debit, checkout, purchase, payment)' ),
			array( 'ticon ticon-rss' => 'rss(blog)(feed)' ),
			array( 'ticon ticon-hdd-o' => 'HDD(harddrive, hard drive, storage, save)' ),
			array( 'ticon ticon-bullhorn' => 'bullhorn(announcement, share, broadcast, louder, megaphone)' ),
			array( 'ticon ticon-bell' => 'bell(alert, reminder, notification)' ),
			array( 'ticon ticon-certificate' => 'certificate(badge, star)' ),
			array( 'ticon ticon-globe' => 'Globe(world, planet, map, place, travel, earth, global, translate, all, language, localize, location, coordinates, country)' ),
			array( 'ticon ticon-wrench' => 'Wrench(settings, fix, update, spanner)' ),
			array( 'ticon ticon-tasks' => 'Tasks(progress, loading, downloading, downloads, settings)' ),
			array( 'ticon ticon-filter' => 'Filter(funnel, options)' ),
			array( 'ticon ticon-briefcase' => 'Briefcase(work, business, office, luggage, bag)' ),
			array( 'ticon ticon-users' => 'Users(people, profiles, persons)(group)' ),
			array( 'ticon ticon-cloud' => 'Cloud(save)' ),
			array( 'ticon ticon-flask' => 'Flask(science, beaker, experimental, labs)' ),
			array( 'ticon ticon-square' => 'Square(block, box)' ),
			array( 'ticon ticon-bars' => 'Bars(menu, drag, reorder, settings, list, ul, ol, checklist, todo, list, hamburger)(navicon, reorder)' ),
			array( 'ticon ticon-magic' => 'magic(wizard, automatic, autocomplete)' ),
			array( 'ticon ticon-truck' => 'truck(shipping)' ),
			array( 'ticon ticon-money' => 'Money(cash, money, buy, checkout, purchase, payment)' ),
			array( 'ticon ticon-sort' => 'Sort(order)(unsorted)' ),
			array( 'ticon ticon-sort-desc' => 'Sort Descending(dropdown, more, menu, arrow)(sort-down)' ),
			array( 'ticon ticon-sort-asc' => 'Sort Ascending(arrow)(sort-up)' ),
			array( 'ticon ticon-envelope' => 'Envelope(email, e-mail, letter, support, mail, message, notification)' ),
			array( 'ticon ticon-gavel' => 'Gavel(judge, lawyer, opinion)(legal)' ),
			array( 'ticon ticon-tachometer' => 'Tachometer(speedometer, fast)(dashboard)' ),
			array( 'ticon ticon-comment-o' => 'comment-o(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
			array( 'ticon ticon-comments-o' => 'comments-o(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
			array( 'ticon ticon-bolt' => 'Lightning Bolt(lightning, weather)(flash)' ),
			array( 'ticon ticon-sitemap' => 'Sitemap(directory, hierarchy, organization)' ),
			array( 'ticon ticon-umbrella' => 'Umbrella' ),
			array( 'ticon ticon-lightbulb-o' => 'Lightbulb Outlined(idea, inspiration)' ),
			array( 'ticon ticon-exchange' => 'Exchange(transfer, arrows, arrow)' ),
			array( 'ticon ticon-cloud-download' => 'Cloud Download(import)' ),
			array( 'ticon ticon-cloud-upload' => 'Cloud Upload(import)' ),
			array( 'ticon ticon-suitcase' => 'Suitcase(trip, luggage, travel, move, baggage)' ),
			array( 'ticon ticon-bell-o' => 'Bell Outlined(alert, reminder, notification)' ),
			array( 'ticon ticon-coffee' => 'Coffee(morning, mug, breakfast, tea, drink, cafe)' ),
			array( 'ticon ticon-cutlery' => 'Cutlery(food, restaurant, spoon, knife, dinner, eat)' ),
			array( 'ticon ticon-building-o' => 'Building Outlined(work, business, apartment, office, company)' ),
			array( 'ticon ticon-fighter-jet' => 'fighter-jet(fly, plane, airplane, quick, fast, travel)' ),
			array( 'ticon ticon-beer' => 'beer(alcohol, stein, drink, mug, bar, liquor)' ),
			array( 'ticon ticon-plus-square' => 'Plus Square(add, new, create, expand)' ),
			array( 'ticon ticon-desktop' => 'Desktop(monitor, screen, desktop, computer, demo, device)' ),
			array( 'ticon ticon-laptop' => 'Laptop(demo, computer, device)' ),
			array( 'ticon ticon-tablet' => 'tablet(ipad, device)' ),
			array( 'ticon ticon-mobile' => 'Mobile Phone(cell phone, cellphone, text, call, iphone, number, telephone)(mobile-phone)' ),
			array( 'ticon ticon-circle-o' => 'Circle Outlined' ),
			array( 'ticon ticon-quote-left' => 'quote-left' ),
			array( 'ticon ticon-quote-right' => 'quote-right' ),
			array( 'ticon ticon-spinner' => 'Spinner(loading, progress)' ),
			array( 'ticon ticon-circle' => 'Circle(dot, notification)' ),
			array( 'ticon ticon-reply' => 'Reply(mail-reply)' ),
			array( 'ticon ticon-folder-o' => 'Folder Outlined' ),
			array( 'ticon ticon-folder-open-o' => 'Folder Open Outlined' ),
			array( 'ticon ticon-smile-o' => 'Smile Outlined(face, emoticon, happy, approve, satisfied, rating)' ),
			array( 'ticon ticon-frown-o' => 'Frown Outlined(face, emoticon, sad, disapprove, rating)' ),
			array( 'ticon ticon-meh-o' => 'Meh Outlined(face, emoticon, rating, neutral)' ),
			array( 'ticon ticon-gamepad' => 'Gamepad(controller)' ),
			array( 'ticon ticon-keyboard-o' => 'Keyboard Outlined(type, input)' ),
			array( 'ticon ticon-flag-o' => 'Flag Outlined(report, notification)' ),
			array( 'ticon ticon-flag-checkered' => 'flag-checkered(report, notification, notify)' ),
			array( 'ticon ticon-terminal' => 'Terminal(command, prompt, code)' ),
			array( 'ticon ticon-code' => 'Code(html, brackets)' ),
			array( 'ticon ticon-reply-all' => 'reply-all(mail-reply-all)' ),
			array( 'ticon ticon-star-half-o' => 'Star Half Outlined(award, achievement, rating, score)(star-half-empty, star-half-full)' ),
			array( 'ticon ticon-location-arrow' => 'location-arrow(map, coordinates, location, address, place, where)' ),
			array( 'ticon ticon-crop' => 'crop' ),
			array( 'ticon ticon-code-fork' => 'code-fork(git, fork, vcs, svn, github, rebase, version, merge)' ),
			array( 'ticon ticon-question' => 'Question(help, information, unknown, support)' ),
			array( 'ticon ticon-info' => 'Info(help, information, more, details)' ),
			array( 'ticon ticon-exclamation' => 'exclamation(warning, error, problem, notification, notify, alert)' ),
			array( 'ticon ticon-eraser' => 'eraser(remove, delete)' ),
			array( 'ticon ticon-puzzle-piece' => 'Puzzle Piece(addon, add-on, section)' ),
			array( 'ticon ticon-microphone' => 'microphone(record, voice, sound)' ),
			array( 'ticon ticon-microphone-slash' => 'Microphone Slash(record, voice, sound, mute)' ),
			array( 'ticon ticon-shield' => 'shield(award, achievement, security, winner)' ),
			array( 'ticon ticon-calendar-o' => 'calendar-o(date, time, when, event)' ),
			array( 'ticon ticon-fire-extinguisher' => 'fire-extinguisher' ),
			array( 'ticon ticon-rocket' => 'rocket(app)' ),
			array( 'ticon ticon-anchor' => 'Anchor(link)' ),
			array( 'ticon ticon-unlock-alt' => 'Unlock Alt(protect, admin, password, lock)' ),
			array( 'ticon ticon-bullseye' => 'Bullseye(target)' ),
			array( 'ticon ticon-ellipsis-h' => 'Ellipsis Horizontal(dots)' ),
			array( 'ticon ticon-ellipsis-v' => 'Ellipsis Vertical(dots)' ),
			array( 'ticon ticon-rss-square' => 'RSS Square(feed, blog)' ),
			array( 'ticon ticon-ticket' => 'Ticket(movie, pass, support)' ),
			array( 'ticon ticon-minus-square' => 'Minus Square(hide, minify, delete, remove, trash, hide, collapse)' ),
			array( 'ticon ticon-minus-square-o' => 'Minus Square Outlined(hide, minify, delete, remove, trash, hide, collapse)' ),
			array( 'ticon ticon-level-up' => 'Level Up(arrow)' ),
			array( 'ticon ticon-level-down' => 'Level Down(arrow)' ),
			array( 'ticon ticon-check-square' => 'Check Square(checkmark, done, todo, agree, accept, confirm, ok)' ),
			array( 'ticon ticon-pencil-square' => 'Pencil Square(write, edit, update)' ),
			array( 'ticon ticon-external-link-square' => 'External Link Square(open, new)' ),
			array( 'ticon ticon-share-square' => 'Share Square(social, send)' ),
			array( 'ticon ticon-compass' => 'Compass(safari, directory, menu, location)' ),
			array( 'ticon ticon-caret-square-o-down' => 'Caret Square Outlined Down(more, dropdown, menu)(toggle-down)' ),
			array( 'ticon ticon-caret-square-o-up' => 'Caret Square Outlined Up(toggle-up)' ),
			array( 'ticon ticon-caret-square-o-right' => 'Caret Square Outlined Right(next, forward)(toggle-right)' ),
			array( 'ticon ticon-sort-alpha-asc' => 'Sort Alpha Ascending' ),
			array( 'ticon ticon-sort-alpha-desc' => 'Sort Alpha Descending' ),
			array( 'ticon ticon-sort-amount-asc' => 'Sort Amount Ascending' ),
			array( 'ticon ticon-sort-amount-desc' => 'Sort Amount Descending' ),
			array( 'ticon ticon-sort-numeric-asc' => 'Sort Numeric Ascending(numbers)' ),
			array( 'ticon ticon-sort-numeric-desc' => 'Sort Numeric Descending(numbers)' ),
			array( 'ticon ticon-thumbs-up' => 'thumbs-up(like, favorite, approve, agree, hand)' ),
			array( 'ticon ticon-thumbs-down' => 'thumbs-down(dislike, disapprove, disagree, hand)' ),
			array( 'ticon ticon-female' => 'Female(woman, user, person, profile)' ),
			array( 'ticon ticon-male' => 'Male(man, user, person, profile)' ),
			array( 'ticon ticon-sun-o' => 'Sun Outlined(weather, contrast, lighter, brighten, day)' ),
			array( 'ticon ticon-moon-o' => 'Moon Outlined(night, darker, contrast)' ),
			array( 'ticon ticon-archive' => 'Archive(box, storage)' ),
			array( 'ticon ticon-bug' => 'Bug(report, insect)' ),
			array( 'ticon ticon-caret-square-o-left' => 'Caret Square Outlined Left(previous, back)(toggle-left)' ),
			array( 'ticon ticon-dot-circle-o' => 'Dot Circle Outlined(target, bullseye, notification)' ),
			array( 'ticon ticon-wheelchair' => 'Wheelchair(handicap, person)' ),
			array( 'ticon ticon-plus-square-o' => 'Plus Square Outlined(add, new, create, expand)' ),
			array( 'ticon ticon-space-shuttle' => 'Space Shuttle' ),
			array( 'ticon ticon-envelope-square' => 'Envelope Square(email, e-mail, letter, support, mail, message, notification)' ),
			array( 'ticon ticon-university' => 'University(institution, bank)' ),
			array( 'ticon ticon-graduation-cap' => 'Graduation Cap(learning, school, student)(mortar-board)' ),
			array( 'ticon ticon-language' => 'Language(translate)' ),
			//array( 'ticon ticon-fax' => 'Fax' ), // not in ticons
			array( 'ticon ticon-building' => 'Building(work, business, apartment, office, company)' ),
			array( 'ticon ticon-child' => 'Child' ),
			array( 'ticon ticon-paw' => 'Paw(pet)' ),
			array( 'ticon ticon-spoon' => 'spoon' ),
			array( 'ticon ticon-cube' => 'Cube' ),
			array( 'ticon ticon-cubes' => 'Cubes' ),
			array( 'ticon ticon-recycle' => 'Recycle' ),
			array( 'ticon ticon-car' => 'Car(vehicle)(automobile)' ),
			array( 'ticon ticon-taxi' => 'Taxi(vehicle)(cab)' ),
			array( 'ticon ticon-tree' => 'Tree' ),
			array( 'ticon ticon-database' => 'Database' ),
			array( 'ticon ticon-file-pdf-o' => 'PDF File Outlined' ),
			array( 'ticon ticon-file-word-o' => 'Word File Outlined' ),
			array( 'ticon ticon-file-excel-o' => 'Excel File Outlined' ),
			array( 'ticon ticon-file-powerpoint-o' => 'Powerpoint File Outlined' ),
			array( 'ticon ticon-file-image-o' => 'Image File Outlined(file-photo-o, file-picture-o)' ),
			array( 'ticon ticon-file-archive-o' => 'Archive File Outlined(file-zip-o)' ),
			array( 'ticon ticon-file-audio-o' => 'Audio File Outlined(file-sound-o)' ),
			array( 'ticon ticon-file-video-o' => 'Video File Outlined(file-movie-o)' ),
			array( 'ticon ticon-file-code-o' => 'Code File Outlined' ),
			array( 'ticon ticon-life-ring' => 'Life Ring(life-bouy, life-buoy, life-saver, support)' ),
			array( 'ticon ticon-circle-o-notch' => 'Circle Outlined Notched' ),
			array( 'ticon ticon-paper-plane' => 'Paper Plane(send)' ),
			array( 'ticon ticon-paper-plane-o' => 'Paper Plane Outlined(send-o)' ),
			array( 'ticon ticon-history' => 'History' ),
			array( 'ticon ticon-circle-thin' => 'Circle Outlined Thin' ),
			array( 'ticon ticon-sliders' => 'Sliders(settings)' ),
			array( 'ticon ticon-share-alt' => 'Share Alt' ),
			array( 'ticon ticon-share-alt-square' => 'Share Alt Square' ),
			array( 'ticon ticon-bomb' => 'Bomb' ),
			array( 'ticon ticon-futbol-o' => 'Futbol Outlined(soccer-ball-o)' ),
			array( 'ticon ticon-tty' => 'TTY' ),
			array( 'ticon ticon-binoculars' => 'Binoculars' ),
			array( 'ticon ticon-plug' => 'Plug(power, connect)' ),
			array( 'ticon ticon-newspaper-o' => 'Newspaper Outlined(press)' ),
			array( 'ticon ticon-wifi' => 'WiFi' ),
			array( 'ticon ticon-calculator' => 'Calculator' ),
			array( 'ticon ticon-bell-slash' => 'Bell Slash' ),
			array( 'ticon ticon-bell-slash-o' => 'Bell Slash Outlined' ),
			array( 'ticon ticon-trash' => 'Trash(garbage, delete, remove, hide)' ),
			array( 'ticon ticon-copyright' => 'Copyright' ),
			array( 'ticon ticon-at' => 'At(email, e-mail)' ),
			array( 'ticon ticon-eyedropper' => 'Eyedropper' ),
			array( 'ticon ticon-paint-brush' => 'Paint Brush' ),
			array( 'ticon ticon-birthday-cake' => 'Birthday Cake' ),
			array( 'ticon ticon-area-chart' => 'Area Chart(graph, analytics, statistics)' ),
			array( 'ticon ticon-pie-chart' => 'Pie Chart(graph, analytics, statistics)' ),
			array( 'ticon ticon-line-chart' => 'Line Chart(graph, analytics, statistics)' ),
			array( 'ticon ticon-toggle-off' => 'Toggle Off' ),
			array( 'ticon ticon-toggle-on' => 'Toggle On' ),
			array( 'ticon ticon-bicycle' => 'Bicycle(vehicle, bike)' ),
			array( 'ticon ticon-bus' => 'Bus(vehicle)' ),
			array( 'ticon ticon-cc' => 'Closed Captions' ),
			array( 'ticon ticon-cart-plus' => 'Add to Shopping Cart(add, shopping)' ),
			array( 'ticon ticon-cart-arrow-down' => 'Shopping Cart Arrow Down(shopping)' ),
			array( 'ticon ticon-diamond' => 'Diamond(gem, gemstone)' ),
			array( 'ticon ticon-ship' => 'Ship(boat, sea)' ),
			array( 'ticon ticon-user-secret' => 'User Secret(whisper, spy, incognito, privacy)' ),
			array( 'ticon ticon-motorcycle' => 'Motorcycle(vehicle, bike)' ),
			array( 'ticon ticon-street-view' => 'Street View(map)' ),
			array( 'ticon ticon-heartbeat' => 'Heartbeat(ekg)' ),
			array( 'ticon ticon-server' => 'Server' ),
			array( 'ticon ticon-user-plus' => 'Add User(sign up, signup)' ),
			array( 'ticon ticon-user-times' => 'Remove User' ),
			array( 'ticon ticon-bed' => 'Bed(travel)(hotel)' ),
			array( 'ticon ticon-battery-full' => 'Battery Full(power)(battery-4, battery)' ),
			array( 'ticon ticon-battery-three-quarters' => 'Battery 3/4 Full(power)(battery-3)' ),
			array( 'ticon ticon-battery-half' => 'Battery 1/2 Full(power)(battery-2)' ),
			array( 'ticon ticon-battery-quarter' => 'Battery 1/4 Full(power)(battery-1)' ),
			array( 'ticon ticon-battery-empty' => 'Battery Empty(power)(battery-0)' ),
			array( 'ticon ticon-mouse-pointer' => 'Mouse Pointer' ),
			array( 'ticon ticon-i-cursor' => 'I Beam Cursor' ),
			array( 'ticon ticon-object-group' => 'Object Group' ),
			array( 'ticon ticon-object-ungroup' => 'Object Ungroup' ),
			array( 'ticon ticon-sticky-note' => 'Sticky Note' ),
			array( 'ticon ticon-sticky-note-o' => 'Sticky Note Outlined' ),
			array( 'ticon ticon-clone' => 'Clone(copy)' ),
			array( 'ticon ticon-balance-scale' => 'Balance Scale' ),
			array( 'ticon ticon-hourglass-o' => 'Hourglass Outlined' ),
			array( 'ticon ticon-hourglass-start' => 'Hourglass Start(hourglass-1)' ),
			array( 'ticon ticon-hourglass-half' => 'Hourglass Half(hourglass-2)' ),
			array( 'ticon ticon-hourglass-end' => 'Hourglass End(hourglass-3)' ),
			array( 'ticon ticon-hourglass' => 'Hourglass' ),
			array( 'ticon ticon-hand-rock-o' => 'Rock (Hand)(hand-grab-o)' ),
			array( 'ticon ticon-hand-paper-o' => 'Paper (Hand)(stop)(hand-stop-o)' ),
			array( 'ticon ticon-hand-scissors-o' => 'Scissors (Hand)' ),
			array( 'ticon ticon-hand-lizard-o' => 'Lizard (Hand)' ),
			array( 'ticon ticon-hand-spock-o' => 'Spock (Hand)' ),
			array( 'ticon ticon-hand-pointer-o' => 'Hand Pointer' ),
			array( 'ticon ticon-hand-peace-o' => 'Hand Peace' ),
			array( 'ticon ticon-trademark' => 'Trademark' ),
			array( 'ticon ticon-registered' => 'Registered Trademark' ),
			array( 'ticon ticon-creative-commons' => 'Creative Commons' ),
			array( 'ticon ticon-television' => 'Television(display, computer, monitor)(tv)' ),
			array( 'ticon ticon-calendar-plus-o' => 'Calendar Plus Outlined' ),
			array( 'ticon ticon-calendar-minus-o' => 'Calendar Minus Outlined' ),
			array( 'ticon ticon-calendar-times-o' => 'Calendar Times Outlined' ),
			array( 'ticon ticon-calendar-check-o' => 'Calendar Check Outlined(ok)' ),
			array( 'ticon ticon-industry' => 'Industry(factory)' ),
			array( 'ticon ticon-map-pin' => 'Map Pin' ),
			array( 'ticon ticon-map-signs' => 'Map Signs' ),
			array( 'ticon ticon-map-o' => 'Map Outlined' ),
			array( 'ticon ticon-map' => 'Map' ),
			array( 'ticon ticon-commenting' => 'Commenting(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
			array( 'ticon ticon-commenting-o' => 'Commenting Outlined(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
			array( 'ticon ticon-credit-card-alt' => 'Credit Card(money, buy, debit, checkout, purchase, payment, credit card)' ),
			array( 'ticon ticon-shopping-bag' => 'Shopping Bag' ),
			array( 'ticon ticon-shopping-basket' => 'Shopping Basket' ),
			array( 'ticon ticon-hashtag' => 'Hashtag' ),
			array( 'ticon ticon-bluetooth' => 'Bluetooth' ),
			array( 'ticon ticon-bluetooth-b' => 'Bluetooth' ),
			array( 'ticon ticon-percent' => 'Percent' ),
			array( 'ticon ticon-universal-access' => 'Universal Access' ),
			array( 'ticon ticon-wheelchair-alt' => 'Wheelchair Alt(handicap, person)' ),
			array( 'ticon ticon-question-circle-o' => 'Question Circle Outlined' ),
			array( 'ticon ticon-blind' => 'Blind' ),
			array( 'ticon ticon-audio-description' => 'Audio Description' ),
			array( 'ticon ticon-volume-control-phone' => 'Volume Control Phone(telephone)' ),
			array( 'ticon ticon-braille' => 'Braille' ),
			array( 'ticon ticon-assistive-listening-systems' => 'Assistive Listening Systems' ),
			array( 'ticon ticon-american-sign-language-interpreting' => 'American Sign Language Interpreting(asl-interpreting)' ),
			array( 'ticon ticon-deaf' => 'Deaf(deafness, hard-of-hearing)' ),
			array( 'ticon ticon-sign-language' => 'Sign Language(signing)' ),
			array( 'ticon ticon-low-vision' => 'Low Vision' ),
			array( 'ticon ticon-handshake-o' => 'Handshake Outlined' ),
			array( 'ticon ticon-envelope-open' => 'Envelope Open(email, e-mail, letter, support, mail, message, notification)' ),
			array( 'ticon ticon-envelope-open-o' => 'Envelope Open Outlined(email, e-mail, letter, support, mail, message, notification)' ),
			array( 'ticon ticon-address-book' => 'Address Book' ),
			array( 'ticon ticon-address-book-o' => 'Address Book Outlined' ),
			array( 'ticon ticon-address-card' => 'Address Card(vcard)' ),
			array( 'ticon ticon-address-card-o' => 'Address Card Outlined(vcard-o)' ),
			array( 'ticon ticon-user-circle' => 'User Circle' ),
			array( 'ticon ticon-user-circle-o' => 'User Circle Outlined' ),
			array( 'ticon ticon-user-o' => 'User Outlined' ),
			array( 'ticon ticon-id-badge' => 'Identification Badge' ),
			array( 'ticon ticon-id-card' => 'Identification Card(drivers-license)' ),
			array( 'ticon ticon-id-card-o' => 'Identification Card Outlined(drivers-license-o)' ),
			array( 'ticon ticon-thermometer-full' => 'Thermometer Full(thermometer-4, thermometer)' ),
			array( 'ticon ticon-thermometer-three-quarters' => 'Thermometer 3/4 Full(thermometer-3)' ),
			array( 'ticon ticon-thermometer-half' => 'Thermometer 1/2 Full(thermometer-2)' ),
			array( 'ticon ticon-thermometer-quarter' => 'Thermometer 1/4 Full(thermometer-1)' ),
			array( 'ticon ticon-thermometer-empty' => 'Thermometer Empty(thermometer-0)' ),
			array( 'ticon ticon-shower' => 'Shower' ),
			array( 'ticon ticon-bath' => 'Bath(bathtub, s15)' ),
			array( 'ticon ticon-podcast' => 'Podcast' ),
			array( 'ticon ticon-window-maximize' => 'Window Maximize' ),
			array( 'ticon ticon-window-minimize' => 'Window Minimize' ),
			array( 'ticon ticon-window-restore' => 'Window Restore' ),
			array( 'ticon ticon-window-close' => 'Window Close(times-rectangle)' ),
			array( 'ticon ticon-window-close-o' => 'Window Close Outline(times-rectangle-o)' ),
			array( 'ticon ticon-microchip' => 'Microchip' ),
			array( 'ticon ticon-snowflake-o' => 'Snowflake Outlined' ),
			array( 'ticon ticon-heart' => 'Heart(love, like, favorite)' ),
			array( 'ticon ticon-heart-o' => 'Heart Outlined(love, like, favorite)' ),
			array( 'ticon ticon-user-md' => 'user-md(doctor, profile, medical, nurse)' ),
			array( 'ticon ticon-stethoscope' => 'Stethoscope' ),
			array( 'ticon ticon-hospital-o' => 'hospital Outlined(building)' ),
			array( 'ticon ticon-ambulance' => 'ambulance(vehicle, support, help)' ),
			array( 'ticon ticon-medkit' => 'medkit(first aid, firstaid, help, support, health)' ),
			array( 'ticon ticon-h-square' => 'H Square(hospital, hotel)' ),
			array( 'ticon ticon-plus-square' => 'Plus Square(add, new, create, expand)' ),
			array( 'ticon ticon-wheelchair' => 'Wheelchair(handicap, person)' ),
			array( 'ticon ticon-heartbeat' => 'Heartbeat(ekg)' ),
			array( 'ticon ticon-wheelchair-alt' => 'Wheelchair Alt(handicap, person)' ),
			array( 'ticon ticon-th-large' => 'th-large(blocks, squares, boxes, grid)' ),
			array( 'ticon ticon-th' => 'th(blocks, squares, boxes, grid)' ),
			array( 'ticon ticon-th-list' => 'th-list(ul, ol, checklist, finished, completed, done, todo)' ),
			array( 'ticon ticon-file-o' => 'File Outlined(new, page, pdf, document)' ),
			array( 'ticon ticon-repeat' => 'Repeat(redo, forward)(rotate-right)' ),
			array( 'ticon ticon-list-alt' => 'list-alt(ul, ol, checklist, finished, completed, done, todo)' ),
			array( 'ticon ticon-font' => 'font(text)' ),
			array( 'ticon ticon-bold' => 'bold' ),
			array( 'ticon ticon-italic' => 'italic(italics)' ),
			array( 'ticon ticon-text-height' => 'text-height' ),
			array( 'ticon ticon-text-width' => 'text-width' ),
			array( 'ticon ticon-align-left' => 'align-left(text)' ),
			array( 'ticon ticon-align-center' => 'align-center(middle, text)' ),
			array( 'ticon ticon-align-right' => 'align-right(text)' ),
			array( 'ticon ticon-align-justify' => 'align-justify(text)' ),
			array( 'ticon ticon-list' => 'list(ul, ol, checklist, finished, completed, done, todo)' ),
			array( 'ticon ticon-outdent' => 'Outdent(dedent)' ),
			array( 'ticon ticon-indent' => 'Indent' ),
			array( 'ticon ticon-link' => 'Link(chain)(chain)' ),
			array( 'ticon ticon-scissors' => 'Scissors(cut)' ),
			array( 'ticon ticon-files-o' => 'Files Outlined(duplicate, clone, copy)(copy)' ),
			array( 'ticon ticon-paperclip' => 'Paperclip(attachment)' ),
			array( 'ticon ticon-floppy-o' => 'Floppy Outlined(save)' ),
			array( 'ticon ticon-list-ul' => 'list-ul(ul, ol, checklist, todo, list)' ),
			array( 'ticon ticon-list-ol' => 'list-ol(ul, ol, checklist, list, todo, list, numbers)' ),
			array( 'ticon ticon-strikethrough' => 'Strikethrough' ),
			array( 'ticon ticon-underline' => 'Underline' ),
			array( 'ticon ticon-table' => 'table(data, excel, spreadsheet)' ),
			array( 'ticon ticon-columns' => 'Columns(split, panes)' ),
			array( 'ticon ticon-undo' => 'Undo(back)(rotate-left)' ),
			array( 'ticon ticon-clipboard' => 'Clipboard(copy)(paste)' ),
			array( 'ticon ticon-file-text-o' => 'File Text Outlined(new, page, pdf, document)' ),
			array( 'ticon ticon-chain-broken' => 'Chain Broken(remove)(unlink)' ),
			array( 'ticon ticon-superscript' => 'superscript(exponential)' ),
			array( 'ticon ticon-subscript' => 'subscript' ),
			array( 'ticon ticon-eraser' => 'eraser(remove, delete)' ),
			array( 'ticon ticon-file' => 'File(new, page, pdf, document)' ),
			array( 'ticon ticon-file-text' => 'File Text(new, page, pdf, document)' ),
			array( 'ticon ticon-header' => 'header(heading)' ),
			array( 'ticon ticon-paragraph' => 'paragraph' ),
			array( 'ticon ticon-cog' => 'cog(settings)(gear)' ),
			array( 'ticon ticon-refresh' => 'refresh(reload, sync)' ),
			array( 'ticon ticon-spinner' => 'Spinner(loading, progress)' ),
			array( 'ticon ticon-circle-o-notch' => 'Circle Outlined Notched' ),
			array( 'ticon ticon-file-o' => 'File Outlined(new, page, pdf, document)' ),
			array( 'ticon ticon-file-text-o' => 'File Text Outlined(new, page, pdf, document)' ),
			array( 'ticon ticon-file' => 'File(new, page, pdf, document)' ),
			array( 'ticon ticon-file-text' => 'File Text(new, page, pdf, document)' ),
			array( 'ticon ticon-file-pdf-o' => 'PDF File Outlined' ),
			array( 'ticon ticon-file-word-o' => 'Word File Outlined' ),
			array( 'ticon ticon-file-excel-o' => 'Excel File Outlined' ),
			array( 'ticon ticon-file-powerpoint-o' => 'Powerpoint File Outlined' ),
			array( 'ticon ticon-file-image-o' => 'Image File Outlined(file-photo-o, file-picture-o)' ),
			array( 'ticon ticon-file-archive-o' => 'Archive File Outlined(file-zip-o)' ),
			array( 'ticon ticon-file-audio-o' => 'Audio File Outlined(file-sound-o)' ),
			array( 'ticon ticon-file-video-o' => 'Video File Outlined(file-movie-o)' ),
			array( 'ticon ticon-file-code-o' => 'Code File Outlined' ),
			array( 'ticon ticon-arrow-circle-o-down' => 'Arrow Circle Outlined Down(download)' ),
			array( 'ticon ticon-arrow-circle-o-up' => 'Arrow Circle Outlined Up' ),
			array( 'ticon ticon-arrows' => 'Arrows(move, reorder, resize)' ),
			array( 'ticon ticon-chevron-left' => 'chevron-left(bracket, previous, back)' ),
			array( 'ticon ticon-chevron-right' => 'chevron-right(bracket, next, forward)' ),
			array( 'ticon ticon-arrow-left' => 'arrow-left(previous, back)' ),
			array( 'ticon ticon-arrow-right' => 'arrow-right(next, forward)' ),
			array( 'ticon ticon-arrow-up' => 'arrow-up' ),
			array( 'ticon ticon-arrow-down' => 'arrow-down(download)' ),
			array( 'ticon ticon-chevron-up' => 'chevron-up' ),
			array( 'ticon ticon-chevron-down' => 'chevron-down' ),
			array( 'ticon ticon-arrows-v' => 'Arrows Vertical(resize)' ),
			array( 'ticon ticon-arrows-h' => 'Arrows Horizontal(resize)' ),
			array( 'ticon ticon-hand-o-right' => 'Hand Outlined Right(point, right, next, forward, finger)' ),
			array( 'ticon ticon-hand-o-left' => 'Hand Outlined Left(point, left, previous, back, finger)' ),
			array( 'ticon ticon-hand-o-up' => 'Hand Outlined Up(point, finger)' ),
			array( 'ticon ticon-hand-o-down' => 'Hand Outlined Down(point, finger)' ),
			array( 'ticon ticon-arrow-circle-left' => 'Arrow Circle Left(previous, back)' ),
			array( 'ticon ticon-arrow-circle-right' => 'Arrow Circle Right(next, forward)' ),
			array( 'ticon ticon-arrow-circle-up' => 'Arrow Circle Up' ),
			array( 'ticon ticon-arrow-circle-down' => 'Arrow Circle Down(download)' ),
			array( 'ticon ticon-arrows-alt' => 'Arrows Alt(expand, enlarge, fullscreen, bigger, move, reorder, resize, arrow)' ),
			array( 'ticon ticon-caret-down' => 'Caret Down(more, dropdown, menu, triangle down, arrow)' ),
			array( 'ticon ticon-caret-up' => 'Caret Up(triangle up, arrow)' ),
			array( 'ticon ticon-caret-left' => 'Caret Left(previous, back, triangle left, arrow)' ),
			array( 'ticon ticon-caret-right' => 'Caret Right(next, forward, triangle right, arrow)' ),
			array( 'ticon ticon-exchange' => 'Exchange(transfer, arrows, arrow)' ),
			array( 'ticon ticon-angle-double-left' => 'Angle Double Left(laquo, quote, previous, back, arrows)' ),
			array( 'ticon ticon-angle-double-right' => 'Angle Double Right(raquo, quote, next, forward, arrows)' ),
			array( 'ticon ticon-angle-double-up' => 'Angle Double Up(arrows)' ),
			array( 'ticon ticon-angle-double-down' => 'Angle Double Down(arrows)' ),
			array( 'ticon ticon-angle-left' => 'angle-left(previous, back, arrow)' ),
			array( 'ticon ticon-angle-right' => 'angle-right(next, forward, arrow)' ),
			array( 'ticon ticon-angle-up' => 'angle-up(arrow)' ),
			array( 'ticon ticon-angle-down' => 'angle-down(arrow)' ),
			array( 'ticon ticon-chevron-circle-left' => 'Chevron Circle Left(previous, back, arrow)' ),
			array( 'ticon ticon-chevron-circle-right' => 'Chevron Circle Right(next, forward, arrow)' ),
			array( 'ticon ticon-chevron-circle-up' => 'Chevron Circle Up(arrow)' ),
			array( 'ticon ticon-chevron-circle-down' => 'Chevron Circle Down(more, dropdown, menu, arrow)' ),
			array( 'ticon ticon-caret-square-o-down' => 'Caret Square Outlined Down(more, dropdown, menu)(toggle-down)' ),
			array( 'ticon ticon-caret-square-o-up' => 'Caret Square Outlined Up(toggle-up)' ),
			array( 'ticon ticon-caret-square-o-right' => 'Caret Square Outlined Right(next, forward)(toggle-right)' ),
			array( 'ticon ticon-long-arrow-down' => 'Long Arrow Down' ),
			array( 'ticon ticon-long-arrow-up' => 'Long Arrow Up' ),
			array( 'ticon ticon-long-arrow-left' => 'Long Arrow Left(previous, back)' ),
			array( 'ticon ticon-long-arrow-right' => 'Long Arrow Right' ),
			array( 'ticon ticon-arrow-circle-o-right' => 'Arrow Circle Outlined Right(next, forward)' ),
			array( 'ticon ticon-arrow-circle-o-left' => 'Arrow Circle Outlined Left(previous, back)' ),
			array( 'ticon ticon-caret-square-o-left' => 'Caret Square Outlined Left(previous, back)(toggle-left)' ),
			array( 'ticon ticon-play-circle-o' => 'Play Circle Outlined' ),
			array( 'ticon ticon-step-backward' => 'step-backward(rewind, previous, beginning, start, first)' ),
			//array( 'ticon ticon-fast-backward' => 'fast-backward(rewind, previous, beginning, start, first)' ), // not in ticons
			array( 'ticon ticon-backward' => 'backward(rewind, previous)' ),
			array( 'ticon ticon-play' => 'play(start, playing, music, sound)' ),
			array( 'ticon ticon-pause' => 'pause(wait)' ),
			array( 'ticon ticon-stop' => 'stop(block, box, square)' ),
			array( 'ticon ticon-forward' => 'forward(forward, next)' ),
			//array( 'ticon ticon-fast-forward' => 'fast-forward(next, end, last)' ), // not in ticons
			array( 'ticon ticon-step-forward' => 'step-forward(next, end, last)' ),
			array( 'ticon ticon-eject' => 'eject' ),
			array( 'ticon ticon-expand' => 'Expand(enlarge, bigger, resize)' ),
			array( 'ticon ticon-compress' => 'Compress(collapse, combine, contract, merge, smaller)' ),
			array( 'ticon ticon-random' => 'random(sort, shuffle)' ),
			array( 'ticon ticon-arrows-alt' => 'Arrows Alt(expand, enlarge, fullscreen, bigger, move, reorder, resize, arrow)' ),
			array( 'ticon ticon-play-circle' => 'Play Circle(start, playing)' ),
			array( 'ticon ticon-youtube-play' => 'YouTube Play(start, playing)' ),
			array( 'ticon ticon-pause-circle' => 'Pause Circle' ),
			array( 'ticon ticon-pause-circle-o' => 'Pause Circle Outlined' ),
			array( 'ticon ticon-stop-circle' => 'Stop Circle' ),
			array( 'ticon ticon-stop-circle-o' => 'Stop Circle Outlined' ),
			array( 'ticon ticon-check-square-o' => 'Check Square Outlined(todo, done, agree, accept, confirm, ok)' ),
			array( 'ticon ticon-square-o' => 'Square Outlined(block, square, box)' ),
			array( 'ticon ticon-square' => 'Square(block, box)' ),
			array( 'ticon ticon-plus-square' => 'Plus Square(add, new, create, expand)' ),
			array( 'ticon ticon-circle-o' => 'Circle Outlined' ),
			array( 'ticon ticon-circle' => 'Circle(dot, notification)' ),
			array( 'ticon ticon-minus-square' => 'Minus Square(hide, minify, delete, remove, trash, hide, collapse)' ),
			array( 'ticon ticon-minus-square-o' => 'Minus Square Outlined(hide, minify, delete, remove, trash, hide, collapse)' ),
			array( 'ticon ticon-check-square' => 'Check Square(checkmark, done, todo, agree, accept, confirm, ok)' ),
			array( 'ticon ticon-dot-circle-o' => 'Dot Circle Outlined(target, bullseye, notification)' ),
			array( 'ticon ticon-plus-square-o' => 'Plus Square Outlined(add, new, create, expand)' ),
			array( 'ticon ticon-plane' => 'plane(travel, trip, location, destination, airplane, fly, mode)' ),
			array( 'ticon ticon-truck' => 'truck(shipping)' ),
			array( 'ticon ticon-ambulance' => 'ambulance(vehicle, support, help)' ),
			array( 'ticon ticon-fighter-jet' => 'fighter-jet(fly, plane, airplane, quick, fast, travel)' ),
			array( 'ticon ticon-rocket' => 'rocket(app)' ),
			array( 'ticon ticon-wheelchair' => 'Wheelchair(handicap, person)' ),
			array( 'ticon ticon-space-shuttle' => 'Space Shuttle' ),
			array( 'ticon ticon-car' => 'Car(vehicle)(automobile)' ),
			array( 'ticon ticon-taxi' => 'Taxi(vehicle)(cab)' ),
			array( 'ticon ticon-bicycle' => 'Bicycle(vehicle, bike)' ),
			array( 'ticon ticon-bus' => 'Bus(vehicle)' ),
			array( 'ticon ticon-ship' => 'Ship(boat, sea)' ),
			array( 'ticon ticon-motorcycle' => 'Motorcycle(vehicle, bike)' ),
			array( 'ticon ticon-train' => 'Train' ),
			array( 'ticon ticon-subway' => 'Subway' ),
			array( 'ticon ticon-wheelchair-alt' => 'Wheelchair Alt(handicap, person)' ),
			array( 'ticon ticon-bar-chart' => 'Bar Chart(graph, analytics, statistics)(bar-chart-o)' ),
			array( 'ticon ticon-area-chart' => 'Area Chart(graph, analytics, statistics)' ),
			array( 'ticon ticon-pie-chart' => 'Pie Chart(graph, analytics, statistics)' ),
			array( 'ticon ticon-line-chart' => 'Line Chart(graph, analytics, statistics)' ),
			array( 'ticon ticon-twitter-square' => 'Twitter Square(tweet, social network)' ),
			array( 'ticon ticon-facebook-square' => 'Facebook Square(social network)' ),
			array( 'ticon ticon-linkedin-square' => 'LinkedIn Square' ),
			array( 'ticon ticon-github-square' => 'GitHub Square(octocat)' ),
			array( 'ticon ticon-twitter' => 'Twitter(tweet, social network)' ),
			array( 'ticon ticon-facebook' => 'Facebook(social network)(facebook-f)' ),
			array( 'ticon ticon-github' => 'GitHub(octocat)' ),
			array( 'ticon ticon-pinterest' => 'Pinterest' ),
			array( 'ticon ticon-pinterest-square' => 'Pinterest Square' ),
			//array( 'ticon ticon-google-plus-square' => 'Google Plus Square(social network)' ),
			//array( 'ticon ticon-google-plus' => 'Google Plus(social network)' ),
			array( 'ticon ticon-linkedin' => 'LinkedIn' ),
			array( 'ticon ticon-github-alt' => 'GitHub Alt(octocat)' ),
			array( 'ticon ticon-maxcdn' => 'MaxCDN' ),
			array( 'ticon ticon-html5' => 'HTML 5 Logo' ),
			array( 'ticon ticon-css3' => 'CSS 3 Logo(code)' ),
			array( 'ticon ticon-btc' => 'Bitcoin (BTC)(bitcoin)' ),
			array( 'ticon ticon-youtube-square' => 'YouTube Square(video, film)' ),
			array( 'ticon ticon-youtube' => 'YouTube(video, film)' ),
			array( 'ticon ticon-xing' => 'Xing' ),
			array( 'ticon ticon-xing-square' => 'Xing Square' ),
			array( 'ticon ticon-youtube-play' => 'YouTube Play(start, playing)' ),
			array( 'ticon ticon-dropbox' => 'Dropbox' ),
			array( 'ticon ticon-stack-overflow' => 'Stack Overflow' ),
			array( 'ticon ticon-instagram' => 'Instagram' ),
			array( 'ticon ticon-flickr' => 'Flickr' ),
			array( 'ticon ticon-adn' => 'App.net' ),
			array( 'ticon ticon-bitbucket' => 'Bitbucket(git)' ),
			array( 'ticon ticon-bitbucket-square' => 'Bitbucket Square(git)' ),
			array( 'ticon ticon-tumblr' => 'Tumblr' ),
			array( 'ticon ticon-tumblr-square' => 'Tumblr Square' ),
			array( 'ticon ticon-apple' => 'Apple(osx, food)' ),
			array( 'ticon ticon-windows' => 'Windows(microsoft)' ),
			array( 'ticon ticon-android' => 'Android(robot)' ),
			array( 'ticon ticon-linux' => 'Linux(tux)' ),
			array( 'ticon ticon-dribbble' => 'Dribbble' ),
			array( 'ticon ticon-skype' => 'Skype' ),
			array( 'ticon ticon-foursquare' => 'Foursquare' ),
			array( 'ticon ticon-trello' => 'Trello' ),
			array( 'ticon ticon-gratipay' => 'Gratipay (Gittip)(heart, like, favorite, love)(gittip)' ),
			array( 'ticon ticon-vk' => 'VK' ),
			array( 'ticon ticon-weibo' => 'Weibo' ),
			array( 'ticon ticon-renren' => 'Renren' ),
			array( 'ticon ticon-pagelines' => 'Pagelines(leaf, leaves, tree, plant, eco, nature)' ),
			array( 'ticon ticon-stack-exchange' => 'Stack Exchange' ),
			array( 'ticon ticon-vimeo-square' => 'Vimeo Square' ),
			array( 'ticon ticon-slack' => 'Slack Logo(hashtag, anchor, hash)' ),
			array( 'ticon ticon-wordpress' => 'WordPress Logo' ),
			array( 'ticon ticon-openid' => 'OpenID' ),
			array( 'ticon ticon-yahoo' => 'Yahoo Logo' ),
			array( 'ticon ticon-google' => 'Google Logo' ),
			array( 'ticon ticon-reddit' => 'reddit Logo' ),
			array( 'ticon ticon-reddit-square' => 'reddit Square' ),
			array( 'ticon ticon-stumbleupon-circle' => 'StumbleUpon Circle' ),
			array( 'ticon ticon-stumbleupon' => 'StumbleUpon Logo' ),
			array( 'ticon ticon-delicious' => 'Delicious Logo' ),
			array( 'ticon ticon-digg' => 'Digg Logo' ),
			array( 'ticon ticon-pied-piper-pp' => 'Pied Piper PP Logo (Old)' ),
			array( 'ticon ticon-pied-piper-alt' => 'Pied Piper Alternate Logo' ),
			array( 'ticon ticon-drupal' => 'Drupal Logo' ),
			array( 'ticon ticon-joomla' => 'Joomla Logo' ),
			array( 'ticon ticon-behance' => 'Behance' ),
			array( 'ticon ticon-behance-square' => 'Behance Square' ),
			array( 'ticon ticon-steam' => 'Steam' ),
			array( 'ticon ticon-steam-square' => 'Steam Square' ),
			array( 'ticon ticon-spotify' => 'Spotify' ),
			array( 'ticon ticon-deviantart' => 'deviantART' ),
			array( 'ticon ticon-soundcloud' => 'SoundCloud' ),
			array( 'ticon ticon-vine' => 'Vine' ),
			array( 'ticon ticon-codepen' => 'Codepen' ),
			array( 'ticon ticon-jsfiddle' => 'jsFiddle' ),
			array( 'ticon ticon-rebel' => 'Rebel Alliance(ra, resistance)' ),
			array( 'ticon ticon-empire' => 'Galactic Empire(ge)' ),
			array( 'ticon ticon-git-square' => 'Git Square' ),
			array( 'ticon ticon-git' => 'Git' ),
			array( 'ticon ticon-hacker-news' => 'Hacker News(y-combinator-square, yc-square)' ),
			array( 'ticon ticon-tencent-weibo' => 'Tencent Weibo' ),
			array( 'ticon ticon-qq' => 'QQ' ),
			array( 'ticon ticon-weixin' => 'Weixin (WeChat)(wechat)' ),
			array( 'ticon ticon-share-alt' => 'Share Alt' ),
			array( 'ticon ticon-share-alt-square' => 'Share Alt Square' ),
			array( 'ticon ticon-slideshare' => 'Slideshare' ),
			array( 'ticon ticon-twitch' => 'Twitch' ),
			array( 'ticon ticon-yelp' => 'Yelp' ),
			array( 'ticon ticon-paypal' => 'Paypal' ),
			array( 'ticon ticon-google-wallet' => 'Google Wallet' ),
			array( 'ticon ticon-cc-visa' => 'Visa Credit Card' ),
			array( 'ticon ticon-cc-mastercard' => 'MasterCard Credit Card' ),
			array( 'ticon ticon-cc-discover' => 'Discover Credit Card' ),
			array( 'ticon ticon-cc-amex' => 'American Express Credit Card(amex)' ),
			array( 'ticon ticon-cc-paypal' => 'Paypal Credit Card' ),
			array( 'ticon ticon-cc-stripe' => 'Stripe Credit Card' ),
			array( 'ticon ticon-lastfm' => 'last.fm' ),
			array( 'ticon ticon-lastfm-square' => 'last.fm Square' ),
			array( 'ticon ticon-ioxhost' => 'ioxhost' ),
			array( 'ticon ticon-angellist' => 'AngelList' ),
			array( 'ticon ticon-meanpath' => 'meanpath' ),
			array( 'ticon ticon-buysellads' => 'BuySellAds' ),
			array( 'ticon ticon-connectdevelop' => 'Connect Develop' ),
			array( 'ticon ticon-dashcube' => 'DashCube' ),
			array( 'ticon ticon-forumbee' => 'Forumbee' ),
			array( 'ticon ticon-leanpub' => 'Leanpub' ),
			array( 'ticon ticon-sellsy' => 'Sellsy' ),
			array( 'ticon ticon-shirtsinbulk' => 'Shirts in Bulk' ),
			array( 'ticon ticon-simplybuilt' => 'SimplyBuilt' ),
			array( 'ticon ticon-skyatlas' => 'skyatlas' ),
			array( 'ticon ticon-facebook-official' => 'Facebook Official' ),
			array( 'ticon ticon-pinterest-p' => 'Pinterest P' ),
			array( 'ticon ticon-whatsapp' => 'What\'s App' ),
			array( 'ticon ticon-viacoin' => 'Viacoin' ),
			array( 'ticon ticon-medium' => 'Medium' ),
			array( 'ticon ticon-y-combinator' => 'Y Combinator(yc)' ),
			array( 'ticon ticon-optin-monster' => 'Optin Monster' ),
			array( 'ticon ticon-opencart' => 'OpenCart' ),
			array( 'ticon ticon-expeditedssl' => 'ExpeditedSSL' ),
			array( 'ticon ticon-cc-jcb' => 'JCB Credit Card' ),
			array( 'ticon ticon-cc-diners-club' => 'Diner\'s Club Credit Card' ),
			array( 'ticon ticon-gg' => 'GG Currency' ),
			array( 'ticon ticon-gg-circle' => 'GG Currency Circle' ),
			array( 'ticon ticon-tripadvisor' => 'TripAdvisor' ),
			array( 'ticon ticon-odnoklassniki' => 'Odnoklassniki' ),
			array( 'ticon ticon-odnoklassniki-square' => 'Odnoklassniki Square' ),
			array( 'ticon ticon-get-pocket' => 'Get Pocket' ),
			array( 'ticon ticon-wikipedia-w' => 'Wikipedia W' ),
			//array( 'ticon ticon-safari' => 'Safari(browser)' ),
			array( 'ticon ticon-chrome' => 'Chrome(browser)' ),
			array( 'ticon ticon-firefox' => 'Firefox(browser)' ),
			array( 'ticon ticon-opera' => 'Opera' ),
			array( 'ticon ticon-internet-explorer' => 'Internet-explorer(browser, ie)' ),
			array( 'ticon ticon-contao' => 'Contao' ),
			array( 'ticon ticon-500px' => '500px' ),
			array( 'ticon ticon-amazon' => 'Amazon' ),
			array( 'ticon ticon-houzz' => 'Houzz' ),
			array( 'ticon ticon-vimeo' => 'Vimeo' ),
			array( 'ticon ticon-black-tie' => 'Font Awesome Black Tie' ),
			array( 'ticon ticon-fonticons' => 'Fonticons' ),
			array( 'ticon ticon-reddit-alien' => 'reddit Alien' ),
			array( 'ticon ticon-edge' => 'Edge Browser(browser, ie)' ),
			array( 'ticon ticon-codiepie' => 'Codie Pie' ),
			array( 'ticon ticon-modx' => 'MODX' ),
			array( 'ticon ticon-fort-awesome' => 'Fort Awesome' ),
			array( 'ticon ticon-usb' => 'USB' ),
			array( 'ticon ticon-product-hunt' => 'Product Hunt' ),
			array( 'ticon ticon-mixcloud' => 'Mixcloud' ),
			array( 'ticon ticon-scribd' => 'Scribd' ),
			array( 'ticon ticon-bluetooth' => 'Bluetooth' ),
			array( 'ticon ticon-bluetooth-b' => 'Bluetooth' ),
			array( 'ticon ticon-gitlab' => 'GitLab' ),
			array( 'ticon ticon-wpbeginner' => 'WPBeginner' ),
			array( 'ticon ticon-wpforms' => 'WPForms' ),
			array( 'ticon ticon-envira' => 'Envira Gallery(leaf)' ),
			array( 'ticon ticon-glide' => 'Glide' ),
			array( 'ticon ticon-glide-g' => 'Glide G' ),
			array( 'ticon ticon-viadeo' => 'Viadeo' ),
			array( 'ticon ticon-viadeo-square' => 'Viadeo Square' ),
			array( 'ticon ticon-snapchat' => 'Snapchat' ),
			array( 'ticon ticon-snapchat-ghost' => 'Snapchat Ghost' ),
			array( 'ticon ticon-snapchat-square' => 'Snapchat Square' ),
			array( 'ticon ticon-pied-piper' => 'Pied Piper Logo' ),
			array( 'ticon ticon-first-order' => 'First Order' ),
			array( 'ticon ticon-yoast' => 'Yoast' ),
			array( 'ticon ticon-themeisle' => 'ThemeIsle' ),
			//array( 'ticon ticon-google-plus-official' => 'Google Plus Official(google-plus-circle)' ),
			array( 'ticon ticon-font-awesome' => 'Font Awesome(fa)' ),
			array( 'ticon ticon-linode' => 'Linode' ),
			array( 'ticon ticon-quora' => 'Quora' ),
			array( 'ticon ticon-free-code-camp' => 'Free Code Camp' ),
			array( 'ticon ticon-telegram' => 'Telegram' ),
			array( 'ticon ticon-bandcamp' => 'Bandcamp' ),
			array( 'ticon ticon-grav' => 'Grav' ),
			array( 'ticon ticon-etsy' => 'Etsy' ),
			array( 'ticon ticon-imdb' => 'IMDB' ),
			array( 'ticon ticon-ravelry' => 'Ravelry' ),
			array( 'ticon ticon-eercast' => 'Eercast' ),
			array( 'ticon ticon-superpowers' => 'Superpowers' ),
			array( 'ticon ticon-wpexplorer' => 'WPExplorer' ),
			array( 'ticon ticon-meetup' => 'Meetup' ),
			array( 'ticon ticon-thumbs-o-up' => 'Thumbs Up Outlined(like, approve, favorite, agree, hand)' ),
			array( 'ticon ticon-thumbs-o-down' => 'Thumbs Down Outlined(dislike, disapprove, disagree, hand)' ),
			array( 'ticon ticon-hand-o-right' => 'Hand Outlined Right(point, right, next, forward, finger)' ),
			array( 'ticon ticon-hand-o-left' => 'Hand Outlined Left(point, left, previous, back, finger)' ),
			array( 'ticon ticon-hand-o-up' => 'Hand Outlined Up(point, finger)' ),
			array( 'ticon ticon-hand-o-down' => 'Hand Outlined Down(point, finger)' ),
			array( 'ticon ticon-thumbs-up' => 'thumbs-up(like, favorite, approve, agree, hand)' ),
			array( 'ticon ticon-thumbs-down' => 'thumbs-down(dislike, disapprove, disagree, hand)' ),
			array( 'ticon ticon-hand-rock-o' => 'Rock (Hand)(hand-grab-o)' ),
			array( 'ticon ticon-hand-paper-o' => 'Paper (Hand)(stop)(hand-stop-o)' ),
			array( 'ticon ticon-hand-scissors-o' => 'Scissors (Hand)' ),
			array( 'ticon ticon-hand-lizard-o' => 'Lizard (Hand)' ),
			array( 'ticon ticon-hand-spock-o' => 'Spock (Hand)' ),
			array( 'ticon ticon-hand-pointer-o' => 'Hand Pointer' ),
			array( 'ticon ticon-hand-peace-o' => 'Hand Peace' ),
			array( 'ticon ticon-credit-card' => 'credit-card(money, buy, debit, checkout, purchase, payment)' ),
			array( 'ticon ticon-paypal' => 'Paypal' ),
			array( 'ticon ticon-google-wallet' => 'Google Wallet' ),
			array( 'ticon ticon-cc-visa' => 'Visa Credit Card' ),
			array( 'ticon ticon-cc-mastercard' => 'MasterCard Credit Card' ),
			array( 'ticon ticon-cc-discover' => 'Discover Credit Card' ),
			array( 'ticon ticon-cc-amex' => 'American Express Credit Card(amex)' ),
			array( 'ticon ticon-cc-paypal' => 'Paypal Credit Card' ),
			array( 'ticon ticon-cc-stripe' => 'Stripe Credit Card' ),
			array( 'ticon ticon-cc-jcb' => 'JCB Credit Card' ),
			array( 'ticon ticon-cc-diners-club' => 'Diner\'s Club Credit Card' ),
			array( 'ticon ticon-credit-card-alt' => 'Credit Card(money, buy, debit, checkout, purchase, payment, credit card)' ),
			array( 'ticon ticon-money' => 'Money(cash, money, buy, checkout, purchase, payment)' ),
			array( 'ticon ticon-eur' => 'Euro (EUR)(euro)' ),
			array( 'ticon ticon-gbp' => 'GBP' ),
			array( 'ticon ticon-usd' => 'US Dollar(dollar)' ),
			array( 'ticon ticon-inr' => 'Indian Rupee (INR)(rupee)' ),
			array( 'ticon ticon-jpy' => 'Japanese Yen (JPY)(cny, rmb, yen)' ),
			array( 'ticon ticon-rub' => 'Russian Ruble (RUB)(ruble, rouble)' ),
			array( 'ticon ticon-krw' => 'Korean Won (KRW)(won)' ),
			array( 'ticon ticon-btc' => 'Bitcoin (BTC)(bitcoin)' ),
			array( 'ticon ticon-try' => 'Turkish Lira (TRY)(turkish-lira)' ),
			array( 'ticon ticon-ils' => 'Shekel (ILS)(shekel, sheqel)' ),
			array( 'ticon ticon-gg' => 'GG Currency' ),
			array( 'ticon ticon-gg-circle' => 'GG Currency Circle' ),
			array( 'ticon ticon-wheelchair' => 'Wheelchair(handicap, person)' ),
			array( 'ticon ticon-tty' => 'TTY' ),
			array( 'ticon ticon-cc' => 'Closed Captions' ),
			array( 'ticon ticon-universal-access' => 'Universal Access' ),
			array( 'ticon ticon-wheelchair-alt' => 'Wheelchair Alt(handicap, person)' ),
			array( 'ticon ticon-question-circle-o' => 'Question Circle Outlined' ),
			array( 'ticon ticon-blind' => 'Blind' ),
			array( 'ticon ticon-audio-description' => 'Audio Description' ),
			array( 'ticon ticon-volume-control-phone' => 'Volume Control Phone(telephone)' ),
			array( 'ticon ticon-braille' => 'Braille' ),
			array( 'ticon ticon-assistive-listening-systems' => 'Assistive Listening Systems' ),
			array( 'ticon ticon-american-sign-language-interpreting' => 'American Sign Language Interpreting(asl-interpreting)' ),
			array( 'ticon ticon-deaf' => 'Deaf(deafness, hard-of-hearing)' ),
			array( 'ticon ticon-sign-language' => 'Sign Language(signing)' ),
			array( 'ticon ticon-low-vision' => 'Low Vision' ),
			array( 'ticon ticon-venus' => 'Venus(female)' ),
			array( 'ticon ticon-mars' => 'Mars(male)' ),
			array( 'ticon ticon-mercury' => 'Mercury(transgender)' ),
			array( 'ticon ticon-transgender' => 'Transgender(intersex)' ),
			array( 'ticon ticon-transgender-alt' => 'Transgender Alt' ),
			array( 'ticon ticon-venus-double' => 'Venus Double' ),
			array( 'ticon ticon-mars-double' => 'Mars Double' ),
			array( 'ticon ticon-venus-mars' => 'Venus Mars' ),
			array( 'ticon ticon-mars-stroke' => 'Mars Stroke' ),
			array( 'ticon ticon-mars-stroke-v' => 'Mars Stroke Vertical' ),
			array( 'ticon ticon-mars-stroke-h' => 'Mars Stroke Horizontal' ),
			array( 'ticon ticon-neuter' => 'Neuter' ),
			array( 'ticon ticon-genderless' => 'Genderless' ),

			// Added in 5.2
			array( 'ticon ticon-tiktok' => 'TikTok' ),

			// Added in 5.3.1
			array( 'ticon ticon-discord' => 'Discord' ),

			// Added in 5.4
			array( 'ticon ticon-shopping-cart-alt' => 'shopping-cart-alt(checkout, buy, purchase, payment)' ),
			array( 'ticon ticon-shopping-bag-alt' => 'Shopping Bag Alt' ),
			array( 'ticon ticon-shopping-basket-alt' => 'Shopping Basket Alt' ),
		);

		return array_merge( $icons, $ticons );
	}

}