<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Title
$html .= $this->get_title( array(
	'class' => 'wpex-heading wpex-text-lg wpex-mb-10',
) );

// Excerpt
$html .= $this->get_excerpt( array(
	'class' => 'wpex-mb-20',
) );

// More Link
$html .= $this->get_more_link( array(
	'text' => esc_html__( 'Learn more', 'total' ),
	'link_class' => 'wpex-hover-underline',
	'suffix' => ' &rarr;',
) );

return $html;