<?php
/**
 * Header Flex Container Side Content.
 *
 * @package TotalTheme
 * @subpackage Partials
 * @version 5.4.6
 */

defined( 'ABSPATH' ) || exit;

$content = wpex_header_flex_aside_content();

if ( ! $content ) {
	return;
}

?>

<div id="site-header-flex-aside" <?php wpex_header_flex_aside_class(); ?>>
    <div id="site-header-flex-aside-inner" class="header-aside-content wpex-flex wpex-flex-wrap wpex-items-center"><?php
        echo do_shortcode( wp_kses_post( $content ) );
    ?></div>
</div>