<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Media
$html .= $this->get_media( array(
	'class' => 'wpex-mb-15',
) );

// Details
$html .= '<div class="wpex-card-details wpex-flex wpex-items-center">';

	// Avatar
	$html .= $this->get_avatar( array(
		'size' => 32,
		'class' => 'wpex-flex-shrink-0 wpex-mr-15',
		'image_class' => 'wpex-rounded-full wpex-align-middle',
	) );

	$html .= '<div class="wpex-card-details wpex-flex-grow">';

		// Title
		$html .= $this->get_title( array(
			'class' => 'wpex-heading wpex-text-md',
		) );

		// Terms
		$html .= $this->get_terms_list( array(
			'class' => 'wpex-text-3',
			'separator'  => ' &middot; ',
			'term_class' => 'wpex-inherit-color wpex-hover-underline',
		) );

	$html .= '</div>';

$html .= '</div>';

return $html;