<?php
/**
 * Register Custom WPBakery Shortcode Parameters.
 *
 * @package TotalThemeCore
 * @version 1.4.6
 */

defined( 'ABSPATH' ) || exit;

$js       = vcex_wpbakery_asset_url( 'js/params/vcex-params.min.js?v=' . TTC_VERSION );
$location = 'TotalThemeCore\\WPBakery\\Params\\';

vc_add_shortcode_param( 'vcex_text', $location . 'Text::output' );
vc_add_shortcode_param( 'vcex_colorpicker', $location . 'Colorpicker::output' );
vc_add_shortcode_param( 'vcex_subheading', $location . 'Subheading::output' );
vc_add_shortcode_param( 'vcex_attach_images', $location . 'Attach_Images::output' );
vc_add_shortcode_param( 'vcex_sorter', $location . 'Sorter::output', $js );
vc_add_shortcode_param( 'vcex_button_colors', $location . 'Button_Colors::output', $js );
vc_add_shortcode_param( 'vcex_button_styles', $location . 'Button_Styles::output' );
vc_add_shortcode_param( 'vcex_font_family_select', $location . 'Font_Family::output', $js );
vc_add_shortcode_param( 'vcex_font_size', $location . 'Font_Size::output', $js );
vc_add_shortcode_param( 'vcex_grid_columns', $location . 'Grid_Column::output' );
vc_add_shortcode_param( 'vcex_column_gaps', $location . 'Grid_Column_Gap::output' );
vc_add_shortcode_param( 'vcex_grid_columns_responsive', $location . 'Grid_Column_Responsive::output', $js );
vc_add_shortcode_param( 'vcex_hover_animations', $location . 'Hover_Animation::output' );
vc_add_shortcode_param( 'vcex_image_crop_locations', $location . 'Image_Crop_Location::output' );
vc_add_shortcode_param( 'vcex_image_sizes', $location . 'Image_Size::output' );
vc_add_shortcode_param( 'vcex_menus_select', $location . 'Menu::output' );
vc_add_shortcode_param( 'vcex_notice', $location . 'Notice::output' );
vc_add_shortcode_param( 'vcex_number', $location . 'Number::output' );
vc_add_shortcode_param( 'vcex_ofswitch', $location . 'On_Off_Switch::output', $js );
vc_add_shortcode_param( 'vcex_orderby', $location . 'Query_Orderby::output' );
vc_add_shortcode_param( 'vcex_responsive_sizes', $location . 'Responsive_Input::output', $js );
vc_add_shortcode_param( 'vcex_select_buttons', $location . 'Select_Buttons::output', $js );
vc_add_shortcode_param( 'vcex_social_button_styles', $location . 'Select_Social_Button_Style::output' );
vc_add_shortcode_param( 'vcex_text_alignments', $location . 'Text_Align::output' );
vc_add_shortcode_param( 'vcex_trbl', $location . 'Top_Right_Bottom_Left::output', $js );
vc_add_shortcode_param( 'vcex_template_select', $location . 'Select_Template::output' );
vc_add_shortcode_param( 'vcex_preset_textfield', $location . 'Preset_Textfield::output', $js );
vc_add_shortcode_param( 'vcex_min_max', $location . 'Min_Max::output', $js );
vc_add_shortcode_param( 'vcex_select', $location . 'Select::output' );

if ( get_theme_mod( 'cards_enable', true ) ) {
	vc_add_shortcode_param( 'vcex_wpex_card_select', $location . 'Select_Card_Style::output' );
}

if ( defined( 'WPCF7_VERSION' ) ) {
	vc_add_shortcode_param( 'vcex_cf7_select', $location . 'Cf7_Select::output' );
}