<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Inner
$html .= '<div class="wpex-card-inner wpex-flex wpex-flex-col wpex-flex-grow wpex-p-25 wpex-border wpex-border-main wpex-border-solid wpex-last-mb-0">';

	// Date
	$html .= $this->get_date( array(
		'class' => 'wpex-mb-5 wpex-text-3',
	) );

	// Title
	$html .= $this->get_title( array(
		'class' => 'wpex-heading wpex-text-lg wpex-mb-15',
	) );

	// Excerpt
	$html .= $this->get_excerpt();

$html .= '</div>';

return $html;