<?php
namespace TotalTheme;

use TotalTheme\Blog\Single_Blocks as Blocks;

/**
 * Blog Quote Format Single Layout.
 *
 * @package Total WordPress theme
 * @subpackage Partials
 * @version 5.4.6
 */

defined( 'ABSPATH' ) || exit;

?>

<article id="post-<?php the_ID(); ?>" class="single-quote-format">

	<div <?php wpex_blog_entry_quote_class(); ?>>
		<?php if ( 'font' === Theme_Icons::get_format() ) { ?>
			<span <?php wpex_blog_entry_quote_icon_class(); ?> aria-hidden="true"></span>
		<?php } ?>
		<div class="quote-entry-content wpex-last-mb-0 wpex-clr"><?php the_content(); ?></div>
		<div class="quote-entry-author wpex-text-sm wpex-not-italic wpex-mt-20 wpex-style-none"><span>-</span> <?php the_title(); ?></div>
	</div>

	<?php if ( ! is_singular( 'post' ) ) { ?>
		<?php wpex_blog_entry_sep();  ?>
	<?php } ?>

</article>

<?php
$single_blocks = Blocks::get();

if ( $single_blocks && is_array( $single_blocks ) && in_array( 'comments', $single_blocks ) ) {
	comments_template();
}