<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Media
$html .= $this->get_media( array(
	'class' => 'wpex-mb-15',
) );

// Date
$html .= $this->get_date( array(
	'class'  => 'wpex-mb-10',
	'type'   => 'published',
	'format' => ( ! WPEX_WPML_ACTIVE && ! WPEX_POLYLANG_ACTIVE && 0 === strpos( get_locale(), 'en_' ) ) ? 'n/j/Y' : '',
) );

// Title
$html .= $this->get_title( array(
	'class' => 'wpex-heading wpex-text-2xl',
) );

// Excerpt
$html .= $this->get_excerpt( array(
	'class'  => 'wpex-mt-15',
	'length' => 30,
) );

// More Button.
$html .= $this->get_more_link( array(
	'class'      => 'wpex-mt-15',
	'link_class' => 'wpex-border-0 wpex-border-b wpex-border-solid wpex-pb-5 wpex-no-underline',
	'text'       => esc_html__( 'Read more', 'total' ),
) );

return $html;