#top-bar-wrap>.customize-partial-edit-shortcut{left:50px}#footer-bottom .customize-partial-edit-shortcut{left:50px}#footer-callout-wrap .customize-partial-edit-shortcut{margin-left:50px}.woocommerce.single-product .wpex-social-share .customize-partial-edit-shortcut,#site-header-flex-aside .customize-partial-edit-shortcut{display:none !important}
