.wpex-license-activation{max-width:760px}.wpex-license-activation h1{margin-bottom:20px}.wpex-license-activation__card{font-size:13px;line-height:2.1em;background:#fff;box-sizing:border-box;border-radius:3px;border:1px solid #e2e4e7}.wpex-license-activation__card p:last-child{margin:0}.wpex-license-activation__card-inner{padding:16px 24px}.wpex-license-activation__heading{border-bottom:1px solid #e2e4e7;font-weight:600;font-size:20px;line-height:28px;padding:16px 24px;margin:0}.wpex-license-activation__info{font-size:14px;font-size:.875rem;margin:0 0 20px}.wpex-license-activation__input[type="text"]{width:100%;padding:10px;font-size:14px;min-height:50px}.wpex-license-activation__submit{margin:20px 0;display:flex;align-items:center}.wpex-license-activation__spinner{display:inline-block;margin-left:20px;position:relative;top:7px}.wpex-license-activation__spinner svg{height:20px;width:20px;fill:currentColor}.wpex-license-activation__spinner:not(.wpex-license-activation__spinner--visible){visibility:hidden;opacity:0}.wpex-license-activation__notice{display:none}.wpex-license-activation__notice.updated,.wpex-license-activation__notice.notice-warning{display:block}.wpex-license-activation__description{color:#757575;font-style:normal;font-weight:400;font-size:14px;font-size:.875rem;line-height:20px}.wpex-license-activation__troubleshoot{padding-top:10px;text-align:right}.wpex-license-activation__dev label{font-size:13px;font-style:italic;color:#767676}.wpex-license-activation__response{margin:1rem 0;font-size:1.25rem;background:#fff;box-sizing:border-box;border-radius:3px;border:1px solid #e2e4e7;padding:16px 24px}.wpex-license-activation__response strong{color:#DF0505}.wpex-license-activation__response--200 strong{color:#3D9830}
