#tribe-events-content{margin-bottom:var(--wpex-el-margin-bottom)}.tribe-common--breakpoint-medium.tribe-events .tribe-events-l-container{padding-top:0}.single-tribe_events #primary{padding-bottom:0}.single-tribe_events .tribe-events-back{display:none}.single-tribe_events .tribe-events-schedule h2{margin:0}.single-tribe_events #tribe-events-content .tribe-events-schedule{margin:.385em 0 var(--wpex-el-margin-bottom)}.single-tribe_events .tribe-events-event-meta{background:none;border:0 none}.single-tribe_events .tribe-events-event-meta .tribe-events-meta-group{padding-left:0}.single-tribe_events .tribe-events-nav-pagination a,.single-tribe_events .tribe-events-back a{color:inherit;font-weight:normal}.single-tribe_events .tribe-events-nav-pagination ul,.single-tribe_events .tribe-events-back ul{margin:0}.single-tribe_events .tribe-events-single .tribe-events-sub-nav{font-size:inherit}.single-tribe_events.tribe-page-header-details .tribe-events-schedule,.single-tribe_events.tribe-page-header-details .tribe-events-single-event-title{display:none}.single-tribe_events .tribe-events-venue-map{background:none;border:0;border-radius:0}.single-tribe_events #tribe-events-content{margin-bottom:var(--wpex-el-margin-bottom)}.single-tribe_events #tribe-events-footer{margin:0;padding:var(--wpex-el-margin-bottom) 0 0}.tribe-events-content{font-family:inherit;font-size:inherit;line-height:inherit;color:inherit}.tribe-events-content ol,.tribe-events-content p,.tribe-events-content ul{font-size:inherit;line-height:inherit;margin-bottom:20px}.tribe-events-meta-group .tribe-events-single-section-title{margin-top:0}.tribe-events-single-event-title{font-size:2em;line-height:1.4;color:var(--wpex-heading-color)}.tribe-events-single .tribe-events-sub-nav .tribe-events-nav-next a:after,.tribe-events-single .tribe-events-sub-nav .tribe-events-nav-previous a:before{background-size:.5em}.tribe-events-nav-previous a:before{margin-right:5px}.tribe-events-nav-next a:after{margin-left:5px}.tribe-events-schedule h2{font-weight:500;color:inherit;line-height:inherit;font-size:var(--wpex-text-md)}
