<?php
namespace TotalTheme\Actions;

use TotalTheme\Scripts\CSS;
use TotalTheme\Scripts\JS;

defined( 'ABSPATH' ) || exit;

/**
 * Hooks into wp_enqueue_scripts.
 *
 * @package TotalTheme
 * @subpackage Actions
 * @version 5.4
 */
final class WP_Enqueue_Scripts {

	/**
	 * Callback method.
	 */
	public static function callback() {
		CSS::register();
		CSS::enqueue();
		JS::register();
		JS::enqueue();
	}

}