<?php
namespace TotalTheme\Filters;

use TotalTheme\Walkers\Widget_Nav_Menu as Walker;

defined( 'ABSPATH' ) || exit;

/**
 * Hooks into "widget_nav_menu_args".
 *
 * @package TotalTheme
 * @subpackage Filters
 * @version 5.5
 */
final class Widget_Nav_Menu_args {

	/**
	 * Callback method.
	 */
	public static function callback( $nav_menu_args, $nav_menu, $args, $instance ) {
		// @todo should also add the classname "widget_nav_menu_accordion" somehow if possible.
		$nav_menu_args['walker'] = new Walker;
		return $nav_menu_args;
	}

}