<?php
defined( 'ABSPATH' ) || exit;

$this->sections['wpex_visual_composer'] = array(
	'title' => esc_html__( 'General', 'total' ),
	'settings' => array(
		array(
			'id' => 'vcex_theme_style_is_default',
			'default' => false,
			'control' => array(
				'type' => 'wpex_toggle',
				'label' => esc_html__( 'Use Theme Styles', 'total' ),
				'description' => esc_html__( 'Applies the theme style by default to WPBakery elements such as Tabs, Toggle, Accordion and Tour elements. Please save and refresh the live site in ordder to take affect.', 'total' ),
			),
		),
		array(
			'id' => 'vcex_heading_typography_tag_styles',
			'default' => false,
			'control' => array(
				'type' => 'wpex_toggle',
				'label' => esc_html__( 'Custom Heading Typography', 'total' ),
				'description' => esc_html__( 'Enable to apply the settings under Typography > h1, h2, h3, h4 to the heading module.', 'total' ),
			),
		),
		array(
			'id' => 'vc_row_bottom_margin',
			'default' => '40px',
			'control' => array(
				'type' => 'wpex_length_unit',
				'units' => array( 'px', 'rem', 'var', 'func' ),
				'label' => esc_html__( 'Column Bottom Margin', 'total' ),
				'description' => esc_html__( 'Having a default bottom margin makes it easier for your website to be responsive so on mobile devices when columns stack they will automatically have space between them.', 'total' ),
			),
			'inline_css' => array(
				'target' => ':root',
				'alter' => '--wpex-vc-column-inner-margin-bottom',
			),
		),
		array(
			'id' => 'vcex_heading_default_tag',
			'default' => 'div',
			'control' => array(
				'type' => 'select',
				'label' => esc_html__( 'Heading Module Default HTML Tag', 'total' ),
				'choices' => array(
					'div'  => 'div',
					'span' => 'span',
					'h1'   => 'h1',
					'h2'   => 'h2',
					'h3'   => 'h3',
					'h4'   => 'h4',
					'h5'   => 'h5',
				),
			),
		),
	),
);