.vcex-justified-gallery {
	width: 100%;
	position: relative;
	overflow: hidden;

	// Hide items to prevent FOC.
	.vcex-image-grid-entry {
		position: absolute;
		display: inline-block;
		overflow: hidden;
		margin: 0;
		padding: 0;
		&:not(.jg-entry-visible) {
			opacity: 0;
		}
	}

	// Force remove bottom margin on images.
	// @todo use PHP instead to remove the default wpex-mb-20 class
	.vcex-image-grid-entry-img {
		margin: 0;
	}

}