.wpex-mf-metabox {

	table {

		tr {
			border-top: 1px solid #eee;

			&:first-child {
				border: none
			}

		}

		th {
			width: 240px;
			padding: 15px 30px 15px 0;

			#side-sortables & {
				width: auto;
			}

		}

		td[colspan="2"] {
			padding-left: 0;
			padding-right: 0;
		}

		.wpex-mf-label {
			color: #555;
			font-weight: bold;
			font-style: italic;

			.fa {
				margin-right: 10px
			}

		}

	}

	.wpex-mf-description {
		color: #666;
		font-size: 12px;
		font-weight: normal;
		margin: 0;
		padding: 0;
		padding-top: 4px;
	}

	.wpex-mf-field_extras {
		margin-top: 12px;
	}

	fieldset {
		background-color: #fafafa;
		border: 1px solid #ededed;
		padding: 10px 15px;
	}

	// Group
	.wpex-mf-group-set {
		border: 1px solid #ddd;
	}

	.wpex-mf-group-fields table {
		border-collapse: collapse;
		width: 100%;
		border: 0;
		tr {
			border: 0;
		}
		td,th {
			border: 0;
			padding: 10px;
		}

	}

	.wpex-mf-group-header {
		display: flex;
		justify-content: space-between;
    	align-items: center;
    	border-bottom: 1px solid #ddd;
		padding: 8px;
		font-weight: bold;
		background-color: #efefef;
		.dashicons-no-alt {
			color: red;
			margin-right: 10px;
			cursor: pointer;
		}
	}

	.wpex-mf-group-fields {
		padding: 10px;
	}

	.wpex-mf-group-handle {
		text-align: right;
		.dashicons {
			cursor: pointer;
		}
	}

	/*.wpex-mf-upload {
		margin-top: 8px;
	}*/

	.wpex-mf-group-set {
		margin-bottom: 20px;
	}

	.wpex-mf-remove-group-set[disabled] {
		display: none !important;
	}

}

/* RTL Fixes */

/* Full Width Inputs
@media only screen and (min-width: 768px) {

	#normal-sortables .wpex-mf-metabox {

		input[type="text"],
		input[type="number"],
		textarea,
		select {
			width: 100%;
			max-width: 100%;
		}

	}

}*/