<div class="free-vs-pro-info-wrap">
    <div class="free-vs-pro-info">
        <h4><?php esc_html_e('ONE TIME PAYMENT', 'total'); ?></h4>
        <p><?php esc_html_e('No renewal needed', 'total'); ?></p>
    </div>

    <div class="free-vs-pro-info">
        <h4><?php esc_html_e('UNLIMITED DOMAIN LICENCE', 'total'); ?></h4>
        <p><?php esc_html_e('Use in as many websites as you need', 'total'); ?></p>
    </div>

    <div class="free-vs-pro-info">
        <h4><?php esc_html_e('FREE UPDATES FOR LIFETIME', 'total'); ?></h4>
        <p><?php esc_html_e('Keep up to date', 'total'); ?></p>
    </div>
</div>

<table class="comparison-table">
    <tr>
        <td>
            <span><?php esc_html_e('Upgrade to Pro', 'total'); ?></span>
            <p><?php esc_html_e('Upgrade to pro version for additional features and better supports.', 'total'); ?></p>
        </td>
        <td colspan="2">
            <a target="__blank" class="buy-pro-btn" href="https://hashthemes.com/wordpress-theme/total/?utm_source=wordpress&utm_medium=total-freevspro&utm_campaign=total-upgrade"><?php esc_html_e('Buy Now ($65 only)', 'total'); ?></a>
        </td>
    </tr>
    <tr>
        <th><?php esc_html_e('Features', 'total'); ?></th>
        <th><?php esc_html_e('Free', 'total'); ?></th>
        <th><?php esc_html_e('Pro', 'total'); ?></th>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('One Click Demo Import', 'total'); ?></span>
            <p><?php esc_html_e('With one click demo-import, you can install the demo content with just one click.', 'total'); ?></td>
        <td><?php esc_html_e('3 Demos', 'total'); ?></td>
        <td><?php esc_html_e('5 More Demos', 'total'); ?></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('GDPR Compliance & Cookies Consent', 'total'); ?></span>
            <p><?php esc_html_e('The Premium version is fully GDPR compliance. Means no data is collected if you use the theme alone. Also the premium version has option to add GDPR Compliance & Cookies Consent text with buttons.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Multiple Header Layouts and Settings', 'total'); ?></span>
            <p><?php esc_html_e('The premium version gives the option to choose from 6 header layout. Additionally, it allows changing the header background color, text color, header height and more.', 'total'); ?></p></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Elementor Widgets', 'total'); ?></span>
            <p><?php esc_html_e('Elementor provides you with unlimited possibilities to create the website of your imagination.', 'total'); ?></td>
        <td>10 Widgets</td>
        <td>45+ Widgets</td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Elementor Section Extenders', 'total'); ?></span>
            <p><?php esc_html_e('You can extend the Elementor section with amazing interactive extenders like Parallax Background , Parallax Animation, Colors Animation, Water Ripples, Particles Background, Background Effects & lot more.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Mega Menu', 'total'); ?></span>
            <p><?php esc_html_e('The Premium version has an inbuilt mega menu that will allow you to create beautiful big menus in no time.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Unlimited Blocks for Each Section', 'total'); ?></span>
            <p><?php esc_html_e('The premium version allows adding an unlimited block for all the sections on the front page. This include slider, featured block, highlight block, service, team, testimonial, counter, pricing, tabs, news and update block, logo. Moreover, it has the option to choose the number of columns to show in each row.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Maintenance Mode', 'total'); ?></span>
            <p><?php esc_html_e('The premium version has inbuilt option to add the Maintenance(underconstruction) Screen with countdown time. You don\'t need to install additional plugins', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Blog Layouts', 'total'); ?></span>
            <p><?php esc_html_e('The premium version gives the option to choose from 4 differently designed blog layout.', 'total'); ?></td>
        <td>1</td>
        <td>4</td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Advanced Typography Options', 'total'); ?></span>
            <p><?php esc_html_e('The premium version has 800+ Google Fonts to choose from. Don\'t want to use Google Font? No problem, it has web safe standard non-Google fonts to choose from as well.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Video Background, Image Motion Background, Gradient Background', 'total'); ?></span>
            <p><?php esc_html_e('The premium version has advanced background options that include an option to choose from a video background, moving background or gradient background.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Color Options', 'total'); ?></span>
            <p><?php esc_html_e('The free version has a basic color option but the premium version has advanced color options that allow customizing the color everywhere like header, post/page, footer, front page sections.', 'total'); ?></td>
        <td><?php esc_html_e('Basic', 'total'); ?></td>
        <td><?php esc_html_e('Advanced', 'total'); ?></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Home Section Reorder', 'total'); ?></span>
            <p><?php esc_html_e('Option to organize how the front page section appears.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Shape Divider', 'total'); ?></span>
            <p><?php esc_html_e('The theme has 16 shape divider that you can choose from to create a nice transition effect between sections', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Top Header Bar', 'total'); ?></span>
            <p><?php esc_html_e('Total Plus comes with an option for the top bar where you can add contact address, social icon, language picker or any informative texts.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Front Page Sections', 'total'); ?></span>
            <p><?php esc_html_e('Total Plus has additional 7 section added', 'total'); ?></td>
        <td>11</td>
        <td>18</td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Front Page Block Style Variations', 'total'); ?></span>
            <p><?php esc_html_e('Option to switch the style of the front page blocks. Featured block - 7 styles, HighLight Block - 4 styles, Service Block - 4 styles, Portfolio - 6 styles, Counter - 4 styles, Team - 6 styles, Testimonial - 4 styles, Pricing - 4 styles, News &amp; Update block - 3 styles, Tabs - 5 styles, Blog block - 4 styles, Client Logo - 4 styles.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('PreLoader Option', 'total'); ?></span>
            <p><?php esc_html_e('The loading screen that appears until the website is fully loaded. The premium version has the option to choose from 16 preloaders or add your own preloader image as well.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Sidebar Layout Options', 'total'); ?></span>
            <p><?php esc_html_e('The premium version has the option to change the sidebar layout universally or change the sidebar for individual post/page. Moreover, it allows choosing the sidebar widgets for individual post/page.', 'total'); ?></td>
        <td><?php esc_html_e('Basic', 'total'); ?></td>
        <td><?php esc_html_e('Advanced', 'total'); ?></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Website Layout (Fullwidth or Boxed)', 'total'); ?></span>
            <p><?php esc_html_e('The premium version has the option to change the website layout to be full width or boxed. Additionally, you can set the width of the website container.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Slider', 'total'); ?></span>
            <p><?php esc_html_e('The premium version has an option for the Simple slider, Revolution Slider and Single Banner Image with advanced customization options.', 'total'); ?></td>
        <td><?php esc_html_e('Basic', 'total'); ?></td>
        <td><?php esc_html_e('Advanced', 'total'); ?></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Advanced Blog Settings', 'total'); ?></span>
            <p><?php esc_html_e('The Premium version has advanced blog page setting option. The option allows to show or hide each element of the blog.', 'total'); ?></td>
        <td><?php esc_html_e('Basic', 'total'); ?></td>
        <td><?php esc_html_e('Advanced', 'total'); ?></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Advanced Footer Setting', 'total'); ?></span>
            <p><?php esc_html_e('The premium version has the option to choose from 5 different footer style and 11 footer columns layout.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Icon Picker', 'total'); ?></span>
            <p><?php esc_html_e('The premium theme has 4 icon pack included(Ico Font, FontAwesome, Essential Icon and Material Icon) and has the option to choose an icon by typing icon name.', 'total'); ?></td>
        <td><?php esc_html_e('Basic', 'total'); ?></td>
        <td><?php esc_html_e('Advanced', 'total'); ?></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Remove Footer Credit Text', 'total'); ?></span>
            <p><?php esc_html_e('The premium version easily allows to remove or change the footer credit text.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Front Page Sections with Full Window Height', 'total'); ?></span>
            <p><?php esc_html_e('A frontpage section that covers the full window despite having less content. It is useful for a one-page website.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Custom Widgets', 'total'); ?></span>
            <p><?php esc_html_e('With custom widget and Site origin page builder, you can play to create various website layout.', 'total'); ?></td>
        <td>0</td>
        <td>26</td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Blog Single Page - Author Box, Social Share and Related Post', 'total'); ?></span>
            <p><?php esc_html_e('Shows the short intro of the post author along with social icons, Major Social Share Icons without using a plugin and related posts by category.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Google Map Option', 'total'); ?></span>
            <p><?php esc_html_e('Shows the physical location with an interactive contact form.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('WooCommerce Compatible', 'total'); ?></span>
            <p><?php esc_html_e('The premium Version has enhanced WooCommerce options like adding cart icon in the menu, product page settings, sidebar layout settings and more.', 'total'); ?></td>
        <td><?php esc_html_e('Basic', 'total'); ?></td>
        <td><?php esc_html_e('Advanced', 'total'); ?></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('RTL Ready', 'total'); ?></span>
            <p><?php esc_html_e('The Premium Version is fully compatible with RTL (Right to left) languages like Arabic', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/no.png'); ?>" alt="No"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Multilingual Ready', 'total'); ?></span>
            <p><?php esc_html_e('The Premium Version is fully compatible with WPML and Poylang. Create the website in multiple languages.', 'total'); ?></td>
        <td><?php esc_html_e('Partially', 'total'); ?></td>
        <td><?php esc_html_e('Fully', 'total'); ?></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Translation Ready', 'total'); ?></span>
            <p><?php esc_html_e('Both free and pro version are fully translation ready.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Search Engine Optimization', 'total'); ?></span>
            <p><?php esc_html_e('Follows best SEO practices so that your website always rank higher in Search Engines.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Major Browser Compatible', 'total'); ?></span>
            <p><?php esc_html_e('The website shows good and runs smoothly in all major browsers.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Responsive - Mobile Friendly', 'total'); ?></span>
            <p><?php esc_html_e('Adapts to any screen size and display beautifully.', 'total'); ?></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Fast and Friendly Support', 'total'); ?></span>
            <p><?php esc_html_e('For Premium theme, the user will get a reply in 10 hours or less.', 'total'); ?></td>
        <td>-</td>
        <td><img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/yes.png'); ?>" alt="Yes"></td>
    </tr>
    <tr>
        <td>
            <span><?php esc_html_e('Upgrade to Pro', 'total'); ?></span>
            <p><?php esc_html_e('Upgrade to pro version for additional features and better supports.', 'total'); ?></p>
        </td>
        <td colspan="2">
            <a target="__blank" class="buy-pro-btn" href="https://hashthemes.com/wordpress-theme/total/?utm_source=wordpress&utm_medium=total-freevspro&utm_campaign=total-upgrade"><?php esc_html_e('Buy Now ($65 only)', 'total'); ?></a>
        </td>
    </tr>
</table>