<?php
namespace TotalTheme;

defined( 'ABSPATH' ) || exit;

/**
 * Registers ajax callbacks.
 *
 * @package TotalTheme
 * @version 5.4.5
 */
final class Register_AJAX_Callbacks {

	/**
	 * Hook into actions and filters.
	 */
	public function __construct() {

		// Load more pagination.
		add_action( 'wp_ajax_wpex_ajax_load_more', 'TotalTheme\Pagination\Load_More::get_posts' );
		add_action( 'wp_ajax_nopriv_wpex_ajax_load_more', 'TotalTheme\Pagination\Load_More::get_posts' );

	}

}