/* Modified for Total */

.hvr-grow{
    vertical-align:middle;
    transition-duration:.3s
}
.hvr-grow:active,.hvr-grow:focus,.hvr-grow:hover{
    transform:scale(1.1)
}
.hvr-shrink{
    vertical-align:middle;
    transition-duration:.3s
}
.hvr-shrink:active,.hvr-shrink:focus,.hvr-shrink:hover{
    transform:scale(.9)
}
@keyframes hvr-pulse{
    25%{
        transform:scale(1.1)
    }
    75%{
        transform:scale(.9)
    }
}
.hvr-pulse{
    vertical-align:middle;
}
.hvr-pulse:active,.hvr-pulse:focus,.hvr-pulse:hover{
    animation-name:hvr-pulse;
    animation-duration:1s;
    animation-timing-function:linear;
    animation-iteration-count:infinite
}
@keyframes hvr-pulse-grow{
    to{
        transform:scale(1.1)
    }
}
.hvr-pulse-grow{
    vertical-align:middle;
}
.hvr-pulse-grow:active,.hvr-pulse-grow:focus,.hvr-pulse-grow:hover{
    animation-name:hvr-pulse-grow;
    animation-duration:.3s;
    animation-timing-function:linear;
    animation-iteration-count:infinite;
    animation-direction:alternate
}
@keyframes hvr-pulse-shrink{
    to{
        transform:scale(.9)
    }
}
.hvr-pulse-shrink{
    vertical-align:middle;
}
.hvr-pulse-shrink:active,.hvr-pulse-shrink:focus,.hvr-pulse-shrink:hover{
    animation-name:hvr-pulse-shrink;
    animation-duration:.3s;
    animation-timing-function:linear;
    animation-iteration-count:infinite;
    animation-direction:alternate
}
@keyframes hvr-push{
    50%{
        transform:scale(.8)
    }
    100%{
        transform:scale(1)
    }
}
.hvr-push{
    vertical-align:middle;
}
.hvr-push:active,.hvr-push:focus,.hvr-push:hover{
    animation-name:hvr-push;
    animation-duration:.3s;
    animation-timing-function:linear;
    animation-iteration-count:1
}
@keyframes hvr-pop{
    50%{
        transform:scale(1.2)
    }
}
.hvr-pop{
    vertical-align:middle;
}
.hvr-pop:active,.hvr-pop:focus,.hvr-pop:hover{
    animation-name:hvr-pop;
    animation-duration:.3s;
    animation-timing-function:linear;
    animation-iteration-count:1
}
.hvr-bounce-in{
    vertical-align:middle;;
    transition-duration:.5s
}
.hvr-bounce-in:active,.hvr-bounce-in:focus,.hvr-bounce-in:hover{
    transform:scale(1.2);
    transition-timing-function:cubic-bezier(.47,2.02,.31,-.36)
}
.hvr-bounce-out{
    vertical-align:middle;;
    transition-duration:.5s
}
.hvr-bounce-out:active,.hvr-bounce-out:focus,.hvr-bounce-out:hover{
    transform:scale(.8);
    transition-timing-function:cubic-bezier(.47,2.02,.31,-.36)
}
.hvr-rotate{
    vertical-align:middle;;
    transition-duration:.3s
}
.hvr-rotate:active,.hvr-rotate:focus,.hvr-rotate:hover{
    transform:rotate(4deg)
}
.hvr-grow-rotate{
    vertical-align:middle;;
    transition-duration:.3s
}
.hvr-grow-rotate:active,.hvr-grow-rotate:focus,.hvr-grow-rotate:hover{
    transform:scale(1.1) rotate(4deg)
}
.hvr-float{
    vertical-align:middle;;
    transition-duration:.3s;
    transition-timing-function:ease-out
}
.hvr-float:active,.hvr-float:focus,.hvr-float:hover{
    transform:translateY(-8px)
}
.hvr-sink{
    vertical-align:middle;;
    transition-duration:.3s;
    transition-timing-function:ease-out
}
.hvr-sink:active,.hvr-sink:focus,.hvr-sink:hover{
    transform:translateY(8px)
}
@keyframes hvr-bob{
    0%{
        transform:translateY(-8px)
    }
    50%{
        transform:translateY(-4px)
    }
    100%{
        transform:translateY(-8px)
    }
}
@keyframes hvr-bob-float{
    100%{
        transform:translateY(-8px)
    }
}
.hvr-bob{
    vertical-align:middle;
}
.hvr-bob:active,.hvr-bob:focus,.hvr-bob:hover{
    animation-name:hvr-bob-float,hvr-bob;
    animation-duration:.3s,1.5s;
    animation-delay:0s,.3s;
    animation-timing-function:ease-out,ease-in-out;
    animation-iteration-count:1,infinite;
    animation-fill-mode:forwards;
    animation-direction:normal,alternate
}
@keyframes hvr-hang{
    0%{
        transform:translateY(8px)
    }
    50%{
        transform:translateY(4px)
    }
    100%{
        transform:translateY(8px)
    }
}
@keyframes hvr-hang-sink{
    100%{
        transform:translateY(8px)
    }
}
.hvr-hang{
    vertical-align:middle;
}
.hvr-hang:active,.hvr-hang:focus,.hvr-hang:hover{
    animation-name:hvr-hang-sink,hvr-hang;
    animation-duration:.3s,1.5s;
    animation-delay:0s,.3s;
    animation-timing-function:ease-out,ease-in-out;
    animation-iteration-count:1,infinite;
    animation-fill-mode:forwards;
    animation-direction:normal,alternate
}
.hvr-skew{
    vertical-align:middle;;
    transition-duration:.3s
}
.hvr-skew:active,.hvr-skew:focus,.hvr-skew:hover{
    transform:skew(-10deg)
}
.hvr-skew-forward{
    vertical-align:middle;;
    transition-duration:.3s;
    transform-origin:0 100%
}
.hvr-skew-forward:active,.hvr-skew-forward:focus,.hvr-skew-forward:hover{
    transform:skew(-10deg)
}
.hvr-skew-backward{
    vertical-align:middle;;
    transition-duration:.3s;
    transform-origin:0 100%
}
.hvr-skew-backward:active,.hvr-skew-backward:focus,.hvr-skew-backward:hover{
    transform:skew(10deg)
}
@keyframes hvr-wobble-vertical{
    16.65%{
        transform:translateY(8px)
    }
    33.3%{
        transform:translateY(-6px)
    }
    49.95%{
        transform:translateY(4px)
    }
    66.6%{
        transform:translateY(-2px)
    }
    83.25%{
        transform:translateY(1px)
    }
    100%{
        transform:translateY(0)
    }
}
.hvr-wobble-vertical{
    vertical-align:middle;
}
.hvr-wobble-vertical:active,.hvr-wobble-vertical:focus,.hvr-wobble-vertical:hover{
    animation-name:hvr-wobble-vertical;
    animation-duration:1s;
    animation-timing-function:ease-in-out;
    animation-iteration-count:1
}
@keyframes hvr-wobble-horizontal{
    16.65%{
        transform:translateX(8px)
    }
    33.3%{
        transform:translateX(-6px)
    }
    49.95%{
        transform:translateX(4px)
    }
    66.6%{
        transform:translateX(-2px)
    }
    83.25%{
        transform:translateX(1px)
    }
    100%{
        transform:translateX(0)
    }
}
.hvr-wobble-horizontal{
    vertical-align:middle;
}
.hvr-wobble-horizontal:active,.hvr-wobble-horizontal:focus,.hvr-wobble-horizontal:hover{
    animation-name:hvr-wobble-horizontal;
    animation-duration:1s;
    animation-timing-function:ease-in-out;
    animation-iteration-count:1
}
@keyframes hvr-wobble-to-bottom-right{
    16.65%{
        transform:translate(8px,8px)
    }
    33.3%{
        transform:translate(-6px,-6px)
    }
    49.95%{
        transform:translate(4px,4px)
    }
    66.6%{
        transform:translate(-2px,-2px)
    }
    83.25%{
        transform:translate(1px,1px)
    }
    100%{
        transform:translate(0,0)
    }
}
.hvr-wobble-to-bottom-right{
    vertical-align:middle;
}
.hvr-wobble-to-bottom-right:active,.hvr-wobble-to-bottom-right:focus,.hvr-wobble-to-bottom-right:hover{
    animation-name:hvr-wobble-to-bottom-right;
    animation-duration:1s;
    animation-timing-function:ease-in-out;
    animation-iteration-count:1
}
@keyframes hvr-wobble-to-top-right{
    16.65%{
        transform:translate(8px,-8px)
    }
    33.3%{
        transform:translate(-6px,6px)
    }
    49.95%{
        transform:translate(4px,-4px)
    }
    66.6%{
        transform:translate(-2px,2px)
    }
    83.25%{
        transform:translate(1px,-1px)
    }
    100%{
        transform:translate(0,0)
    }
}
.hvr-wobble-to-top-right{
    vertical-align:middle;
}
.hvr-wobble-to-top-right:active,.hvr-wobble-to-top-right:focus,.hvr-wobble-to-top-right:hover{
    animation-name:hvr-wobble-to-top-right;
    animation-duration:1s;
    animation-timing-function:ease-in-out;
    animation-iteration-count:1
}
@keyframes hvr-wobble-top{
    16.65%{
        transform:skew(-12deg)
    }
    33.3%{
        transform:skew(10deg)
    }
    49.95%{
        transform:skew(-6deg)
    }
    66.6%{
        transform:skew(4deg)
    }
    83.25%{
        transform:skew(-2deg)
    }
    100%{
        transform:skew(0)
    }
}
.hvr-wobble-top{
    vertical-align:middle;
    transform-origin:0 100%
}
.hvr-wobble-top:active,.hvr-wobble-top:focus,.hvr-wobble-top:hover{
    animation-name:hvr-wobble-top;
    animation-duration:1s;
    animation-timing-function:ease-in-out;
    animation-iteration-count:1
}
@keyframes hvr-wobble-bottom{
    16.65%{
        transform:skew(-12deg)
    }
    33.3%{
        transform:skew(10deg)
    }
    49.95%{
        transform:skew(-6deg)
    }
    66.6%{
        transform:skew(4deg)
    }
    83.25%{
        transform:skew(-2deg)
    }
    100%{
        transform:skew(0)
    }
}
.hvr-wobble-bottom{
    vertical-align:middle;
    transform-origin:100% 0
}
.hvr-wobble-bottom:active,.hvr-wobble-bottom:focus,.hvr-wobble-bottom:hover{
    animation-name:hvr-wobble-bottom;
    animation-duration:1s;
    animation-timing-function:ease-in-out;
    animation-iteration-count:1
}
@keyframes hvr-wobble-skew{
    16.65%{
        transform:skew(-12deg)
    }
    33.3%{
        transform:skew(10deg)
    }
    49.95%{
        transform:skew(-6deg)
    }
    66.6%{
        transform:skew(4deg)
    }
    83.25%{
        transform:skew(-2deg)
    }
    100%{
        transform:skew(0)
    }
}
.hvr-wobble-skew{
    vertical-align:middle;
}
.hvr-wobble-skew:active,.hvr-wobble-skew:focus,.hvr-wobble-skew:hover{
    animation-name:hvr-wobble-skew;
    animation-duration:1s;
    animation-timing-function:ease-in-out;
    animation-iteration-count:1
}
@keyframes hvr-buzz{
    50%{
        transform:translateX(3px) rotate(2deg)
    }
    100%{
        transform:translateX(-3px) rotate(-2deg)
    }
}
.hvr-buzz{
    vertical-align:middle;
}
.hvr-buzz:active,.hvr-buzz:focus,.hvr-buzz:hover{
    animation-name:hvr-buzz;
    animation-duration:.15s;
    animation-timing-function:linear;
    animation-iteration-count:infinite
}
@keyframes hvr-buzz-out{
    10%{
        transform:translateX(3px) rotate(2deg)
    }
    20%{
        transform:translateX(-3px) rotate(-2deg)
    }
    30%{
        transform:translateX(3px) rotate(2deg)
    }
    40%{
        transform:translateX(-3px) rotate(-2deg)
    }
    50%{
        transform:translateX(2px) rotate(1deg)
    }
    60%{
        transform:translateX(-2px) rotate(-1deg)
    }
    70%{
        transform:translateX(2px) rotate(1deg)
    }
    80%{
        transform:translateX(-2px) rotate(-1deg)
    }
    90%{
        transform:translateX(1px) rotate(0)
    }
    100%{
        transform:translateX(-1px) rotate(0)
    }
}
.hvr-buzz-out{
    vertical-align:middle;
}
.hvr-buzz-out:active,.hvr-buzz-out:focus,.hvr-buzz-out:hover{
    animation-name:hvr-buzz-out;
    animation-duration:.75s;
    animation-timing-function:linear;
    animation-iteration-count:1
}
.hvr-bounce-to-right{
    vertical-align:middle;;
    position:relative;
    transition-property:color;
    transition-duration:.5s
}
.hvr-bounce-to-right:before{
    content:"";
    position:absolute;
    z-index:-1;
    top:0;
    left:0;
    right:0;
    bottom:0;
    background:#2098d1;
    transform:scaleX(0);
    transform-origin:0 50%;
    transition-duration:.5s;
    transition-timing-function:ease-out
}
.hvr-bounce-to-right:active,.hvr-bounce-to-right:focus,.hvr-bounce-to-right:hover{
    color:#fff
}
.hvr-bounce-to-right:active:before,.hvr-bounce-to-right:focus:before,.hvr-bounce-to-right:hover:before{
    transform:scaleX(1);
    transition-timing-function:cubic-bezier(.52,1.64,.37,.66)
}
.hvr-bounce-to-left{
    vertical-align:middle;;
    position:relative;
    transition-property:color;
    transition-duration:.5s
}
.hvr-bounce-to-left:before{
    content:"";
    position:absolute;
    z-index:-1;
    top:0;
    left:0;
    right:0;
    bottom:0;
    background:#2098d1;
    transform:scaleX(0);
    transform-origin:100% 50%;
    transition-duration:.5s;
    transition-timing-function:ease-out
}
.hvr-bounce-to-left:active,.hvr-bounce-to-left:focus,.hvr-bounce-to-left:hover{
    color:#fff
}
.hvr-bounce-to-left:active:before,.hvr-bounce-to-left:focus:before,.hvr-bounce-to-left:hover:before{
    transform:scaleX(1);
    transition-timing-function:cubic-bezier(.52,1.64,.37,.66)
}
.hvr-bounce-to-bottom{
    vertical-align:middle;;
    position:relative;
    transition-property:color;
    transition-duration:.5s
}
.hvr-bounce-to-bottom:before{
    content:"";
    position:absolute;
    z-index:-1;
    top:0;
    left:0;
    right:0;
    bottom:0;
    background:#2098d1;
    transform:scaleY(0);
    transform-origin:50% 0;
    transition-duration:.5s;
    transition-timing-function:ease-out
}
.hvr-bounce-to-bottom:active,.hvr-bounce-to-bottom:focus,.hvr-bounce-to-bottom:hover{
    color:#fff
}
.hvr-bounce-to-bottom:active:before,.hvr-bounce-to-bottom:focus:before,.hvr-bounce-to-bottom:hover:before{
    transform:scaleY(1);
    transition-timing-function:cubic-bezier(.52,1.64,.37,.66)
}
.hvr-bounce-to-top{
    vertical-align:middle;;
    position:relative;
    transition-property:color;
    transition-duration:.5s
}
.hvr-bounce-to-top:before{
    content:"";
    position:absolute;
    z-index:-1;
    top:0;
    left:0;
    right:0;
    bottom:0;
    background:#2098d1;
    transform:scaleY(0);
    transform-origin:50% 100%;
    transition-duration:.5s;
    transition-timing-function:ease-out
}
.hvr-bounce-to-top:active,.hvr-bounce-to-top:focus,.hvr-bounce-to-top:hover{
    color:#fff
}
.hvr-bounce-to-top:active:before,.hvr-bounce-to-top:focus:before,.hvr-bounce-to-top:hover:before{
    transform:scaleY(1);
    transition-timing-function:cubic-bezier(.52,1.64,.37,.66)
}
.hvr-radial-out{
    vertical-align:middle;;
    position:relative;
    overflow:hidden;
    background:#e1e1e1;
    transition-property:color;
    transition-duration:.3s
}
.hvr-radial-out:before{
    content:"";
    position:absolute;
    z-index:-1;
    top:0;
    left:0;
    right:0;
    bottom:0;
    background:#2098d1;
    border-radius:100%;
    transform:scale(0);
    transition-duration:.3s;
    transition-timing-function:ease-out
}
.hvr-radial-out:active,.hvr-radial-out:focus,.hvr-radial-out:hover{
    color:#fff
}
.hvr-radial-out:active:before,.hvr-radial-out:focus:before,.hvr-radial-out:hover:before{
    transform:scale(2)
}
.hvr-radial-in{
    vertical-align:middle;;
    position:relative;
    overflow:hidden;
    background:#2098d1;
    transition-property:color;
    transition-duration:.3s
}
.hvr-radial-in:before{
    content:"";
    position:absolute;
    z-index:-1;
    top:0;
    left:0;
    right:0;
    bottom:0;
    background:#e1e1e1;
    border-radius:100%;
    transform:scale(2);
    transition-duration:.3s;
    transition-timing-function:ease-out
}
.hvr-radial-in:active,.hvr-radial-in:focus,.hvr-radial-in:hover{
    color:#fff
}
.hvr-radial-in:active:before,.hvr-radial-in:focus:before,.hvr-radial-in:hover:before{
    transform:scale(0)
}
.hvr-glow{
    vertical-align:middle;;
    transition-duration:.3s;
    transition-property:box-shadow
}
.hvr-glow:active,.hvr-glow:focus,.hvr-glow:hover{
    box-shadow:0 0 8px rgba(0,0,0,.6)
}
.hvr-shadow{
    vertical-align:middle;;
    transition-duration:.3s;
    transition-property:box-shadow
}
.hvr-shadow:active,.hvr-shadow:focus,.hvr-shadow:hover{
    box-shadow:0 10px 10px -10px rgba(0,0,0,.5)
}
.hvr-grow-shadow{
    vertical-align:middle;;
    transition-duration:.3s
}
.hvr-grow-shadow:active,.hvr-grow-shadow:focus,.hvr-grow-shadow:hover{
    box-shadow:0 10px 10px -10px rgba(0,0,0,.25);
    transform:scale(1.1)
}
.hvr-box-shadow-outset{
    vertical-align:middle;;
    transition-duration:.3s;
    transition-property:box-shadow
}
.hvr-box-shadow-outset:active,.hvr-box-shadow-outset:focus,.hvr-box-shadow-outset:hover{
    box-shadow:2px 2px 2px rgba(0,0,0,.6)
}
.hvr-box-shadow-inset{
    vertical-align:middle;;
    transition-duration:.3s;
    transition-property:box-shadow;
    box-shadow:inset 0 0 0 rgba(0,0,0,.6),0 0 1px transparent
}
.hvr-box-shadow-inset:active,.hvr-box-shadow-inset:focus,.hvr-box-shadow-inset:hover{
    box-shadow:inset 2px 2px 2px rgba(0,0,0,.6),0 0 1px transparent
}
.hvr-float-shadow{
    vertical-align:middle;;
    position:relative;
    transition-duration:.3s
}
.hvr-float-shadow:before{
    pointer-events:none;
    position:absolute;
    z-index:-1;
    content:'';
    top:100%;
    left:5%;
    height:10px;
    width:90%;
    opacity:0;
    background:radial-gradient(ellipse at center,rgba(0,0,0,.35) 0,rgba(0,0,0,0) 80%);
    transition-duration:.3s;
    transition-property:transform,opacity
}
.hvr-float-shadow:active,.hvr-float-shadow:focus,.hvr-float-shadow:hover{
    transform:translateY(-5px)
}
.hvr-float-shadow:active:before,.hvr-float-shadow:focus:before,.hvr-float-shadow:hover:before{
    opacity:1;
    transform:translateY(5px)
}
.hvr-shadow-radial{
    vertical-align:middle;;
    position:relative
}
.hvr-shadow-radial:after,.hvr-shadow-radial:before{
    pointer-events:none;
    position:absolute;
    content:'';
    left:0;
    width:100%;
    box-sizing:border-box;
    background-repeat:no-repeat;
    height:5px;
    opacity:0;
    transition-duration:.3s;
    transition-property:opacity
}
.hvr-shadow-radial:before{
    bottom:100%;
    background:radial-gradient(ellipse at 50% 150%,rgba(0,0,0,.6) 0,rgba(0,0,0,0) 80%)
}
.hvr-shadow-radial:after{
    top:100%;
    background:radial-gradient(ellipse at 50% -50%,rgba(0,0,0,.6) 0,rgba(0,0,0,0) 80%)
}
.hvr-shadow-radial:active:after,.hvr-shadow-radial:active:before,.hvr-shadow-radial:focus:after,.hvr-shadow-radial:focus:before,.hvr-shadow-radial:hover:after,.hvr-shadow-radial:hover:before{
    opacity:1
}