<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Rating.
$html .= $this->get_star_rating( array(
	'class' => 'wpex-text-md wpex-text-accent',
) );

// Title.
$html .= $this->get_title( array(
	'link' => false,
	'class' => 'wpex-heading wpex-text-md wpex-font-semibold wpex-my-5',
) );

// Excerpt.
$html .= $this->get_excerpt( array(
	'length' => '-1',
	'class' => 'wpex-italic',
) );

return $html;