<?php
defined( 'ABSPATH' ) || exit;

$this->sections['wpex_tables'] = array(
	'title' => esc_html__( 'Tables', 'total' ),
	'panel' => 'wpex_global_styles',
	'settings' => array(
		array(
			'id' => 'thead_background',
			'transport' => 'postMessage',
			'control' => array(
				'type' => 'color',
				'label' => esc_html__( 'Table Header Background', 'total' ),
			),
			'inline_css' => array(
				'target' => ':root',
				'alter' => '--wpex-table-thead-bg',
			),
		),
		array(
			'id' => 'thead_color',
			'transport' => 'postMessage',
			'control' => array(
				'type' => 'color',
				'label' => esc_html__( 'Table Header Color', 'total' ),
			),
			'inline_css' => array(
				'target' => ':root',
				'alter' => '--wpex-table-thead-color',
			),
		),
		array(
			'id' => 'tables_th_color',
			'transport' => 'postMessage',
			'control' => array(
				'type' => 'color',
				'label' => esc_html__( 'Th Color', 'total' ),
			),
			'inline_css' => array(
				'target' => ':root',
				'alter' => '--wpex-table-th-color',
			),
		),
		array(
			'id' => 'tables_border_color',
			'transport' => 'postMessage',
			'control' => array(
				'type' => 'color',
				'label' => esc_html__( 'Cells Border Color', 'total' ),
			),
			'inline_css' => array(
				'target' => ':root',
				'alter' => '--wpex-table-cell-border-color',
			),
		),
		array(
			'id' => 'tables_cell_padding',
			'transport' => 'postMessage',
			'control' => array(
				'type' => 'wpex_trbl',
				'shorthand' => true,
				'label' => esc_html__( 'Cell Padding', 'total' ),
			),
			'inline_css' => array(
				'target' => ':root',
				'alter' => '--wpex-table-cell-padding',
			),
		),
	),
);