<?php
namespace TotalTheme\Customizer\Controls;

use WP_Customize_Control;

defined( 'ABSPATH' ) || exit;

/**
 * Customizer Notice Control.
 *
 * @package TotalTheme
 * @subpackage Customizer
 * @version 5.5
 */

class Notice extends WP_Customize_Control {

	/**
	 * The control type.
	 */
	public $type = 'wpex_notice';

	/**
	 * Don't render the control content from PHP, as it's rendered via JS on load.
	 */
	public function render_content() {}

	/**
	 * The control template.
	 */
	public function content_template() {
		?>

		<# if ( data.description ) { #>
			<div class="wpex-customizer-notice">{{ data.description }}</div>
		<# } #>

	<?php }

}