<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Video
$html .= $this->get_video( array(
	'class' => 'wpex-mb-15',
) );

// Title
$html .= $this->get_title( array(
	'class'      => 'wpex-heading wpex-text-md',
	'link_class' => 'wpex-inherit-color-important wpex-hover-underline',
) );

// Terms
$html .= $this->get_terms_list( array(
	'class'      => 'wpex-text-1',
	'separator'  => ' &middot; ',
	'term_class' => 'wpex-inherit-color',
) );

return $html;