<?php
defined( 'ABSPATH' ) || exit;

$templates['call-to-action-1'] = array();
$templates['call-to-action-1']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 1';
$templates['call-to-action-1']['category'] = 'call-to-action';
$templates['call-to-action-1']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627246841767{padding-top: 65px !important;padding-bottom: 65px !important;background-color: #f7f7f7 !important;}"][vc_column][vcex_heading text="Limited Time Offer" color="accent" text_align="center" font_weight="semibold" text_transform="uppercase" font_size="1em" letter_spacing=".5px"][vcex_spacing size="5px"][vcex_heading text="What are you waiting for?`{`br`}`Get Started Today!" color="#222222" text_align="center" tag="h2" font_size="d:35px|pl:25px" font_weight="bold"][vcex_spacing size="25px"][vcex_button align="center" color="black" border_radius="0px" border="0px" font_padding="top:15px|right:25px|bottom:15px|left:25px" font_weight="bold" text_transform="uppercase" letter_spacing="1px" font_size=".9em" custom_hover_background="accent"]Create Account[/vcex_button][/vc_column][/vc_row]
CONTENT;

$templates['call-to-action-2'] = array();
$templates['call-to-action-2']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 2';
$templates['call-to-action-2']['category'] = 'call-to-action';
$templates['call-to-action-2']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" remove_bottom_col_margin="true" css=".vc_custom_1626756519381{padding-top: 50px !important;padding-bottom: 50px !important;background-color: #f7f7f7 !important;}"][vc_column][vcex_flex_container align_items="center" justify_content="space-between" flex_wrap="true" flex_direction="row"][vcex_heading text="Sign up today for a free 1 month trial.`{`br`}`Cancel at anytime." color="#222222" tag="h2" font_size="24px" font_weight="bold"][vcex_button layout="block" align="center" color="black" border_radius="0px" border="0px" font_padding="top:15px|right:25px|bottom:15px|left:25px" font_weight="bold" text_transform="uppercase" letter_spacing="1px" font_size=".9em" custom_hover_background="accent"]Create Account[/vcex_button][/vcex_flex_container][/vc_column][/vc_row]
CONTENT;

$templates['call-to-action-3'] = array();
$templates['call-to-action-3']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 3';
$templates['call-to-action-3']['category'] = 'call-to-action';
$templates['call-to-action-3']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" remove_bottom_col_margin="true" css=".vc_custom_1626757548607{padding-top: 60px !important;padding-bottom: 60px !important;background-color: #f7f7f7 !important;}"][vc_column][vcex_spacing size="15px"][vcex_heading text="Ready to Grow Your Business?" align="center" color="#222222" text_align="center" tag="h2" font_size="d:55px|pl:35px" font_weight="bold" width="700px" line_height="120%"][vcex_spacing size="20px"][vc_column_text width="500px" align="center" text_align="center" font_size="16px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vcex_spacing][vcex_button align="center" border_radius="4px" border="0px" font_padding="top:12px|right:25px|bottom:12px|left:25px" font_weight="bold" text_transform="uppercase" letter_spacing="1px" font_size=".92em"]Get Started[/vcex_button][/vc_column][/vc_row]
CONTENT;

$templates['call-to-action-4'] = array();
$templates['call-to-action-4']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 4';
$templates['call-to-action-4']['category'] = 'call-to-action';
$templates['call-to-action-4']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" remove_bottom_col_margin="true" css=".vc_custom_1626827015757{padding-top: 60px !important;padding-bottom: 60px !important;}" el_class="wpex-bg-accent"][vc_column][vcex_flex_container align_items="center" justify_content="space-between" flex_wrap="true" flex_direction="row"][vcex_heading text="Take Your Business to the Next Level.`{`br`}`Set up your free online consultation today." color="#ffffff" tag="div" font_size="24px" font_weight="semibold" font_family="Merriweather"][vcex_button color="white" border_radius="0px" border="0px" font_padding="top:12px|right:25px|bottom:12px|left:25px" font_weight="bold" text_transform="uppercase" letter_spacing=".5px" font_size="1em" icon_right="ticon ticon-chevron-right" icon_right_transform="5px"]Get Started[/vcex_button][/vcex_flex_container][/vc_column][/vc_row]
CONTENT;

$templates['call-to-action-5'] = array();
$templates['call-to-action-5']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 5';
$templates['call-to-action-5']['category'] = 'call-to-action';
$templates['call-to-action-5']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" remove_bottom_col_margin="true" css=".vc_custom_1626757548607{padding-top: 60px !important;padding-bottom: 60px !important;background-color: #f7f7f7 !important;}"][vc_column][vc_column_text text_align="center" text_transform="uppercase" letter_spacing="1px" font_size=".9em" font_weight="500"]What are you waiting for?[/vc_column_text][vcex_spacing size="5px"][vcex_heading text="Contact Us For A Free Consultation" align="center" color="#222222" text_align="center" tag="h2" font_size="d:50px|pl:35px" font_weight="bold" width="700px" line_height="125%"][vcex_spacing size="25px"][vcex_button align="center" border_radius="9999px" font_padding="top:14px|right:24px|bottom:14px|left:24px" font_weight="bold" text_transform="uppercase" letter_spacing="1px" font_size="12px" icon_right="ticon ticon-chevron-right" style="outline" border="2px solid currentColor" icon_right_transform="5px"]Contact us[/vcex_button][/vc_column][/vc_row]
CONTENT;

$templates['call-to-action-6'] = array();
$templates['call-to-action-6']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 6';
$templates['call-to-action-6']['category'] = 'call-to-action';
$templates['call-to-action-6']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627246784853{padding-top: 60px !important;padding-right: 60px !important;padding-bottom: 60px !important;padding-left: 60px !important;background-color: #222222 !important;border-radius: 10px !important;}"][vc_column][vcex_heading text="Activate Your Code Today!" color="#ffffff" text_align="center" tag="h2" font_size="d:40px|pl:35px" font_weight="bold" line_height="125%"][vcex_spacing size="20px"][vc_column_text text_align="center" width="600px" align="center" color="rgba(255,255,255,0.6)"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci.[/vc_column_text][vcex_spacing][vcex_button align="center" font_padding="top:12px|right:25px|bottom:12px|left:25px" text_transform="uppercase" letter_spacing="1px" icon_right="ticon ticon-chevron-right" style="three-d" font_weight="bold"]Get Started[/vcex_button][/vc_column][/vc_row]
CONTENT;

$templates['call-to-action-7'] = array();
$templates['call-to-action-7']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 7';
$templates['call-to-action-7']['category'] = 'call-to-action';
$templates['call-to-action-7']['content'] = <<<CONTENT
[vc_section css=".vc_custom_1631658159039{padding-top: 60px !important;padding-bottom: 60px !important;}"][vc_row content_placement="middle"][vc_column width="1/2"][vcex_heading text="Try Product X for a limited time 100% FREE. Enjoy!" font_weight="800" font_size="2.4em"][/vc_column][vc_column width="1/2"][vc_column_text]With product X you can reach new levels of success, take on any challenge and beat your competition. It's time to take action now and register.[/vc_column_text][/vc_column][/vc_row][vc_row remove_bottom_col_margin="true" el_class="wpex-md-text-center"][vc_column][vcex_button font_padding="top:15px|right:50px|bottom:15px|left:50px" font_weight="bold" font_size="1em"]Get Started[/vcex_button][vcex_spacing size="10px"][vc_column_text font_size=".8em"]Hurry! Offer expires in 30 days.[/vc_column_text][/vc_column][/vc_row][/vc_section]
CONTENT;

$templates['call-to-action-8'] = array();
$templates['call-to-action-8']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 8';
$templates['call-to-action-8']['category'] = 'call-to-action';
$templates['call-to-action-8']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1631659582678{padding-top: 60px !important;padding-bottom: 60px !important;}"][vc_column][vcex_flex_container align_items="center" justify_content="space-between" row_stack_bp="md" flex_direction="row" gap="60px" row_stack_gap="25px"][vcex_heading text="We are the best in the industry" font_weight="800" font_size="2.4em"][vc_column_text]With product X you can reach new levels of success, take on any challenge and beat your competition. It's time to take action now and register.[/vc_column_text][vcex_button font_padding="top:15px|right:50px|bottom:15px|left:50px" font_weight="bold" font_size="1em" width="200px" classes="wpex-flex-shrink-0"]Click Here[/vcex_button][/vcex_flex_container][/vc_column][/vc_row]
CONTENT;

$templates['call-to-action-9'] = array();
$templates['call-to-action-9']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 9';
$templates['call-to-action-9']['category'] = 'call-to-action';
$templates['call-to-action-9']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1631659582678{padding-top: 60px !important;padding-bottom: 60px !important;}"][vc_column][vc_column_text font_size=".9em" text_transform="uppercase" letter_spacing=".5px" font_weight="500"]Why Total?[/vc_column_text][vcex_spacing size="10px"][vcex_heading text="Learn more about our product features and how you can use it to increase your productivity by up to 500% via our explainer video." font_weight="800" font_size="2.4em" tag="h3"][vcex_spacing size="25px"][vcex_flex_container justify_content="start" flex_direction="row"][vcex_icon_box heading="Video - 40 seconds" icon_spacing="10px" align_center="true" icon_type="material" url_wrap="true" onclick="lightbox_video" heading_bottom_margin="0px" border_radius="9999px" css=".vc_custom_1631730255077{border-top-width: 1px !important;border-right-width: 1px !important;border-bottom-width: 1px !important;border-left-width: 1px !important;padding-top: 10px !important;padding-right: 16px !important;padding-bottom: 10px !important;padding-left: 10px !important;border-left-color: #ededed !important;border-left-style: solid !important;border-right-color: #ededed !important;border-right-style: solid !important;border-top-color: #ededed !important;border-top-style: solid !important;border-bottom-color: #ededed !important;border-bottom-style: solid !important;}" icon_background="accent" icon_color="#ffffff" icon_size="26px" icon_border_radius="9999px" icon_width="45px" icon_height="45px" heading_weight="normal" onclick_url="https://www.youtube.com/watch?v=UKI93s1yVDo" hover_background="#f9f9f9" icon_material="vc-material vc-material-play_arrow"][/vcex_icon_box][/vcex_flex_container][/vc_column][/vc_row]
CONTENT;

$templates['call-to-action-10'] = array();
$templates['call-to-action-10']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 10';
$templates['call-to-action-10']['category'] = 'call-to-action';
$templates['call-to-action-10']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1631659582678{padding-top: 60px !important;padding-bottom: 60px !important;}"][vc_column][vc_column_text letter_spacing=".5px"]Trendsetting design[/vc_column_text][vcex_spacing size="10px"][vcex_flex_container align_items="center" justify_content="space-between" row_stack_bp="sm" flex_direction="row" gap="80px" row_stack_gap="20px"][vcex_heading text="Everything you need right at your finger tips, don't look any further. Get started with Product X today." font_weight="800" font_size="2.4em" tag="h3"][vcex_icon icon_type="material" icon_material="vc-material vc-material-arrow_forward" background="accent" color="#ffffff" border_radius="9999px" width="50px" height="50px" custom_size="24px" link_url="url:%23" hover_animation="grow-shadow"][/vcex_flex_container][/vc_column][/vc_row]
CONTENT;

$templates['call-to-action-11'] = array();
$templates['call-to-action-11']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 11';
$templates['call-to-action-11']['category'] = 'call-to-action';
$templates['call-to-action-11']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1631663637441{padding-top: 10% !important;padding-bottom: 10% !important;background-color: #222222 !important;}"][vc_column][vcex_spacing size="10px"][vcex_heading text="Ready to start sharing videos online? Download the Total App" align="center" color="#ffffff" text_align="center" tag="h3" font_size="d:40px|pl:30px" font_weight="normal" width="700px"][vcex_spacing size="40px"][vcex_flex_container align_items="center" justify_content="center" flex_wrap="true" flex_direction="row" gap="10px"][vcex_icon_box heading="Available on the" icon_spacing="15px" align_center="true" icon="ticon ticon-apple" url_wrap="true" onclick="custom_link" heading_color="#ffffff" font_color="#ffffff" heading_size="8px" font_size="18px" onclick_url="https://www.apple.com/app-store/" heading_bottom_margin="0px" icon_color="#ffffff" heading_line_height="1" font_weight="normal" background_color="#e7612b" css=".vc_custom_1631664693675{padding-top: 15px !important;padding-right: 35px !important;padding-bottom: 15px !important;padding-left: 35px !important;}" border_radius="9999px" hover_background="#e96c3a"]App Store[/vcex_icon_box][vcex_icon_box heading="Get it on" icon_spacing="15px" align_center="true" icon="ticon ticon-play" url_wrap="true" onclick="custom_link" heading_color="#ffffff" font_color="#ffffff" heading_size="8px" font_size="18px" onclick_url="https://play.google.com/store" heading_bottom_margin="0px" icon_color="#ffffff" heading_line_height="1" font_weight="normal" background_color="#e7612b" css=".vc_custom_1631664699647{padding-top: 15px !important;padding-right: 35px !important;padding-bottom: 15px !important;padding-left: 35px !important;}" border_radius="9999px" hover_background="#e96c3a"]Google Play[/vcex_icon_box][/vcex_flex_container][/vc_column][/vc_row]
CONTENT;

$templates['call-to-action-12'] = array();
$templates['call-to-action-12']['name'] = esc_html__( 'Call to Action', 'total' ) . ' 12';
$templates['call-to-action-12']['category'] = 'call-to-action';
$templates['call-to-action-12']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1632872254249{padding-top: 50px !important;padding-bottom: 50px !important;}"][vc_column][vcex_heading text="Complete Framework" font_weight="800" font_size="3em" text_align="center"][vcex_spacing][vc_column_text width="700px" align="center" text_align="center" font_size="16px"]With product X you can reach new levels of success, take on any challenge and beat your competition. It's time to take action now and register.[/vc_column_text][vcex_spacing size="40px"][vcex_flex_container justify_content="center" flex_wrap="true" flex_direction="row" gap="25px"][vcex_button font_padding="top:15px|right:35px|bottom:15px|left:35px" font_weight="bold" font_size="1em" style="minimal-border" border="2px solid #eee" border_radius="3px" custom_color="#222222" custom_hover_background="#f9f9f9"]Learn More[/vcex_button][vcex_button font_padding="top:15px|right:35px|bottom:15px|left:35px" font_weight="bold" font_size="1em"]Get Started[/vcex_button][/vcex_flex_container][/vc_column][/vc_row]
CONTENT;
// IMPORTANT - Space required to prevent HEREDOC errors.
?>