.wpex_gallery_images .details.attachment{box-shadow:none;-moz-box-shadow:none;-webkit-box-shadow:none}.wpex_gallery_images .image>div{width:75px;height:75px;box-shadow:none;-moz-box-shadow:none;-webkit-box-shadow:none}.wpex_gallery_images .attachment-preview{position:relative}.wpex_gallery_images .attachment-preview .thumbnail{cursor:move}.wpex_gallery_images .wpex-metabox-sortable-placeholder{width:75px;height:75px;border:4px dashed #ddd;background:#f7f7f7;box-sizing:border-box}.wpex_gallery_images .wpex-gmb-remove{position:absolute;top:-8px;right:-8px;padding:2px;display:none;height:1em;width:1em;text-indent:-9999px;font-size:1.4em}.wpex_gallery_images .wpex-gmb-remove::before{font-family:Dashicons;speak:none;font-weight:400;text-transform:none;-webkit-font-smoothing:antialiased;text-indent:0px;position:absolute;top:0px;left:0px;text-align:center;content:"";color:#999;height:1em;width:1em;line-height:1em;font-variant:normal;margin:0px;background:#fff;border-radius:50%}.wpex_gallery_images .wpex-gmb-remove:hover::before{color:#a00}body.rtl .wpex_gallery_images .wpex-gmb-remove{right:auto;right:-8px}.wpex_gallery_images .image div:hover .wpex-gmb-remove{display:block}.wpex_gallery_images>li{float:left;cursor:move;margin:9px 9px 0 0;border:1px solid #d5d5d5;width:75px;height:75px;border-radius:2px;box-sizing:border-box}body.rtl .wpex_gallery_images>li{float:right;margin:9px 0 0 9px}.wpex_gallery_images li.image img{width:75px;height:75px}.wpex_gallery_images .attachment-preview:before{display:none !important}.wpex_gallery_images:after,#wpex_gallery_images_container:after{content:"";display:block;height:0;clear:both;visibility:hidden;zoom:1}#wpex_gallery_images_container ul{margin:0 0 9px !important}
