<div class="support-wrap">
    <div class="support-col">
        <h3><?php echo esc_html__('Documentation', 'total'); ?></h3>
        <p><?php
            printf(
                    /* translators: Theme Name */
                    esc_html__('Read the detailed documentation of the theme. The documentation contains all the necessary information required to set up the %s theme.', 'total'), esc_html($this->theme_name));
            ?></p>
        <a class="button button-primary" target="_blank" href="https://hashthemes.com/documentation/total-documentation/"><?php echo esc_html__('Read Full Documentation', 'total'); ?></a>
    </div>

    <div class="support-col">
        <h3><?php echo esc_html__('Create Support Tickets', 'total'); ?></h3>
        <p><?php echo esc_html__('Still, having problems after reading all the documentation? No Problem!! Please create a support ticket. Our dedicated support team will help you to solve your problem.', 'total'); ?></p>
        <a class="button button-primary" target="_blank" href="https://hashthemes.com/support/forum/total/"><?php echo esc_html__('Create Support Tickets', 'total'); ?></a>
    </div>
</div>