<?php
defined( 'ABSPATH' ) || exit;

$templates['contact-1'] = array();
$templates['contact-1']['name'] = esc_html__( 'Contact', 'total' ) . ' 1';
$templates['contact-1']['category'] = 'contact';
$templates['contact-1']['content'] = <<<CONTENT
[vc_row content_placement="middle" column_spacing="50" css=".vc_custom_1627255337214{margin-top: 40px !important;}"][vc_column width="1/2"][vc_gmaps][/vc_column][vc_column width="1/2"][vcex_heading text="Feel free to contact us for any inquiry, we will get back to you asap." bottom_margin="30px" font_size="25px" font_weight="bold" tag="h2"][vc_column_text font_size="1.23em"]Storey Ave, San Francisco, CA 94129
<strong>Email:</strong> email@example.com
<strong>Phone:</strong> 202-555-0119[/vc_column_text][vcex_spacing][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="10px" style="flat-color-round" size="16px" width="35px" height="35px"][/vc_column][/vc_row]
CONTENT;

$templates['contact-2'] = array();
$templates['contact-2']['name'] = esc_html__( 'Contact', 'total' ) . ' 2';
$templates['contact-2']['category'] = 'contact';
$templates['contact-2']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627255795152{padding-top: 80px !important;padding-bottom: 80px !important;background-color: #222222 !important;}"][vc_column][vcex_flex_container align_items="center" justify_content="space-between" flex_grow="true" flex_wrap="true" flex_direction="row" gap="40px"][vcex_icon_box heading="Office Location" icon="ticon ticon-map-marker" heading_size="1.4em" heading_color="#ffffff" icon_color="#ffffff" icon_size="40px" font_color="rgba(255,255,255,0.6)" font_size="1.2em" heading_bottom_margin="0px"]Storey Ave, San Francisco, CA 94129[/vcex_icon_box][vcex_icon_box heading="Phone Number" icon="ticon ticon-phone" heading_size="1.4em" heading_color="#ffffff" icon_color="#ffffff" icon_size="40px" font_color="rgba(255,255,255,0.6)" font_size="1.2em" heading_bottom_margin="0px"]1-800-202-555-0119[/vcex_icon_box][vcex_icon_box heading="Send a Message" icon="ticon ticon-envelope-o" heading_size="1.4em" heading_color="#ffffff" icon_color="#ffffff" icon_size="40px" font_color="rgba(255,255,255,0.6)" font_size="1.2em" heading_bottom_margin="0px"]email@example.com[/vcex_icon_box][/vcex_flex_container][/vc_column][/vc_row]
CONTENT;

$templates['contact-3'] = array();
$templates['contact-3']['name'] = esc_html__( 'Contact', 'total' ) . ' 3';
$templates['contact-3']['category'] = 'contact';
$templates['contact-3']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" column_spacing="50" css=".vc_custom_1627256276848{padding-top: 60px !important;padding-bottom: 20px !important;background-color: #f7f7f7 !important;}"][vc_column width="1/2"][vcex_heading text="Feel free to contact us for any inquiry, we will get back to you asap." bottom_margin="30px" font_size="25px" font_weight="bold" tag="h2"][vc_column_text font_size="1.23em"]Storey Ave, San Francisco, CA 94129
<strong>Email:</strong> email@example.com
<strong>Phone:</strong> 202-555-0119[/vc_column_text][vcex_spacing][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="10px" style="flat-color-round" size="16px" width="35px" height="35px"][/vc_column][vc_column width="1/2"][vcex_contact_form enable_placeholders="true" stack_fields="true" enable_privacy_check="false" enable_required_label="false" shadow="shadow-lg" css=".vc_custom_1627256627959{padding-top: 40px !important;padding-right: 40px !important;padding-bottom: 40px !important;padding-left: 40px !important;background-color: #ffffff !important;border-radius: 10px !important;}" button_text="Send message"][/vc_column][/vc_row]
CONTENT;

$templates['contact-4'] = array();
$templates['contact-4']['name'] = esc_html__( 'Contact', 'total' ) . ' 4';
$templates['contact-4']['category'] = 'contact';
$templates['contact-4']['content'] = <<<CONTENT
[vc_row content_placement="middle"][vc_column width="1/2"][vcex_heading text="Contact us" bottom_margin="20px" font_size="30px" font_weight="bold"][vc_column_text]Feel free to send us a message, give us a call or stop by and say hi. Our group of friendly staff is here to help.[/vc_column_text][vcex_spacing size="40px"][vcex_icon_box heading="Office Location" icon="ticon ticon-map-marker" heading_size="1.2em" heading_bottom_margin="0px" icon_size="20px" icon_color="#454545" icon_background="#fdecb9" icon_border_radius="50%" icon_width="45px" icon_height="45px"]Storey Ave, San Francisco, CA 94129[/vcex_icon_box][vcex_spacing][vcex_icon_box heading="Phone Number" icon="ticon ticon-phone" heading_size="1.2em" icon_size="20px" heading_bottom_margin="0px" icon_width="45px" icon_height="45px" icon_background="#fdecb9" icon_border_radius="50%" icon_color="#424242"]1-800-202-555-0119[/vcex_icon_box][vcex_spacing][vcex_icon_box heading="Send a Message" icon="ticon ticon-envelope" heading_size="1.2em" icon_size="20px" heading_bottom_margin="0px" icon_color="#454545" icon_background="#fdecb9" icon_border_radius="50%" icon_width="45px" icon_height="45px"]email@example.com[/vcex_icon_box][/vc_column][vc_column width="1/2"][vc_gmaps link="#E-8_JTNDaWZyYW1lJTIwc3JjJTNEJTIyaHR0cHMlM0ElMkYlMkZ3d3cuZ29vZ2xlLmNvbSUyRm1hcHMlMkZlbWJlZCUzRnBiJTNEJTIxMW0xOCUyMTFtMTIlMjExbTMlMjExZDYzMDQuODI5OTg2MTMxMjcxJTIxMmQtMTIyLjQ3NDY5NjgwMzMwOTIlMjEzZDM3LjgwMzc0NzUyMTYwNDQzJTIxMm0zJTIxMWYwJTIxMmYwJTIxM2YwJTIxM20yJTIxMWkxMDI0JTIxMmk3NjglMjE0ZjEzLjElMjEzbTMlMjExbTIlMjExczB4ODA4NTg2ZTYzMDI2MTVhMSUyNTNBMHg4NmJkMTMwMjUxNzU3YzAwJTIxMnNTdG9yZXklMkJBdmUlMjUyQyUyQlNhbiUyQkZyYW5jaXNjbyUyNTJDJTJCQ0ElMkI5NDEyOSUyMTVlMCUyMTNtMiUyMTFzZW4lMjEyc3VzJTIxNHYxNDM1ODI2NDMyMDUxJTIyJTIwd2lkdGglM0QlMjI2MDAlMjIlMjBoZWlnaHQlM0QlMjI0NTAlMjIlMjBmcmFtZWJvcmRlciUzRCUyMjAlMjIlMjBzdHlsZSUzRCUyMmJvcmRlciUzQTAlMjIlMjBhbGxvd2Z1bGxzY3JlZW4lM0UlM0MlMkZpZnJhbWUlM0U="][/vc_column][/vc_row]
CONTENT;

$templates['contact-5'] = array();
$templates['contact-5']['name'] = esc_html__( 'Contact', 'total' ) . ' 5';
$templates['contact-5']['category'] = 'contact';
$templates['contact-5']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627331819768{padding-top: 60px !important;padding-bottom: 70px !important;}"][vc_column][vcex_heading text="Get in Touch" text_align="center" font_size="d:50px|pl:30px" font_weight="bold"][vcex_spacing size="50px"][vcex_grid_container gap="60px"][vcex_teaser heading="For general inquiries:" heading_type="h3" css=".vc_custom_1627331652679{border-top-width: 4px !important;padding-top: 20px !important;border-top-color: #7ce89f !important;border-top-style: solid !important;}" heading_size="24px" content_font_size="18px" heading_weight="normal"]support@example.com[/vcex_teaser][vcex_teaser heading="For press and marketing:" heading_type="h3" css=".vc_custom_1627331690270{border-top-width: 4px !important;padding-top: 20px !important;border-top-color: #7ad9ff !important;border-top-style: solid !important;}" heading_size="24px" content_font_size="18px" heading_weight="normal"]media@example.com[/vcex_teaser][vcex_teaser heading="Our Address:" heading_type="h3" css=".vc_custom_1627331701057{border-top-width: 4px !important;padding-top: 20px !important;border-top-color: #768af7 !important;border-top-style: solid !important;}" heading_size="24px" content_font_size="18px" heading_weight="normal"]Storey Ave, San Francisco, CA 94129[/vcex_teaser][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['contact-6'] = array();
$templates['contact-6']['name'] = esc_html__( 'Contact', 'total' ) . ' 6';
$templates['contact-6']['category'] = 'contact';
$templates['contact-6']['content'] = <<<CONTENT
[vc_row column_spacing="50" css=".vc_custom_1627332668204{margin-top: 50px !important;}"][vc_column width="3/5"][vcex_image source="external" external_image="{$ph_landscape}"][vcex_spacing][vcex_flex_container align_items="center" justify_content="space-between" flex_wrap="true" flex_direction="row"][vcex_icon_box heading="Press Inquiries:" icon="" heading_bottom_margin="0px" heading_size="1.2em" heading_weight="semibold"]press@example.com[/vcex_icon_box][vcex_icon_box heading="Phone Support:" icon="" heading_bottom_margin="0px" heading_size="1.2em" heading_weight="semibold"]1-800-202-555-0119[/vcex_icon_box][vcex_icon_box heading="Our Address:" icon="" heading_bottom_margin="0px" heading_size="1.2em" heading_weight="semibold"]Storey Ave, San Francisco, CA 94129[/vcex_icon_box][/vcex_flex_container][/vc_column][vc_column width="2/5"][vcex_heading text="Get in Touch" font_size="30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text font_size="1.2em" color="#888888"]Have an inquiry or feedback for us? Fill out the form below to contact our team and we'll get back to you asap.[/vc_column_text][vcex_spacing size="20px"][vcex_contact_form enable_placeholders="true" stack_fields="true" enable_privacy_check="false" message_rows="4" label_required="(required)"][/vc_column][/vc_row]
CONTENT;

$templates['contact-7'] = array();
$templates['contact-7']['name'] = esc_html__( 'Contact', 'total' ) . ' 7';
$templates['contact-7']['category'] = 'contact';
$templates['contact-7']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1632872211415{padding-top: 50px !important;padding-bottom: 50px !important;}"][vc_column][vcex_heading text="Got questions?" font_weight="800" font_size="3em" text_align="center"][vcex_spacing size="20px"][vc_column_text width="700px" align="center" text_align="center" font_size="16px"]Please contact one of our support departments for support or to report an issue.[/vc_column_text][vcex_spacing size="40px"][vcex_grid_container columns_lg="" columns_md="3" gap="25px"][vcex_icon_box heading="Customization" style="two" wpex_padding="40px" shadow="shadow-xs" icon="ticon ticon-paint-brush" icon_border_width="2" url_wrap="true" onclick="custom_link" background_color="#f5f8fe" css=".vc_custom_1632871878414{padding-top: 60px !important;padding-bottom: 60px !important;}" heading_type="h2" heading_weight="bold" heading_size="1.3em" onclick_url="#" heading_color="#000000" border_radius="4px" icon_color="accent" icon_border_radius="9999px" icon_width="45px" icon_height="45px" icon_size="20px"]Get in touch with a designer for help with product customization.[/vcex_icon_box][vcex_icon_box heading="Hosting" style="two" wpex_padding="40px" shadow="shadow-xs" icon="ticon ticon-database" icon_border_width="2" url_wrap="true" onclick="custom_link" background_color="#f5f8fe" css=".vc_custom_1632871916145{padding-top: 60px !important;padding-bottom: 60px !important;}" heading_type="h2" heading_weight="bold" heading_size="1.3em" onclick_url="#" heading_color="#000000" border_radius="4px" icon_color="accent" icon_border_radius="9999px" icon_width="45px" icon_height="45px" icon_size="20px"]If you are having problems with your site hosting please report issues here.[/vcex_icon_box][vcex_icon_box heading="Refunds" style="two" wpex_padding="40px" shadow="shadow-xs" icon="ticon ticon-usd" icon_border_width="2" url_wrap="true" onclick="custom_link" background_color="#f5f8fe" css=".vc_custom_1632871761689{padding-top: 60px !important;padding-bottom: 60px !important;}" heading_type="h2" heading_weight="bold" heading_size="1.3em" onclick_url="#" heading_color="#000000" border_radius="4px" icon_color="accent" icon_border_radius="9999px" icon_width="45px" icon_height="45px" icon_size="20px"]Need a refund? Contact our refund department for assistance.[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['contact-8'] = array();
$templates['contact-8']['name'] = esc_html__( 'Contact', 'total' ) . ' 8';
$templates['contact-8']['category'] = 'contact';
$templates['contact-8']['content'] = <<<CONTENT
[vc_row css=".vc_custom_1632872357000{padding-top: 50px !important;padding-bottom: 10px !important;}"][vc_column][vcex_heading text="Our offices" font_weight="800" font_size="2.4em" text_align="left" tag="h2"][vcex_spacing size="15px"][vc_column_text]We currently have three locations in the USA.[/vc_column_text][vcex_spacing][vcex_grid_container columns_lg="" columns_md="3"][vcex_teaser heading="California" heading_type="h3" image_source="external" img_bottom_margin="0px" external_image="{$ph_square}" heading_weight="semibold" heading_size="1.3em" css=".vc_custom_1632872794867{border: 1px solid #e0e0e0 !important;}" content_padding="top:30px|right:30px|bottom:30px|left:30px"]hello-california@gmail.com
+1 800 123 456[/vcex_teaser][vcex_teaser heading="New York" heading_type="h3" image_source="external" img_bottom_margin="0px" external_image="{$ph_square}" heading_weight="semibold" heading_size="1.3em" css=".vc_custom_1632872810771{border-top-width: 1px !important;border-right-width: 1px !important;border-bottom-width: 1px !important;border-left-width: 1px !important;border-left-color: #e0e0e0 !important;border-left-style: solid !important;border-right-color: #e0e0e0 !important;border-right-style: solid !important;border-top-color: #e0e0e0 !important;border-top-style: solid !important;border-bottom-color: #e0e0e0 !important;border-bottom-style: solid !important;}" content_padding="top:30px|right:30px|bottom:30px|left:30px"]hello-newyork@gmail.com
+1 800 123 456[/vcex_teaser][vcex_teaser heading="Texas" heading_type="h3" image_source="external" img_bottom_margin="0px" external_image="{$ph_square}" heading_weight="semibold" heading_size="1.3em" css=".vc_custom_1632872828309{border-top-width: 1px !important;border-right-width: 1px !important;border-bottom-width: 1px !important;border-left-width: 1px !important;border-left-color: #e0e0e0 !important;border-left-style: solid !important;border-right-color: #e0e0e0 !important;border-right-style: solid !important;border-top-color: #e0e0e0 !important;border-top-style: solid !important;border-bottom-color: #e0e0e0 !important;border-bottom-style: solid !important;}" content_padding="top:30px|right:30px|bottom:30px|left:30px"]hello-texas@gmail.com
+1 800 123 456[/vcex_teaser][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['contact-9'] = array();
$templates['contact-9']['name'] = esc_html__( 'Contact', 'total' ) . ' 9';
$templates['contact-9']['category'] = 'contact';
$templates['contact-9']['content'] = <<<CONTENT
[vc_row content_placement="middle" remove_bottom_col_margin="true" css=".vc_custom_1632873329034{padding-top: 60px !important;padding-bottom: 60px !important;}"][vc_column width="3/5"][vcex_heading text="Feel free to contact us.`{`br`}`We are here to help!" font_weight="800" font_size="3em"][/vc_column][vc_column width="2/5"][vcex_heading text="Address" bottom_margin="10px" tag="h3" font_size="1.3em" font_weight="bold"][vc_column_text]Storey Ave, San Francisco, CA 94129[/vc_column_text][vcex_spacing size="35px"][vcex_heading text="Email" bottom_margin="10px" tag="h3" font_size="1.3em" font_weight="bold"][vc_column_text]hello-example@gmail.com[/vc_column_text][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][vc_gmaps link="#E-8_JTNDaWZyYW1lJTIwc3JjJTNEJTIyaHR0cHMlM0ElMkYlMkZ3d3cuZ29vZ2xlLmNvbSUyRm1hcHMlMkZlbWJlZCUzRnBiJTNEJTIxMW0xOCUyMTFtMTIlMjExbTMlMjExZDYzMDQuODI5OTg2MTMxMjcxJTIxMmQtMTIyLjQ3NDY5NjgwMzMwOTIlMjEzZDM3LjgwMzc0NzUyMTYwNDQzJTIxMm0zJTIxMWYwJTIxMmYwJTIxM2YwJTIxM20yJTIxMWkxMDI0JTIxMmk3NjglMjE0ZjEzLjElMjEzbTMlMjExbTIlMjExczB4ODA4NTg2ZTYzMDI2MTVhMSUyNTNBMHg4NmJkMTMwMjUxNzU3YzAwJTIxMnNTdG9yZXklMkJBdmUlMjUyQyUyQlNhbiUyQkZyYW5jaXNjbyUyNTJDJTJCQ0ElMkI5NDEyOSUyMTVlMCUyMTNtMiUyMTFzZW4lMjEyc3VzJTIxNHYxNDM1ODI2NDMyMDUxJTIyJTIwd2lkdGglM0QlMjI2MDAlMjIlMjBoZWlnaHQlM0QlMjI0NTAlMjIlMjBmcmFtZWJvcmRlciUzRCUyMjAlMjIlMjBzdHlsZSUzRCUyMmJvcmRlciUzQTAlMjIlMjBhbGxvd2Z1bGxzY3JlZW4lM0UlM0MlMkZpZnJhbWUlM0U=" size="300px"][/vc_column][/vc_row]
CONTENT;
// IMPORTANT - Space required to prevent HEREDOC errors.
?>