/* Utilities */
.wpex-hidden {
	display: none;
}

/* Main page wrap */
.wpex-demo-import-page h1 {
	margin-bottom: 15px;
}

.wpex-demo-import-error-page h1 {
	margin-bottom: 20px;
}

/* Filters */
.wpex-demo-import-top {
	display: flex;
	align-items: center;
	flex-wrap: wrap;
	gap: 10px;
	border-bottom: 1px solid #ccc;
	padding-bottom: 20px;
	margin-bottom: 20px;
}

.wpex-demo-import-filter {
	display: flex;
	align-items: center;
	flex-wrap: wrap;
	gap: 10px;
	&__search {
		height: 30px;
		width: 300px;
		font-size: 16px;
		font-weight: 300;
		color: #777;
		max-width: 100%;
	}
}

.wpex-demo-import-grid-loader {
	margin: 0 1%;
	&:not(.wpex-demo-import-grid-loader--visible) {
		display: none;
	}
}

button.wpex-demo-import-refresh-button.button-secondary {
	display: flex;
	align-items: center;
	.dashicons {
		margin-left: 4px;
	}
}

.wpex-demo-import-refresh-notice {
	display: flex;
	align-items: center;
	background: #fff;
    border: 1px solid #c3c4c7;
    border-left-width: 4px;
    border-left-color: #dba617;
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
    margin: 15px 0;
    padding: 1em 12px;
    svg {
    	margin-right: 10px;
    }
	&:not(.wpex-demo-import-refresh-notice--visible) {
		display: none;
	}
}

/* Spinner */
.wpex-demo-spinner {
	position: absolute;
	z-index: 10;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
	margin: auto;
	background-color: #FFF;
	width: auto;
	height: auto;
	background-position: center;
	visibility: visible;
	display: none;
}

.wpex-visible-spinner {
	display: inline-block;
}

/* Demos List */
.wpex-demo-import-grid {
	margin-left: -1%;

	&-item {
	    cursor: pointer;
	    float: left;
	    margin: 1%;
	    position: relative;
	    width: 30.6%;
	    border: 1px solid #dcdcde;
	    box-shadow: 0 1px 1px -1px rgba(0,0,0,.1);
	    box-sizing: border-box;

	    &:nth-child(3n) {
		    margin-right: 0
		}

		&:after {
			content: "";
			display: block;
			height: 0;
			clear: both;
			visibility: hidden;
			zoom: 1;
		}

		&:hover,
		&:focus {
			.wpex-demo-import-grid-item__actions {
				opacity: 1;
			}
		}

		a, img {
			display: block;
			cursor: pointer;
		}

		&__screenshot {
			cursor: pointer !important;
			display: block;
		    overflow: hidden;
		    position: relative;
		    -webkit-backface-visibility: hidden;
		    transition: opacity .2s ease-in-out;

		    &:after {
			    content: "";
			    display: block;
			    padding-top: 66.66666%
			}

			img {
				display: block;
				position: relative;
				height: auto;
			    position: absolute;
			    left: 0;
			    top: 0;
			    width: 100%;
			    height: 100%;
			    transition: opacity .2s ease-in-out;
			    object-fit: cover;
			    object-position: top;
			}

			&:hover img {
				opacity: 0.75;
			}

		}

		&__actions {
			position: absolute;
		    top: 50%;
		    transform: translateY(-50%);
		    right: 0;
		    padding: 9px 15px;
		    box-shadow: inset 0 1px 0 rgba(0,0,0,.1);
			opacity: 0;
		    transition: opacity .1s ease-in-out;
		    height: auto;
		    background: rgba(246,247,247,.7);
		    border-left: 1px solid rgba(0,0,0,.05);
		}

		&__name {
			cursor: default !important;
			position: relative;
			font-size: 15px;
		    font-weight: 600;
		    height: 18px;
		    margin: 0;
		    padding: 15px;
		    box-shadow: inset 0 1px 0 rgba(0,0,0,.1);
		    overflow: hidden;
		    white-space: nowrap;
		    text-overflow: ellipsis;
		    background: #fff;
		    background: rgba(255,255,255,.65);
		}

		&__button {
			font-weight: normal;
		}

	}

}

/* Popup */
.wpex-demo-import-popup {
	position: fixed;
	overflow-y: scroll;
	overflow-x: hidden;
	width: 100%;
	height: 100%;
	visibility: hidden;
	top: 0;
	left: 0;
	opacity: 0;
	background: rgba(0, 0, 0, 0.8);
	transition: all 0.3s;
	z-index: 999990;
}

.wpex-demo-import-popup__inner {
	padding: 50px 15%;
}

.wpex-demo-import-popup__content {
	background: #fff;
	max-width: 750px;
	position: relative;
	margin: 0 auto;
	transform: scale(0.7);
	opacity: 0;
	transition: all 0.3s;
}

.wpex-demo-import-popup.wpex-show {
	opacity: 1;
	visibility: visible;
}

.wpex-demo-import-popup.wpex-show .wpex-demo-import-popup__content {
	transform: scale(1);
	opacity: 1;
}

/* Popup close */
.wpex-demo-import-popup__close {
	position: absolute;
	right: 20px;
	top: 20px;
	color: #fff;
	text-decoration: none;
}

.wpex-demo-import-popup__close:hover {
	color: #fff;
}

.wpex-demo-import-popup__close .dashicons {
	font-size: 42px;
	line-height: 1;
	color: inherit;
	height: auto;
	width: auto;
}

/* Selected > Heading */
.wpex-demo-import-selected {

	&__heading {
		background: #fafafa;
		border-bottom: 1px solid #ddd;
		color: #444;
		font-size: 18px;
		font-weight: 600;
		margin-bottom: 30px;
		line-height: normal;
		padding: 20px 30px;
		text-align: center;
		span {
			color: #777;
			font-style: italic;
		}
	}

}

/* Selected > Screenshot */
.wpex-demo-import-selected {

	&__screenshot {
		position: relative;
		height: 300px;
		overflow: hidden;
		padding: 30px;
		background: #eee;
		border-bottom: 1px solid #ddd;
		img {
			display: block;
			width: 100%;
			box-shadow: 0 0 15px rgba(0,0,0,0.2);
		}
	}

}

/* Selected > Notices */
.wpex-demo-import-selected__warning {
	margin: 30px;
	font-size: 14px;
	line-height: 1.5;
}

/* Selected > Required plugins */
.wpex-demo-import-required-plugins {
	padding: 20px 30px;
	border-top: 1px solid #ddd;

	&__heading {
		font-size: 16px;
		font-weight: bold;
		margin-bottom: 20px;
	}

	&__notice {
		margin-bottom: 20px;
	}

	&__list {
		width: 100%;
		font-size: 14px;
		border-collapse: collapse;

		tr {
			border-bottom: 1px solid #ddd;
		}

		td {
			padding: 10px 0;
			&:first-child {
				white-space: nowrap;
				vertical-align: middle;
				color: #777;
				font-weight: 500;
			}
			&:last-child {
				height: 50px;
				line-height: 2;
				box-sizing: border-box;
				padding-left: 10px;
				text-align: right;
			}
		}

		.button {
			min-width: 100px;
			min-height: 30px;
			line-height: 2;
			text-align: center;
		}

	}

	&__item {

		.disabled {
			color: #999;
		}

	}

}

/* Selected Buttons */
.wpex-demo-import-buttons {
	margin-top: 35px;
}

.wpex-demo-import-buttons .button-primary {
	width: 100%;
	height: 60px;
	line-height: 60px;
	text-align: center;
	font-size: 16px;
	font-weight: 600;
	border-radius: 0;
}

.wpex-plugin-action-success:before {
	font: 400 18px/1 dashicons;
	color: #53BE62;
	content: '\f12a';
	vertical-align: bottom;
}

.wpex-plugin-action-failed {
	color: #DD0000;
}

.wpex-plugin-action-failed:before {
	font: 400 18px/1 dashicons;
	color: #DD0000;
	content: '\f158';
	vertical-align: bottom;
}

/* Content to import screen */
.wpex-demo-import-form {
	display: none;
}

.wpex-demo-import-form__types {
	font-size: 15px;
}

.wpex-demo-import-form__types ul {
	margin: 30px;
}

.wpex-demo-import-form__types ul li {
	margin: 0;
	padding: 15px 0;
}

.wpex-demo-import-form__types ul li:not(:last-child) {
	border-bottom: 1px solid #ddd;
}

.wpex-demo-import-form__types ul strong {
	font-weight: bold;
	font-size: 14px;
}

.wpex-demo-import-form__types .wpex-warning {
	color: red;
}

/* Content importing preloader */
.wpex-demo-import-loading {
	display: none;
}

.wpex-demo-import-status {
	min-height: 100px;
	padding: 0 30px 30px;
}

.wpex-demo-import-status__content,
.wpex-demo-import-failed-notice,
.wpex-demo-import-status__complete {
	margin: 10px 0;
	font-size: 15px;
}

.wpex-demo-import-failed-notice {
	color: #DD0000;
}

.wpex-demo-import-status p::before,
p.wpex-demo-import-failed-notice::before {
	display: inline-block;
	font: 400 18px/1 dashicons;
	vertical-align: bottom;
	margin-right: 15px;
}

.wpex-demo-import-status__complete::before {
	content: '\f12a';
	color: #53BE62;
}

p.wpex-demo-import-failed-notice::before {
	content: "\f534";
}

.wpex-demo-import-status__content::before {
	content: '\f463';
	color: #f56e28;
	animation: wpex-demo-import-rotate 2s infinite linear;
}

.wpex-import-complete {
	display: none;
	text-align: center;
}

.wpex-import-complete__message {
	padding: 70px 0 30px;
	font-size: 38px;
	color: #53BE62;
	font-weight: 600;
}

.wpex-import-complete__message .dashicons {
	height: auto;
	width: auto;
	font-size: inherit;
	line-height: inherit;
	margin-left: 10px;
	margin-top: 2px;
}


/* Hide things */
#setting-error-tgmpa,
.woocommerce-message {
	display: none !important;
}
body.theme-panel_page_wpex-panel-demo-importer #wpfooter {
	display: none !important;
}

/* Animations */
@-webkit-keyframes wpex-demo-import-rotate {
	0% {
		transform: rotate(0deg);
	}
	100% {
		transform: rotate(359deg);
	}
}