.wpex-ca-admin-inner{display:grid;grid-template-columns:1fr 360px;gap:24px}.wpex-ca-admin-list{margin-top:20px}.wpex-ca-admin-list-group{border-bottom:1px solid #e0e0e0;margin-bottom:40px}.wpex-ca-admin-list-group h2{margin:0 0 15px;padding:0;font-size:16px}.wpex-ca-admin-list-item.wpex-ca-admin-not-empty .wpex-ca-admin-list-item-header h3{color:#274af5}.wpex-ca-admin-list-item-header{display:flex;align-items:center;justify-content:space-between;line-height:1.4;border:1px solid #e0e0e0;border-bottom:0;background:#fff;cursor:pointer;user-select:none}.wpex-ca-admin-list-item-header h3{display:block;font-size:14px;padding:15px;margin:0}.wpex-ca-admin-list-item-header .dashicons{line-height:inherit}.wpex-ca-admin-list-item-header button.wpex-ca-admin-toggle{display:inline-flex;align-items:center;justify-content:center;height:44px;width:44px;padding:0;border:0;background:0;cursor:pointer}.wpex-ca-admin-list-item-header button.wpex-ca-admin-toggle svg{height:24px;width:24px}.wpex-ca-admin-list-item-header button.wpex-ca-admin-toggle[aria-expanded="true"] svg{transform:rotate(180deg)}.wpex-ca-admin-list-item-fields{background:#fff;padding:15px;border:1px solid #e0e0e0;border-bottom:0}.wpex-ca-closed .wpex-ca-admin-list-item-fields{display:none}.wpex-ca-admin-list-item-fields label{font-weight:600;color:#23282d}.wpex-ca-admin-list-item-fields p{padding:0;margin:0 0 20px}.wpex-ca-admin-list-item-fields p:last-child{margin:0}.wpex-ca-admin-list-item-fields textarea{margin:12px 0 3px;background:#f5f5f5;color:#000;padding:15px;font-family:'Verdana'}.wpex-ca-admin-list-item-fields input[type="number"]{background:#f5f5f5;color:#000;width:60px}.wpex-ca-admin-save{background:#fff;box-sizing:border-box;border-radius:3px;border:1px solid #e0e0e0;margin-bottom:24px;margin-top:52px}.wpex-ca-admin-save h3{border-bottom:1px solid #e0e0e0;padding:16px 24px;font-weight:400;font-size:20px;line-height:28px;margin:0}.wpex-ca-admin-save__inner{padding:16px 24px}.wpex-ca-admin-save__inner p{margin:0;padding:0;font-style:normal;font-weight:400;font-size:14px;font-size:.875rem;line-height:20px;color:#757575}.wpex-ca-admin-save__inner p:not(:last-child){margin-bottom:16px}@media only screen and (max-width: 1100px){.wpex-ca-admin-inner{grid-template-columns:auto 300px}}@media only screen and (max-width: 800px){.wpex-ca-admin-inner{grid-template-columns:1fr}}
