<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Media
$html .= $this->get_media( array(
	'class'       => 'wpex-mb-20 wpex-rounded-lg',
	'image_class' => 'wpex-rounded-lg',
) );

// Details
$html .= '<div class="wpex-card-details">';

	// Title
	$html .= $this->get_title( array(
		'class' => 'wpex-heading wpex-text-xl wpex-font-medium wpex-mb-10',
	) );

	// Excerpt
	$html .= $this->get_excerpt( array(
		'class' => 'wpex-mb-15',
	) );

	// Author
	$html .= $this->get_author( array(
		'class' => 'wpex-font-bold wpex-child-inherit-color',
		'link_class' => 'wpex-inherit-color wpex-hover-underline',
		'prefix' => esc_html__( 'By', 'total' ) . ' ',
	) );

	// Date
	$html .= '<div class="wpex-card-meta">';

		$html .= $this->get_date( array(
			'class' => 'wpex-tex-xs wpex-text-3',
			'html_tag' => 'span',
			'suffix' => '. '
		) );

		$html .= $this->get_time( array(
			'class' => 'wpex-tex-xs wpex-text-3',
			'html_tag' => 'span',
		) );

	$html .= '</div>';

$html .= '</div>';

return $html;