<?php
defined( 'ABSPATH' ) || exit;

$templates['team-1'] = array();
$templates['team-1']['name'] = esc_html__( 'Team', 'total' ) . ' 1';
$templates['team-1']['category'] = 'team';
$templates['team-1']['content'] = <<<CONTENT
[vc_row css=".vc_custom_1627416538908{margin-top: 40px !important;}"][vc_column][vcex_heading text="Meet The Team" text_align="center" tag="h2" font_size="30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing size="20px"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vcex_image source="external" bottom_margin="20px" align="center" overlay_style="" external_image="{$ph_square}" border_radius="9999px" width="120px"][vcex_heading text="Jonathan Smith" text_align="center" font_weight="semibold" font_size="1.5em" tag="h3"][vc_column_text text_align="center" color="#757575" text_transform="uppercase" letter_spacing="0.5px" font_size=".9em"]Accountant[/vc_column_text][vcex_spacing size="15px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="20px"][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="10px" style="flat-color-round" align="center" width="30px" height="30px" size="14px"][/vc_column][vc_column width="1/3"][vcex_image source="external" bottom_margin="20px" align="center" overlay_style="" external_image="{$ph_square}" border_radius="9999px" width="120px"][vcex_heading text="Jane Doe" text_align="center" font_weight="semibold" font_size="1.5em" tag="h3"][vc_column_text text_align="center" color="#757575" text_transform="uppercase" letter_spacing="0.5px" font_size=".9em"]Web Designer[/vc_column_text][vcex_spacing size="15px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="20px"][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="10px" style="flat-color-round" align="center" width="30px" height="30px" size="14px"][/vc_column][vc_column width="1/3"][vcex_image source="external" bottom_margin="20px" align="center" overlay_style="" external_image="{$ph_square}" border_radius="9999px" width="120px"][vcex_heading text="Jonathan Smith" text_align="center" font_weight="semibold" font_size="1.5em" tag="h3"][vc_column_text text_align="center" color="#757575" text_transform="uppercase" letter_spacing="0.5px" font_size=".9em"]CEO/Founder[/vc_column_text][vcex_spacing size="15px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="20px"][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="10px" style="flat-color-round" align="center" width="30px" height="30px" size="14px"][/vc_column][/vc_row]
CONTENT;

$templates['team-2'] = array();
$templates['team-2']['name'] = esc_html__( 'Team', 'total' ) . ' 2';
$templates['team-2']['category'] = 'team';
$templates['team-2']['content'] = <<<CONTENT
[vc_row css=".vc_custom_1627255127117{margin-top: 40px !important;}"][vc_column][vcex_heading text="Our Friendly Staff" text_align="center" tag="h2" font_size="30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/2" offset="vc_col-md-3"][vcex_image source="external" bottom_margin="20px" align="center" overlay_style="" external_image="{$ph_square}"][vcex_heading text="Jonathan Smith" font_weight="semibold" font_size="1.5em" tag="h3"][vc_column_text color="#757575" text_transform="uppercase" letter_spacing="0.5px" font_size=".9em"]Accountant[/vc_column_text][vcex_spacing size="15px"][vc_column_text width="650px" align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="20px"][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="5px" style="flat-color" width="30px" height="30px" size="14px"][/vc_column][vc_column width="1/2" offset="vc_col-md-3"][vcex_image source="external" bottom_margin="20px" align="center" overlay_style="" external_image="{$ph_square}"][vcex_heading text="Jonathan Smith" font_weight="semibold" font_size="1.5em" tag="h3"][vc_column_text color="#757575" text_transform="uppercase" letter_spacing="0.5px" font_size=".9em"]Sales Assistant[/vc_column_text][vcex_spacing size="15px"][vc_column_text width="650px" align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="20px"][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="5px" style="flat-color" width="30px" height="30px" size="14px"][/vc_column][vc_column width="1/2" offset="vc_col-md-3"][vcex_image source="external" bottom_margin="20px" align="center" overlay_style="" external_image="{$ph_square}"][vcex_heading text="Jonathan Smith" font_weight="semibold" font_size="1.5em" tag="h3"][vc_column_text color="#757575" text_transform="uppercase" letter_spacing="0.5px" font_size=".9em"]Secretary[/vc_column_text][vcex_spacing size="15px"][vc_column_text width="650px" align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="20px"][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="5px" style="flat-color" width="30px" height="30px" size="14px"][/vc_column][vc_column width="1/2" offset="vc_col-md-3"][vcex_image source="external" bottom_margin="20px" align="center" overlay_style="" external_image="{$ph_square}"][vcex_heading text="Jonathan Smith" font_weight="semibold" font_size="1.5em" tag="h3"][vc_column_text color="#757575" text_transform="uppercase" letter_spacing="0.5px" font_size=".9em"]CEO &amp; Founder[/vc_column_text][vc_column_text width="650px" align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="20px"][vcex_spacing size="15px"][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="5px" style="flat-color" width="30px" height="30px" size="14px"][/vc_column][/vc_row]
CONTENT;

$templates['team-3'] = array();
$templates['team-3']['name'] = esc_html__( 'Team', 'total' ) . ' 3';
$templates['team-3']['category'] = 'team';
$templates['team-3']['content'] = <<<CONTENT
[vc_row css=".vc_custom_1627255150358{margin-top: 40px !important;}"][vc_column][vcex_heading text="Meet the Team" tag="h2" font_size="30px" font_weight="bold"][vcex_spacing size="15px"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit.
Vivamus et justo ultricies.[/vc_column_text][vcex_divider color="#bdbdbd" width="60px" align="left" margin="top:25px|bottom:50px"][vcex_grid_container align_items="center" columns_lg="4" columns_sm="2"][vcex_image_banner justify_content="end" image_source="external" heading="Jonathan Smith" caption="Software Engineer" text_align="left" content_align="left" external_image="{$ph_square}" image_position="50% 50%" padding="top:20px|right:20px|bottom:20px|left:20px" heading_font_size="20px" caption_font_size="14px" min_height="350px"][vcex_image_banner justify_content="end" image_source="external" heading="Jonathan Smith" caption="Executive Assistant" text_align="left" content_align="left" min_height="400px" external_image="{$ph_square}" image_position="50% 50%" padding="top:20px|right:20px|bottom:20px|left:20px" heading_font_size="20px" caption_font_size="14px"][vcex_image_banner justify_content="end" image_source="external" heading="Jonathan Smith" caption="Sales Manager" text_align="left" content_align="left" min_height="350px" external_image="{$ph_square}" image_position="50% 50%" padding="top:20px|right:20px|bottom:20px|left:20px" heading_font_size="20px" caption_font_size="14px"][vcex_image_banner justify_content="end" image_source="external" heading="Jonathan Smith" caption="Sales Manager" text_align="left" content_align="left" min_height="400px" external_image="{$ph_square}" image_position="50% 50%" padding="top:20px|right:20px|bottom:20px|left:20px" heading_font_size="20px" caption_font_size="14px"][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['team-4'] = array();
$templates['team-4']['name'] = esc_html__( 'Team', 'total' ) . ' 4';
$templates['team-4']['category'] = 'team';
$templates['team-4']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627255029534{padding-top: 60px !important;padding-bottom: 70px !important;background-color: #f7f7f7 !important;}"][vc_column][vcex_heading text="Our Team" text_align="center" tag="h2" font_size="30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing size="50px"][vcex_grid_container columns_lg="4" columns_sm="2" gap="35px"][vcex_icon_box style="two" wpex_padding="30px" shadow="shadow-lg" image_source="external" image_border_radius="rounded-full" external_image="{$ph_square}" image_width="100px" image_height="100px" background_color="#ffffff" border_radius="8px" heading_bottom_margin="0px" heading_size="1.2em" heading_type="h3"]Software Engineer[/vcex_icon_box][vcex_icon_box style="two" wpex_padding="30px" shadow="shadow-lg" image_source="external" image_border_radius="rounded-full" external_image="{$ph_square}" image_width="100px" image_height="100px" background_color="#ffffff" border_radius="8px" heading_bottom_margin="0px" heading_size="1.2em" heading_type="h3"]Sales Manager[/vcex_icon_box][vcex_icon_box style="two" wpex_padding="30px" shadow="shadow-lg" image_source="external" image_border_radius="rounded-full" external_image="{$ph_square}" image_width="100px" image_height="100px" background_color="#ffffff" border_radius="8px" heading_bottom_margin="0px" heading_size="1.2em" heading_type="h3"]Executive Assistant[/vcex_icon_box][vcex_icon_box style="two" wpex_padding="30px" shadow="shadow-lg" image_source="external" image_border_radius="rounded-full" external_image="{$ph_square}" image_width="100px" image_height="100px" background_color="#ffffff" border_radius="8px" heading_bottom_margin="0px" heading_size="1.2em" heading_type="h3"]CEO and Founder[/vcex_icon_box][/vcex_grid_container][vcex_spacing size="50px"][vc_column_text width="370px" align="center" text_align="center" font_size="1.1em"]Feel free to <a href="#">contact us</a> for any questions or concerns. We will respond as soon as possible.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

$templates['team-5'] = array();
$templates['team-5']['name'] = esc_html__( 'Team', 'total' ) . ' 5';
$templates['team-5']['category'] = 'team';
$templates['team-5']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" css=".vc_custom_1627255076527{padding-top: 60px !important;padding-bottom: 20px !important;background-color: #222222 !important;}"][vc_column width="1/3"][vcex_heading text="Meet The Team" bottom_margin="10px" tag="h2" font_size="30px" font_weight="bold" color="#ffffff"][vc_column_text color="#9e9e9e"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="25px"][vcex_button color="white" border_radius="0px" border="0px" font_padding="top:12px|right:25px|bottom:12px|left:25px" font_weight="bold" text_transform="uppercase" letter_spacing="1px" font_size=".9em"]Contact US[/vcex_button][/vc_column][vc_column css_animation="none" width="2/3"][vcex_grid_container columns_lg="2" gap="30px"][vcex_icon_box heading="Jonathan Smith" align_center="true" wpex_padding="25px" shadow="shadow-2xl" icon_border_width="2" image_source="external" image_border_radius="rounded-full" background_color="#333333" border_radius="15px" icon_border_radius="50px" icon_width="60px" icon_height="60px" heading_size="1.3em" heading_bottom_margin="0px" external_image="{$ph_square}" image_width="90px" image_height="90px" heading_color="#ffffff" font_color="#9e9e9e"]Executive Assistant[/vcex_icon_box][vcex_icon_box heading="Jonathan Smith" align_center="true" wpex_padding="25px" shadow="shadow-2xl" icon_border_width="2" image_source="external" image_border_radius="rounded-full" background_color="#333333" border_radius="15px" icon_border_radius="50px" icon_width="60px" icon_height="60px" heading_size="1.3em" heading_bottom_margin="0px" external_image="{$ph_square}" image_width="90px" image_height="90px" heading_color="#ffffff" font_color="#9e9e9e"]Marketing Manager[/vcex_icon_box][vcex_icon_box heading="Jonathan Smith" align_center="true" wpex_padding="25px" shadow="shadow-2xl" icon_border_width="2" image_source="external" image_border_radius="rounded-full" background_color="#333333" border_radius="15px" icon_border_radius="50px" icon_width="60px" icon_height="60px" heading_size="1.3em" heading_bottom_margin="0px" external_image="{$ph_square}" image_width="90px" image_height="90px" heading_color="#ffffff" font_color="#9e9e9e"]Office Assistant[/vcex_icon_box][vcex_icon_box heading="Jonathan Smith" align_center="true" wpex_padding="25px" shadow="shadow-2xl" icon_border_width="2" image_source="external" image_border_radius="rounded-full" background_color="#333333" border_radius="15px" icon_border_radius="50px" icon_width="60px" icon_height="60px" heading_size="1.3em" heading_bottom_margin="0px" external_image="{$ph_square}" image_width="90px" image_height="90px" heading_color="#ffffff" font_color="#9e9e9e"]CEO and Founder[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['team-6'] = array();
$templates['team-6']['name'] = esc_html__( 'Team', 'total' ) . ' 6';
$templates['team-6']['category'] = 'team';
$templates['team-6']['content'] = <<<CONTENT
[vc_row css=".vc_custom_1627255170360{margin-top: 40px !important;}"][vc_column][vcex_heading text="Meet Our Team" text_align="center" tag="h2" font_size="30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing size="20px"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vcex_image source="external" bottom_margin="20px" align="center" overlay_style="" external_image="{$ph_square}" border_radius="9999px" width="120px"][vcex_heading text="Jonathan Smith" text_align="center" font_weight="semibold" font_size="1.3em" tag="h3"][vcex_spacing size="15px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="20px"][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="15px" style="none" align="center" width="30px" height="30px" size="18px" color="#222222"][/vc_column][vc_column width="1/3"][vcex_image source="external" bottom_margin="20px" align="center" overlay_style="" external_image="{$ph_square}" border_radius="9999px" width="120px"][vcex_heading text="Jane Doe" text_align="center" font_weight="semibold" font_size="1.3em" tag="h3"][vcex_spacing size="15px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="20px"][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="15px" style="none" align="center" width="30px" height="30px" size="18px" color="#222222"][/vc_column][vc_column width="1/3"][vcex_image source="external" bottom_margin="20px" align="center" overlay_style="" external_image="{$ph_square}" border_radius="9999px" width="120px"][vcex_heading text="Jonathan Smith" text_align="center" font_weight="semibold" font_size="1.3em" tag="h3"][vcex_spacing size="15px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="20px"][vcex_social_links social_links="%5B%7B%22site%22%3A%22twitter%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22linkedin%22%2C%22link%22%3A%22%23%22%7D%2C%7B%22site%22%3A%22facebook%22%2C%22link%22%3A%22%23%22%7D%5D" spacing="15px" style="none" align="center" width="30px" height="30px" size="18px" color="#222222"][/vc_column][/vc_row]
CONTENT;
// IMPORTANT - Space required to prevent HEREDOC errors.
?>