<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Media
$html .= $this->get_media( array(
	'class' => 'wpex-mb-25',
) );

// Primary term
$html .= $this->get_primary_term( array(
	'class' => 'wpex-uppercase wpex-text-3 wpex-text-xs wpex-font-semibold wpex-tracking-wide wpex-mb-5',
	'term_class' => 'wpex-inherit-color wpex-hover-underline',
) );

// Title
$html .= $this->get_title( array(
	'class' => 'wpex-heading wpex-text-xl wpex-mb-15',
) );

// Excerpt
$html .= $this->get_excerpt();

return $html;