@font-face {
  font-family: 'ticons';
  src: url('../fonts/ticons.eot');
  src: url('../fonts/ticons.woff2') format('woff2'), url('../fonts/ticons.woff') format('woff'), url('../fonts/ticons.ttf') format('truetype'), url('../fonts/ticons.svg#ticons') format('svg');
  font-weight: normal;
  font-style: normal;
  font-display: block;
}
.ticon {
  display: inline-block;
  font: normal normal normal 14px/1 ticons;
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.elementor-icons-manager__tab__item__icon.ticon {
  font-size: 25px;
}

/* makes the font 33% larger relative to the icon container */
.ticon-lg {
  font-size: 1.33333333em;
  line-height: 0.75em;
  vertical-align: -15%;
}
.ticon-2x {
  font-size: 2em;
}
.ticon-3x {
  font-size: 3em;
}
.ticon-4x {
  font-size: 4em;
}
.ticon-5x {
  font-size: 5em;
}
.ticon-fw {
  width: 1.28571429em;
  text-align: center;
}
.ticon-ul {
  padding-left: 0;
  margin-left: 2.14285714em;
  list-style-type: none;
}
.ticon-ul > li {
  position: relative;
}
.ticon-li {
  position: absolute;
  left: -2.14285714em;
  width: 2.14285714em;
  top: 0.14285714em;
  text-align: center;
}
.ticon-li.ticon-lg {
  left: -1.85714286em;
}
.ticon-border {
  padding: .2em .25em .15em;
  border: solid 0.08em #eeeeee;
  border-radius: .1em;
}
.ticon-pull-left {
  float: left;
  margin-right: .3em;
}
.ticon-pull-right {
  float: right;
  margin-left: .3em;
}
.ticon-spin {
  animation: ticon-spin 2s infinite linear;
}
.ticon-pulse {
  animation: ticon-spin 1s infinite steps(8);
}
@keyframes ticon-spin {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.ticon-rotate-90 {
  transform: rotate(90deg);
}
.ticon-rotate-180 {
  transform: rotate(180deg);
}
.ticon-rotate-270 {
  transform: rotate(270deg);
}
.ticon-flip-horizontal {
  transform: scale(-1, 1);
}
.ticon-flip-vertical {
  transform: scale(1, -1);
}
:root .ticon-rotate-90,
:root .ticon-rotate-180,
:root .ticon-rotate-270,
:root .ticon-flip-horizontal,
:root .ticon-flip-vertical {
  filter: none;
}
.ticon-stack {
  position: relative;
  display: inline-block;
  width: 2em;
  height: 2em;
  line-height: 2em;
  vertical-align: middle;
}
.ticon-stack-1x,
.ticon-stack-2x {
  position: absolute;
  left: 0;
  width: 100%;
  text-align: center;
}
.ticon-stack-1x {
  line-height: inherit;
}
.ticon-stack-2x {
  font-size: 2em;
}
.ticon-inverse {
  color: #ffffff;
}

/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen
   readers do not read off random characters that represent icons */
.ticon-glass:before {
  content: "\f000";
}
.ticon-music:before {
  content: "\f001";
}
.ticon-search:before {
  content: "\f002";
}
.ticon-envelope-o:before {
  content: "\f003";
}
.ticon-heart:before {
  content: "\f004";
}
.ticon-star:before {
  content: "\f005";
}
.ticon-star-empty:before,
.ticon-star-o:before {
  content: "\f006";
}
.ticon-user:before {
  content: "\f007";
}
.ticon-film:before {
  content: "\f008";
}
.ticon-th-large:before {
  content: "\f009";
}
.ticon-th:before {
  content: "\f00a";
}
.ticon-th-list:before {
  content: "\f00b";
}
.ticon-check:before {
  content: "\f00c";
}
.ticon-remove:before,
.ticon-close:before,
.ticon-times:before {
  content: "\f00d";
}
.ticon-search-plus:before {
  content: "\f00e";
}
.ticon-search-minus:before {
  content: "\f010";
}
.ticon-power-off:before {
  content: "\f011";
}
.ticon-signal:before {
  content: "\f012";
}
.ticon-gear:before,
.ticon-cog:before {
  content: "\f013";
}
.ticon-trash-o:before {
  content: "\f014";
}
.ticon-home:before {
  content: "\f015";
}
.ticon-file-o:before {
  content: "\f016";
}
.ticon-clock-o:before {
  content: "\f017";
}
.ticon-road:before {
  content: "\f018";
}
.ticon-download:before {
  content: "\f019";
}
.ticon-arrow-circle-o-down:before {
  content: "\f01a";
}
.ticon-arrow-circle-o-up:before {
  content: "\f01b";
}
.ticon-inbox:before {
  content: "\f01c";
}
.ticon-play-circle-o:before {
  content: "\f01d";
}
.ticon-rotate-right:before,
.ticon-repeat:before {
  content: "\f01e";
}
.ticon-refresh:before {
  content: "\f021";
}
.ticon-list-alt:before {
  content: "\f022";
}
.ticon-lock:before {
  content: "\f023";
}
.ticon-flag:before {
  content: "\f024";
}
.ticon-headphones:before {
  content: "\f025";
}
.ticon-volume-off:before {
  content: "\f026";
}
.ticon-volume-down:before {
  content: "\f027";
}
.ticon-volume-up:before {
  content: "\f028";
}
.ticon-qrcode:before {
  content: "\f029";
}
.ticon-barcode:before {
  content: "\f02a";
}
.ticon-tag:before {
  content: "\f02b";
}
.ticon-tags:before {
  content: "\f02c";
}
.ticon-book:before {
  content: "\f02d";
}
.ticon-bookmark:before {
  content: "\f02e";
}
.ticon-print:before {
  content: "\f02f";
}
.ticon-camera:before {
  content: "\f030";
}
.ticon-font:before {
  content: "\f031";
}
.ticon-bold:before {
  content: "\f032";
}
.ticon-italic:before {
  content: "\f033";
}
.ticon-text-height:before {
  content: "\f034";
}
.ticon-text-width:before {
  content: "\f035";
}
.ticon-align-left:before {
  content: "\f036";
}
.ticon-align-center:before {
  content: "\f037";
}
.ticon-align-right:before {
  content: "\f038";
}
.ticon-align-justify:before {
  content: "\f039";
}
.ticon-list:before {
  content: "\f03a";
}
.ticon-dedent:before,
.ticon-outdent:before {
  content: "\f03b";
}
.ticon-indent:before {
  content: "\f03c";
}
.ticon-video-camera:before {
  content: "\f03d";
}
.ticon-photo:before,
.ticon-image:before,
.ticon-picture-o:before {
  content: "\f03e";
}
.ticon-pencil:before {
  content: "\f040";
}
.ticon-map-marker:before {
  content: "\f041";
}
.ticon-adjust:before {
  content: "\f042";
}
.ticon-tint:before {
  content: "\f043";
}
.ticon-edit:before,
.ticon-pencil-square-o:before {
  content: "\f044";
}
.ticon-share-square-o:before {
  content: "\f045";
}
.ticon-check-square-o:before {
  content: "\f046";
}
.ticon-arrows:before {
  content: "\f047";
}
.ticon-step-backward:before {
  content: "\f048";
}
.ticon-fast-backward:before {
  content: "\f049";
}
.ticon-backward:before {
  content: "\f04a";
}
.ticon-play:before {
  content: "\f04b";
}
.ticon-pause:before {
  content: "\f04c";
}
.ticon-stop:before {
  content: "\f04d";
}
.ticon-forward:before {
  content: "\f04e";
}
.ticon-fast-forward:before {
  content: "\f050";
}
.ticon-step-forward:before {
  content: "\f051";
}
.ticon-eject:before {
  content: "\f052";
}
.ticon-chevron-left:before {
  content: "\f053";
}
.ticon-chevron-right:before {
  content: "\f054";
}
.ticon-plus-circle:before {
  content: "\f055";
}
.ticon-minus-circle:before {
  content: "\f056";
}
.ticon-times-circle:before {
  content: "\f057";
}
.ticon-check-circle:before {
  content: "\f058";
}
.ticon-question-circle:before {
  content: "\f059";
}
.ticon-info-circle:before {
  content: "\f05a";
}
.ticon-crosshairs:before {
  content: "\f05b";
}
.ticon-times-circle-o:before {
  content: "\f05c";
}
.ticon-check-circle-o:before {
  content: "\f05d";
}
.ticon-ban:before {
  content: "\f05e";
}
.ticon-arrow-left:before {
  content: "\f060";
}
.ticon-arrow-right:before {
  content: "\f061";
}
.ticon-arrow-up:before {
  content: "\f062";
}
.ticon-arrow-down:before {
  content: "\f063";
}
.ticon-mail-forward:before,
.ticon-share:before {
  content: "\f064";
}
.ticon-expand:before {
  content: "\f065";
}
.ticon-compress:before {
  content: "\f066";
}
.ticon-plus:before {
  content: "\f067";
}
.ticon-minus:before {
  content: "\f068";
}
.ticon-asterisk:before {
  content: "\f069";
}
.ticon-exclamation-circle:before {
  content: "\f06a";
}
.ticon-gift:before {
  content: "\f06b";
}
.ticon-leaf:before {
  content: "\f06c";
}
.ticon-fire:before {
  content: "\f06d";
}
.ticon-eye:before {
  content: "\f06e";
}
.ticon-eye-slash:before {
  content: "\f070";
}
.ticon-warning:before,
.ticon-exclamation-triangle:before {
  content: "\f071";
}
.ticon-plane:before {
  content: "\f072";
}
.ticon-calendar:before {
  content: "\f073";
}
.ticon-random:before {
  content: "\f074";
}
.ticon-comment:before {
  content: "\f075";
}
.ticon-magnet:before {
  content: "\f076";
}
.ticon-chevron-up:before {
  content: "\f077";
}
.ticon-chevron-down:before {
  content: "\f078";
}
.ticon-retweet:before {
  content: "\f079";
}
.ticon-shopping-cart:before {
  content: "\f07a";
}
.ticon-shopping-cart-alt:before {
  content: "\e901";
}
.ticon-folder:before {
  content: "\f07b";
}
.ticon-folder-open:before {
  content: "\f07c";
}
.ticon-arrows-v:before {
  content: "\f07d";
}
.ticon-arrows-h:before {
  content: "\f07e";
}
.ticon-bar-chart-o:before,
.ticon-bar-chart:before {
  content: "\f080";
}
.ticon-twitter-square:before {
  content: "\f081";
}
.ticon-facebook-square:before {
  content: "\f082";
}
.ticon-camera-retro:before {
  content: "\f083";
}
.ticon-key:before {
  content: "\f084";
}
.ticon-gears:before,
.ticon-cogs:before {
  content: "\f085";
}
.ticon-comments:before {
  content: "\f086";
}
.ticon-thumbs-o-up:before {
  content: "\f087";
}
.ticon-thumbs-o-down:before {
  content: "\f088";
}
.ticon-star-half:before {
  content: "\f089";
}
.ticon-heart-o:before {
  content: "\f08a";
}
.ticon-sign-out:before {
  content: "\f08b";
}
.ticon-linkedin-square:before {
  content: "\f08c";
}
.ticon-thumb-tack:before {
  content: "\f08d";
}
.ticon-external-link:before {
  content: "\f08e";
}
.ticon-sign-in:before {
  content: "\f090";
}
.ticon-trophy:before {
  content: "\f091";
}
.ticon-github-square:before {
  content: "\f092";
}
.ticon-upload:before {
  content: "\f093";
}
.ticon-lemon-o:before {
  content: "\f094";
}
.ticon-phone:before {
  content: "\f095";
}
.ticon-square-o:before {
  content: "\f096";
}
.ticon-bookmark-o:before {
  content: "\f097";
}
.ticon-phone-square:before {
  content: "\f098";
}
.ticon-twitter:before {
  content: "\f099";
}
.ticon-facebook-f:before,
.ticon-facebook:before {
  content: "\f09a";
}
.ticon-github:before {
  content: "\f09b";
}
.ticon-unlock:before {
  content: "\f09c";
}
.ticon-credit-card:before {
  content: "\f09d";
}
.ticon-feed:before,
.ticon-rss:before {
  content: "\f09e";
}
.ticon-hdd-o:before {
  content: "\f0a0";
}
.ticon-bullhorn:before {
  content: "\f0a1";
}
.ticon-bell:before {
  content: "\f0f3";
}
.ticon-certificate:before {
  content: "\f0a3";
}
.ticon-hand-o-right:before {
  content: "\f0a4";
}
.ticon-hand-o-left:before {
  content: "\f0a5";
}
.ticon-hand-o-up:before {
  content: "\f0a6";
}
.ticon-hand-o-down:before {
  content: "\f0a7";
}
.ticon-arrow-circle-left:before {
  content: "\f0a8";
}
.ticon-arrow-circle-right:before {
  content: "\f0a9";
}
.ticon-arrow-circle-up:before {
  content: "\f0aa";
}
.ticon-arrow-circle-down:before {
  content: "\f0ab";
}
.ticon-globe:before {
  content: "\f0ac";
}
.ticon-wrench:before {
  content: "\f0ad";
}
.ticon-tasks:before {
  content: "\f0ae";
}
.ticon-filter:before {
  content: "\f0b0";
}
.ticon-briefcase:before {
  content: "\f0b1";
}
.ticon-arrows-alt:before {
  content: "\f0b2";
}
.ticon-group:before,
.ticon-users:before {
  content: "\f0c0";
}
.ticon-chain:before,
.ticon-link:before {
  content: "\f0c1";
}
.ticon-cloud:before {
  content: "\f0c2";
}
.ticon-flask:before {
  content: "\f0c3";
}
.ticon-cut:before,
.ticon-scissors:before {
  content: "\f0c4";
}
.ticon-copy:before,
.ticon-files-o:before {
  content: "\f0c5";
}
.ticon-paperclip:before {
  content: "\f0c6";
}
.ticon-save:before,
.ticon-floppy-o:before {
  content: "\f0c7";
}
.ticon-square:before {
  content: "\f0c8";
}
.ticon-navicon:before,
.ticon-reorder:before,
.ticon-bars:before {
  content: "\f0c9";
}
.ticon-list-ul:before {
  content: "\f0ca";
}
.ticon-list-ol:before {
  content: "\f0cb";
}
.ticon-strikethrough:before {
  content: "\f0cc";
}
.ticon-underline:before {
  content: "\f0cd";
}
.ticon-table:before {
  content: "\f0ce";
}
.ticon-magic:before {
  content: "\f0d0";
}
.ticon-truck:before {
  content: "\f0d1";
}
.ticon-pinterest:before {
  content: "\f0d2";
}
.ticon-pinterest-square:before {
  content: "\f0d3";
}
/*.ticon-google-plus-square:before {
  content: "\f0d4";
}
.ticon-google-plus:before {
  content: "\f0d5";
}*/
.ticon-money:before {
  content: "\f0d6";
}
.ticon-caret-down:before {
  content: "\f0d7";
}
.ticon-caret-up:before {
  content: "\f0d8";
}
.ticon-caret-left:before {
  content: "\f0d9";
}
.ticon-caret-right:before {
  content: "\f0da";
}
.ticon-columns:before {
  content: "\f0db";
}
.ticon-unsorted:before,
.ticon-sort:before {
  content: "\f0dc";
}
.ticon-sort-down:before,
.ticon-sort-desc:before {
  content: "\f0dd";
}
.ticon-sort-up:before,
.ticon-sort-asc:before {
  content: "\f0de";
}
.ticon-envelope:before {
  content: "\f0e0";
}
.ticon-linkedin:before {
  content: "\f0e1";
}
.ticon-rotate-left:before,
.ticon-undo:before {
  content: "\f0e2";
}
.ticon-legal:before,
.ticon-gavel:before {
  content: "\f0e3";
}
.ticon-dashboard:before,
.ticon-tachometer:before {
  content: "\f0e4";
}
.ticon-comment-o:before {
  content: "\f0e5";
}
.ticon-comments-o:before {
  content: "\f0e6";
}
.ticon-flash:before,
.ticon-bolt:before {
  content: "\f0e7";
}
.ticon-sitemap:before {
  content: "\f0e8";
}
.ticon-umbrella:before {
  content: "\f0e9";
}
.ticon-paste:before,
.ticon-clipboard:before {
  content: "\f0ea";
}
.ticon-lightbulb-o:before {
  content: "\f0eb";
}
.ticon-exchange:before {
  content: "\f0ec";
}
.ticon-cloud-download:before {
  content: "\f0ed";
}
.ticon-cloud-upload:before {
  content: "\f0ee";
}
.ticon-user-md:before {
  content: "\f0f0";
}
.ticon-stethoscope:before {
  content: "\f0f1";
}
.ticon-suitcase:before {
  content: "\f0f2";
}
.ticon-bell-o:before {
  content: "\f0a2";
}
.ticon-coffee:before {
  content: "\f0f4";
}
.ticon-cutlery:before {
  content: "\f0f5";
}
.ticon-file-text-o:before {
  content: "\f0f6";
}
.ticon-building-o:before {
  content: "\f0f7";
}
.ticon-hospital-o:before {
  content: "\f0f8";
}
.ticon-ambulance:before {
  content: "\f0f9";
}
.ticon-medkit:before {
  content: "\f0fa";
}
.ticon-fighter-jet:before {
  content: "\f0fb";
}
.ticon-beer:before {
  content: "\f0fc";
}
.ticon-h-square:before {
  content: "\f0fd";
}
.ticon-plus-square:before {
  content: "\f0fe";
}
.ticon-angle-double-left:before {
  content: "\f100";
}
.ticon-angle-double-right:before {
  content: "\f101";
}
.ticon-angle-double-up:before {
  content: "\f102";
}
.ticon-angle-double-down:before {
  content: "\f103";
}
.ticon-angle-left:before {
  content: "\f104";
}
.ticon-angle-right:before {
  content: "\f105";
}
.ticon-angle-up:before {
  content: "\f106";
}
.ticon-angle-down:before {
  content: "\f107";
}
.ticon-desktop:before {
  content: "\f108";
}
.ticon-laptop:before {
  content: "\f109";
}
.ticon-tablet:before {
  content: "\f10a";
}
.ticon-mobile-phone:before,
.ticon-mobile:before {
  content: "\f10b";
}
.ticon-circle-o:before {
  content: "\f10c";
}
.ticon-quote-left:before {
  content: "\f10d";
}
.ticon-quote-right:before {
  content: "\f10e";
}
.ticon-spinner:before {
  content: "\f110";
}
.ticon-circle:before {
  content: "\f111";
}
.ticon-mail-reply:before,
.ticon-reply:before {
  content: "\f112";
}
.ticon-github-alt:before {
  content: "\f113";
}
.ticon-folder-o:before {
  content: "\f114";
}
.ticon-folder-open-o:before {
  content: "\f115";
}
.ticon-smile-o:before {
  content: "\f118";
}
.ticon-frown-o:before {
  content: "\f119";
}
.ticon-meh-o:before {
  content: "\f11a";
}
.ticon-gamepad:before {
  content: "\f11b";
}
.ticon-keyboard-o:before {
  content: "\f11c";
}
.ticon-flag-o:before {
  content: "\f11d";
}
.ticon-flag-checkered:before {
  content: "\f11e";
}
.ticon-terminal:before {
  content: "\f120";
}
.ticon-code:before {
  content: "\f121";
}
.ticon-mail-reply-all:before,
.ticon-reply-all:before {
  content: "\f122";
}
.ticon-star-half-empty:before,
.ticon-star-half-full:before,
.ticon-star-half-o:before {
  content: "\f123";
}
.ticon-location-arrow:before {
  content: "\f124";
}
.ticon-crop:before {
  content: "\f125";
}
.ticon-code-fork:before {
  content: "\f126";
}
.ticon-unlink:before,
.ticon-chain-broken:before {
  content: "\f127";
}
.ticon-question:before {
  content: "\f128";
}
.ticon-info:before {
  content: "\f129";
}
.ticon-exclamation:before {
  content: "\f12a";
}
.ticon-superscript:before {
  content: "\f12b";
}
.ticon-subscript:before {
  content: "\f12c";
}
.ticon-eraser:before {
  content: "\f12d";
}
.ticon-puzzle-piece:before {
  content: "\f12e";
}
.ticon-microphone:before {
  content: "\f130";
}
.ticon-microphone-slash:before {
  content: "\f131";
}
.ticon-shield:before {
  content: "\f132";
}
.ticon-calendar-o:before {
  content: "\f133";
}
.ticon-fire-extinguisher:before {
  content: "\f134";
}
.ticon-rocket:before {
  content: "\f135";
}
.ticon-maxcdn:before {
  content: "\f136";
}
.ticon-chevron-circle-left:before {
  content: "\f137";
}
.ticon-chevron-circle-right:before {
  content: "\f138";
}
.ticon-chevron-circle-up:before {
  content: "\f139";
}
.ticon-chevron-circle-down:before {
  content: "\f13a";
}
.ticon-html5:before {
  content: "\f13b";
}
.ticon-css3:before {
  content: "\f13c";
}
.ticon-anchor:before {
  content: "\f13d";
}
.ticon-unlock-alt:before {
  content: "\f13e";
}
.ticon-bullseye:before {
  content: "\f140";
}
.ticon-ellipsis-h:before {
  content: "\f141";
}
.ticon-ellipsis-v:before {
  content: "\f142";
}
.ticon-rss-square:before {
  content: "\f143";
}
.ticon-play-circle:before {
  content: "\f144";
}
.ticon-ticket:before {
  content: "\f145";
}
.ticon-minus-square:before {
  content: "\f146";
}
.ticon-minus-square-o:before {
  content: "\f147";
}
.ticon-level-up:before {
  content: "\f148";
}
.ticon-level-down:before {
  content: "\f149";
}
.ticon-check-square:before {
  content: "\f14a";
}
.ticon-pencil-square:before {
  content: "\f14b";
}
.ticon-external-link-square:before {
  content: "\f14c";
}
.ticon-share-square:before {
  content: "\f14d";
}
.ticon-compass:before {
  content: "\f14e";
}
.ticon-toggle-down:before,
.ticon-caret-square-o-down:before {
  content: "\f150";
}
.ticon-toggle-up:before,
.ticon-caret-square-o-up:before {
  content: "\f151";
}
.ticon-toggle-right:before,
.ticon-caret-square-o-right:before {
  content: "\f152";
}
.ticon-euro:before,
.ticon-eur:before {
  content: "\f153";
}
.ticon-gbp:before {
  content: "\f154";
}
.ticon-dollar:before,
.ticon-usd:before {
  content: "\f155";
}
.ticon-rupee:before,
.ticon-inr:before {
  content: "\f156";
}
.ticon-cny:before,
.ticon-rmb:before,
.ticon-yen:before,
.ticon-jpy:before {
  content: "\f157";
}
.ticon-ruble:before,
.ticon-rouble:before,
.ticon-rub:before {
  content: "\f158";
}
.ticon-won:before,
.ticon-krw:before {
  content: "\f159";
}
.ticon-bitcoin:before,
.ticon-btc:before {
  content: "\f15a";
}
.ticon-file:before {
  content: "\f15b";
}
.ticon-file-text:before {
  content: "\f15c";
}
.ticon-sort-alpha-asc:before {
  content: "\f15d";
}
.ticon-sort-alpha-desc:before {
  content: "\f15e";
}
.ticon-sort-amount-asc:before {
  content: "\f160";
}
.ticon-sort-amount-desc:before {
  content: "\f161";
}
.ticon-sort-numeric-asc:before {
  content: "\f162";
}
.ticon-sort-numeric-desc:before {
  content: "\f163";
}
.ticon-thumbs-up:before {
  content: "\f164";
}
.ticon-thumbs-down:before {
  content: "\f165";
}
.ticon-youtube-square:before {
  content: "\f166";
}
.ticon-youtube:before {
  content: "\f167";
}
.ticon-xing:before {
  content: "\f168";
}
.ticon-xing-square:before {
  content: "\f169";
}
.ticon-youtube-play:before {
  content: "\f16a";
}
.ticon-dropbox:before {
  content: "\f16b";
}
.ticon-stack-overflow:before {
  content: "\f16c";
}
.ticon-instagram:before {
  content: "\f16d";
}
.ticon-flickr:before {
  content: "\f16e";
}
.ticon-adn:before {
  content: "\f170";
}
.ticon-bitbucket:before {
  content: "\f171";
}
.ticon-bitbucket-square:before {
  content: "\f172";
}
.ticon-tumblr:before {
  content: "\f173";
}
.ticon-tumblr-square:before {
  content: "\f174";
}
.ticon-long-arrow-down:before {
  content: "\f175";
}
.ticon-long-arrow-up:before {
  content: "\f176";
}
.ticon-long-arrow-left:before {
  content: "\f177";
}
.ticon-long-arrow-right:before {
  content: "\f178";
}
.ticon-apple:before {
  content: "\f179";
}
.ticon-windows:before {
  content: "\f17a";
}
.ticon-android:before {
  content: "\f17b";
}
.ticon-linux:before {
  content: "\f17c";
}
.ticon-dribbble:before {
  content: "\f17d";
}
.ticon-skype:before {
  content: "\f17e";
}
.ticon-foursquare:before {
  content: "\f180";
}
.ticon-trello:before {
  content: "\f181";
}
.ticon-female:before {
  content: "\f182";
}
.ticon-male:before {
  content: "\f183";
}
.ticon-gittip:before,
.ticon-gratipay:before {
  content: "\f184";
}
.ticon-sun-o:before {
  content: "\f185";
}
.ticon-moon-o:before {
  content: "\f186";
}
.ticon-archive:before {
  content: "\f187";
}
.ticon-bug:before {
  content: "\f188";
}
.ticon-vk:before {
  content: "\f189";
}
.ticon-weibo:before {
  content: "\f18a";
}
.ticon-renren:before {
  content: "\f18b";
}
.ticon-pagelines:before {
  content: "\f18c";
}
.ticon-stack-exchange:before {
  content: "\f18d";
}
.ticon-arrow-circle-o-right:before {
  content: "\f18e";
}
.ticon-arrow-circle-o-left:before {
  content: "\f190";
}
.ticon-toggle-left:before,
.ticon-caret-square-o-left:before {
  content: "\f191";
}
.ticon-dot-circle-o:before {
  content: "\f192";
}
.ticon-wheelchair:before {
  content: "\f193";
}
.ticon-vimeo-square:before {
  content: "\f194";
}
.ticon-turkish-lira:before,
.ticon-try:before {
  content: "\f195";
}
.ticon-plus-square-o:before {
  content: "\f196";
}
.ticon-space-shuttle:before {
  content: "\f197";
}
.ticon-slack:before {
  content: "\f198";
}
.ticon-envelope-square:before {
  content: "\f199";
}
.ticon-wordpress:before {
  content: "\f19a";
}
.ticon-openid:before {
  content: "\f19b";
}
.ticon-institution:before,
.ticon-bank:before,
.ticon-university:before {
  content: "\f19c";
}
.ticon-mortar-board:before,
.ticon-graduation-cap:before {
  content: "\f19d";
}
.ticon-yahoo:before {
  content: "\f19e";
}
.ticon-google:before {
  content: "\f1a0";
}
.ticon-reddit:before {
  content: "\f1a1";
}
.ticon-reddit-square:before {
  content: "\f1a2";
}
.ticon-stumbleupon-circle:before {
  content: "\f1a3";
}
.ticon-stumbleupon:before {
  content: "\f1a4";
}
.ticon-delicious:before {
  content: "\f1a5";
}
.ticon-digg:before {
  content: "\f1a6";
}
.ticon-pied-piper-pp:before {
  content: "\f1a7";
}
.ticon-pied-piper-alt:before {
  content: "\f1a8";
}
.ticon-drupal:before {
  content: "\f1a9";
}
.ticon-joomla:before {
  content: "\f1aa";
}
.ticon-language:before {
  content: "\f1ab";
}
.ticon-fax:before {
  content: "\f1ac";
}
.ticon-building:before {
  content: "\f1ad";
}
.ticon-child:before {
  content: "\f1ae";
}
.ticon-paw:before {
  content: "\f1b0";
}
.ticon-spoon:before {
  content: "\f1b1";
}
.ticon-cube:before {
  content: "\f1b2";
}
.ticon-cubes:before {
  content: "\f1b3";
}
.ticon-behance:before {
  content: "\f1b4";
}
.ticon-behance-square:before {
  content: "\f1b5";
}
.ticon-steam:before {
  content: "\f1b6";
}
.ticon-steam-square:before {
  content: "\f1b7";
}
.ticon-recycle:before {
  content: "\f1b8";
}
.ticon-automobile:before,
.ticon-car:before {
  content: "\f1b9";
}
.ticon-cab:before,
.ticon-taxi:before {
  content: "\f1ba";
}
.ticon-tree:before {
  content: "\f1bb";
}
.ticon-spotify:before {
  content: "\f1bc";
}
.ticon-deviantart:before {
  content: "\f1bd";
}
.ticon-soundcloud:before {
  content: "\f1be";
}
.ticon-database:before {
  content: "\f1c0";
}
.ticon-file-pdf-o:before {
  content: "\f1c1";
}
.ticon-file-word-o:before {
  content: "\f1c2";
}
.ticon-file-excel-o:before {
  content: "\f1c3";
}
.ticon-file-powerpoint-o:before {
  content: "\f1c4";
}
.ticon-file-photo-o:before,
.ticon-file-picture-o:before,
.ticon-file-image-o:before {
  content: "\f1c5";
}
.ticon-file-zip-o:before,
.ticon-file-archive-o:before {
  content: "\f1c6";
}
.ticon-file-sound-o:before,
.ticon-file-audio-o:before {
  content: "\f1c7";
}
.ticon-file-movie-o:before,
.ticon-file-video-o:before {
  content: "\f1c8";
}
.ticon-file-code-o:before {
  content: "\f1c9";
}
/*.ticon-vine:before {
  content: "\f1ca";
}*/
.ticon-codepen:before {
  content: "\f1cb";
}
.ticon-jsfiddle:before {
  content: "\f1cc";
}
.ticon-life-bouy:before,
.ticon-life-buoy:before,
.ticon-life-saver:before,
.ticon-support:before,
.ticon-life-ring:before {
  content: "\f1cd";
}
.ticon-circle-o-notch:before {
  content: "\f1ce";
}
.ticon-ra:before,
.ticon-resistance:before,
.ticon-rebel:before {
  content: "\f1d0";
}
.ticon-ge:before,
.ticon-empire:before {
  content: "\f1d1";
}
.ticon-git-square:before {
  content: "\f1d2";
}
.ticon-git:before {
  content: "\f1d3";
}
.ticon-y-combinator-square:before,
.ticon-yc-square:before,
.ticon-hacker-news:before {
  content: "\f1d4";
}
.ticon-tencent-weibo:before {
  content: "\f1d5";
}
.ticon-qq:before {
  content: "\f1d6";
}
.ticon-wechat:before,
.ticon-weixin:before {
  content: "\f1d7";
}
.ticon-send:before,
.ticon-paper-plane:before {
  content: "\f1d8";
}
.ticon-send-o:before,
.ticon-paper-plane-o:before {
  content: "\f1d9";
}
.ticon-history:before {
  content: "\f1da";
}
.ticon-circle-thin:before {
  content: "\f1db";
}
.ticon-header:before {
  content: "\f1dc";
}
.ticon-paragraph:before {
  content: "\f1dd";
}
.ticon-sliders:before {
  content: "\f1de";
}
.ticon-share-alt:before {
  content: "\f1e0";
}
.ticon-share-alt-square:before {
  content: "\f1e1";
}
.ticon-bomb:before {
  content: "\f1e2";
}
.ticon-soccer-ball-o:before,
.ticon-futbol-o:before {
  content: "\f1e3";
}
.ticon-tty:before {
  content: "\f1e4";
}
.ticon-binoculars:before {
  content: "\f1e5";
}
.ticon-plug:before {
  content: "\f1e6";
}
.ticon-slideshare:before {
  content: "\f1e7";
}
.ticon-twitch:before {
  content: "\f1e8";
}
.ticon-yelp:before {
  content: "\f1e9";
}
.ticon-newspaper-o:before {
  content: "\f1ea";
}
.ticon-wifi:before {
  content: "\f1eb";
}
.ticon-calculator:before {
  content: "\f1ec";
}
.ticon-paypal:before {
  content: "\f1ed";
}
.ticon-google-wallet:before {
  content: "\f1ee";
}
.ticon-cc-visa:before {
  content: "\f1f0";
}
.ticon-cc-mastercard:before {
  content: "\f1f1";
}
.ticon-cc-discover:before {
  content: "\f1f2";
}
.ticon-cc-amex:before {
  content: "\f1f3";
}
.ticon-cc-paypal:before {
  content: "\f1f4";
}
.ticon-cc-stripe:before {
  content: "\f1f5";
}
.ticon-bell-slash:before {
  content: "\f1f6";
}
.ticon-bell-slash-o:before {
  content: "\f1f7";
}
.ticon-trash:before {
  content: "\f1f8";
}
.ticon-copyright:before {
  content: "\f1f9";
}
.ticon-at:before {
  content: "\f1fa";
}
.ticon-eyedropper:before {
  content: "\f1fb";
}
.ticon-paint-brush:before {
  content: "\f1fc";
}
.ticon-birthday-cake:before {
  content: "\f1fd";
}
.ticon-area-chart:before {
  content: "\f1fe";
}
.ticon-pie-chart:before {
  content: "\f200";
}
.ticon-line-chart:before {
  content: "\f201";
}
.ticon-lastfm:before {
  content: "\f202";
}
.ticon-lastfm-square:before {
  content: "\f203";
}
.ticon-toggle-off:before {
  content: "\f204";
}
.ticon-toggle-on:before {
  content: "\f205";
}
.ticon-bicycle:before {
  content: "\f206";
}
.ticon-bus:before {
  content: "\f207";
}
.ticon-ioxhost:before {
  content: "\f208";
}
.ticon-angellist:before {
  content: "\f209";
}
.ticon-cc:before {
  content: "\f20a";
}
.ticon-shekel:before,
.ticon-sheqel:before,
.ticon-ils:before {
  content: "\f20b";
}
.ticon-meanpath:before {
  content: "\f20c";
}
.ticon-buysellads:before {
  content: "\f20d";
}
.ticon-connectdevelop:before {
  content: "\f20e";
}
.ticon-dashcube:before {
  content: "\f210";
}
.ticon-forumbee:before {
  content: "\f211";
}
.ticon-leanpub:before {
  content: "\f212";
}
.ticon-sellsy:before {
  content: "\f213";
}
.ticon-shirtsinbulk:before {
  content: "\f214";
}
.ticon-simplybuilt:before {
  content: "\f215";
}
.ticon-skyatlas:before {
  content: "\f216";
}
.ticon-cart-plus:before {
  content: "\f217";
}
.ticon-cart-arrow-down:before {
  content: "\f218";
}
.ticon-diamond:before {
  content: "\f219";
}
.ticon-ship:before {
  content: "\f21a";
}
.ticon-user-secret:before {
  content: "\f21b";
}
.ticon-motorcycle:before {
  content: "\f21c";
}
.ticon-street-view:before {
  content: "\f21d";
}
.ticon-heartbeat:before {
  content: "\f21e";
}
.ticon-venus:before {
  content: "\f221";
}
.ticon-mars:before {
  content: "\f222";
}
.ticon-mercury:before {
  content: "\f223";
}
.ticon-intersex:before,
.ticon-transgender:before {
  content: "\f224";
}
.ticon-transgender-alt:before {
  content: "\f225";
}
.ticon-venus-double:before {
  content: "\f226";
}
.ticon-mars-double:before {
  content: "\f227";
}
.ticon-venus-mars:before {
  content: "\f228";
}
.ticon-mars-stroke:before {
  content: "\f229";
}
.ticon-mars-stroke-v:before {
  content: "\f22a";
}
.ticon-mars-stroke-h:before {
  content: "\f22b";
}
.ticon-neuter:before {
  content: "\f22c";
}
.ticon-genderless:before {
  content: "\f22d";
}
.ticon-facebook-official:before {
  content: "\f230";
}
.ticon-pinterest-p:before {
  content: "\f231";
}
.ticon-whatsapp:before {
  content: "\f232";
}
.ticon-server:before {
  content: "\f233";
}
.ticon-user-plus:before {
  content: "\f234";
}
.ticon-user-times:before {
  content: "\f235";
}
.ticon-hotel:before,
.ticon-bed:before {
  content: "\f236";
}
.ticon-viacoin:before {
  content: "\f237";
}
.ticon-train:before {
  content: "\f238";
}
.ticon-subway:before {
  content: "\f239";
}
.ticon-medium:before {
  content: "\f23a";
}
.ticon-yc:before,
.ticon-y-combinator:before {
  content: "\f23b";
}
.ticon-optin-monster:before {
  content: "\f23c";
}
.ticon-opencart:before {
  content: "\f23d";
}
.ticon-expeditedssl:before {
  content: "\f23e";
}
.ticon-battery-4:before,
.ticon-battery:before,
.ticon-battery-full:before {
  content: "\f240";
}
.ticon-battery-3:before,
.ticon-battery-three-quarters:before {
  content: "\f241";
}
.ticon-battery-2:before,
.ticon-battery-half:before {
  content: "\f242";
}
.ticon-battery-1:before,
.ticon-battery-quarter:before {
  content: "\f243";
}
.ticon-battery-0:before,
.ticon-battery-empty:before {
  content: "\f244";
}
.ticon-mouse-pointer:before {
  content: "\f245";
}
.ticon-i-cursor:before {
  content: "\f246";
}
.ticon-object-group:before {
  content: "\f247";
}
.ticon-object-ungroup:before {
  content: "\f248";
}
.ticon-sticky-note:before {
  content: "\f249";
}
.ticon-sticky-note-o:before {
  content: "\f24a";
}
.ticon-cc-jcb:before {
  content: "\f24b";
}
.ticon-cc-diners-club:before {
  content: "\f24c";
}
.ticon-clone:before {
  content: "\f24d";
}
.ticon-balance-scale:before {
  content: "\f24e";
}
.ticon-hourglass-o:before {
  content: "\f250";
}
.ticon-hourglass-1:before,
.ticon-hourglass-start:before {
  content: "\f251";
}
.ticon-hourglass-2:before,
.ticon-hourglass-half:before {
  content: "\f252";
}
.ticon-hourglass-3:before,
.ticon-hourglass-end:before {
  content: "\f253";
}
.ticon-hourglass:before {
  content: "\f254";
}
.ticon-hand-grab-o:before,
.ticon-hand-rock-o:before {
  content: "\f255";
}
.ticon-hand-stop-o:before,
.ticon-hand-paper-o:before {
  content: "\f256";
}
.ticon-hand-scissors-o:before {
  content: "\f257";
}
.ticon-hand-lizard-o:before {
  content: "\f258";
}
.ticon-hand-spock-o:before {
  content: "\f259";
}
.ticon-hand-pointer-o:before {
  content: "\f25a";
}
.ticon-hand-peace-o:before {
  content: "\f25b";
}
.ticon-trademark:before {
  content: "\f25c";
}
.ticon-registered:before {
  content: "\f25d";
}
.ticon-creative-commons:before {
  content: "\f25e";
}
.ticon-gg:before {
  content: "\f260";
}
.ticon-gg-circle:before {
  content: "\f261";
}
.ticon-tripadvisor:before {
  content: "\f262";
}
.ticon-odnoklassniki:before {
  content: "\f263";
}
.ticon-odnoklassniki-square:before {
  content: "\f264";
}
.ticon-get-pocket:before {
  content: "\f265";
}
.ticon-wikipedia-w:before {
  content: "\f266";
}
.ticon-safari:before {
  content: "\f267";
}
.ticon-chrome:before {
  content: "\f268";
}
.ticon-firefox:before {
  content: "\f269";
}
.ticon-opera:before {
  content: "\f26a";
}
.ticon-internet-explorer:before {
  content: "\f26b";
}
.ticon-tv:before,
.ticon-television:before {
  content: "\f26c";
}
.ticon-contao:before {
  content: "\f26d";
}
.ticon-500px:before {
  content: "\f26e";
}
.ticon-amazon:before {
  content: "\f270";
}
.ticon-calendar-plus-o:before {
  content: "\f271";
}
.ticon-calendar-minus-o:before {
  content: "\f272";
}
.ticon-calendar-times-o:before {
  content: "\f273";
}
.ticon-calendar-check-o:before {
  content: "\f274";
}
.ticon-industry:before {
  content: "\f275";
}
.ticon-map-pin:before {
  content: "\f276";
}
.ticon-map-signs:before {
  content: "\f277";
}
.ticon-map-o:before {
  content: "\f278";
}
.ticon-map:before {
  content: "\f279";
}
.ticon-commenting:before {
  content: "\f27a";
}
.ticon-commenting-o:before {
  content: "\f27b";
}
.ticon-houzz:before {
  content: "\f27c";
}
.ticon-vimeo:before {
  content: "\f27d";
}
.ticon-black-tie:before {
  content: "\f27e";
}
.ticon-fonticons:before {
  content: "\f280";
}
.ticon-reddit-alien:before {
  content: "\f281";
}
.ticon-edge:before {
  content: "\f282";
}
.ticon-credit-card-alt:before {
  content: "\f283";
}
.ticon-codiepie:before {
  content: "\f284";
}
.ticon-modx:before {
  content: "\f285";
}
.ticon-fort-awesome:before {
  content: "\f286";
}
.ticon-usb:before {
  content: "\f287";
}
.ticon-product-hunt:before {
  content: "\f288";
}
.ticon-mixcloud:before {
  content: "\f289";
}
.ticon-scribd:before {
  content: "\f28a";
}
.ticon-pause-circle:before {
  content: "\f28b";
}
.ticon-pause-circle-o:before {
  content: "\f28c";
}
.ticon-stop-circle:before {
  content: "\f28d";
}
.ticon-stop-circle-o:before {
  content: "\f28e";
}
.ticon-shopping-bag:before {
  content: "\f290";
}
.ticon-shopping-bag-alt:before {
  content: "\e902";
}
.ticon-shopping-basket:before {
  content: "\f291";
}
.ticon-shopping-basket-alt:before {
  content: "\e903";
}
.ticon-hashtag:before {
  content: "\f292";
}
.ticon-bluetooth:before {
  content: "\f293";
}
.ticon-bluetooth-b:before {
  content: "\f294";
}
.ticon-percent:before {
  content: "\f295";
}
.ticon-gitlab:before {
  content: "\f296";
}
.ticon-wpbeginner:before {
  content: "\f297";
}
.ticon-wpforms:before {
  content: "\f298";
}
.ticon-envira:before {
  content: "\f299";
}
.ticon-universal-access:before {
  content: "\f29a";
}
.ticon-wheelchair-alt:before {
  content: "\f29b";
}
.ticon-question-circle-o:before {
  content: "\f29c";
}
.ticon-blind:before {
  content: "\f29d";
}
.ticon-audio-description:before {
  content: "\f29e";
}
.ticon-volume-control-phone:before {
  content: "\f2a0";
}
.ticon-braille:before {
  content: "\f2a1";
}
.ticon-assistive-listening-systems:before {
  content: "\f2a2";
}
.ticon-asl-interpreting:before,
.ticon-american-sign-language-interpreting:before {
  content: "\f2a3";
}
.ticon-deafness:before,
.ticon-hard-of-hearing:before,
.ticon-deaf:before {
  content: "\f2a4";
}
.ticon-glide:before {
  content: "\f2a5";
}
.ticon-glide-g:before {
  content: "\f2a6";
}
.ticon-signing:before,
.ticon-sign-language:before {
  content: "\f2a7";
}
.ticon-low-vision:before {
  content: "\f2a8";
}
.ticon-viadeo:before {
  content: "\f2a9";
}
.ticon-viadeo-square:before {
  content: "\f2aa";
}
.ticon-snapchat:before {
  content: "\f2ab";
}
.ticon-snapchat-ghost:before {
  content: "\f2ac";
}
.ticon-snapchat-square:before {
  content: "\f2ad";
}
.ticon-pied-piper:before {
  content: "\f2ae";
}
.ticon-first-order:before {
  content: "\f2b0";
}
.ticon-yoast:before {
  content: "\f2b1";
}
.ticon-themeisle:before {
  content: "\f2b2";
}
/*.ticon-google-plus-circle:before,
.ticon-google-plus-official:before {
  content: "\f2b3";
}*/
.ticon-fa:before,
.ticon-font-awesome:before {
  content: "\f2b4";
}
.ticon-handshake-o:before {
  content: "\f2b5";
}
.ticon-envelope-open:before {
  content: "\f2b6";
}
.ticon-envelope-open-o:before {
  content: "\f2b7";
}
.ticon-linode:before {
  content: "\f2b8";
}
.ticon-address-book:before {
  content: "\f2b9";
}
.ticon-address-book-o:before {
  content: "\f2ba";
}
.ticon-vcard:before,
.ticon-address-card:before {
  content: "\f2bb";
}
.ticon-vcard-o:before,
.ticon-address-card-o:before {
  content: "\f2bc";
}
.ticon-user-circle:before {
  content: "\f2bd";
}
.ticon-user-circle-o:before {
  content: "\f2be";
}
.ticon-user-o:before {
  content: "\f2c0";
}
.ticon-id-badge:before {
  content: "\f2c1";
}
.ticon-drivers-license:before,
.ticon-id-card:before {
  content: "\f2c2";
}
.ticon-drivers-license-o:before,
.ticon-id-card-o:before {
  content: "\f2c3";
}
.ticon-quora:before {
  content: "\f2c4";
}
.ticon-free-code-camp:before {
  content: "\f2c5";
}
.ticon-telegram:before {
  content: "\f2c6";
}
.ticon-thermometer-4:before,
.ticon-thermometer:before,
.ticon-thermometer-full:before {
  content: "\f2c7";
}
.ticon-thermometer-3:before,
.ticon-thermometer-three-quarters:before {
  content: "\f2c8";
}
.ticon-thermometer-2:before,
.ticon-thermometer-half:before {
  content: "\f2c9";
}
.ticon-thermometer-1:before,
.ticon-thermometer-quarter:before {
  content: "\f2ca";
}
.ticon-thermometer-0:before,
.ticon-thermometer-empty:before {
  content: "\f2cb";
}
.ticon-shower:before {
  content: "\f2cc";
}
.ticon-bathtub:before,
.ticon-s15:before,
.ticon-bath:before {
  content: "\f2cd";
}
.ticon-podcast:before {
  content: "\f2ce";
}
.ticon-window-maximize:before {
  content: "\f2d0";
}
.ticon-window-minimize:before {
  content: "\f2d1";
}
.ticon-window-restore:before {
  content: "\f2d2";
}
.ticon-times-rectangle:before,
.ticon-window-close:before {
  content: "\f2d3";
}
.ticon-times-rectangle-o:before,
.ticon-window-close-o:before {
  content: "\f2d4";
}
.ticon-bandcamp:before {
  content: "\f2d5";
}
.ticon-grav:before {
  content: "\f2d6";
}
.ticon-etsy:before {
  content: "\f2d7";
}
.ticon-imdb:before {
  content: "\f2d8";
}
.ticon-ravelry:before {
  content: "\f2d9";
}
.ticon-eercast:before {
  content: "\f2da";
}
.ticon-microchip:before {
  content: "\f2db";
}
.ticon-snowflake-o:before {
  content: "\f2dc";
}
.ticon-superpowers:before {
  content: "\f2dd";
}
.ticon-wpexplorer:before {
  content: "\f2de";
}
.ticon-meetup:before {
  content: "\f2e0";
}

/* Added in 5.1.3 */
.ticon-tiktok:before {
  content: "\e07b";
}

/* Added in 5.3.1 */
.ticon-discord:before {
  content: "\f392";
}

/* Added in 5.4.6 */
.ticon-total-theme:before {
  content: "\e904";
}