table.tablepress{line-height:var(--wpex-leading-relaxed)}table.tablepress tfoot th,table.tablepress thead th{color:var(--wpex-table-thead-color);background:var(--wpex-table-thead-bg);font-weight:var(--wpex-bold)}table.tablepress .sorting:hover,table.tablepress .sorting_asc,table.tablepress .sorting_desc{background:var(--wpex-accent);color:var(--wpex-on-accent)}table.tablepress thead th,table.tablepress tbody td,table.tablepress tfoot th{border-color:var(--wpex-table-cell-border-color)}table.tablepress .odd td{background:var(--wpex-surface-2)}table.tablepress .dataTables_info{padding-top:10px;opacity:0.7}.dataTables_info{color:var(--wpex-text-3)}.dataTables_paginate{padding-top:10px}.dataTables_paginate.paging_simple{padding:10px 0 0 !important}.dataTables_paginate.paging_simple .paginate_button.next:after,.dataTables_paginate.paging_simple .paginate_button.previous:before{font-family:'ticons';text-shadow:none;color:inherit;position:static;top:auto;left:auto;right:auto;margin:0;line-height:inherit}.dataTables_paginate.paging_simple .paginate_button.previous:before{content:"\f137";margin-right:8px}.dataTables_paginate.paging_simple .paginate_button.next:after{content:"\f138";margin-left:8px}.dataTables_paginate.paging_simple a{text-decoration:none;color:var(--wpex-text-2)}.dataTables_paginate.paging_simple .paginate_button.disabled{opacity:0.7}.dataTables_length,.dataTables_filter{height:30px;line-height:30px;margin-bottom:10px}.dataTables_filter input[type="search"]{height:26px;padding:0 4px}
