<?php
defined( 'ABSPATH' ) || exit;

$this->sections['wpex_fixed_menu'] = array(
	'title' => esc_html__( 'Sticky Menu', 'total' ),
	'panel' => 'wpex_header',
	'settings' => array(
		array(
			'id' => 'fixed_header_menu',
			'default' => true,
			'control' => array(
				'label' => esc_html__( 'Sticky Header Menu', 'total' ),
				'type' => 'wpex_toggle',
				'active_callback' => 'wpex_cac_header_supports_fixed_menu',
			),
		),
	)
);