body.has-mobile-menu .show-at-mm-breakpoint{display:none}#site-logo.header-five-logo:not(.display){display:none}.header-seven-logo{width:var(--wpex-header-seven-logo-width, 20%)}.navbar-style-seven{width:var(--wpex-header-seven-nav-width, 60%);display:flex;justify-content:center}.header-seven-aside{width:var(--wpex-header-seven-aside-width, 20%)}.header-ten-logo{width:var(--wpex-header-ten-logo-width, 30%);order:2;justify-content:center;margin-right:auto}.navbar-style-ten{width:var(--wpex-header-ten-nav-width, 35%);order:1;display:flex;justify-content:flex-start}.header-ten-aside{width:var(--wpex-header-ten-aside-width, 35%);order:3}
