.total-sidebar-layouts{
    display: grid;
    grid-template-columns: repeat(2, 1fr);
    gap: 15px;
    margin-bottom: 20px;
}

.total-sidebar-layouts label{
    position: relative;
    display: block;
}

.total-sidebar-layouts label input{
    opacity: 0;
    position: absolute;
    left: 0;
    top: 0;
}

.total-sidebar-layouts label img{
    vertical-align: middle;
    border: 2px solid #EEE;
    width: 100%;
}

.total-sidebar-layouts label input:checked + img{
    border: 2px solid #007cba;
}

.clearfix:after,
.clearfix:before{
    content: "";
    display: table;
}

.clearfix:after{
    clear: both;
}

.widget-content .attachment-media-view{
    font-size: 13px;
    line-height: 1.5;
    margin: 1em 0;
}

.widget-content .placeholder{
    width: 100%;
    position: relative;
    text-align: center;
    cursor: default;
    border: 1px dashed #b4b9be;
    box-sizing: border-box;
    padding: 9px 0;
    line-height: 20px;
}

.widget-content .actions{
    margin-top: 8px;
}

.widget-content .hidden {
    display: none;
}

.widget-content .alignright {
    float: right;
}

.widget-content .alignleft {
    float: left;
}

[data-slug="elementor"] .go_pro,
a[href="admin.php?page=go_elementor_pro"],
#elementor-notice-bar{
    display: none !important;
}