#dflip {
  position: relative;
}

.dflip-tab {
}

#dflip_post_meta_box,
form.dflip-settings {
  background-color: #f7f7f7;
  border: 2px solid #0295d0;
  line-height: 1.5;
}

#dflip_post_meta_box .hndle {
  background-color: #0295d0;
  color: white;
}

form.dflip-settings {
  margin-right: 20px;
  padding: 7px 12px 20px;
}

.dflip-tabs {
  position: relative;
}

.dflip-tabs-list {
  border-bottom: 1px solid #ddd;
  margin: -7px -12px 15px;
  list-style: none;
  padding: 8px 12px 0;
  background-color: #0295d0;
}

#dflip-settings .dflip-tabs-list .nav-tab {
  margin-bottom: -1px;
}

.dflip-tabs-list li {
  display: inline-flex;
  margin: 0;
}

.dflip-tabs-list .dflip-active {
  border-bottom-color: white;
}

.normal-tabs.dflip-tabs {
}

.normal-tabs .dflip-tabs-list {
  background-color: transparent;
  margin: 0 0 -1px;
  border: 0;
  padding: 0;
}

.normal-tabs .dflip-tabs-list li {
  color: #777;
  border: 1px solid transparent;
}

.normal-tabs .dflip-tabs-list .dflip-active {
  background-color: #fdfdfd;
  border: 1px solid #ddd;
  border-bottom-color: #eee;
}

.dflip-tabs-list li a,
.dflip-tabs-list .nav-tab {
  display: block;
  padding: 8px 10px;
  text-decoration: none;
  outline: none;
  box-shadow: none;
  position: relative;
  line-height: 1.5;
  color: #eee;
}

.dflip-tabs-list li a:after, .dflip-tabs-list .nav-tab:after {
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
  border-right-color: #f1f1f1;
  top: 50%;
  opacity: 0;
  margin-top: -8px;
  transition: 0.25s ease;
}

.dflip-tabs-list li.dflip-active a,
.dflip-tabs-list .nav-tab.nav-tab-active {
  background-color: #0085ba;
  color: white;
}

.normal-tabs .dflip-tabs-list li a,
.normal-tabs .dflip-tabs-list .nav-tab {
  color: #0089c8;
  padding: 5px 10px;
}

.normal-tabs .dflip-tabs-list li.dflip-active a,
.normal-tabs .dflip-tabs-list .nav-tab.nav-tab-active {
  background-color: transparent;
  color: #32373c;
}

.dflip-tabs-list li a:hover {
  color: white;
}

.normal-tabs .dflip-tabs-list li a:hover {
  color: #32373c;
  background-color: transparent;
}

div#dflip-tab-layout { }

.dflip-tab-content, .dflip-tab-content:hover {
  display: none;
  /* background-color: white; */
}

.dflip-tab-content.dflip-active {
  display: block;
}

.normal-tabs .dflip-tab-content.dflip-active {
  display: block;
  padding: 10px;
  border: 1px solid #ddd;
  background: #fdfdfd;
}

.has-dragging {
  -webkit-user-select: none;
}

.dflip-box {
  clear: both;
  position: relative;
  border-top: 1px solid #e7e7e7;
  padding: 10px 0 10px;
  margin: 0 10px;
}

.dflip-box:last-child, .dflip-box:first-child {
  border: 0;
}

.dflip-box:last-child {
  padding: 0;
}

.dflip-label {
  display: block;
  width: 35%;
  margin: 0;
  color: #33373a !important;
  font-size: 14px !important;
  font-weight: 600 !important;
  padding: 5px 0px 1px 0px;
}

.dflip-label i {
  font-weight: normal;
}

.dflip-desc {
  font-size: 12px;
  width: 40%;
  margin: 4px 0 10px;
  float: none;
  color: #999;
  display: inline-block;
  vertical-align: top;
  box-sizing: border-box;
  padding-right: 15px;
}

.dflip-option {
  padding: 0;
  box-sizing: border-box;
  position: relative;
  margin-top: -15px;
  float: right;
  display: inline-block;
  vertical-align: top;
  width: 60%;
}

.dflip-option select, .dflip-option input {
  min-width: 160px;
}

.dflip-select select {
  /* height: 28px; */
}

.dflip-option > textarea, .dflip-option > input {
  width: 100%;
}

.dflip-option.dflip-page-list {
  width: 100%;
  padding: 0;
  margin-top: 0;
}

.dflip-page-modal {
  position: fixed;
  top: 20px;
}

ul.dflip-page-list {
  clear: both;
}

.dflip-page-list-add {
}

#dflip_pages_box .dflip-desc, #dflip_outline_box .dflip-desc {
  width: 100%;
  float: none;
  /* position: absolute; */
}

#dflip_outline_box .dflip-option {
  width: 100%;
  padding: 0;
  font-size: 14px;
}

#dflip_outline_box .dflip-option textarea {
  font-size: 13px;
  display: none;
}

#dflip .ui-sortable-handle {
  min-height: 20px;
  cursor: move;
}

.dflip-upload-input {
  height: 29px;
}

.dflip-upload-input + .dflip-button {
  position: absolute;
  /* width: 80px; */
  /* height: 28px; */
  top: 0;
  right: 0;
  text-align: center;
}

.dflip-upload {
  padding-right: 0;
}

.dflip-upload .dflip-global-value {
  /* padding-left: 0; */
}

.dflip-page-options { display: none; }

.dflip-page-actions {
  position: absolute;
  top: -50%;
  transition: 0.2s;
  width: 120px;
  cursor: default;
  background-color: #fff;
}

ul.dflip-outline-actions {
  position: absolute;
  right: 3px;
  top: 3px;
  display: none;
  margin: 0;
  border-radius: 5px;
  transition: 0.2s;
  cursor: default;
  background-color: #fff;
}

.dflip-page-actions > li,
.dflip-outline-actions > li {
  height: 28px;
  min-width: 28px;
  color: #777;
  float: left;
  background-color: inherit;
  margin: 0;
  cursor: pointer;
}

.dflip-page-actions > li:hover,
.dflip-outline-actions > li:hover {
  background-color: #eee;
}

.dflip-page-actions > li:before,
.dflip-outline-actions > li:before {
  line-height: 1.5;
}

.dflip-page-image-action { }

.dflip-page-edit-action { }

li.dflip-page-remove-action {
  float: right;
  /* background-color: #FF5722; */
  color: #F44336;
  /* padding: 7px 0; */
}

.dflip-page-options label:nth-child(1), .dflip-page-options input:nth-child(2) {
  /* margin-left: 80px; */
  /* width: 200px; */
}

.dflip-page-options label {
  display: block;
  padding: 0px 0 5px;
  margin-top: 10px;
}

.dflip-page-options textarea {
  width: 100%;
}

.dflip-page-item {
  border: 1px solid #ccc;
  width: 120px;
  height: 160px;
  background-color: #f7f7f7;
  overflow: hidden;
  cursor: move;
  position: relative;
  margin: 0 10px 10px 0;
  display: inline-block;
}

.dflip-page-edit {
  width: 100%;
  height: auto;
}

.dflip-page-edit .dflip-page-thumb {
  width: 120px;
  left: 0;
  margin: 0;
}

.dflip-page-edit .dflip-page-options {
  display: block;
  padding-left: 130px;
  padding-right: 10px;
  background-color: white;
}

li.dflip-page-item:hover .dflip-page-actions {
  top: 0;
}

.outline-wrapper:hover > .dflip-outline-actions {
  /* right: 2px; */
  display: block;
}

.dflip-empty-page {
  display: none;
}

.dflip-handle {
  cursor: move;
  z-index: 1;
  height: 100%;
  position: relative;
  background-color: #f7f7f7;
}

.dflip-page-thumb {
  width: 100%;
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  margin: auto;
  bottom: 0;
}

img.dflip-page-thumb {
}

.outline-node { position: relative; /* border-top: 1px solid #eee; */ overflow: hidden; cursor: pointer; /* margin-left: 20px; */ padding: 2px 0 0; }

#dflip_outline_box:focus {
  background-color: green;
}

.outline-node.outline-haschild.outline-collapsed .outline-wrapper {
  background-color: #eee;
}

.outline-node:last-child:after {
  display: none;
}

.outline-node:before, .outline-node:after {
  position: absolute;
  content: "";
}

.outline-node:before {
  top: 0px;
  left: 5px;
  margin-top: 0px;
  height: 20px;
  width: 14px;
  border: 0;
  z-index: 0;
  /* border-radius: 0 0 0 4px; */
  border-bottom: 1px solid;
  border-left: 1px solid;
  border-color: #bbb;
}

.outline-node:after {
  top: 20px;
  left: 5px;
  margin-top: 0px;
  height: 100%;
  width: 30px;
  border: 0;
  border-left: 1px solid;
  border-color: #bbb;
}

.outline-node .outline-wrapper > input {
  display: none;
  height: 22px;
  font-size: 13px;
  border: 1px solid #ddd;
}

.outline-node.outline-active > .outline-wrapper > input {
  display: inline-flex;
}

.outline-node.outline-active > .outline-wrapper > label {
  display: none;
}

.outline-node > input {
  box-shadow: none;
  border: 1px solid #bbb;
}

.outline-nodes { padding-left: 20px; position: relative; border-left: 1px solid #fff; }

.outline-nodes .outline-node { }

.outline-node .outline-wrapper {
  height: 34px;
  border: 1px solid #bbb;
  border-radius: 5px;
  padding: 4px;
  z-index: 2;
  position: relative;
  box-sizing: border-box;
  margin-left: 20px;
  padding-left: 10px;
  background-color: #fff;
}

.outline-wrapper.has-drag-over {
  border: 3px solid green;
}

.outline-wrapper.has-drag-after {
  border-bottom: 6px solid green;
}

.outline-wrapper.has-drag-before {
  border-top: 6px solid green;
}

.has-drag-over.is-drag-source, .is-drag-source ~ .outline-nodes .has-drag-over {
  border-color: red !important;
}

.is-drag-source,
.is-drag-source ~ .outline-nodes .outline-wrapper { opacity: 0.2; }

.outline-collapse {
  position: absolute;
  left: 10px;
  font-size: 14px;
  z-index: 3;
  display: none;
  top: 8px;
  border-radius: 50%;
  background-color: #fff;
  border: 1px solid #bbb;
}

.outline-collapse:before {
  line-height: 1.5;
}

.outline-wrapper label {
  /* min-height: 30px; */
  display: inline-block;
  min-width: 30px;
  padding: 2px 5px;
}

.outline-wrapper input:nth-child(3) {
  /* width: 50px; */
  flex-grow: 2;
}

.outline-haschild > .outline-collapse {
  display: block;
  transition: 0.2s;
  transform-origin: center;
}

.outline-collapsed .outline-collapse {
  transform: rotateZ(-90deg);
}

.outline-collapsed .outline-nodes {
  display: none;
}

.drag-helper {
  background-color: #aaa;
  /* width:50px; */
  position: absolute;
  z-index: 200;
  /* height: 50px; */
  padding: 10px;
  color: white;
  pointer-events: none;
}

.dflip-page-modal {
}

.dflip-page-modal .page-modal-close {
  border-left: 1px solid #ddd;
  cursor: pointer;
  text-align: center;
}

.dflip-page-modal .page-modal-close .media-modal-icon {
  margin-top: 15px;
  display: block;
}

.page-modal-image-wrapper {
  max-width: 100%;
  /* max-height: 100%; */
  position: absolute;
  margin-top: 40px;
  /* overflow: hidden; */
  /* padding-right: 300px; */
  -webkit-user-select: none;
}

.dflip-page-modal .media-frame-content {
  /* overflow: hidden; */
  /* position: relative; */
  background-color: #eee;
}

img.page-modal-image {
  max-width: 100%;
  max-height: 100%;
  margin: 0;
  border: 0;
  display: block;
}

.page-hotspot-container { }

.dflip-hotspot {
  position: absolute;
  cursor: pointer;
  border: 1px solid #ccc;
  box-sizing: border-box !important;
}

.dflip-hotspot-helper {
  position: absolute !important;
  z-index: 20;
  cursor: move;
  /* border: 2px solid black; */
  box-sizing: border-box !important;
}

.dflip-hotspot:hover, .dflip-hotspot-helper {
  background-color: rgba(255, 255, 0, 0.22);
}

.dflip-hotspot {
  background-color: rgba(255, 255, 0, 0.22);
}

.dflip-hotspot-helper .ui-resizable-handle {
  background: #f5dc58;
  border: 1px solid #FFF;
  width: 9px;
  height: 9px;
  box-sizing: border-box !important;
  z-index: 2;
  position: absolute;
}

.dflip-hotspot-helper .ui-resizable-nw { cursor: nw-resize; width: 9px; height: 9px; left: -5px; top: -5px; }

.dflip-hotspot-helper .ui-resizable-ne { cursor: ne-resize; width: 9px; height: 9px; right: -5px; top: -5px; }

.dflip-hotspot-helper .ui-resizable-sw { cursor: sw-resize; width: 9px; height: 9px; left: -5px; bottom: -5px; }

.dflip-hotspot-helper .ui-resizable-se { cursor: se-resize; width: 9px; height: 9px; right: -5px; bottom: -5px; }

.dflip-hotspot-helper .dflip-hotspot-delete {
  position: absolute;
  right: 10px;
  top: 5px;
  cursor: pointer;
}

.dflip-hotspot-helper .dflip-hotspot-delete:hover {
  color: #F44336;
}

.dflip-add-hotspot {
  margin: 5px !important;
  /* top: 10px; */
  /* width: 36px; */
  z-index: 50;
  /* position: fixed; */
}

.dflip-hotspot-header {
  position: fixed;
  /* width: 100%; */
  background-color: #eee;
  z-index: 100;
}

.dflip-remove-hotspot {
  float: right;
  margin: 5px !important;
}

.dflip-hotspot-dest {
  height: 30px;
  vertical-align: middle;
  width: 240px;
  font-size: 12px;
  margin: 5px !important;
}

.df-js-code {
  font-family: monospace;
  font-size: 12px;
}

input#dflip_settings_submit {
  float: right;
  margin-right: -12px;
  z-index: 100;
  margin-top: -45px;
}

.dflip-global-value {
  color: #999;
  font-size: 11px;
  display: inline-block;
  /* padding-left: 10px; */
}

.dflip-global-active {
}

.dflip-global-active ~ .dflip-global-value {
}

.dflip-global-inactive ~ .dflip-global-value {
  text-decoration: line-through;
  opacity: 0.4;
}

.dflip-global-active ~ .dflip-global-value:after {
  content: " Active";
}

.dflip-global-inactive ~ .dflip-global-value:after {
  content: " Inactive";
}

.dflip-settings.premium .dflip-box,
.dflip-box.premium {
  background-color: rgba(231, 231, 231, 0.37);
  margin: 0 -10px;
  padding: 10px 20px;
}

#dflip_post_meta_box_limit .inside,
.dflip-settings.premium .dflip-box .dflip-option,
.dflip-box.premium .dflip-option {
  color: red !important;
}

.dflip-settings.premium .dflip-box .dflip-label:after,
.dflip-box.premium .dflip-label:after {
  content: 'Premium!';
  color: red;
  font-size: 12px;
}

.video-tutorial {
  display: block;
  color: crimson;
}

.video-tutorial .dashicons {
  text-decoration: none;
  margin-right: 10px;
}

a.df-offer-notice {
  overflow: hidden;
  font-size: 0;
}

a.df-offer-notice img {
  width: 100%;
  display: block;
  margin: -1px 0 0;
}

a.df-chrome {
  background-image: url("../images/chrome-extension.png");
  height: 77px;
  background-position: center bottom;
  background-repeat: no-repeat;
  display: block;
  border: 2px solid #e5e5e5;
  box-shadow: 0 1px 2px rgba(0, 0, 0, .1);
  padding: 10px;
  /* letter-spacing: 0.2px; */
  background-size: 250px 75px;
  text-decoration: none;
  text-align: right;
  font-size: 12px;
  color: #818284;
  text-transform: uppercase;
}

body.rtl form#dflip-settings {
  margin: 0 0 0 20px;
}

body.rtl .dflip-option {
  float: left;
}

body.rtl .dflip-desc {
  padding: 0 0 0 15px;
}

body.rtl .dflip-upload input {
  padding-right: 100px;
}

body.rtl input#dflip_settings_submit {
  float: left;
  margin: -45px 0 0 -12px;
}

/*Content is used for revision storage*/
body.wp-admin.post-type-dflip #wpbody-content #postdivrich {
  display: none;
}

/*revisions for backups are still beta so disabled for now*/
body.wp-admin.post-type-dflip .misc-pub-revisions,
body.wp-admin.post-type-dflip #revisionsdiv {
  display: none;
}
