<?php
defined( 'ABSPATH' ) || exit;

$html = '';

$html .= '<div class="wpex-card-inner wpex-relative wpex-transition-shadow wpex-duration-150 wpex-hover-shadow-lg">';

	// Sale flash
	$sale_flash = $this->get_sale_flash( array(
		'class' => 'wpex-absolute wpex-z-5 wpex-left-0 wpex-top-0 wpex-inline-block wpex-py-5 wpex-px-10 wpex-mb-20 wpex-bg-accent wpex-leading-normal wpex-text-xs wpex-uppercase wpex-font-semibold',
	) );

	// Media
	$html .= $this->get_media( array(
		'before' => $sale_flash,
	) );

	// Details
	$html .= '<div class="wpex-card-details wpex-p-15 wpex-last-mb-0">';

		// Categories
		$html .= $this->get_terms_list( array(
			'class' => 'wpex-last-mr-0 wpex-text-3 wpex-child-inherit-color',
			'separator' => ' &middot; ',
		) );

		// Title
		$html .= $this->get_title( array(
			'class' => 'wpex-heading wpex-mb-10 wpex-font-semibold',
		) );

		// Price
		$html .= $this->get_price( array(
			'class' => 'wpex-text-1 wpex-text-lg wpex-font-semibold',
			'show_sale' => true,
			'min_max' => true,
		) );

	$html .= '</div>';

$html .= '</div>';

return $html;