<?php
namespace TotalTheme\Filters;

defined( 'ABSPATH' ) || exit;

/**
 * Hooks into "tag_cloud_args".
 *
 * @package TotalTheme
 * @subpackage Filters
 * @version 5.4
 */
final class Tag_Cloud_Args {

	/**
	 * Callback method.
	 */
	public static function callback( $args ) {
		$args['largest']  = '1';
		$args['smallest'] = '1';
		$args['unit']     = 'em';
		return $args;
	}

}