<?php
use TotalTheme\Integration\WPBakery\Shortcode_Inline_Style as WPB_Style;

/**
 * Togglebar content.
 *
 * @package Total WordPress theme
 * @subpackage Partials
 * @version 5.4.6
 */

defined( 'ABSPATH' ) || exit;

if ( $content = wpex_togglebar_content() ) :

	WPB_Style::instance()->render_style( wpex_togglebar_content_id() );
	?>

	<div class="entry wpex-clr"><?php

		echo do_shortcode( wp_kses_post( $content ) );

	?></div>

<?php endif; ?>