<?php
defined( 'ABSPATH' ) || exit;

require_once WPEX_CUSTOMIZER_DIR . 'settings/global-styles/accent-colors.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/global-styles/color-scheme.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/global-styles/user-selection.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/global-styles/links.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/global-styles/buttons.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/global-styles/blockquote.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/global-styles/forms.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/global-styles/tables.php';