/*!
 * jQuery ClassyGradient
 * www.class.pm
 *
 * Written by Marius Stanciu - Sergiu <marius@class.pm>
 * Licensed under the MIT license www.class.pm/LICENSE-MIT
 * Version 1.1.0
 *
 */

.ClassyGradient {
    margin-bottom: 18px
}

.ClassyGradient .canvas {
    border: 1px solid #333
}

.ClassyGradient .info {
    display: none;
    margin-right: 20px;
    margin-top: 20px;
    position: absolute;
    z-index: 80
}

.ClassyGradient .info .arrow {
    top: -17px;
    border-style: solid;
    border-width: 10px;
    height: 0;
    width: 0;
    margin-left: 20px;
    border-color: transparent transparent #000 transparent
}

.ClassyGradient .info .content {
    color: #fff;
    background-color: #000;
    padding: 8px;
    padding-top: 5px;
    padding-bottom: 4px;
    font-size: 12px;
    font-family: Verdana, Arial;
    border-radius: 5px
}

.ClassyGradient .points {
    position: absolute;
    z-index: 99;
    max-height: 20px;
    margin-top: 2px
}

.ClassyGradient .point {
    position: absolute;
    width: 8px;
    margin-left: -4px;
    height: 8px;
    top: 0;
    border: 1px solid #333;
    cursor: pointer
}

.ClassyGradient .point-position {
    position: relative;
    top: -12px;
    margin-left: 6px
}

.ClassyGradient .delete {
    display: inline-block;
    width: 16px;
    height: 16px;
    background-image: url(images/close.png);
    position: relative;
    top: -9px;
    margin-left: 8px
}

.ClassyGradient .point-color {
    display: inline-block;
    width: 36px;
    height: 36px;
    background: url(images/select.png)
}

.ClassyGradient .point-color div {
    position: relative;
    top: 4px;
    left: 4px;
    width: 28px;
    height: 28px;
    background: url(images/select.png) center
}

.colorpicker{
    z-index: 999999;
}
