.wpex-mf-metabox table tr:not(:first-child){border-top:1px solid #eee}.wpex-mf-metabox table th{width:240px;padding:15px 30px 15px 0}#side-sortables .wpex-mf-metabox table th{width:auto}.wpex-mf-metabox table td[colspan="2"]{padding:0}.wpex-mf-metabox table .wpex-mf-label{font-size:14px;color:#444;font-weight:bold}.wpex-mf-metabox textarea{width:100%}.wpex-mf-metabox .wpex-mf-description{color:#666;font-size:12px;font-weight:normal;margin:0;padding:0;padding-top:4px}.wpex-mf-metabox .wpex-mf-after-hook{margin-top:12px}.wpex-mf-metabox .wpex-mf-hidden{display:none}.wpex-mf-metabox fieldset{background-color:#fafafa;border:1px solid #ededed;padding:10px 15px}.wpex-mf-metabox .wpex-mf-upload-preview{margin-top:10px;font-size:0.9em}.wpex-mf-metabox .wpex-mf-upload-preview img{height:50px;width:auto;max-width:100%;vertical-align:middle}.wpex-mf-metabox .wpex-mf-upload-preview__loader{height:15px;width:15px}.wpex-mf-metabox .wpex-mf-group{border:1px solid #ddd}.wpex-mf-metabox .wpex-mf-group-fields{padding:10px}.wpex-mf-metabox .wpex-mf-group-fields table{border-collapse:collapse;width:100%;border:0}.wpex-mf-metabox .wpex-mf-group-fields table tr{border:0}.wpex-mf-metabox .wpex-mf-group-fields table td,.wpex-mf-metabox .wpex-mf-group-fields table th{border:0;padding:5px 8px}.wpex-mf-metabox .wpex-mf-group-fields table th{vertical-align:middle}.wpex-mf-metabox .wpex-mf-group-header{display:flex;justify-content:space-between;align-items:center;border-bottom:1px solid #ddd;padding:0 0 0 10px;min-height:36px;font-weight:bold;background-color:#efefef}.wpex-mf-metabox .wpex-mf-group-header-actions{text-align:right}.wpex-mf-metabox .wpex-mf-group-header-actions button{width:36px;height:36px;margin:0;padding:0;border:0;background:0 0;cursor:pointer}.wpex-mf-metabox .wpex-mf-group{margin-bottom:20px}.wpex-mf-metabox .wpex-mf-remove-group-set[disabled]{display:none !important}.wpex-mf-metabox .wpex-mf-icon-select-modal{position:fixed;top:0;left:0;width:100%;height:100%;z-index:99999;background:rgba(0,0,0,0.7);align-items:center;justify-content:center;display:none}.wpex-mf-metabox .wpex-mf-icon-select-modal.wpex-mf-active{display:flex !important}.wpex-mf-metabox .wpex-mf-icon-select-modal input[type="search"]{width:100%;margin-bottom:8px}.wpex-mf-metabox .wpex-mf-icon-select-modal a{text-decoration:none}.wpex-mf-metabox .wpex-mf-icon-select-modal .wpex-svg-icon{display:flex;align-items:center;justify-content:center}.wpex-mf-metabox .wpex-mf-icon-select-modal-inner{width:520px;max-width:100%;background:#fff;padding:15px}.wpex-mf-metabox .wpex-mf-icon-select-modal-inner button{float:right}.wpex-mf-metabox .wpex-mf-icon-select-modal-choices{height:348px;max-height:100%;overflow-y:scroll;margin-bottom:12px;padding:2px}.wpex-mf-metabox .wpex-mf-icon-select-modal-choices a{display:flex;align-items:center;justify-content:center;float:left;width:40px;height:40px;font-size:24px;border:1px solid #ddd;margin:0 8px 8px 0}.wpex-mf-metabox .wpex-mf-icon-select-modal-choices a svg{fill:currentColor;height:1em;width:auto}.wpex-mf-metabox .wpex-mf-icon-select-modal-choices a:hover{background:#eee}.wpex-mf-metabox .wpex-mf-icon-select-preview{display:flex;margin-top:10px;font-size:32px}.wpex-mf-metabox .wpex-mf-icon-select-preview svg{height:1em;width:auto}.wpex-mf-metabox .wpex-mf-icon-select-preview>span{line-height:initial;height:auto;width:auto}#side-sortables .wpex-mf-metabox tr.wpex-mf-tr th,#side-sortables .wpex-mf-metabox tr.wpex-mf-tr td{display:block}#side-sortables .wpex-mf-metabox tr.wpex-mf-tr th{padding:15px 0 0}#side-sortables .wpex-mf-metabox tr.wpex-mf-tr td{padding:5px 0 15px;margin:0}#side-sortables .wpex-mf-metabox tr.wpex-mf-tr input[type="text"],#side-sortables .wpex-mf-metabox tr.wpex-mf-tr textarea,#side-sortables .wpex-mf-metabox tr.wpex-mf-tr select{width:100%;box-sizing:border-box}
