<?php
defined( 'ABSPATH' ) || exit;

$html = '';

$html .= '<div class="wpex-card-inner wpex-flex wpex-flex-col wpex-flex-grow wpex-surface-2 wpex-text-2 wpex-p-30">';

		// Thumbnail
		$html .= $this->get_thumbnail( array(
			'class' => 'wpex-text-center',
			'image_class' => 'wpex-rounded-full',
			'link' => false,
		) );

		// Excerpt.
		$html .= $this->get_excerpt( array(
			'length' => '-1',
			'class' => 'wpex-my-20',
		) );

		// Author
		$html .= $this->get_element( array(
			'content' => wpex_get_testimonial_author(),
			'class' => 'wpex-card-testimonial-author wpex-text-1 wpex-font-semibold wpex-text-md wpex-mt-auto',
		) );

		// Company
		$html .= $this->get_element( array(
			'content' => wpex_get_testimonial_company(),
			'class' => 'wpex-card-testimonial-company wpex-text-sm wpex-opacity-70',
		) );

$html .= '</div>';

return $html;