<?php
defined( 'ABSPATH' ) || exit;

$templates['faq-1'] = array();
$templates['faq-1']['name'] = esc_html__( 'FAQ', 'total' ) . ' 1';
$templates['faq-1']['category'] = 'faq';
$templates['faq-1']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627254843748{padding-top: 60px !important;padding-bottom: 70px !important;}"][vc_column][vcex_heading text="Frequently Asked Questions" text_align="center" tag="h2" font_size="30px" font_weight="700"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing size="55px"][vcex_grid_container columns_lg="2" gap="40px"][vcex_teaser heading="Lorem ipsum dolor sit amet, consectetur?" heading_type="h3" heading_size="1.38em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_teaser][vcex_teaser heading="Nam sem ante, euismod eget hendrerit?" heading_type="h3" heading_size="1.38em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_teaser][vcex_teaser heading="Suspendisse congue egestas nulla vel?" heading_type="h3" heading_size="1.38em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_teaser][vcex_teaser heading="Interdum et malesuada fames ac ante ipsum?" heading_type="h3" heading_size="1.38em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_teaser][vcex_teaser heading="Integer maximus velit ac rutrum pretium?" heading_type="h3" heading_size="1.38em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_teaser][vcex_teaser heading="Class aptent taciti sociosqu ad litora torquent?" heading_type="h3" heading_size="1.38em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_teaser][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['faq-2'] = array();
$templates['faq-2']['name'] = esc_html__( 'FAQ', 'total' ) . ' 2';
$templates['faq-2']['category'] = 'faq';
$templates['faq-2']['content'] = <<<CONTENT
[vc_row column_spacing="60" css=".vc_custom_1627254912326{margin-top: 40px !important;}"][vc_column width="1/3"][vcex_heading text="Frequently asked questions" icon_position="right" icon_side_margin="5px" tag="h2" font_size="25px" font_weight="700" icon="ticon ticon-question-circle"][vcex_spacing size="15px"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros.[/vc_column_text][vcex_divider color="#222222" visibility="visible-phone" height="2px" margin="top:40px"][/vc_column][vc_column width="2/3"][vcex_grid_container columns_lg="" gap="30px"][vcex_teaser heading="Lorem ipsum dolor sit amet, consectetur?" heading_type="h3" heading_size="1.38em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula. Donec malesuada enim tristique, aliquet ligula vestibulum, placerat lacus.[/vcex_teaser][vcex_teaser heading="Nam sem ante, euismod eget hendrerit?" heading_type="h3" heading_size="1.38em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula. Donec malesuada enim tristique, aliquet ligula vestibulum, placerat lacus.[/vcex_teaser][vcex_teaser heading="Suspendisse congue egestas nulla vel?" heading_type="h3" heading_size="1.38em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula. Donec malesuada enim tristique, aliquet ligula vestibulum, placerat lacus.[/vcex_teaser][vcex_teaser heading="Interdum et malesuada fames ac ante ipsum?" heading_type="h3" heading_size="1.38em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula. Donec malesuada enim tristique, aliquet ligula vestibulum, placerat lacus.[/vcex_teaser][/vcex_grid_container][/vc_column][/vc_row][vc_row][vc_column][/vc_column][/vc_row]
CONTENT;

$templates['faq-3'] = array();
$templates['faq-3']['name'] = esc_html__( 'FAQ', 'total' ) . ' 3';
$templates['faq-3']['category'] = 'faq';
$templates['faq-3']['content'] = <<<CONTENT
[vc_row gap="30" equal_height="yes" css=".vc_custom_1627254934565{margin-top: 40px !important;margin-right: 0px !important;margin-left: 0px !important;}"][vc_column width="2/5" css=".vc_custom_1626898651216{background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vcex_image source="external" external_image="{$ph_portrait}"][/vc_column][vc_column width="3/5"][vcex_heading text="Frequently asked questions" icon_position="right" tag="h2" font_size="25px" font_weight="700"][vcex_spacing size="15px"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing][vcex_toggle_group width="600px"][vcex_toggle icon_position="right" content_spacing="" heading_color_hover="accent" heading_color="#000000" heading_font_weight="semibold"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla eros urna, aliquet et porttitor in, congue ut risus. Nunc placerat faucibus ligula a mattis.[/vcex_toggle][vcex_toggle heading="Nam sem ante, euismod eget hendrerit?" icon_position="right" content_spacing="" heading_color_hover="accent" heading_color="#000000" heading_font_weight="semibold"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla eros urna, aliquet et porttitor in, congue ut risus. Nunc placerat faucibus ligula a mattis.[/vcex_toggle][vcex_toggle heading="Suspendisse congue egestas nulla vel?" icon_position="right" content_spacing="" heading_color_hover="accent" heading_color="#000000" heading_font_weight="semibold"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla eros urna, aliquet et porttitor in, congue ut risus. Nunc placerat faucibus ligula a mattis.[/vcex_toggle][vcex_toggle heading="Interdum et malesuada fames ac ante ipsum?" icon_position="right" content_spacing="" heading_color_hover="accent" heading_color="#000000" heading_font_weight="semibold"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla eros urna, aliquet et porttitor in, congue ut risus. Nunc placerat faucibus ligula a mattis.[/vcex_toggle][vcex_toggle heading="Class aptent taciti sociosqu ad litora torquent?" icon_position="right" content_spacing="" heading_color_hover="accent" heading_color="#000000" heading_font_weight="semibold"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla eros urna, aliquet et porttitor in, congue ut risus. Nunc placerat faucibus ligula a mattis.[/vcex_toggle][/vcex_toggle_group][/vc_column][/vc_row]
CONTENT;

$templates['faq-4'] = array();
$templates['faq-4']['name'] = esc_html__( 'FAQ', 'total' ) . ' 4';
$templates['faq-4']['category'] = 'faq';
$templates['faq-4']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1626838082392{padding-top: 8% !important;padding-bottom: 10% !important;background-color: #3858e9 !important;}"][vc_column][vcex_heading text="Frequently Asked Questions" tag="h2" font_size="30px" font_weight="700" color="#ffffff"][vcex_divider color="rgba(255,255,255,0.7)" margin="top:20px|bottom:50px"][vcex_grid_container columns_lg="2" gap="40px"][vcex_teaser heading="Lorem ipsum dolor sit amet, consectetur?" heading_type="h3" heading_size="1.38em" heading_color="#ffffff" content_color="rgba(255,255,255,0.6)"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_teaser][vcex_teaser heading="Nam sem ante, euismod eget hendrerit?" heading_type="h3" heading_size="1.38em" heading_color="#ffffff" content_color="rgba(255,255,255,0.6)"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_teaser][vcex_teaser heading="Suspendisse congue egestas nulla vel?" heading_type="h3" heading_size="1.38em" heading_color="#ffffff" content_color="rgba(255,255,255,0.6)"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_teaser][vcex_teaser heading="Interdum et malesuada fames ac ante ipsum?" heading_type="h3" heading_size="1.38em" heading_color="#ffffff" content_color="rgba(255,255,255,0.6)"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_teaser][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['faq-5'] = array();
$templates['faq-5']['name'] = esc_html__( 'FAQ', 'total' ) . ' 5';
$templates['faq-5']['category'] = 'faq';
$templates['faq-5']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627254971139{padding-top: 60px !important;padding-bottom: 70px !important;}"][vc_column][vcex_heading text="Frequently Asked Questions" bottom_margin="10px" text_align="center" tag="h2" font_size="30px" font_weight="700"][vcex_divider color="#e0e0e0" width="60px" align="center" margin="top:20px|bottom:50px"][vcex_toggle_group max_width="500px" el_class="wpex-last-border-none"][vcex_toggle icon_type="angle" icon_position="right" heading_tag="h4" heading_font_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc auctor in ante a rhoncus. Nullam ultrices augue odio, id finibus nibh viverra vel. Maecenas arcu mi, placerat ut feugiat a, gravida in nisl. Etiam lacinia tempus orci, id feugiat mi scelerisque vel.[/vcex_toggle][vcex_toggle heading="Nam sem ante, euismod eget hendrerit?" icon_type="angle" icon_position="right" heading_tag="h4" heading_font_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc auctor in ante a rhoncus. Nullam ultrices augue odio, id finibus nibh viverra vel. Maecenas arcu mi, placerat ut feugiat a, gravida in nisl. Etiam lacinia tempus orci, id feugiat mi scelerisque vel.[/vcex_toggle][vcex_toggle heading="Suspendisse congue egestas nulla vel?" icon_type="angle" icon_position="right" heading_tag="h4" heading_font_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc auctor in ante a rhoncus. Nullam ultrices augue odio, id finibus nibh viverra vel. Maecenas arcu mi, placerat ut feugiat a, gravida in nisl. Etiam lacinia tempus orci, id feugiat mi scelerisque vel.[/vcex_toggle][vcex_toggle heading="Quisque id rutrum erat, sed pellentesque ante?" icon_type="angle" icon_position="right" heading_tag="h4" heading_font_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla eros urna, aliquet et porttitor in, congue ut risus. Nunc placerat faucibus ligula a mattis.[/vcex_toggle][vcex_toggle heading="Nulla eros urna, aliquet et porttitor?" icon_type="angle" icon_position="right" heading_tag="h4" heading_font_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla eros urna, aliquet et porttitor in, congue ut risus. Nunc placerat faucibus ligula a mattis.[/vcex_toggle][vcex_toggle heading="Dolor sit amet, consectetur adipiscing?" icon_type="angle" icon_position="right" heading_tag="h4" heading_font_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla eros urna, aliquet et porttitor in, congue ut risus. Nunc placerat faucibus ligula a mattis.[/vcex_toggle][/vcex_toggle_group][vcex_spacing size="40px"][vcex_heading text="Still Have Questions?" bottom_margin="10px" text_align="center" tag="h2" font_size="1.6em" font_weight="700"][vc_column_text width="500px" align="center" text_align="center" font_size="1.1em"]If you can't find an answer to your question in the FAQ's below, you can always <a href="#">contact us</a> and we'll respond asap.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

$templates['faq-6'] = array();
$templates['faq-6']['name'] = esc_html__( 'FAQ', 'total' ) . ' 6';
$templates['faq-6']['category'] = 'faq';
$templates['faq-6']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627250940195{padding-top: 60px !important;padding-bottom: 70px !important;background-color: #f7f7f7 !important;}"][vc_column][vcex_heading text="FAQs" text_align="center" tag="h2" font_size="d:100px|tp:60px" font_weight="700" line_height="1"][vcex_spacing size="50px"][vcex_grid_container columns_lg="2" gap="35px"][vcex_icon_box heading="Nam sem ante, euismod eget hendrerit?" wpex_padding="30px" shadow="shadow-lg" icon="ticon ticon-question-circle-o" heading_size="1.38em" heading_type="h3" heading_weight="600" heading_bottom_margin="10px" background_color="#ffffff" icon_size="32px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_icon_box][vcex_icon_box heading="Suspendisse congue egestas nulla vel?" wpex_padding="30px" shadow="shadow-lg" icon="ticon ticon-question-circle-o" heading_size="1.38em" heading_type="h3" heading_weight="600" heading_bottom_margin="10px" background_color="#ffffff" icon_size="32px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_icon_box][vcex_icon_box heading="Integer maximus velit ac rutrum pretium?" wpex_padding="30px" shadow="shadow-lg" icon="ticon ticon-question-circle-o" heading_size="1.38em" heading_type="h3" heading_weight="600" heading_bottom_margin="10px" background_color="#ffffff" icon_size="32px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_icon_box][vcex_icon_box heading="Class aptent taciti sociosqu ad torquent?" wpex_padding="30px" shadow="shadow-lg" icon="ticon ticon-question-circle-o" heading_size="1.38em" heading_type="h3" heading_weight="600" heading_bottom_margin="10px" background_color="#ffffff" icon_size="32px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique.[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;
// IMPORTANT - Space required to prevent HEREDOC errors.
?>