<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Title
$html .= $this->get_title( array(
	'class' => 'wpex-heading wpex-text-lg',
) );

$html .= '<div class="wpex-card-meta wpex-mt-5 wpex-text-3 wpex-child-inherit-color wpex-last-mr-0">';

	// Author
	$html .= $this->get_author( array(
		'html_tag' => 'span',
		'prefix' => esc_html( 'by', 'total' ) . ' ',
		'class' => 'wpex-inline-block wpex-mr-5',
		'link_class' => 'wpex-underline',
	) );

	// Date
	$html .= $this->get_date( array(
		'html_tag' => 'span',
		'prefix' => esc_html( 'on', 'total' ) . ' ',
		'class' => 'wpex-inline-block wpex-mr-5',
	) );

$html .= '</div>';

return $html;