.wpex-has-vertical-header{position:relative}.wpex-has-vertical-header #site-header{position:absolute;z-index:99;top:0;width:var(--wpex-vertical-header-width, 280px);height:100%}.wpex-has-vertical-header #site-header.header-six{box-shadow:0 0 7px rgba(0,0,0,0.1)}.wpex-has-vertical-header #site-header .container{width:100%;max-width:100%}.wpex-has-vertical-header.wpex-fixed-vertical-header #site-header{overflow:visible}.wpex-has-vertical-header.wpex-fixed-vertical-header.site-full-width #site-header{position:fixed}.wpex-has-vertical-header.wpex-fixed-vertical-header.site-full-width.admin-bar #site-header{top:32px}.wpex-has-vertical-header.wpex-fixed-vertical-header.site-boxed #outer-wrap{overflow:visible}.wpex-has-vertical-header.wpex-fixed-vertical-header.site-boxed #site-header-inner{position:sticky;top:0;height:auto}.wpex-has-vertical-header #site-logo{display:block}.wpex-has-vertical-header #site-logo .logo-img{display:block;margin:0 auto}.wpex-has-vertical-header .header-six #site-logo{padding:0 30px 30px 30px}.wpex-has-vertical-header #site-logo-inner{display:block}.wpex-has-vertical-header #site-navigation{--wpex-main-nav-gutter:0px}.wpex-has-vertical-header #site-navigation .main-navigation-ul ul{top:0;text-align:right}.wpex-has-vertical-header #site-navigation .main-navigation-ul .megamenu{position:relative}.wpex-has-vertical-header #site-navigation .main-navigation-ul .megamenu>ul{width:750px}.wpex-has-vertical-header .page-header{border-top:0}.wpex-has-vertical-header .wcmenucart-icon{margin-left:var(--wpex-main-nav-icon-margin, .615em)}.wpex-has-vertical-header .wcmenucart-text{display:inline-block}.wpex-vertical-header-left.full-width-main-layout #wrap,.wpex-vertical-header-left .toggle-bar-inline{padding-right:var(--wpex-vertical-header-width, 280px)}.wpex-vertical-header-left #site-header{right:0}.wpex-vertical-header-left #site-navigation .main-navigation-ul ul{right:100%}.wpex-vertical-header-left .main-navigation-ul .megamenu>ul{right:100%}.wpex-vertical-header-left.boxed-main-layout #wrap{padding-right:var(--wpex-vertical-header-width, 280px)}.wpex-vertical-header-left.boxed-main-layout.wpex-site-header-disabled #wrap{padding-right:0}.wpex-vertical-header-left.boxed-main-layout #site-header .container{padding-right:0 !important;padding-left:0 !important}.wpex-vertical-header-right.full-width-main-layout #wrap,.wpex-vertical-header-right .toggle-bar-inline{padding-left:var(--wpex-vertical-header-width, 280px)}.wpex-vertical-header-right #site-header{left:0}.wpex-vertical-header-right.boxed-main-layout #wrap{padding-left:var(--wpex-vertical-header-width, 280px)}.wpex-vertical-header-right.boxed-main-layout.wpex-site-header-disabled #wrap{padding-left:0}.wpex-vertical-header-right.boxed-main-layout #site-header .container{padding-left:0 !important;padding-right:0 !important}.wpex-vertical-header-right #site-navigation .main-navigation-ul ul{left:100%;left:initial}.wpex-vertical-header-right .main-navigation-ul .megamenu>ul{left:100%;left:initial}.navbar-style-six{--wpex-main-nav-link-padding-y:1em;--wpex-main-nav-link-padding-x:30px;--wpex-hover-main-nav-link-bg:var(--wpex-surface-2);--wpex-active-main-nav-link-bg:var(--wpex-surface-2);background:var(--wpex-main-nav-bg, transparent)}.main-navigation-six{--wpex-main-nav-icon-margin:.769em;border-top:var(--wpex-main-nav-item-border-width, 1px) solid var(--wpex-main-nav-border-color, var(--wpex-surface-3))}.main-navigation-six .main-navigation-ul>.menu-item{display:block;float:none;width:100%;height:auto;border-bottom:var(--wpex-main-nav-item-border-width, 1px) solid var(--wpex-main-nav-border-color, var(--wpex-surface-3))}.main-navigation-six .main-navigation-ul>.menu-item.menu-item-has-children>a{padding-left:50px}.main-navigation-six .main-navigation-ul>.menu-item>a{line-height:inherit}.main-navigation-six .main-navigation-ul .nav-arrow.top-level{position:absolute;left:20px;top:50%;height:20px;line-height:20px;margin-top:-10px}.main-navigation-six .wpex-menu-search-text{display:inline-block}.main-navigation-six .sf-menu{float:none}.main-navigation-six .sf-menu .menu-item{white-space:normal}.main-navigation-six .menu-button>a{--wpex-menu-btn-padding:var(--wpex-btn-padding)}.anim-shrink-header #site-header-sticky-wrapper,.anim-shrink-header #site-header,.anim-shrink-header #site-header-inner,.anim-shrink-header .navbar-style-five,.anim-shrink-header .navbar-style-five #site-navigation,.anim-shrink-header #site-logo,.anim-shrink-header #site-logo-inner,.anim-shrink-header #site-logo-link,.anim-shrink-header #site-logo .logo-img{transition:none}.wpex-has-vertical-header{--wpex-vc-full-width-offset:var(--wpex-vertical-header-width, 280px)}
