<?php
/**
 * Customizer Settings > Tribe Events
 *
 * @package TotalTheme
 * @subpackage Tribe Events
 * @version 5.4
 */

defined( 'ABSPATH' ) || exit;

// General
$this->sections['wpex_tribe_events'] = array(
	'settings' => array(
		array(
			'id' => 'tribe_events_total_styles',
			'default' => true,
			'control' => array(
				'label' => esc_html__( 'Theme Styles', 'total' ),
				'type' => 'wpex_toggle',
				'description' => esc_html__( 'Enables theme styles. Disable to use the plugin with it\'s default styling only.', 'total' ),
			),
		),
		array(
			'id' => 'tribe_events_page_header_details',
			'default' => true,
			'control' => array(
				'label' => esc_html__( 'Page Header Event Details', 'total' ),
				'type' => 'wpex_toggle',
				'description' => esc_html__( 'If the page header is disabled the event details will display in the default location.', 'total' ),
			),
		),
		array(
			'id' => 'tribe_events_main_page',
			'control' => array(
				'label' => esc_html__( 'Events Page', 'total' ),
				'type' => 'wpex-dropdown-pages',
				'description' => esc_html__( 'Select the page being used as your main Events page.', 'total' ),
			),
		),
		array(
			'id' => 'tribe_events_archive_layout',
			'default' => 'full-width',
			'control' => array(
				'label' => esc_html__( 'Archives Layout', 'total' ),
				'type' => 'select',
				'choices' => 'post_layout',
			),
		),
		array(
			'id' => 'tribe_events_single_layout',
			'default' => 'full-width',
			'control' => array(
				'label' => esc_html__( 'Single Layout', 'total' ),
				'type' => 'select',
				'choices' => 'post_layout',
			),
		),
	),
);