<div class="welcome-upgrade-wrap">
    <div class="welcome-upgrade-header">
        <h3><?php printf(esc_html__('Total Plus Demos - Premium Version of %s (Customizer & Elementor Version)', 'total'), $this->theme_name); ?></h3>
        <p><?php echo sprintf(esc_html__('Create beautiful websites with the premium version of the %s Theme. The demos are available in both Customizer and Elementor Version. These demos can be imported with just one click in the premium version.', 'total'), $this->theme_name); ?></p>
    </div>

    <div class="recomended-plugin-wrap">
        <div class="recommended-plugins">
            <div class="plugin-image">
                <img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/total.jpg'); ?>" alt="<?php echo esc_attr__('Total Plus Demo', 'total'); ?>">
            </div>

            <div class="plugin-title-wrap">
                <div class="plugin-title">Total</div>
                <div class="plugin-btn-wrapper">
                    <a target="_blank" href="https://demo.hashthemes.com/total-plus/total/" class="button button-primary"><?php echo esc_html__('Preview', 'total'); ?></a>
                </div>
            </div>
        </div>

        <div class="recommended-plugins">
            <div class="plugin-image">
                <img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/construction.jpg'); ?>" alt="<?php echo esc_attr__('Total Plus Demo', 'total'); ?>">
            </div>

            <div class="plugin-title-wrap">
                <div class="plugin-title">Construction</div>
                <div class="plugin-btn-wrapper">
                    <a target="_blank" href="https://demo.hashthemes.com/total-plus/construction/" class="button button-primary"><?php echo esc_html__('Preview', 'total'); ?></a>
                </div>
            </div>
        </div>

        <div class="recommended-plugins">
            <div class="plugin-image">
                <img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/main-demo.jpg'); ?>" alt="<?php echo esc_attr__('Total Plus Demo', 'total'); ?>">
            </div>

            <div class="plugin-title-wrap">
                <div class="plugin-title">Main Demo</div>
                <div class="plugin-btn-wrapper">
                    <a target="_blank" href="https://demo.hashthemes.com/total-plus/main/" class="button button-primary"><?php echo esc_html__('Preview', 'total'); ?></a>
                </div>
            </div>
        </div>

        <div class="recommended-plugins">
            <div class="plugin-image">
                <img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/creative-agency.jpg'); ?>" alt="<?php echo esc_attr__('Total Plus Demo', 'total'); ?>">
            </div>

            <div class="plugin-title-wrap">
                <div class="plugin-title">Creative Agency</div>
                <div class="plugin-btn-wrapper">
                    <a target="_blank" href="https://demo.hashthemes.com/total-plus/creative-agency" class="button button-primary"><?php echo esc_html__('Preview', 'total'); ?></a>
                </div>
            </div>
        </div>

        <div class="recommended-plugins">
            <div class="plugin-image">
                <img src="<?php echo esc_url(get_template_directory_uri() . '/welcome/css/one-page.jpg'); ?>" alt="<?php echo esc_attr__('Total Plus Demo', 'total'); ?>">
            </div>

            <div class="plugin-title-wrap">
                <div class="plugin-title">One Page</div>
                <div class="plugin-btn-wrapper">
                    <a target="_blank" href="https://demo.hashthemes.com/total-plus/one-page" class="button button-primary"><?php echo esc_html__('Preview', 'total'); ?></a>
                </div>
            </div>
        </div>

    </div>
</div>

<div class="welcome-upgrade-box">
    <div class="upgrade-box-text">
        <h3><?php echo esc_html__('Upgrade To Premium Version (7 Days Money Back Guarantee)', 'total'); ?></h3>
        <p><?php echo sprintf(esc_html__('With %s Theme you can create a beautiful website. But if you want to unlock more possibilities then upgrade to the premium version.', 'total'), $this->theme_name); ?></p>
        <p><?php echo esc_html__('Try the Premium version and check if it fits your need or not. If not, we have 7 days money-back guarantee.', 'total'); ?></p>
    </div>

    <a class="upgrade-button" href="https://hashthemes.com/wordpress-theme/total/?utm_source=wordpress&utm_medium=total-footer&utm_campaign=total-upgrade" target="_blank"><?php esc_html_e('Upgrade Now', 'total'); ?></a>
</div>

