$scheme-name: "ectoplasm";
$base-color: #523f6d;
$icon-color: #ece6f6;
$highlight-color: #a3b745;
$notification-color: #d46f15;

$form-checked: $base-color;

$dashboard-accent-1: $base-color;

@import "../_admin.scss";
