.vcex-justified-gallery{width:100%;position:relative;overflow:hidden}.vcex-justified-gallery .vcex-image-grid-entry{position:absolute;display:inline-block;overflow:hidden;margin:0;padding:0}.vcex-justified-gallery .vcex-image-grid-entry:not(.jg-entry-visible){opacity:0}.vcex-justified-gallery .vcex-image-grid-entry-img{margin:0}
