<?php
defined( 'ABSPATH' ) || exit;

/*-----------------------------------------------------------------------------------*/
/*  - Shortcodes turned into classes in 1.2.8
/*-----------------------------------------------------------------------------------*/

// @since 1.2.8
if ( ! function_exists( 'wpex_fix_shortcodes' ) ) {
	function wpex_fix_shortcodes( $content = '' ) {
		_deprecated_function( 'wpex_fix_shortcodes', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_site_url_shortcode' ) ) {
	function wpex_site_url_shortcode( $atts ) {
		_deprecated_function( 'wpex_site_url_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_menu_site_url_shortcode' ) ) {
	function wpex_menu_site_url_shortcode( $atts ) {
		_deprecated_function( 'wpex_menu_site_url_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_text_highlight' ) ) {
	function wpex_text_highlight( $atts, $content = '' ) {
		_deprecated_function( 'wpex_text_highlight', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_br_shortcode' ) ) {
	function wpex_br_shortcode() {
		_deprecated_function( 'wpex_br_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_username_shortcode' ) ) {
	function wpex_username_shortcode() {
		_deprecated_function( 'wpex_username_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_select_menu_shortcode' ) ) {
	function wpex_select_menu_shortcode( $atts, $content = null ) {
		_deprecated_function( 'wpex_select_menu_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_date_format' ) ) {
	function wpex_date_format( $atts ) {
		_deprecated_function( 'wpex_date_format', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_staff_social_shortcode' ) ) {
	function wpex_staff_social_shortcode( $atts = NULL ) {
		_deprecated_function( 'wpex_staff_social_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_polylang_switcher_shortcode' ) ) {
	function wpex_polylang_switcher_shortcode( $atts, $content = null ) {
		_deprecated_function( 'wpex_polylang_switcher_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_enqueue_imagesloaded' ) ) {
	function wpex_enqueue_imagesloaded() {
		_deprecated_function( 'wpex_enqueue_imagesloaded', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_lightbox_scripts_shortcode' ) ) {
	function wpex_lightbox_scripts_shortcode() {
		_deprecated_function( 'wpex_lightbox_scripts_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_wpml_translate_shortcode' ) ) {
	function wpex_wpml_translate_shortcode( $atts, $content = null ) {
		_deprecated_function( 'wpex_wpml_translate_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_wpml_lang_selector_shortcode' ) ) {
	function wpex_wpml_lang_selector_shortcode( $atts = array(), $content = null ) {
		_deprecated_function( 'wpex_wpml_lang_selector_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_searchform_shortcode' ) ) {
	function wpex_searchform_shortcode() {
		_deprecated_function( 'wpex_searchform_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_post_title' ) ) {
	function wpex_post_title() {
		_deprecated_function( 'wpex_post_title', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_post_permalink' ) ) {
	function wpex_post_permalink() {
		_deprecated_function( 'wpex_post_permalink', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_post_publish_date' ) ) {
	function wpex_post_publish_date() {
		_deprecated_function( 'wpex_post_publish_date', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_post_modified_date' ) ) {
	function wpex_post_modified_date() {
		_deprecated_function( 'wpex_post_modified_date', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_post_author' ) ) {
	function wpex_post_author() {
		_deprecated_function( 'wpex_post_author', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_year_shortcode' ) ) {
	function wpex_year_shortcode() {
		_deprecated_function( 'wpex_year_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_cf_value_shortcode' ) ) {
	function wpex_cf_value_shortcode( $atts = array() ) {
		_deprecated_function( 'wpex_cf_value_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_font_awesome_shortcode' ) ) {
	function wpex_font_awesome_shortcode( $atts = array() ) {
		_deprecated_function( 'wpex_font_awesome_shortcode', '1.2.8' );
	}
}

// @since 1.2.8
if ( ! function_exists( 'wpex_wp_login_url_shortcode' ) ) {
	function wpex_wp_login_url_shortcode( $atts = array() ) {
		_deprecated_function( 'wpex_wp_login_url_shortcode', '1.2.8' );
	}
}

/*-----------------------------------------------------------------------------------*/
/*  - v1.4.3
/*-----------------------------------------------------------------------------------*/

function vcex_suggest_user_roles( $search_string ) {
	return TotalThemeCore\WPBakery\Autocomplete\User_Roles::callback( $search_string );
}
function vcex_render_user_roles( $data ) {
	return TotalThemeCore\WPBakery\Autocomplete\User_Roles::render( $data );
}