// Opacity
.opacity(@opacity) {
  opacity: @opacity;
  // IE8 filter
  @opacity-ie: (@opacity * 100);
  filter: ~"alpha(opacity=@{opacity-ie})";
}

body.compose-mode {
  .vc-templatera, .vc_templatera {
    .templatera_shortcode {
      .opacity(0.5);
    }
  }
}
