<?php
defined( 'ABSPATH' ) || exit;

$templates['pricing-1'] = array();
$templates['pricing-1']['name'] = esc_html__( 'Pricing', 'total' ) . ' 1';
$templates['pricing-1']['category'] = 'pricing';
$templates['pricing-1']['content'] = <<<CONTENT
[vc_row css=".vc_custom_1627254640963{margin-top: 40px !important;}"][vc_column][vcex_heading text="Choose Your Plan" text_align="center" tag="h2" font_size="30px" font_weight="700"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][vcex_grid_container align_items="center" gap="40px"][vcex_pricing style="alt-1" cost="$19" button_text="Get Started" button_url="url:%23" plan_weight="semibold" button_transform="uppercase" button_size=".9em" button_weight="bold" button_letter_spacing="1px"]
<ul class="check-list">
 	<li>30GB Storage</li>
 	<li>512MB Ram</li>
 	<li>10 databases</li>
 	<li>1,000 Emails</li>
 	<li>25GB Bandwidth</li>
</ul>
[/vcex_pricing][vcex_pricing style="alt-1" featured="yes" plan="Business" cost="$49" button_text="Get Started" button_url="url:%23" plan_size="2.4em" cost_size="2em" plan_weight="semibold" button_size=".9em" button_letter_spacing="1px" button_weight="bold" button_transform="uppercase"]
<ul class="check-list">
 	<li>30GB Storage</li>
 	<li>512MB Ram</li>
 	<li>10 databases</li>
 	<li>1,000 Emails</li>
 	<li>25GB Bandwidth</li>
</ul>
[/vcex_pricing][vcex_pricing style="alt-1" plan="Enterprice" cost="$99" button_text="Get Started" button_url="url:%23" plan_weight="semibold" button_weight="bold" button_transform="uppercase" button_size=".9em" button_letter_spacing="1px"]
<ul class="check-list">
 	<li>30GB Storage</li>
 	<li>512MB Ram</li>
 	<li>10 databases</li>
 	<li>1,000 Emails</li>
 	<li>25GB Bandwidth</li>
</ul>
[/vcex_pricing][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['pricing-2'] = array();
$templates['pricing-2']['name'] = esc_html__( 'Pricing', 'total' ) . ' 2';
$templates['pricing-2']['category'] = 'pricing';
$templates['pricing-2']['content'] = <<<CONTENT
[vc_row css=".vc_custom_1627254728765{margin-top: 40px !important;}"][vc_column][vcex_heading text="Choose Your Plan" text_align="center" tag="h2" font_size="30px" font_weight="700"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][vcex_grid_container columns_lg="4" columns_md="2" gap="40px"][vcex_pricing style="alt-3" plan="Starter" cost="FREE" button_text="Get Started" button_url="url:%23" line_height="200%" cost_weight="900" plan_color="#757575" button_style_color="black" button_transform="uppercase" button_letter_spacing=".5px"]
<ul>
 	<li>30GB Storage</li>
 	<li>512MB Ram</li>
 	<li>10 databases</li>
 	<li>1,000 Emails</li>
</ul>
[/vcex_pricing][vcex_pricing style="alt-3" featured="yes" cost="$19" button_text="Get Started" button_url="url:%23" line_height="200%" cost_weight="900" css=".vc_custom_1627249526205{background-color: #222222 !important;}" button_size=".9em" button_letter_spacing=".5px" button_transform="uppercase"]
<ul>
 	<li>30GB Storage</li>
 	<li>512MB Ram</li>
 	<li>10 databases</li>
 	<li>1,000 Emails</li>
</ul>
[/vcex_pricing][vcex_pricing style="alt-3" plan="Pro" cost="$29" button_text="Get Started" button_url="url:%23" line_height="200%" button_style_color="black" cost_weight="900" plan_color="#757575" button_transform="uppercase" button_size=".9em" button_letter_spacing=".5px"]
<ul>
 	<li>30GB Storage</li>
 	<li>512MB Ram</li>
 	<li>10 databases</li>
 	<li>1,000 Emails</li>
</ul>
[/vcex_pricing][vcex_pricing style="alt-3" plan="Business" cost="$49" button_text="Get Started" button_url="url:%23" line_height="200%" button_style_color="black" cost_weight="900" plan_color="#757575" button_transform="uppercase" button_size=".9em" button_letter_spacing=".5px"]
<ul>
 	<li>30GB Storage</li>
 	<li>512MB Ram</li>
 	<li>10 databases</li>
 	<li>1,000 Emails</li>
</ul>
[/vcex_pricing][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['pricing-3'] = array();
$templates['pricing-3']['name'] = esc_html__( 'Pricing', 'total' ) . ' 3';
$templates['pricing-3']['category'] = 'pricing';
$templates['pricing-3']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627247180672{padding-top: 100px !important;padding-bottom: 100px !important;background-color: #222222 !important;}"][vc_column][vcex_heading text="Get started Today" color="#9e9e9e" text_align="center" font_size="14px" font_weight="600" text_transform="uppercase"][vcex_heading text="Choose your Plan" align="center" color="#ffffff" text_align="center" tag="h2" font_size="d:40px|pl:30px" font_weight="700" text_transform="uppercase" width="900px"][vcex_spacing size="25px"][vc_row_inner gap="35" css=".vc_custom_1626746505658{margin-right: 0px !important;margin-left: 0px !important;}"][vc_column_inner width="1/2" css=".vc_custom_1626746230480{padding-top: 30px !important;padding-right: 30px !important;padding-bottom: 30px !important;padding-left: 30px !important;background-color: #ffffff !important;}"][vcex_heading text="Free" bottom_margin="10px" font_size="45px" font_weight="900"][vcex_heading text="For personal use only" font_size="1.3em" font_weight="600" text_transform="uppercase"][vcex_divider color="#bdbdbd" margin="top:20px|bottom:20px"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing][vcex_button style="minimal-border" color="black" font_weight="500" font_size="1.1em" text_transform="uppercase"]Learn more[/vcex_button][/vc_column_inner][vc_column_inner width="1/2" css=".vc_custom_1626746451906{padding: 30px !important;background-color: #ffffff !important;}"][vcex_heading text="Premium" bottom_margin="10px" font_size="45px" font_weight="900"][vcex_heading text="$49 per license" font_size="1.3em" font_weight="600" text_transform="uppercase"][vcex_divider color="#bdbdbd" margin="top:20px|bottom:20px"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing][vcex_button style="minimal-border" color="black" font_weight="500" font_size="1.1em" text_transform="uppercase"]Learn more[/vcex_button][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

$templates['pricing-4'] = array();
$templates['pricing-4']['name'] = esc_html__( 'Pricing', 'total' ) . ' 4';
$templates['pricing-4']['category'] = 'pricing';
$templates['pricing-4']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627247321029{padding-top: 60px !important;padding-bottom: 60px !important;background-color: #222222 !important;}"][vc_column][vcex_spacing size="15px"][vcex_heading text="Our Licensing Options" align="center" color="#ffffff" text_align="center" tag="h2" font_size="30px" font_weight="semibold" width="900px" letter_spacing="2px"][vcex_divider_dots spacing="15px" color="rgba(255,255,255,0.5)" margin="top:10px|bottom:20px"][vc_row_inner content_placement="middle" gap="30" remove_bottom_col_margin="true" css=".vc_custom_1627247508167{margin-right: 0px !important;margin-left: 0px !important;}"][vc_column_inner width="1/3" css=".vc_custom_1626751085049{padding: 40px !important;border: 1px solid #9e9e9e !important;border-radius: 4px !important;}"][vcex_heading text="Free" color="#ffffff" text_align="center" font_size="30px" text_transform="uppercase" font_weight="bold" letter_spacing="1px"][vcex_spacing size="20px"][vc_column_text color="#e0e0e0" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis.[/vc_column_text][vcex_spacing][vcex_button align="center" color="white" border_radius="0px" font_weight="bold" text_transform="uppercase" letter_spacing=".5px" font_padding="top:12px|right:25px|bottom:12px|left:25px" icon_right="ticon ticon-angle-double-right"]Get Started[/vcex_button][/vc_column_inner][vc_column_inner width="1/3" css=".vc_custom_1626751565881{padding: 40px !important;border: 1px solid #9e9e9e !important;border-radius: 4px !important;}"][vcex_heading text="Basic" color="#ffffff" text_align="center" font_size="30px" text_transform="uppercase" font_weight="bold" letter_spacing="1px"][vcex_spacing size="10px"][vcex_heading text="Best Offer" add_css_to_inner="true" background_color="accent" color="#ffffff" text_align="center" font_size=".9em" font_weight="bold" text_transform="uppercase" letter_spacing="1px" css=".vc_custom_1627247586250{padding-top: 5px !important;padding-right: 15px !important;padding-bottom: 5px !important;padding-left: 15px !important;}"][vcex_spacing size="20px"][vc_column_text color="#e0e0e0" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis.[/vc_column_text][vcex_spacing][vcex_button align="center" color="white" border_radius="0px" font_weight="bold" text_transform="uppercase" letter_spacing=".5px" font_padding="top:12px|right:25px|bottom:12px|left:25px" icon_right="ticon ticon-angle-double-right"]Get Started[/vcex_button][/vc_column_inner][vc_column_inner width="1/3" css=".vc_custom_1626751650274{padding: 40px !important;border: 1px solid #9e9e9e !important;border-radius: 4px !important;}"][vcex_heading text="Agency" color="#ffffff" text_align="center" font_size="30px" text_transform="uppercase" font_weight="bold" letter_spacing="1px"][vcex_spacing size="20px"][vc_column_text color="#e0e0e0" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis.[/vc_column_text][vcex_spacing][vcex_button align="center" color="white" border_radius="0px" font_weight="bold" text_transform="uppercase" letter_spacing=".5px" font_padding="top:12px|right:25px|bottom:12px|left:25px" icon_right="ticon ticon-angle-double-right"]Get Started[/vcex_button][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

$templates['pricing-5'] = array();
$templates['pricing-5']['name'] = esc_html__( 'Pricing', 'total' ) . ' 5';
$templates['pricing-5']['category'] = 'pricing';
$templates['pricing-5']['content'] = <<<CONTENT
[vc_row css=".vc_custom_1627254774765{margin-top: 40px !important;}"][vc_column][vcex_flex_container justify_content="center" flex_wrap="true" flex_direction="row" flex_basis="360px" gap="40px"][vcex_pricing style="alt-3" shadow="shadow-2xl" plan="Beginner" cost="$50" per_display="block" button_text="Choose Plan" button_url="url:%23|title:Get%20Total" css=".vc_custom_1627249732474{border-top-width: 1px !important;border-right-width: 1px !important;border-bottom-width: 1px !important;border-left-width: 1px !important;padding-top: 50px !important;padding-right: 40px !important;padding-bottom: 60px !important;padding-left: 40px !important;background-color: #ffffff !important;border-left-color: #dddddd !important;border-left-style: solid !important;border-right-color: #dddddd !important;border-right-style: solid !important;border-top-color: #dddddd !important;border-top-style: solid !important;border-bottom-color: #dddddd !important;border-bottom-style: solid !important;border-radius: 20px !important;}" plan_size="20px" cost_size="60px" cost_weight="bold" per="per year" per_size="16px" per_weight="normal" button_wrap_padding="top:30px|right:30px|left:30px" button_style="minimal-border" button_color="#00c9ab" button_size="20px" button_weight="normal" button_border_radius="10px"][/vcex_pricing][vcex_pricing style="alt-3" shadow="shadow-2xl" plan="Professional" cost="$199" per_display="block" button_text="Choose Plan" button_url="url:%23|title:Get%20Total" css=".vc_custom_1627249724920{border-top-width: 1px !important;border-right-width: 1px !important;border-bottom-width: 1px !important;border-left-width: 1px !important;padding-top: 50px !important;padding-right: 40px !important;padding-bottom: 60px !important;padding-left: 40px !important;background-color: #ffffff !important;border-left-color: #dddddd !important;border-left-style: solid !important;border-right-color: #dddddd !important;border-right-style: solid !important;border-top-color: #dddddd !important;border-top-style: solid !important;border-bottom-color: #dddddd !important;border-bottom-style: solid !important;border-radius: 20px !important;}" plan_size="20px" cost_size="60px" cost_weight="bold" per="per year" per_size="16px" per_weight="normal" button_wrap_padding="top:30px|right:30px|left:30px" button_style="minimal-border" button_color="#00c9ab" button_size="20px" button_weight="normal" button_border_radius="10px"][/vcex_pricing][/vcex_flex_container][/vc_column][/vc_row][vc_row css=".vc_custom_1603930802144{margin-top: 40px !important;margin-bottom: 40px !important;}"][vc_column][vcex_button style="flat" align="center" font_size="20px" custom_background="#00c9ab" custom_hover_background="#00b291" font_padding="top:15px|right:80px|bottom:15px|left:80px" border_radius="10px"]14 Day Free Trial[/vcex_button][vcex_spacing size="20px"][vc_column_text text_align="center"]*New customers only. Restrictions apply.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

$templates['pricing-6'] = array();
$templates['pricing-6']['name'] = esc_html__( 'Pricing', 'total' ) . ' 6';
$templates['pricing-6']['category'] = 'pricing';
$templates['pricing-6']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627250339940{padding-top: 60px !important;padding-bottom: 60px !important;background-color: #f7f7f7 !important;}"][vc_column][vcex_heading text="Choose Your Plan" text_align="center" tag="h2" font_size="d:35px|pl:30px" font_weight="700"][vcex_spacing size="15px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing size="20px"][vc_row_inner gap="35" remove_bottom_col_margin="true" css=".vc_custom_1627250328395{margin-right: 0px !important;margin-left: 0px !important;}"][vc_column_inner width="1/3" css=".vc_custom_1626752781822{padding: 40px !important;background-color: #ffffff !important;}"][vcex_heading text="Basic" tag="h3" font_weight="bold" text_align="center" font_size="24px" color="#222222"][vcex_heading text="$19" bottom_margin="5px" tag="div" font_weight="bold" text_align="center" font_size="40px" color="#222222"][vc_column_text text_align="center"]per year[/vc_column_text][vcex_divider color="#e0e0e0" height="1px" margin="top:25px|bottom:30px"][vcex_skillbar title="Feature 1" percentage="45" animate_percent_onscroll="true" style="alt-1" bottom_margin="15px" border_radius="rounded-full" show_icon="true" background="#e0e0e0" container_height="22px" label_color="#222222" percentage_color="#757575" percentage_font_size="11px" icon="ticon ticon-wrench"][vcex_skillbar title="Feature 2" percentage="80" animate_percent_onscroll="true" style="alt-1" bottom_margin="15px" border_radius="rounded-full" show_icon="true" background="#e0e0e0" container_height="22px" label_color="#222222" percentage_color="#757575" percentage_font_size="11px" icon="ticon ticon-bug"][vcex_skillbar title="Feature 3" percentage="65" animate_percent_onscroll="true" style="alt-1" bottom_margin="15px" border_radius="rounded-full" show_icon="true" background="#e0e0e0" container_height="22px" label_color="#222222" percentage_font_size="11px" percentage_color="#757575" icon="ticon ticon-database"][vc_column_text text_align="center"]personal use only*[/vc_column_text][vcex_spacing size="25px"][vcex_button font_padding="top:15px|right:25px|bottom:15px|left:25px" align="center" color="black" border_radius="9999px" font_weight="semibold" text_transform="uppercase" letter_spacing="1px" font_size=".85em" custom_hover_background="accent"]Select License[/vcex_button][/vc_column_inner][vc_column_inner width="1/3" css=".vc_custom_1626752802734{padding: 40px !important;background-color: #ffffff !important;}"][vcex_heading text="Professional" tag="h3" font_weight="bold" text_align="center" font_size="24px" color="#222222"][vcex_heading text="$29" bottom_margin="5px" tag="div" font_weight="bold" text_align="center" font_size="40px" color="#222222"][vc_column_text text_align="center"]per year[/vc_column_text][vcex_divider color="#e0e0e0" height="1px" margin="top:25px|bottom:30px"][vcex_skillbar title="Feature 1" percentage="45" animate_percent_onscroll="true" style="alt-1" bottom_margin="15px" border_radius="rounded-full" show_icon="true" background="#e0e0e0" container_height="22px" label_color="#222222" percentage_color="#757575" percentage_font_size="11px" icon="ticon ticon-wrench"][vcex_skillbar title="Feature 2" percentage="80" animate_percent_onscroll="true" style="alt-1" bottom_margin="15px" border_radius="rounded-full" show_icon="true" background="#e0e0e0" container_height="22px" label_color="#222222" percentage_color="#757575" percentage_font_size="11px" icon="ticon ticon-bug"][vcex_skillbar title="Feature 3" percentage="65" animate_percent_onscroll="true" style="alt-1" bottom_margin="15px" border_radius="rounded-full" show_icon="true" background="#e0e0e0" container_height="22px" label_color="#222222" percentage_font_size="11px" percentage_color="#757575" icon="ticon ticon-database"][vc_column_text text_align="center"]personal &amp; commercial use*[/vc_column_text][vcex_spacing size="25px"][vcex_button font_padding="top:15px|right:25px|bottom:15px|left:25px" align="center" color="black" border_radius="9999px" font_weight="semibold" text_transform="uppercase" letter_spacing="1px" font_size=".85em" custom_hover_background="accent"]Select License[/vcex_button][/vc_column_inner][vc_column_inner width="1/3" css=".vc_custom_1626752809833{padding: 40px !important;background-color: #ffffff !important;}"][vcex_heading text="Unlimited" tag="h3" font_weight="bold" text_align="center" font_size="24px" color="#222222"][vcex_heading text="$250" bottom_margin="5px" tag="div" font_weight="bold" text_align="center" font_size="40px" color="#222222"][vc_column_text text_align="center"]one payment[/vc_column_text][vcex_divider color="#e0e0e0" height="1px" margin="top:25px|bottom:30px"][vcex_skillbar title="Feature 1" percentage="45" animate_percent_onscroll="true" style="alt-1" bottom_margin="15px" border_radius="rounded-full" show_icon="true" background="#e0e0e0" container_height="22px" label_color="#222222" percentage_color="#757575" percentage_font_size="11px" icon="ticon ticon-wrench"][vcex_skillbar title="Feature 2" percentage="80" animate_percent_onscroll="true" style="alt-1" bottom_margin="15px" border_radius="rounded-full" show_icon="true" background="#e0e0e0" container_height="22px" label_color="#222222" percentage_color="#757575" percentage_font_size="11px" icon="ticon ticon-bug"][vcex_skillbar title="Feature 3" percentage="65" animate_percent_onscroll="true" style="alt-1" bottom_margin="15px" border_radius="rounded-full" show_icon="true" background="#e0e0e0" container_height="22px" label_color="#222222" percentage_font_size="11px" percentage_color="#757575" icon="ticon ticon-database"][vc_column_text text_align="center"]redistribution allowed*[/vc_column_text][vcex_spacing size="25px"][vcex_button font_padding="top:15px|right:25px|bottom:15px|left:25px" align="center" color="black" border_radius="9999px" font_weight="semibold" text_transform="uppercase" letter_spacing="1px" font_size=".85em" custom_hover_background="accent"]Select License[/vcex_button][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

$templates['pricing-7'] = array();
$templates['pricing-7']['name'] = esc_html__( 'Pricing', 'total' ) . ' 7';
$templates['pricing-7']['category'] = 'pricing';
$templates['pricing-7']['content'] = <<<CONTENT
[vc_section full_width="stretch_row" css=".vc_custom_1631739618216{padding-top: 10% !important;padding-bottom: 10% !important;background-color: #fafafa !important;}"][vc_row][vc_column][vcex_heading text="Select a plan that fits your needs." text_align="center" tag="h2" font_size="2.8em" font_weight="500"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center" color="rgba(0,0,0,0.5)"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][/vc_column][/vc_row][vc_row gap="35"][vc_column wpex_shadow="shadow-lg" width="1/3" css=".vc_custom_1631742011400{border-top-width: 3px !important;padding-top: 40px !important;padding-right: 40px !important;padding-bottom: 40px !important;padding-left: 40px !important;background-color: #ffffff !important;border-top-color: #4e5cf5 !important;border-top-style: solid !important;}"][vcex_heading text="Free" tag="div" font_weight="semibold" font_size="2em" color="#222222"][vcex_spacing][vcex_heading text="Starter Plan" bottom_margin="5px" tag="h3" font_weight="500" font_size="1.3em" color="#222222"][vc_column_text]All the basic features to setup your site.[/vc_column_text][vcex_divider color="#ededed" margin="top:30px|bottom:30px"][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]5 domains[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]1,000 monthly visits[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]Ads[/vcex_list_item][vcex_spacing][vcex_button layout="expanded" style="outline" border="2px solid currentColor" border_radius="9999px" custom_color="#4e5cf5" custom_hover_background="#4e5cf5" custom_hover_color="#ffffff" font_weight="bold" font_padding="top:15px|right:30px|bottom:15px|left:30px"]Choose Free plan[/vcex_button][/vc_column][vc_column wpex_shadow="shadow-lg" width="1/3" css=".vc_custom_1631742018352{border-top-width: 3px !important;padding-top: 40px !important;padding-right: 40px !important;padding-bottom: 40px !important;padding-left: 40px !important;background-color: #ffffff !important;border-top-color: #4cc791 !important;border-top-style: solid !important;}"][vcex_heading text="#E-8_JTI0MjklMjAlM0NzcGFuJTIwc3R5bGUlM0QlMjJmb250LXNpemUlM0ExMnB4JTNCY29sb3IlM0ElMjM3NTc1NzUlM0IlMjIlM0UlMkZtb250aCUzQyUyRnNwYW4lM0U=" tag="span" font_weight="semibold" font_size="2em" color="#22222"][vcex_spacing][vcex_heading text="Standard Plan" bottom_margin="5px" tag="h3" font_weight="500" font_size="1.3em" color="#222222"][vc_column_text]Everything you need to setup your site plus a little extra.[/vc_column_text][vcex_divider color="#ededed" margin="top:30px|bottom:30px"][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]10 domains[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]2,000 monthly visits[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]Without Ads[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]Chat Support[/vcex_list_item][vcex_spacing][vcex_button layout="expanded" style="flat" border_radius="9999px" font_weight="bold" custom_color="#ffffff" custom_background="#4e5cf5" custom_hover_background="rgba(78,92,245,0.9)" font_padding="top:15px|right:30px|bottom:15px|left:30px"]Choose Standard plan[/vcex_button][/vc_column][vc_column wpex_shadow="shadow-lg" width="1/3" css=".vc_custom_1631742024786{border-top-width: 3px !important;padding-top: 40px !important;padding-right: 40px !important;padding-bottom: 40px !important;padding-left: 40px !important;background-color: #ffffff !important;border-top-color: #f59b36 !important;border-top-style: solid !important;}"][vcex_heading text="#E-8_JTI0NzklMjAlM0NzcGFuJTIwc3R5bGUlM0QlMjJmb250LXNpemUlM0ExMnB4JTNCY29sb3IlM0ElMjM3NTc1NzUlM0IlMjIlM0UlMkZtb250aCUzQyUyRnNwYW4lM0U=" tag="span" font_weight="semibold" font_size="2em" color="#222222"][vcex_spacing][vcex_heading text="Business Plan" bottom_margin="5px" tag="h3" font_weight="500" font_size="1.3em" color="#222222"][vc_column_text]All the basic features to setup your site.[/vc_column_text][vcex_divider color="#ededed" margin="top:30px|bottom:30px"][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]Unlimited domains[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]Unlimited monthly visits[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]Without Ads[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]Custom Branding[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]Free Migration[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]Team Dashboard[/vcex_list_item][vcex_list_item bottom_margin="15px" flex_align="center" icon="ticon ticon-check" icon_border_radius="9999px" icon_width="25px" icon_height="25px" color="#00b075" icon_background="#e0f4ec" font_weight="semibold" font_color="#222222"]Chat & Phone Support[/vcex_list_item][vcex_spacing][vcex_button layout="expanded" style="outline" border="2px solid currentColor" border_radius="9999px" custom_color="#4e5cf5" custom_hover_background="#4e5cf5" custom_hover_color="#ffffff" font_weight="bold" font_padding="top:15px|right:30px|bottom:15px|left:30px"]Choose Business plan[/vcex_button][/vc_column][/vc_row][/vc_section]
CONTENT;

$templates['pricing-8'] = array();
$templates['pricing-8']['name'] = esc_html__( 'Pricing', 'total' ) . ' 8';
$templates['pricing-8']['category'] = 'pricing';
$templates['pricing-8']['content'] = <<<CONTENT
[vc_row css=".vc_custom_1627254640963{margin-top: 40px !important;}"][vc_column][vcex_heading text="Park Passes" add_css_to_inner="true" border_radius="rounded-full" tag="h2" font_size="14px" text_align="center" color="#1c4d40" css=".vc_custom_1631744459539{padding-top: 6px !important;padding-right: 14px !important;padding-bottom: 6px !important;padding-left: 14px !important;background-color: #e8edec !important;}"][vcex_spacing size="15px"][vcex_heading text="Select a Park Pass" text_align="center" tag="h3" font_size="30px" font_weight="700"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing size="20px"][/vc_column][/vc_row][vc_row][vc_column][vcex_grid_container align_items="center" gap="40px"][vcex_pricing style="alt-1" plan="One Day pass" cost="$5" button_text="Buy Now" button_url="url:%23" plan_weight="normal" button_size="16px" button_weight="normal" button_letter_spacing="1px" plan_size="16px" plan_color="#555555" font_color="#555555" cost_size="55px" cost_color="#222222" font_size="16px" button_style="outline" button_border_width="1px" button_color="#1c4d40" button_hover_bg_color="#1c4d40" button_hover_color="#ffffff" button_wrap_padding="top:15px" button_padding="top:15px|right:30px|bottom:15px|left:30px"]All park access for a single day for up to 5 people.[/vcex_pricing][vcex_pricing style="alt-1" plan="Season Pass" cost="$19" button_text="Buy Now" button_url="url:%23" plan_weight="normal" button_size="16px" button_weight="normal" button_letter_spacing="1px" plan_size="16px" plan_color="#ffffff" font_color="rgba(255,255,255,0.8)" cost_size="55px" font_size="16px" button_style="flat" button_border_width="1px" button_color="#1c4d40" css=".vc_custom_1631744841898{border-top-width: 1px !important;border-right-width: 1px !important;border-bottom-width: 1px !important;border-left-width: 1px !important;background-color: #1c4d40 !important;border-left-color: #1c4d40 !important;border-left-style: solid !important;border-right-color: #1c4d40 !important;border-right-style: solid !important;border-top-color: #1c4d40 !important;border-top-style: solid !important;border-bottom-color: #1c4d40 !important;border-bottom-style: solid !important;}" button_bg_color="#ffffff" cost_color="#ffffff" button_hover_color="#000000" button_wrap_padding="top:15px" button_padding="top:15px|right:30px|bottom:15px|left:30px"]All park access for 6 months for up to 5 people.[/vcex_pricing][vcex_pricing style="alt-1" plan="Yearly Pass" cost="$49" button_text="Buy Now" button_url="url:%23" plan_weight="normal" button_size="16px" button_weight="normal" button_letter_spacing="1px" plan_size="16px" plan_color="#555555" font_color="#555555" cost_size="55px" cost_color="#222222" font_size="16px" button_style="outline" button_border_width="1px" button_color="#1c4d40" button_hover_bg_color="#1c4d40" button_hover_color="#ffffff" button_wrap_padding="top:15px" button_padding="top:15px|right:30px|bottom:15px|left:30px"]All park access for 12 months for up to 5 people.[/vcex_pricing][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['pricing-9'] = array();
$templates['pricing-9']['name'] = esc_html__( 'Pricing', 'total' ) . ' 9';
$templates['pricing-9']['category'] = 'pricing';
$templates['pricing-9']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" css=".vc_custom_1631745672380{padding-top: 100px !important;padding-bottom: 60px !important;background-color: #000000 !important;}"][vc_column width="2/5"][vc_column_text color="#ffffff" font_size="50px" font_weight="500"]$19.99[/vc_column_text][vc_column_text color="rgba(255,255,255,0.6)" font_size="16px"]billed monthly[/vc_column_text][/vc_column][vc_column width="3/5"][vcex_heading text="Get access to all videos on demand and future releases." color="#ffffff" tag="h2" font_size="d:35px|pl:30px" font_weight="bold"][vcex_spacing size="40px"][vcex_bullets icon_type="material" gap="40px" alignment="horizontal" icon_color="#f2c86d" icon_material="vc-material vc-material-check" font_size="16px" color="#ffffff"]
<ul>
 	<li>Over 500 movies</li>
 	<li>Download and watch later</li>
 	<li>Easily monthly billing</li>
 	<li>No advertisements</li>
</ul>
[/vcex_bullets][vcex_spacing size="50px"][vcex_button custom_background="#f2c86d" custom_color="#000000" font_padding="top:20px|right:50px|bottom:20px|left:50px" border_radius="9999px" font_size="15px" font_weight="normal"]Create an account[/vcex_button][/vc_column][/vc_row]
CONTENT;
// IMPORTANT - Space required to prevent HEREDOC errors.
?>