<?php
/**
 * Open the footer reveal container.
 *
 * @package Total WordPress theme
 * @subpackage Partials
 * @version 5.3
 */

defined( 'ABSPATH' ) || exit;

?>

<div id="footer-reveal" class="footer-reveal-visible wpex-clr">