.gform_wrapper ul li.gfield{margin-bottom:15px}.gform_wrapper .gform_validation_errors{border-color:var(--wpex-red-error)}.gform_wrapper li.gfield.gfield_error,.gform_wrapper li.gfield.gfield_error.gfield_contains_required.gfield_creditcard_warning{background:none;border:0;padding:0}.gform_wrapper li.gfield.gfield_error.gfield_contains_required div.gfield_description,.gform_wrapper li.gfield.gfield_error.gfield_contains_required div.ginput_container,.gform_wrapper li.gfield.gfield_error.gfield_contains_required fieldset legend.gfield_label,.gform_wrapper li.gfield.gfield_error.gfield_contains_required label.gfield_label{margin-left:0}.gform_wrapper li.gfield_error input[type=email],.gform_wrapper li.gfield_error input[type=number],.gform_wrapper li.gfield_error input[type=password],.gform_wrapper li.gfield_error input[type=tel],.gform_wrapper li.gfield_error input[type=text],.gform_wrapper li.gfield_error input[type=url],.gform_wrapper li.gfield_error textarea{border-color:var(--wpex-red-error)}.gform_confirmation_message{padding:8px 10px;border:0;text-align:center;margin-top:var(--wpex-el-margin-bottom);background:var(--wpex-success-bg);border-left:4px solid var(--wpex-green-success);color:var(--wpex-alert-color)}body .light-form .gform_wrapper .gfield_required,body .light-form .gform_wrapper .gfield_error .gfield_label{color:var(--wpex-white)}.gfield_list thead{background:none}.gform_wrapper.gravity-theme .gfield_label{font-weight:var(--wpex-bold)}
