<?php
defined( 'ABSPATH' ) || exit;

$templates['features-1'] = array();
$templates['features-1']['name'] = esc_html__( 'Features', 'total' ) . ' 1';
$templates['features-1']['category'] = 'features';
$templates['features-1']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627252248232{padding-top: 60px !important;padding-bottom: 70px !important;}"][vc_column][vcex_heading text="Our Services &amp; Features" text_align="center" tag="h2" font_size="30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing size="55px"][vcex_grid_container columns_md="2" gap="30px"][vcex_icon_box heading="Cloud Storage" icon="ticon ticon-cloud" heading_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][vcex_icon_box heading="Easy Installation" icon="ticon ticon-star" heading_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][vcex_icon_box heading="Building Blocks" icon="ticon ticon-cubes" heading_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][vcex_icon_box heading="Quality Hardware" icon="ticon ticon-cog" heading_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][vcex_icon_box heading="Premium Plugins" icon="ticon ticon-plug" heading_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][vcex_icon_box heading="Quick &amp; Easy" icon="ticon ticon-paper-plane" heading_size="1.2em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['features-2'] = array();
$templates['features-2']['name'] = esc_html__( 'Features', 'total' ) . ' 2';
$templates['features-2']['category'] = 'features';
$templates['features-2']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627253732338{padding-top: 60px !important;padding-bottom: 70px !important;}"][vc_column][vcex_heading text="Voted #1 by X Magazine" color="#888888" text_align="center" font_size=".92em" font_weight="600" text_transform="uppercase"][vcex_heading text="Our Services &amp; Features" text_align="center" tag="h2" font_size="30px" font_weight="bold"][vcex_divider color="#bdbdbd" margin="top:25px|bottom:55px" width="60px" align="center"][vcex_grid_container columns_md="2" gap="30px"][vcex_icon_box heading="5 Star Rated" style="two" heading_size="1.2em" icon_color="accent"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][vcex_icon_box heading="100 Building Blocks" style="two" icon="ticon ticon-cubes" heading_size="1.2em" icon_color="accent"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][vcex_icon_box heading="Recycled Materials" style="two" icon="ticon ticon-refresh" heading_size="1.2em" icon_color="accent"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][vcex_icon_box heading="Inventive Design" style="two" icon="ticon ticon-lightbulb-o" heading_size="1.2em" icon_color="accent"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][vcex_icon_box heading="Quality Support" style="two" icon="ticon ticon-commenting-o" heading_size="1.2em" icon_color="accent"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][vcex_icon_box heading="Unmatched Security" style="two" icon="ticon ticon-shield" heading_size="1.2em" icon_color="accent"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['features-3'] = array();
$templates['features-3']['name'] = esc_html__( 'Features', 'total' ) . ' 3';
$templates['features-3']['category'] = 'features';
$templates['features-3']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627253862037{padding-top: 80px !important;padding-bottom: 90px !important;background-color: #222222 !important;}"][vc_column][vcex_heading text="Quick Setup`{`br`}`Without all the Hassle" align="center" color="#ffffff" text_align="center" tag="h2" font_size="30px" font_weight="700" width="900px"][vcex_spacing size="20px"][vc_column_text text_align="center" color="rgba(255,255,255,0.5)" width="500px" align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec egestas hendrerit felis quis convallis. Sed erat ex, finibus non tellus in, molestie.[/vc_column_text][vcex_spacing size="50px"][vcex_flex_container justify_content="space-between" flex_wrap="true" flex_direction="row" gap="40px"][vcex_icon_box heading="Design`{`br`}`&amp; Development" align_center="true" icon="" icon_border_width="1" onclick="custom_link" heading_color="#ffffff" heading_size="1.2em" heading_transform="uppercase" icon_color="#ffffff" icon_size="24px" heading_type="h3" heading_weight="normal" onclick_url="#" heading_letter_spacing="1px" icon_border_radius="50%" icon_alternative_character="1" icon_width="50px" icon_height="50px" heading_bottom_margin="0px"][/vcex_icon_box][vcex_icon_box heading="Planning`{`br`}`&amp; Strategy" align_center="true" icon="" icon_border_width="1" onclick="custom_link" heading_color="#ffffff" heading_size="1.2em" heading_transform="uppercase" icon_color="#ffffff" icon_size="24px" heading_type="h3" heading_weight="normal" onclick_url="#" heading_letter_spacing="1px" icon_border_radius="50%" icon_alternative_character="2" icon_width="50px" icon_height="50px" heading_bottom_margin="0px"][/vcex_icon_box][vcex_icon_box heading="Setup`{`br`}`&amp; Implement" align_center="true" icon="" icon_border_width="1" onclick="custom_link" heading_color="#ffffff" heading_size="1.2em" heading_transform="uppercase" icon_color="#ffffff" icon_size="24px" heading_type="h3" heading_weight="normal" onclick_url="#" heading_letter_spacing="1px" icon_border_radius="50%" icon_alternative_character="3" icon_width="50px" icon_height="50px" heading_bottom_margin="0px"][/vcex_icon_box][vcex_icon_box heading="Finish`{`br`}`&amp; Monitor" align_center="true" icon="" icon_border_width="1" onclick="custom_link" heading_color="#ffffff" heading_size="1.2em" heading_transform="uppercase" icon_color="#ffffff" icon_size="24px" heading_type="h3" heading_weight="normal" onclick_url="#" heading_letter_spacing="1px" icon_border_radius="50%" icon_alternative_character="4" icon_width="50px" icon_height="50px" heading_bottom_margin="0px"][/vcex_icon_box][/vcex_flex_container][/vc_column][/vc_row]
CONTENT;

$templates['features-4'] = array();
$templates['features-4']['name'] = esc_html__( 'Features', 'total' ) . ' 4';
$templates['features-4']['category'] = 'features';
$templates['features-4']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" content_placement="middle" css=".vc_custom_1626733007345{padding-top: 100px !important;padding-bottom: 60px !important;background-color: #f7f7f7 !important;}"][vc_column width="1/3"][vcex_heading text="Core Features" bottom_margin="10px" tag="h2" font_size="30px" font_weight="bold"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies.[/vc_column_text][vcex_spacing size="20px"][vcex_button color="black" border_radius="0px" border="0px" font_padding="top:12px|right:25px|bottom:12px|left:25px" text_transform="uppercase" letter_spacing="1.5px" font_size=".92em" font_weight="semibold"]See more[/vcex_button][/vc_column][vc_column css_animation="none" width="2/3"][vcex_grid_container columns_lg="2" gap="30px"][vcex_icon_box heading="Premium Plugins" align_center="true" wpex_padding="25px" shadow="shadow-2xl" icon="ticon ticon-plug" icon_border_width="2" background_color="#ffffff" border_radius="15px" icon_border_radius="50px" icon_width="60px" icon_height="60px" heading_size="1.2em" heading_bottom_margin="5px" heading_type="h3"]Lorem ipsum dolor sit amet, consectetur elit.[/vcex_icon_box][vcex_icon_box heading="Cloud Storage" align_center="true" wpex_padding="25px" shadow="shadow-2xl" icon="ticon ticon-database" icon_border_width="2" background_color="#ffffff" border_radius="15px" icon_border_radius="50px" icon_width="60px" icon_height="60px" heading_size="1.2em" heading_bottom_margin="5px" heading_type="h3"]Lorem ipsum dolor sit amet, consectetur elit.[/vcex_icon_box][vcex_icon_box heading="Rocket Speed" align_center="true" wpex_padding="25px" shadow="shadow-2xl" icon="ticon ticon-rocket" icon_border_width="2" background_color="#ffffff" border_radius="15px" icon_border_radius="50px" icon_width="60px" icon_height="60px" heading_size="1.2em" heading_bottom_margin="5px" heading_type="h3"]Lorem ipsum dolor sit amet, consectetur elit.[/vcex_icon_box][vcex_icon_box heading="Quality Design" align_center="true" wpex_padding="25px" shadow="shadow-2xl" icon="ticon ticon-paint-brush" icon_border_width="2" background_color="#ffffff" border_radius="15px" icon_border_radius="50px" icon_width="60px" icon_height="60px" heading_size="1.2em" heading_bottom_margin="5px" heading_type="h3"]Lorem ipsum dolor sit amet, consectetur elit.[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['features-5'] = array();
$templates['features-5']['name'] = esc_html__( 'Features', 'total' ) . ' 5';
$templates['features-5']['category'] = 'features';
$templates['features-5']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627253976873{padding-top: 60px !important;padding-bottom: 70px !important;}"][vc_column][vcex_heading text="Our Services &amp; Features" text_align="center" tag="h2" font_size="30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing size="40px"][vcex_grid_container gap="35px"][vcex_teaser style="four" text_align="center" image_source="external" external_image="{$ph_landscape}"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique vel vitae arcu.

<a class="theme-button" href="#">Learn more</a>[/vcex_teaser][vcex_teaser style="four" text_align="center" image_source="external" external_image="{$ph_landscape}"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique vel vitae arcu.

<a class="theme-button" href="#">Learn more</a>[/vcex_teaser][vcex_teaser style="four" text_align="center" image_source="external" external_image="{$ph_landscape}"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed faucibus feugiat convallis. Integer nec eros et risus condimentum tristique vel vitae arcu.

<a class="theme-button" href="#">Learn more</a>[/vcex_teaser][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['features-6'] = array();
$templates['features-6']['name'] = esc_html__( 'Features', 'total' ) . ' 6';
$templates['features-6']['category'] = 'features';
$templates['features-6']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" remove_bottom_col_margin="true" css=".vc_custom_1627254107020{padding-top: 60px !important;padding-bottom: 70px !important;background-color: #f7f7f7 !important;}"][vc_column][vcex_heading text="Easy &amp; Proven Step Process" text_align="center" tag="h2" font_size="30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing size="40px"][vcex_grid_container gap="40px"][vcex_icon_box heading="Planning &amp; Mockup" style="two" alignment="left" wpex_padding="40px" shadow="shadow-xl" icon="" icon_border_width="2" icon_alternative_character="1" heading_size="1.23em" heading_weight="semibold" icon_height="50px" icon_width="50px" icon_font_weight="300" background_color="#ffffff" heading_type="h3"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis.[/vcex_icon_box][vcex_icon_box heading="Design &amp; Implementation" style="two" alignment="left" wpex_padding="40px" shadow="shadow-xl" icon="" icon_border_width="2" icon_alternative_character="2" heading_size="1.23em" heading_weight="semibold" icon_height="50px" icon_width="50px" icon_font_weight="300" background_color="#ffffff" heading_type="h3"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis.[/vcex_icon_box][vcex_icon_box heading="Tracking &amp; Monitoring" style="two" alignment="left" wpex_padding="40px" shadow="shadow-xl" icon="" icon_border_width="2" icon_alternative_character="3" heading_size="1.23em" heading_weight="semibold" icon_height="50px" icon_width="50px" icon_font_weight="300" background_color="#ffffff" heading_type="h3"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis.[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['features-7'] = array();
$templates['features-7']['name'] = esc_html__( 'Features', 'total' ) . ' 7';
$templates['features-7']['category'] = 'features';
$templates['features-7']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627254147530{padding-top: 60px !important;padding-bottom: 70px !important;}"][vc_column][vcex_heading text="Our Services &amp; Features" text_align="center" tag="h2" font_size="30px" font_weight="bold"][vcex_spacing size="20px"][vc_column_text width="650px" align="center" text_align="center"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis felis quis, laoreet eros. Vivamus pellentesque mauris orci. Ut vitae congue ligula.[/vc_column_text][vcex_spacing size="55px"][vcex_grid_container columns_lg="4" columns_md="2" gap="25px"][vcex_icon_box heading="Loved by Millions" style="two" icon="ticon ticon-heart-o" icon_border_width="2" heading_size="1.3em" icon_color="accent" icon_border_radius="9999px" heading_type="h3" icon_width="70px" icon_height="70px" icon_size="25px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec.[/vcex_icon_box][vcex_icon_box heading="Creative Design" style="two" icon="ticon ticon-lightbulb-o" icon_border_width="2" heading_size="1.3em" icon_color="accent" icon_border_radius="9999px" heading_type="h3" icon_width="70px" icon_height="70px" icon_size="25px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec.[/vcex_icon_box][vcex_icon_box heading="Flagship Product" style="two" icon="ticon ticon-flag-o" icon_border_width="2" heading_size="1.3em" icon_color="accent" icon_border_radius="9999px" heading_type="h3" icon_width="70px" icon_height="70px" icon_size="25px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec.[/vcex_icon_box][vcex_icon_box heading="Premium Mail" style="two" icon="ticon ticon-paper-plane-o" icon_border_width="2" heading_size="1.3em" icon_color="accent" icon_border_radius="9999px" heading_type="h3" icon_width="70px" icon_height="70px" icon_size="25px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec.[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['features-8'] = array();
$templates['features-8']['name'] = esc_html__( 'Features', 'total' ) . ' 8';
$templates['features-8']['category'] = 'features';
$templates['features-8']['content'] = <<<CONTENT
[vc_section full_width="stretch_row" css=".vc_custom_1627254196734{padding-top: 70px !important;background-color: #3858e9 !important;}"][vc_row][vc_column][vcex_heading text="Heres how our service works:" text_align="center" tag="h2" font_size="30px" font_weight="semibold" color="#ffffff"][vc_column_text text_align="center" font_size="1.2em" color="rgba(255,255,255,0.6)"]Easy steps that anyone can follow[/vc_column_text][vcex_spacing size="50px"][vc_row_inner content_placement="middle"][vc_column_inner width="1/2"][vcex_image source="external" external_image="{$ph_landscape}"][/vc_column_inner][vc_column_inner width="1/2"][vcex_icon_box heading="Create an Account" bottom_margin="40px" icon_alternative_character="1" icon_background="#ffffff" icon_color="#222222" icon_width="50px" icon_height="50px" icon_border_radius="9999px" icon_size="20px" heading_color="#ffffff" heading_type="h3" font_color="rgba(255,255,255,0.7)" heading_size="1.3em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis.[/vcex_icon_box][vcex_icon_box heading="Connect Your Site" bottom_margin="40px" icon_alternative_character="2" icon_background="#ffffff" icon_color="#222222" icon_width="50px" icon_height="50px" icon_border_radius="9999px" icon_size="20px" heading_color="#ffffff" heading_type="h3" font_color="rgba(255,255,255,0.7)" heading_size="1.3em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis.[/vcex_icon_box][vcex_icon_box heading="Increase Conversions" icon_alternative_character="3" icon_background="#ffffff" icon_color="#222222" icon_width="50px" icon_height="50px" icon_border_radius="9999px" icon_size="20px" heading_color="#ffffff" heading_type="h3" font_color="rgba(255,255,255,0.7)" heading_size="1.3em"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus et justo ultricies, mattis.[/vcex_icon_box][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][/vc_section]
CONTENT;

$templates['features-9'] = array();
$templates['features-9']['name'] = esc_html__( 'Features', 'total' ) . ' 9';
$templates['features-9']['category'] = 'features';
$templates['features-9']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627254256202{padding-top: 60px !important;padding-bottom: 70px !important;}"][vc_column][vcex_heading text="Our Services &amp; Features" text_align="center" tag="h2" font_size="30px" font_weight="bold"][vc_column_text text_align="center" font_size="1.2em" color="#757575"]Everything you need in one package.[/vc_column_text][vcex_spacing size="50px"][vcex_grid_container columns_md="2" gap="40px"][vcex_icon_box heading="Cloud Storage" icon="ticon ticon-cloud" heading_size="1.2em" icon_background="accent" icon_color="#ffffff" icon_border_radius="4px" icon_size="20px" icon_width="45px" icon_height="45px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis.[/vcex_icon_box][vcex_icon_box heading="Lightning Speed" icon="ticon ticon-rocket" heading_size="1.2em" icon_size="20px" icon_background="accent" icon_border_radius="4px" icon_width="45px" icon_height="45px" icon_color="#ffffff"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis.[/vcex_icon_box][vcex_icon_box heading="Premium Plugins" icon="ticon ticon-plug" heading_size="1.2em" icon_size="20px" icon_color="#ffffff" icon_background="accent" icon_border_radius="4px" icon_width="45px" icon_height="45px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis.[/vcex_icon_box][vcex_icon_box heading="One-Click Demo Importer" icon="ticon ticon-mouse-pointer" heading_size="1.2em" icon_size="20px" icon_color="#ffffff" icon_background="accent" icon_border_radius="4px" icon_width="45px" icon_height="45px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis.[/vcex_icon_box][vcex_icon_box heading="Security &amp; Monitoring" icon="ticon ticon-shield" heading_size="1.2em" icon_size="20px" icon_color="#ffffff" icon_background="accent" icon_border_radius="4px" icon_width="45px" icon_height="45px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis.[/vcex_icon_box][vcex_icon_box heading="Dashboard Statistics" icon="ticon ticon-signal" heading_size="1.2em" icon_size="20px" icon_color="#ffffff" icon_background="accent" icon_border_radius="4px" icon_width="45px" icon_height="45px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis.[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['features-10'] = array();
$templates['features-10']['name'] = esc_html__( 'Features', 'total' ) . ' 10';
$templates['features-10']['category'] = 'features';
$templates['features-10']['content'] = <<<CONTENT
[vc_row full_width="stretch_row" wpex_shape_divider_top="tilt" wpex_shape_divider_top_flip="true" wpex_shape_divider_bottom="tilt" wpex_shape_divider_bottom_flip="true" css=".vc_custom_1627365796591{padding-top: 100px !important;padding-bottom: 100px !important;background-color: #f6f9fc !important;}" wpex_shape_divider_top_height="40" wpex_shape_divider_bottom_height="40"][vc_column][vcex_heading text="All-in-One Solution" tag="h3" color="#3366fe" text_transform="uppercase" letter_spacing="1px" font_size="1.1em"][vcex_heading text="Everything You Need for Success..." tag="h2" color="#222222" font_size="35px" font_weight="bold"][vcex_spacing size="40px"][vcex_grid_container columns_sm="2" gap="30px"][vcex_icon_box heading="Live Page Editor" style="two" alignment="left" wpex_padding="30px" shadow="shadow-2xl" icon="ticon ticon-paint-brush" heading_color="#3366fe" icon_color="#3366fe" heading_size="1.32em" background_color="#ffffff" border_radius="12px" icon_size="35px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit.[/vcex_icon_box][vcex_icon_box heading="SEO Optimized" style="two" alignment="left" wpex_padding="30px" shadow="shadow-2xl" icon="ticon ticon-search" heading_color="#3366fe" icon_color="#3366fe" heading_size="1.32em" background_color="#ffffff" border_radius="12px" icon_size="35px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit.[/vcex_icon_box][vcex_icon_box heading="Rocket Speed" style="two" alignment="left" wpex_padding="30px" shadow="shadow-2xl" icon="ticon ticon-rocket" heading_color="#3366fe" icon_color="#3366fe" heading_size="1.32em" background_color="#ffffff" border_radius="12px" icon_size="35px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit.[/vcex_icon_box][vcex_icon_box heading="Increased Conversions" style="two" alignment="left" wpex_padding="30px" shadow="shadow-2xl" icon="ticon ticon-line-chart" heading_color="#3366fe" icon_color="#3366fe" heading_size="1.32em" background_color="#ffffff" border_radius="12px" icon_size="35px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit.[/vcex_icon_box][vcex_icon_box heading="Enhanced Security" style="two" alignment="left" wpex_padding="30px" shadow="shadow-2xl" icon="ticon ticon-shield" heading_color="#3366fe" icon_color="#3366fe" heading_size="1.32em" background_color="#ffffff" border_radius="12px" icon_size="35px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit.[/vcex_icon_box][vcex_icon_box heading="Premium Plugins" style="two" alignment="left" wpex_padding="30px" shadow="shadow-2xl" icon="ticon ticon-plug" heading_color="#3366fe" icon_color="#3366fe" heading_size="1.32em" background_color="#ffffff" border_radius="12px" icon_size="35px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit.[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['features-11'] = array();
$templates['features-11']['name'] = esc_html__( 'Features', 'total' ) . ' 11';
$templates['features-11']['category'] = 'features';
$templates['features-11']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627368319950{padding-top: 60px !important;padding-bottom: 70px !important;}"][vc_column][vcex_heading text="Available Courses" font_size="30px" font_weight="bold" tag="h2"][vcex_spacing size="10px"][vc_column_text width="450px" align="left"]Click on any course below to learn more about the program and how to sign up for the course.[/vc_column_text][vcex_spacing size="50px"][vcex_grid_container columns="2" columns_lg="4" columns_md="3" gap="25px"][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Finance[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Antropology[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Marketing[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Business Intelligence[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Strategic Planning[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Business Management[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Entrepreneurship[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Economics[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Finance[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]History[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Social Work[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Sociology[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Political Science[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Writting[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Special Education[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Computer Science[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Geography[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Aerospace Engineering[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Human Resources[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Public Relations[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Biochemistry[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Microbiology[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Animation[/vcex_list_item][vcex_list_item icon="ticon ticon-star" color="#ff7700" link="url:%23" font_color="#0d2341" font_weight="semibold" font_size="15px"]Art History[/vcex_list_item][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['features-12'] = array();
$templates['features-12']['name'] = esc_html__( 'Features', 'total' ) . ' 12';
$templates['features-12']['category'] = 'features';
$templates['features-12']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1627367116935{padding-top: 60px !important;padding-bottom: 70px !important;}"][vc_column][vcex_heading text="What do we specialize in?" font_size="30px" font_weight="bold"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit mattis felis quis.[/vc_column_text][vcex_spacing][vcex_grid_container columns_lg="" columns_md="2"][vcex_icon_box heading="SEO &amp; PPC" style="two" alignment="left" wpex_padding="40px" icon="ticon ticon-search" background_color="#112877" icon_color="#327eff" heading_color="#ffffff" font_color="rgba(255,255,255,0.6)" heading_size="1.3em" heading_weight="bold" icon_size="40px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

<a class="white-text" href="#">Learn more →</a>[/vcex_icon_box][vcex_icon_box heading="Marketing Campaigns" style="two" alignment="left" wpex_padding="40px" icon="ticon ticon-envelope-open-o" background_color="#112877" icon_color="#327eff" heading_color="#ffffff" font_color="rgba(255,255,255,0.6)" heading_size="1.3em" heading_weight="bold" icon_size="40px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

<a class="white-text" href="#">Learn more →</a>[/vcex_icon_box][vcex_icon_box heading="Localization &amp; Translation" style="two" alignment="left" wpex_padding="40px" icon="ticon ticon-globe" background_color="#112877" icon_color="#327eff" heading_color="#ffffff" font_color="rgba(255,255,255,0.6)" heading_size="1.3em" heading_weight="bold" icon_size="40px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

<a class="white-text" href="#">Learn more →</a>[/vcex_icon_box][vcex_icon_box heading="Site Optimization" style="two" alignment="left" wpex_padding="40px" icon="ticon ticon-sliders" background_color="#112877" icon_color="#327eff" heading_color="#ffffff" font_color="rgba(255,255,255,0.6)" heading_size="1.3em" heading_weight="bold" icon_size="40px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

<a class="white-text" href="#">Learn more →</a>[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['features-13'] = array();
$templates['features-13']['name'] = esc_html__( 'Features', 'total' ) . ' 13';
$templates['features-13']['category'] = 'features';
$templates['features-13']['content'] = <<<CONTENT
[vc_row column_spacing="50" equal_height="yes" css=".vc_custom_1633802734629{margin-top: 50px !important;}"][vc_column width="1/2"][vcex_image source="external" external_image="{$ph_square}"][/vc_column][vc_column width="1/2"][vcex_list_item bottom_margin="15px" icon="ticon ticon-circle" color="#0145ff" font_weight="normal" font_color="#777777"]Exclusive features[/vcex_list_item][vcex_heading text="Everything you need to create faster and better websites using WordPress." font_weight="bolder" font_size="2em" tag="h2"][vcex_divider color="#e0e0e0" margin="top:50px|bottom:50px"][vcex_grid_container columns_lg="" columns_sm="2" gap="40px"][vcex_icon_box heading="Section Templates" icon="" heading_type="h3" heading_size="1.2em" heading_weight="semibold"]Build faster websites using the exclusive Total section templates for WPBakery.[/vcex_icon_box][vcex_icon_box heading="Demo Import" icon="" heading_type="h3" heading_size="1.2em" heading_weight="semibold"]Easily import a sample demo to get started with a fully built site you can tweak.[/vcex_icon_box][vcex_icon_box heading="Font Manager" icon="" heading_type="h3" heading_size="1.2em" heading_weight="semibold"]Manage the available fonts for use on the site, upload custom fonts, use Google fonts, etc.[/vcex_icon_box][vcex_icon_box heading="SEO Ready &amp; Fast" icon="" heading_type="h3" heading_size="1.2em" heading_weight="semibold"]Create SEO ready and fast websites that will help take your business to a whole new level.[/vcex_icon_box][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;

$templates['features-14'] = array();
$templates['features-14']['name'] = esc_html__( 'Features', 'total' ) . ' 14';
$templates['features-14']['category'] = 'features';
$templates['features-14']['content'] = <<<CONTENT
[vc_row content_placement="middle" column_spacing="50" equal_height="yes" css=".vc_custom_1633802866801{margin-top: 50px !important;}"][vc_column width="1/2"][vcex_heading text="High Quality WireFrames &amp; Templates" font_weight="bolder" font_size="36px" tag="h2"][vcex_spacing size="20px"][vc_column_text color="#222222" font_size="14px"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque iaculis velit at dictum vulputate. Nullam hendrerit arcu a lorem pretium scelerisque. Vivamus accumsan scelerisque neque, non ornare lectus semper quis.[/vc_column_text][vcex_spacing size="40px"][vcex_list_item bottom_margin="15px" icon_type="fontawesome" icon_fontawesome="far fa-check-circle" color="#0145ff" font_size="16px" font_color="#222222"]Unlimited Customizations[/vcex_list_item][vcex_list_item bottom_margin="15px" icon_type="fontawesome" icon_fontawesome="far fa-check-circle" color="#0145ff" font_size="16px" font_color="#222222"]Professional Designs[/vcex_list_item][vcex_list_item bottom_margin="15px" icon_type="fontawesome" icon_fontawesome="far fa-check-circle" color="#0145ff" font_size="16px" font_color="#222222"]Modern Wireframe Systems[/vcex_list_item][/vc_column][vc_column width="1/2"][vcex_image source="external" external_image="{$ph_square}"][/vc_column][/vc_row]
CONTENT;

$templates['features-15'] = array();
$templates['features-15']['name'] = esc_html__( 'Features', 'total' ) . ' 15';
$templates['features-15']['category'] = 'features';
$templates['features-15']['content'] = <<<CONTENT
[vc_row remove_bottom_col_margin="true" css=".vc_custom_1631659582678{padding-top: 60px !important;padding-bottom: 60px !important;}"][vc_column][vcex_heading text="#E-8_QnVpbGQlMjAlM0NzcGFuJTIwY2xhc3MlM0QlMjJ3cGV4LWZvbnQtc2VtaWJvbGQlMjIlMjBzdHlsZSUzRCUyMmNvbG9yJTNBJTIzM0M2NkVDJTIyJTNFcG93ZXJmdWwlM0MlMkZzcGFuJTNFJTIwZGVzaWducyUyQyUyMGZyYW1ld29ya3MlMjBhbmQlMjBleHBlcmllbmNlcyUyMC4=" align="left" float="false" font_weight="300" font_size="d:45px|pl:30px" tag="h3" font_family="Inter" width="700px"][vcex_spacing size="60px"][vcex_grid_container columns_md="2" gap="50px"][vcex_list_item flex_align="center" icon_type="material" icon_spacing="15px" icon_material="vc-material vc-material-check" icon_size="25px" icon_border_radius="20px" icon_width="40px" icon_height="40px" color="#3c66ec" icon_background="#e9edfa" font_size="16px" font_family="Inter"]Pellentesque iaculis velit at dictum vulputate.[/vcex_list_item][vcex_list_item flex_align="center" icon_type="material" icon_spacing="15px" icon_material="vc-material vc-material-check" icon_size="25px" icon_border_radius="20px" icon_width="40px" icon_height="40px" color="#3c66ec" icon_background="#e9edfa" font_size="16px" font_family="Inter"]Pellentesque iaculis velit at dictum vulputate.[/vcex_list_item][vcex_list_item flex_align="center" icon_type="material" icon_spacing="15px" icon_material="vc-material vc-material-check" icon_size="25px" icon_border_radius="20px" icon_width="40px" icon_height="40px" color="#3c66ec" icon_background="#e9edfa" font_size="16px" font_family="Inter"]Pellentesque iaculis velit at dictum vulputate.[/vcex_list_item][vcex_list_item flex_align="center" icon_type="material" icon_spacing="15px" icon_material="vc-material vc-material-check" icon_size="25px" icon_border_radius="20px" icon_width="40px" icon_height="40px" color="#3c66ec" icon_background="#e9edfa" font_size="16px" font_family="Inter"]Pellentesque iaculis velit at dictum vulputate.[/vcex_list_item][vcex_list_item flex_align="center" icon_type="material" icon_spacing="15px" icon_material="vc-material vc-material-check" icon_size="25px" icon_border_radius="20px" icon_width="40px" icon_height="40px" color="#3c66ec" icon_background="#e9edfa" font_size="16px" font_family="Inter"]Pellentesque iaculis velit at dictum vulputate.[/vcex_list_item][vcex_list_item flex_align="center" icon_type="material" icon_spacing="15px" icon_material="vc-material vc-material-check" icon_size="25px" icon_border_radius="20px" icon_width="40px" icon_height="40px" color="#3c66ec" icon_background="#e9edfa" font_size="16px" font_family="Inter"]Pellentesque iaculis velit at dictum vulputate.[/vcex_list_item][/vcex_grid_container][/vc_column][/vc_row]
CONTENT;
// IMPORTANT - Space required to prevent HEREDOC errors.
?>