<?php
defined( 'ABSPATH' ) || exit;

require_once WPEX_CUSTOMIZER_DIR . 'settings/blog/general.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/blog/archives.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/blog/post.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/blog/author-box.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/blog/author-archives.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/blog/related.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/blog/comments.php';