<?php
defined( 'ABSPATH' ) || exit;

$html = '';

$html .= '<div class="wpex-card-inner wpex-flex wpex-flex-col wpex-flex-grow wpex-border-2 wpex-border-solid wpex-border-gray-200">';

	// Media
	$html .= $this->get_media( array(
		'image_class' => 'wpex-w-100',
	) );

	$html .= '<div class="wpex-card-details wpex-p-20">';

		// Title
		$html .= $this->get_title( array(
			'class' => 'wpex-heading wpex-text-md',
		) );

		// Excerpt
		$html .= $this->get_excerpt( array(
			'class' => 'wpex-mt-10',
		) );

	$html .= '</div>';

$html .= '</div>';

return $html;