<?php
use TotalTheme\Blog\Single_Blocks as Blocks;

/**
 * Single blog post layout.
 *
 * All blog elements can be re-ordered via the WP Customizer or filtered via theme
 * filters. You can also create custom post templates via the WP admin,
 * so do NOT edit this file manually or via a child theme.
 *
 * @package Total WordPress theme
 * @subpackage Partials
 * @version 5.5
 */

defined( 'ABSPATH' ) || exit;

?>

<article id="single-blocks" <?php Blocks::wrapper_class(); ?><?php wpex_schema_markup( 'blog_post' ); ?>><?php

	if ( 'quote' === get_post_format() ) {
		wpex_get_template_part( 'blog_single_quote' ); // Quote format posts are treated differently.
	} else {

		/**
		 * Renders the single blog post blocks.
		 *
		 * @see inc/blog/single-blocks.php
		 *
		 * If you wish to create a custom page design please see the "Dynamic Templates" documentation.
		 *
		 * @link https://wpexplorer-themes.com/total/docs/dynamic-templates/
		 */
		Blocks::render();

	}

?></article>