<?php
use TotalTheme\Footer\Bottom\Copyright;

/**
 * Footer bottom content
 *
 * @package TotalTheme
 * @subpackage Partials
 * @version 5.4.5
 */

defined( 'ABSPATH' ) || exit;

$copyright = Copyright::get_content();

if ( ! $copyright ) {
	return;
}

?>

<div id="copyright" class="wpex-last-mb-0"<?php wpex_aria_landmark( 'copyright' ); ?>><?php

	echo do_shortcode( wp_kses_post( $copyright ) );

?></div>