<?php
defined( 'ABSPATH' ) || exit;

$html = '';

$html .= '<div class="wpex-card-header wpex-flex wpex-items-center">';

	// Thumbnail
	$html .= $this->get_thumbnail( array(
		'link' => false,
		'class' => 'wpex-shrink-0 wpex-rounded-full wpex-mr-15',
		'image_class' => 'wpex-card-thumbnail-sm wpex-rounded-full',
	) );

	// Header aside
	$html .= '<div class="wpex-card-header-aside">';

		// Title
		$html .= $this->get_title( array(
			'link' => false,
			'class' => 'wpex-card-title wpex-heading wpex-text-md wpex-mb-5',
		) );

		// Rating
		$html .= $this->get_star_rating( array(
			'class' => 'wpex-text-sm',
		) );

	$html .= '</div>';

$html .= '</div>';

// Excerpt
$html .= $this->get_excerpt( array(
	'class' => 'wpex-mt-15',
) );

return $html;