.wpex-term-settings-postbox {
	margin-top: 30px;

	h2 {
		font-size: 14px;
		padding: 8px 12px;
		margin: 0;
		line-height: 1.4;
	}

	.form-table {
		th {
			padding: 8px 30px 8px 0;
		}
		td {
			padding: 8px 0;
		}
		tr:not(:first-child) {
			border-top: 1px solid #eee;
		}
	}

	.inside {
		margin-top: 0;
		margin-bottom: 0;
		padding-top: 4px;
		padding-bottom: 4px;
	}

	.form-table {
		padding: 0;
		margin: 0;
	}

	select {
		min-width: 50%;
	}

}