<?php
defined( 'ABSPATH' ) || exit;

$is_custom_menu = wpex_is_header_menu_custom();

require_once WPEX_CUSTOMIZER_DIR . 'settings/header/general.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/header/logo.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/header/logo-icon.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/header/transparent-header.php';
require_once WPEX_CUSTOMIZER_DIR . 'settings/header/sticky.php';
//require_once WPEX_CUSTOMIZER_DIR . 'settings/header/sticky-menu.php'; // added into header tab in 5.5

if ( ! $is_custom_menu ) {
	require_once WPEX_CUSTOMIZER_DIR . 'settings/header/menu.php';
	require_once WPEX_CUSTOMIZER_DIR . 'settings/header/dropdowns.php';
	require_once WPEX_CUSTOMIZER_DIR . 'settings/header/megamenus.php';
}

require_once WPEX_CUSTOMIZER_DIR . 'settings/header/search.php';

if ( ! $is_custom_menu ) {
    require_once WPEX_CUSTOMIZER_DIR . 'settings/header/mobile-menu.php';
}