<?php
use \TotalTheme\Footer\Bottom\Core as Footer_Bottom;

/**
 * Footer bottom content.
 *
 * @package TotalTheme
 * @subpackage Partials
 * @version 5.4.6
 */

defined( 'ABSPATH' ) || exit;

?>

<?php wpex_hook_footer_bottom_before(); ?>

<?php if ( ! wpex_theme_do_location( 'footer_bottom' ) ) : ?>

	<div id="footer-bottom" <?php Footer_Bottom::wrapper_class(); ?><?php wpex_schema_markup( 'footer_bottom' ); ?>>

		<?php wpex_hook_footer_bottom_top(); ?>

		<div id="footer-bottom-inner" <?php Footer_Bottom::inner_class(); ?>><?php

			wpex_hook_footer_bottom_inner();

		?></div>

		<?php wpex_hook_footer_bottom_bottom(); ?>

	</div>

<?php endif; ?>

<?php wpex_hook_footer_bottom_after(); ?>