body.has-mobile-menu .hide-at-mm-breakpoint{display:none}#site-header.wpex-header-two-flex-v #site-header-inner{display:block}#header-two-search{float:left}.header-two-aside{float:none;clear:both;padding-top:20px;text-align:left}.shrink-sticky-header.on-shrink-adjust-height.fixed-scroll--mobile-only #site-logo .logo-img{max-height:var(--wpex-site-header-shrink-start-height, 60px);width:auto}.wpex-mobile-toggle-menu-icon_buttons #site-logo{height:100%;float:left;text-align:left}.wpex-mobile-toggle-menu-icon_buttons_under_logo #site-logo{float:none;width:100%;height:auto;text-align:center}.wpex-mobile-toggle-menu-icon_buttons_under_logo .header-two-aside{text-align:center}.wpex-mobile-toggle-menu-icon_buttons_under_logo #searchform-dropdown{width:100%}.wpex-mobile-toggle-menu-icon_buttons_under_logo .site-header-flex{flex-direction:column}.wpex-mobile-toggle-menu-icon_buttons_under_logo .header-fixed-height #site-header-inner{height:auto;padding:20px 0}.has-mobile-menu.wpex-mobile-toggle-menu-navbar #searchform-dropdown{width:100%;top:calc(100% + var(--wpex-mobile-menu-toggle-height, 50px))}.has-mobile-menu.wpex-mobile-toggle-menu-fixed_top{padding-top:var(--wpex-mobile-menu-toggle-height, 50px)}.has-mobile-menu.wpex-mobile-toggle-menu-fixed_top #site-header:not(.header-seven):not(.header-eight):not(.header-nine):not(.header-ten) #searchform-dropdown{position:fixed;width:100%;top:var(--wpex-mobile-menu-toggle-height, 50px)}.has-mobile-menu.wpex-mobile-toggle-menu-fixed_top #site-header.header-one #site-logo{float:none;width:100%;text-align:center}.header-seven-logo,.header-eight-logo,.header-nine-logo,.header-ten-logo{margin-right:auto}.header-seven-aside,.header-ten-aside{margin-left:var(--wpex-site-header-gutter, 25px)}.wpex-mobile-toggle-menu-icon_buttons_under_logo #site-header-flex{--wpex-site-header-gutter:0;flex-direction:column;justify-content:center}.wpex-mobile-toggle-menu-icon_buttons_under_logo #site-header-flex #site-logo{margin-left:auto;margin-right:auto}.wpex-mobile-toggle-menu-icon_buttons_under_logo #site-header-flex #site-logo-inner{flex-grow:1}.wpex-mobile-toggle-menu-icon_buttons_under_logo #site-header-flex-aside{margin-top:20px}.wpex-mobile-toggle-menu-centered_logo,.wpex-mobile-toggle-menu-next_to_logo{--wpex-site-header-gutter:0}.wpex-mobile-toggle-menu-centered_logo #site-logo,.wpex-mobile-toggle-menu-next_to_logo #site-logo{order:2}.wpex-mobile-toggle-menu-centered_logo #site-header-flex-aside,.wpex-mobile-toggle-menu-next_to_logo #site-header-flex-aside{order:3}.wpex-mobile-toggle-menu-centered_logo #mobile-menu,.wpex-mobile-toggle-menu-next_to_logo #mobile-menu{order:1}.wpex-mobile-toggle-menu-centered_logo #site-header-flex{justify-content:space-between}.wpex-mobile-toggle-menu-centered_logo #site-logo{width:60%;text-align:center}.wpex-mobile-toggle-menu-centered_logo #site-logo-inner{flex-grow:1}.wpex-mobile-toggle-menu-centered_logo #site-header-flex-aside{width:20%}.wpex-mobile-toggle-menu-centered_logo #mobile-menu{width:20%}
