<?php
defined( 'ABSPATH' ) || exit;

$html = '';

$html .= '<div class="wpex-card-inner wpex-flex-col wpex-flex-grow wpex-surface-1 wpex-border wpex-border wpex-border-gray-200 wpex-border-solid wpex-rounded wpex-mt-50 wpex-px-25 wpex-pb-25 wpex-text-center">';

	// Thumbnail.
	$html .= $this->get_thumbnail( array(
		'link' => false,
		'class' => '',
		'image_class' => 'wpex-surface-1 wpex-rounded-full wpex-p-5 wpex-border wpex-border wpex-border-gray-200 wpex-border-solid',
	) );

	// Excerpt.
	$html .= $this->get_excerpt( array(
		'length' => '-1',
		'class' => 'wpex-italic wpex-mt-15',
	) );

	// Author.
	$author = wpex_get_testimonial_author();
	if ( $author ) {
		$company = wpex_get_testimonial_company();
		if ( $company ) {
			$author = $author . ' - '. $company;
		}
		$html .= $this->get_element( array(
			'content'  => $author,
			'class'    => 'wpex-card-testimonial-author wpex-mt-10 wpex-heading wpex-text-sm wpex-text-accent wpex-font-bold',
		) );
	}

	// Rating.
	$html .= $this->get_star_rating( array(
		'class' => 'wpex-mt-5 wpex-text-md',
	) );

$html .= '</div>';

return $html;