<?php
defined( 'ABSPATH' ) || exit;

$html = '';

$html .= '<div class="wpex-card-inner wpex-flex wpex-items-center wpex-surface-1 wpex-p-25 wpex-rounded-md wpex-shadow">';

	$html .= '<div class="wpex-card-details wpex-flex-grow">';

		// Icon
		$quote_dir = is_rtl() ? 'right' : 'left';
		$html .= $this->get_icon( array(
			'icon' => 'ticon ticon-quote-' . $quote_dir,
			'class' => 'wpex-text-accent wpex-mb-10',
		) );

		// Excerpt
		$html .= $this->get_excerpt( array(
			'length' => '-1',
			'class' => 'wpex-font-500',
		) );

		// Author
		$html .= $this->get_element( array(
			'content'  => wpex_get_testimonial_author(),
			'class'    => 'wpex-card-testimonial-author wpex-mt-10 wpex-heading wpex-text-md wpex-text-1 wpex-font-bold wpex-uppercase',
		) );

	$html .= '</div>';

	// Thumbnail
	$html .= $this->get_thumbnail( array(
		'link'        => false,
		'class'       => 'wpex-flex-shrink-0 wpex-ml-20 wpex-rounded-full',
		'image_class' => 'wpex-rounded-full',
	) );

$html .= '</div>';

return $html;