.wpcf7 .screen-reader-response{position:absolute;overflow:hidden;clip:rect(1px, 1px, 1px, 1px);height:1px;width:1px;margin:0;padding:0;border:0}.wpcf7 form.init .wpcf7-response-output,.wpcf7 form.resetting .wpcf7-response-output,.wpcf7 form.submitting .wpcf7-response-output{display:none}span.wpcf7-list-item{display:inline-block;margin-right:20px}.wpcf7-list-item-label::before,.wpcf7-list-item-label::after{content:" "}.wpcf7 div.ajax-error{display:none}.wpcf7 input[type="file"]{cursor:pointer}.wpcf7 input[type="file"]:disabled{cursor:default}.wpcf7 .wpcf7-submit:disabled{cursor:not-allowed}.wpcf7-form-control-wrap{position:relative}.wpcf7-form p{margin-bottom:15px}.wpcf7-form input,.wpcf7-form textarea,.wpcf7-form .wpex-select-wrap{margin-top:3px}.wpcf7-not-valid-tip{color:var(--wpex-red-error);font-size:1em;font-weight:normal;display:block;margin-top:5px}.wpcf7-quiz-label{display:block}.wpcf7 form p:last-of-type{margin:0}.wpcf7 form .wpcf7-response-output{padding:10px 20px;color:var(--wpex-alert-color);background:var(--wpex-alert-bg);border-width:0 0 0 4px;border-style:solid;border-color:currentColor}.wpcf7 form.sent .wpcf7-response-output{background-color:var(--wpex-success-bg);border-left-color:var(--wpex-green-success)}.wpcf7 form.failed .wpcf7-response-output,.wpcf7 form.aborted .wpcf7-response-output{background-color:var(--wpex-error-bg);border-left-color:var(--wpex-red-error)}.wpcf7 form.spam .wpcf7-response-output,.wpcf7 form.invalid .wpcf7-response-output,.wpcf7 form.unaccepted .wpcf7-response-output{color:var(--wpex-alert-color);background-color:var(--wpex-warning-bg);border-color:var(--wpex-yellow-warning)}.wpcf7 .wpcf7-not-valid{border-color:var(--wpex-red-error)}.wpcf7 .one-half input[type="text"],.wpcf7 .one-half input[type="email"],.wpcf7 .one-half input[type="tel"],.wpcf7 .one-half input[type="password"],.wpcf7 .one-half input[type="url"],.wpcf7 .one-half input[type="name"],.wpcf7 .col input[type="text"],.wpcf7 .col input[type="email"],.wpcf7 .col input[type="tel"],.wpcf7 .col input[type="password"],.wpcf7 .col input[type="url"],.wpcf7 .col input[type="name"]{width:100%}.wpcf7 .one-half{padding-left:20px}.wpcf7 .one-half.first{padding-left:0}.wpcf7 .full-width input{width:100%}.full-width-input .wpcf7 .ajax-loader{clear:both;margin:15px 0 0}.wpcf7-spinner{background:var(--wpex-gray-500);transform:scale(0.75);margin:8px 0 0}.wpcf7-spinner::before{background:var(--wpex-white)}.wpcf7-spinner.is-active{display:inline-block}.wpcf7-form:not(.submitting) .wpcf7-spinner{display:none}
