/**
 *
 * Welcome Page Styles
 *
**/

.clearfix:after,
.clearfix:before{
    content: "";
    display: table;
}

.clearfix:after{
    clear: both;
}

.welcome-wrap *{
    box-sizing: border-box;
}

.welcome-wrap{
    position: relative;
    margin: 25px 40px 0 20px;
    max-width: 1150px;
    font-size: 15px;
    line-height: 1.5;
    color: #555d66
}

.welcome-wrap p{
    font-size: 15px;
    line-height: 1.5;
    color: #555d66
}

.welcome-main-content,
.welcome-footer-content{
    background: #FFF;
    padding: 50px;
    margin-bottom: 50px;
}

.welcome-footer-content{
    margin-bottom: 0;
}

/** Welcome Header **/
.welcome-header{
    margin-bottom: 50px;
}

.welcome-intro{
    width: 70%;
    float: left;
    font-size: 18px;
}

.welcome-logo{
    max-width: 320px;
    margin-bottom: 10px;
}

.welcome-intro h2{
    font-size: 32px;
    margin: 0 0 20px;
}

.free-pro-demos{
    margin-top: 20px;
}

.free-pro-demos a.button{
    padding: 0 20px;
    line-height: 42px;
    font-weight: bold;
    margin-right: 20px;
}

.free-pro-demos a.button .dashicons{
    height: auto;
    width: auto;
    line-height: 42px;
    margin-right: 8px;
}

.welcome-promo-banner{
    width: 25%;
    background: #fff;
    border: 1px solid #EEE;
    padding: 20px;
    float: right;
    text-align: center;
}

.welcome-promo-banner p {
    font-weight: bold;
    font-size: 20px;
}

.welcome-promo-banner a.upgrade-btn {
    display: block !important;
    width: 100%;
    padding: 10px;
    font-weight: bold;
    white-space: normal;
}

.welcome-promo-offer {
    display: block !important;
    margin-bottom: 15px;
    padding: 10px;
    border: 2px dashed #dad5d5;
    background: #f4fcff;
    text-decoration: none;
    font-size: 16px;
    line-height: 1.6em;
}

.welcome-promo-offer span{
    font-size: 40px;
    display: block;
    margin: 20px 0;
    font-weight: bold;
}

/** Nav **/
.welcome-nav-wrapper{
    display: flex;
    background: #EEE;
    padding: 15px 15px 0 15px;
    margin-bottom: 50px;
}

.welcome-nav-wrapper .welcome-nav-tab{
    padding: 14px 30px;
    text-decoration: none;
    background: #FFF;
    color: #333;
    text-transform: uppercase;
    margin-right: 10px;
    font-weight: bold;
    border-radius: 5px 5px 0 0;
    box-shadow: none;
}

.welcome-nav-wrapper .welcome-nav-tab:hover{
    color: #007cba;
}

.welcome-nav-wrapper .welcome-nav-tab.welcome-nav-tab-active{
    background: #23282e;
    color: #FFF;
}

/** Getting Started **/
.welcome-getting-started{
    display: flex;
    justify-content: space-between;
}

.welcome-manual-setup,
.welcome-demo-import{
    width: 48%;
    padding: 30px;
    border: 1px solid #EEE;
    box-shadow: 4px 4px 4px rgba(0,0,0,.04);
}

.welcome-getting-started h3{
    margin: 0 0 20px;
    font-size: 18px;
    border-bottom: 1px solid #eee;
    padding: 0 0 20px;
    line-height: 30px;
}

.welcome-getting-started ol{
    margin: 0 0 20px 20px;
}

.welcome-getting-started p{
    margin: 0 0 20px;
}

.welcome-demo-import h3{
    display: flex;
    justify-content: space-between;
}

.welcome-theme-thumb{
    padding-bottom: 72%;
    position: relative;
    overflow: hidden;
    margin-bottom: 20px;
}

.welcome-theme-thumb img{
    position: absolute;
    left: 0;
    top: 0;
    object-fit: cover;
    height: 100%;
    width: 100%;
    object-position: top center;
}

/** Recommende Plugins **/
.recommended_plugins h3{
    margin: 0 0 15px;
}

.recomended-plugin-wrap{
    display: flex;
    flex-wrap: wrap;
    margin-left: -4%;
    margin-top: -20px;
}

.recommended-plugins{
    background: #fff;
    border: 1px solid #EEE;
    width: 29.33%;
    float: left;
    margin-left: 4%;
    margin-top: 50px;
}

.plugin-image img{
    width: 100%;
    padding: 10px;
}

.plugin-title-wrap{
    position: relative;
    font-size: 14px;
    font-weight: 600;
    line-height: 26px;
    padding: 10px 15px;
    border-top: 1px solid #EEE;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
}

.plugin-btn-wrapper{
    transition: opacity .1s ease-in-out;
    position: absolute;
    top: 0;
    bottom: 0;
    right: 0;
    height: 46px;
    padding: 10px 20px;
    background: rgba(244,244,244,.7);
    border-left: 1px solid rgba(0,0,0,.05);
}

/** Support **/
.support-wrap{
    display: flex;
    justify-content: space-between;
    margin: 0 -15px;
}

.support-wrap .support-col{
    width: 50%;
    border: 1px solid #EEE;
    padding: 30px;
    margin: 0 15px;
    box-shadow: 4px 4px 4px rgba(0,0,0,.04);
}

.support-wrap .support-col h3{
    margin-top: 0;
}

/** Free VS Pro **/
.free-vs-pro-info-wrap{
    display: flex;
    margin: 0 -15px 40px;
}

.free-vs-pro-info{
    border: 1px solid #EEE;
    padding: 20px;
    flex-grow: 1;
    flex-basis: 0;
    margin: 0 15px;
    text-align: center;
    box-shadow: 4px 4px 4px rgba(0,0,0,.04);
}

.free-vs-pro-info h4{
    font-weight: bold;
    margin: 0 0 10px;
}

.free-vs-pro-info p{
    margin: 0;
}

table.comparison-table {
    border:#EEE 1px solid;
    width: 100%;
    border-collapse: collapse;
}

table.comparison-table th,
table.comparison-table td{
    border:1px solid #EEE;
    padding: 15px;
    text-align: left;
}

table.comparison-table th:nth-child(2),
table.comparison-table td:nth-child(2),
table.comparison-table th:nth-child(3),
table.comparison-table td:nth-child(3){
    text-align: center;
    width: 140px;
}

table.comparison-table th {
    background: #F6F6F6;
    font-size: 20px;
    padding: 25px 15px;
}

table.comparison-table th p:last-child,
table.comparison-table td p:last-child{
    margin-bottom: 0;
}

table.comparison-table td span{
    font-weight: bold;
}

table.comparison-table tr:hover{
    background: #F6F6F6;
}

table.comparison-table td:nth-child(2) img,
table.comparison-table td:nth-child(3) img{
    width: 40px;
}

a.buy-pro-btn {
    display: block;
    background: #b92424;
    color: #fff;
    text-decoration: none;
    padding: 15px 20px;
    text-align: center;
    white-space: nowrap;
}

a.buy-pro-btn:hover{
    background: #981f1f
}

/** Upgrade Section **/
.welcome-upgrade-header{
    text-align: center;
    width: 90%;
    margin: 0 auto;
}

.welcome-upgrade-header h3{
    margin: 0 0 10px;
}

.welcome-upgrade-header p{
    font-size: 18px;
}

.welcome-upgrade-box{
    border: 2px dashed #DDD;
    padding: 40px 100px;
    text-align: center;
    margin-top: 50px;
    background: #F6F6F6;
}

.upgrade-box-text h3{
    font-size: 26px;
    margin: 0 0 20px;
}

.upgrade-box-text p{
    font-size: 16px;
    margin: 0 0 20px;
}

.welcome-upgrade-box .upgrade-button{
    display: inline-block;
    padding: 14px 30px;
    background: #0185ba;
    color: #FFF;
    text-transform: uppercase;
    text-decoration: none;
    margin-top: 15px;
    font-weight: bold;
}

/** Welcome Notice **/
.total-welcome-notice-wrap{
    position: relative;
    padding: 20px;
}

.total-welcome-notice-wrap h2{
    font-size: 20px;
    margin: 0 0 5px;
}

.notice .total-welcome-notice-wrap > p{
    font-size: 16px;
    margin: 0 0 25px;
}

.total-welcome-info{
    display: flex;
}

.total-welcome-info .total-welcome-thumb{
    width: 200px;
    margin-right: 40px;
}

.total-welcome-info > .total-welcome-import,
.total-welcome-info > .total-welcome-getting-started{
    width: 340px;
    margin-right: 40px;
}

.total-welcome-thumb img{
    width: 100%;
    box-shadow: 0 0 10px rgba(0,0,0,0.1);
}

.total-welcome-info h3{
    margin: 0 0 15px;
}

.notice .total-welcome-info p{
    margin: 0 0 20px;
}

.total-welcome-info .button{
    margin: 0;
    padding: 12px 36px;
    height: auto;
    line-height: 1.5;
    white-space: normal;
}

.total-welcome-info .button-primary.updating-message:before{
    margin: 0px 5px 0 0;
    height: auto;
    font-size: 18px;
}

#adminmenu .toplevel_page_total-welcome div.wp-menu-image.svg{
    background-size: 18px auto;
}

/** Footer Review **/
body.toplevel_page_total-welcome #wpfooter{
    position: fixed;
    background: #1d2427;
    color: #FFF;
    max-width: 1110px;
    left: 40px;
    margin-right: 40px;
}

body.toplevel_page_total-welcome #wpfooter a{
    color: #FFF;
}

/** Admin Notice **/
.total-notice.notice {
    display: flex;
    gap: 20px;
    align-items: center;
    padding: 20px 40px 20px 20px !important;
    position: relative;
}

.total-notice.notice .total-notice-logo{
    width: 84px;
    flex: 84px 0 0;
}

.total-notice.notice .total-notice-logo svg{
    fill: #72aee6;
    display: block;
}

.total-notice.notice p{
    padding: 0;
    margin: 0 0 15px;
    font-size: 16px;
}

.total-notice a.notice-dismiss {
    text-decoration: none;
}

@media screen and (max-width:782px){

    .welcome-wrap{
        margin: 30px 30px 0 20px;
    }

    .welcome-main-content, 
    .welcome-footer-content{
        padding: 20px;
    }

    .welcome-intro,
    .welcome-promo-banner{
        width: auto;
        float: none;
    }

    .welcome-intro{
        margin-bottom: 40px;
    }

    .welcome-nav-wrapper{
        display: block;
        padding-bottom: 15px;
    }

    .welcome-nav-wrapper .welcome-nav-tab{
        display: block;
        margin: 0 0 5px;
        border-radius: 4px;
        text-align: center;
    }

    .recommended-plugins{
        width: 46%;
        margin-top: 30px;
    }
    
    .plugin-title-wrap{
        padding: 16px 15px;
    }
    
    .plugin-btn-wrapper{
        height: 58px;
    }

    .welcome-upgrade-box{
        padding: 40px;
    }
    
    .total-welcome-info .total-welcome-thumb{
        display: none;
    }

}

@media screen and (max-width:580px){
    .welcome-getting-started{
        display: block;
    }

    .welcome-manual-setup, 
    .welcome-demo-import{
        width: auto;
        padding: 20px;
    }

    .welcome-manual-setup{
        margin-bottom: 40px;
    }

    .recomended-plugin-wrap{
        margin-left: 0;
    }

    .recommended-plugins{
        width: auto;
        float: none;
        max-width: 320px;
        margin-left: auto;
        margin-right: auto;
    }

    .support-wrap,
    .free-vs-pro-info-wrap{
        display: block;
    }

    .support-wrap .support-col,
    .free-vs-pro-info{
        width: auto;
        margin-bottom: 40px;
    }

    .support-wrap .support-col:last-child,
    .free-vs-pro-info:last-child{
        margin-bottom: 0;
    }

    table.comparison-table th, 
    table.comparison-table td{
        display: block;
        width: 100% !important;
        text-align: left !important;
    }
    
    .total-welcome-info{
        display: block;
    }
    
    .total-welcome-info > .total-welcome-import, 
    .total-welcome-info > .total-welcome-getting-started{
        width: auto;
        margin: 0 0 30px;
    }
    
    .total-welcome-info > .total-welcome-getting-started{
        margin-bottom: 0;
    }
}