<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Thumbnail
$html .= $this->get_thumbnail( array(
	'class' => 'wpex-rounded-t',
	'image_class' => 'wpex-rounded-t',
) );

// Details
$html .= '<div class="wpex-card-details wpex-surface-1 wpex-flex-col wpex-flex-grow wpex-p-25 wpex-last-mb-0">';

	// Title
	$html .= $this->get_title( array(
		'class' => 'wpex-heading wpex-text-lg wpex-mb-5',
	) );

	// Position
	$html .= $this->get_element( array(
		'content' => wpex_get_staff_member_position(),
		'class' => 'wpex-card-staff-member-position wpex-text-3 wpex-font-bold',
	) );

	// Excerpt
	$html .= $this->get_excerpt( array(
		'length' => 15,
		'class' => 'wpex-my-10 wpex-text-3',
	) );

	// Social Links
	$html .= $this->get_element( array(
		'content' => wpex_get_staff_social( array(
			'show_icons' => false,
			'spacing'    => '10',
		) ),
		'class' => 'wpex-mt-15',
	) );

$html .= '</div>';

return $html;