<?php
/**
 * Blog entry media (legacy template part)
 *
 * @package Total WordPress theme
 * @subpackage Partials
 * @version 5.0
 *
 */

defined( 'ABSPATH' ) || exit;

get_template_part( 'partials/blog/media/blog-entry-thumbnail' );
