.customize-control-total-typography li.total-typography-line-height,
.customize-control-total-typography li.total-typography-font-size,
.customize-control-total-typography li.total-typography-letter-spacing{
    clear: both;
    margin-bottom: 15px;
}

.total-typography-loading {
    opacity: 0.4;
    pointer-events: none;
}

.total-typography-customize-control-title {
    display: block;
    font-size: 14px;
    line-height: 24px;
    font-weight: 600;
    margin-bottom: 4px;
}

.total-typography-slider-range.ui-widget {
    position: relative;
    height: 4px;
    margin: 0;
    background: rgba(0, 0, 0, .15);
    border: none;
    border-radius: 5px;
    cursor: pointer;
    -webkit-transition: background .5s;
    transition: background .5s;
    border: 0;
}

.total-typography-slider-range:hover {
    background: rgba(0, 0, 0, .2);
}

.total-typography-slider-range .ui-slider-range {
    display: inline-block;
    position: absolute;
    top: 0;
    height: 100%;
    background: #13a1dc;
}

.total-typography-slider-range .ui-slider-handle {
    height: 16px;
    width: 16px;
    background: #fff;
    border: none;
    display: inline-block;
    position: absolute;
    top: 50%;
    margin: 0;
    -webkit-transform: translateY(-50%) translateX(-4px);
    transform: translateY(-50%) translateX(-4px);
    -webkit-box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.3);
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.3);
    border-radius: 50%;
    cursor: pointer;
}

.total-typography-font-family,
.total-typography-text-transform{
    float: left;
    width: 48%;
    margin-bottom: 10px;
}

.total-typography-font-style,
.total-typography-text-decoration{
    float: right;
    width: 48%;
    margin-bottom: 10px;
}

.total-typography-slider{
    display: flex;
    align-items: center;
}

.total-typography-slider-range{
    flex-grow: 1;
}

.total-typography-slider-range + div{
    margin-left: 10px;
    width: 50px;
    text-align: right;
    font-weight: bold;
}

.total-typography-color{
    position: relative;
}