<?php
namespace TotalTheme\Actions;

use TotalTheme\Redirections;

defined( 'ABSPATH' ) || exit;

/**
 * Hooks into "template_redirect".
 *
 * @package TotalTheme
 * @subpackage Actions
 * @version 5.4
 */
final class Template_Redirect {

	/**
	 * Callback method.
	 */
	public static function callback() {
		Redirections::maybe_redirect();
	}

}