<?php
namespace TotalTheme\Customizer\Controls;

use \WP_Customize_Control;

defined( 'ABSPATH' ) || exit;

/**
 * Customizer HR Control.
 *
 * @package TotalTheme
 * @subpackage Customizer
 * @version 5.3.1
 */
class Hr extends WP_Customize_Control {

	/**
	 * The control type.
	 */
	public $type = 'hr';

	/**
	 * The control template.
	 */
	public function content_template() { ?>
		<hr>
	<?php }

}