.wpex-social-widget-services-list{margin:5px 0 0 !important;padding:0 !important;list-style:none}.wpex-social-widget-services-list li{cursor:move;background:#f8f9f9;padding:10px;border:1px dashed #a2aab2;margin:0 0 10px !important;list-style:none}.wpex-social-widget-services-list li p{margin:0 !important}.wpex-social-widget-services-list li label{margin-bottom:3px;display:block;color:#222}.wpex-social-widget-services-list li label .ticon{margin-right:8px}.wpex-social-widget-services-list li input[type="text"]{background:#fff}.wpex-social-widget-services-list .placeholder{background:transparent !important;border:1px dashed #aba9a9}.wpex-widget-settings-form .wpex-rpf-clone{display:none}.wpex-widget-settings-form .wpex-repeater-field li{cursor:move;padding:10px 15px;margin-bottom:15px;position:relative;background:#f6f7f7;border:1px solid #c3c4c7}.wpex-widget-settings-form .wpex-repeater-field li:last-child{margin-bottom:0}.wpex-widget-settings-form .wpex-repeater-field label{display:block;margin-bottom:2px}.wpex-widget-settings-form .wpex-repeater-field select,.wpex-widget-settings-form .wpex-repeater-field input{width:100%}.wpex-widget-settings-form .wpex-repeater-field p{margin:5px 0}.wpex-widget-settings-form .wpex-repeater-field .wpex-rpf-remove{position:absolute;right:10px;top:5px;color:#a00;font-size:22px;cursor:pointer}.wpex-widget-settings-form li.wpex-rpf-placeholder{background:transparent !important;border:1px dashed #aba9a9}.wpex-widget-settings-form .wpex-upload-field input[type=text],.wpex-widget-settings-form .wpex-repeater-field .wpex-upload-field input[type=text]{width:70%}.wpex-widget-settings-form .wpex-upload-field .button,.wpex-widget-settings-form .wpex-repeater-field .wpex-upload-field .button{width:28%;text-align:center}
