body.compose-mode #outer-wrap{overflow:visible}.vc_vcex_flex_container,.vc_vcex_grid_container,.vc_vcex_toggle_group{margin-top:31px}.compose-mode .vc_vcex_flex_container>.vcex-flex-container>.vc_element,.view-mode .vc_vcex_flex_container>.vcex-flex-container>.vc_element,.compose-mode .vc_vcex_grid_container>.vcex-grid-container>.vc_element,.view-mode .vc_vcex_grid_container>.vcex-grid-container>.vc_element,.compose-mode .vc_vcex_flex_container>.vcex-flex-container>.wpb_text_column,.compose-mode .vc_vcex_grid_container>.vcex-grid-container>.wpb_text_column{display:flex;flex-direction:column}.compose-mode .vc_vcex_grid_container>.vcex-grid-container>.vc_element>.vcex-module,.view-mode .vc_vcex_grid_container>.vcex-grid-container>.vc_element>.vcex-module,.compose-mode .vc_vcex_grid_container>.vcex-grid-container>.vc_element>.wpb_text_column{flex-grow:1}body .vc_ui-help-block.vc_welcome-visible-e{display:none !important}.vc_welcome-brand{display:none !important}.vc_welcome-header{line-height:normal;margin-bottom:20px}#site-header #vc_no-content-helper.vc_not-empty,.footer-builder-content #vc_no-content-helper.vc_not-empty,.footer-builder-content>.vc_empty-placeholder:first-child,#site-header-inner>.vc_empty-placeholder:first-child{display:none}.vc_navbar,.vc_ui-panel-content-container,.vc_controls-out-tl,.vc_controls-cc{-webkit-font-smoothing:subpixel-antialiased}.compose-mode .vc_row:hover .vc_element,.view-mode .vc_row:hover .vc_element,.compose-mode .vc_vc_section,.view-mode .vc_vc_section{z-index:5}body.rtl.compose-mode .vc_ui-icon-pixel{padding-right:0;padding-left:0.5em}body.rtl.compose-mode .vc_controls-column>div>.vc_element .vc_control-btn-switcher .vc_btn-content,body.rtl.compose-mode .vc_controls-column>div>.vc_element :last-child .vc_btn-content,body.rtl.compose-mode .vc_controls-container>div>.vc_element .vc_control-btn-switcher .vc_btn-content,body.rtl.compose-mode .vc_controls-container>div>.vc_element :last-child .vc_btn-content,body.rtl.compose-mode .vc_controls-row>div>.vc_element .vc_control-btn-switcher .vc_btn-content,body.rtl.compose-mode .vc_controls-row>div>.vc_element :last-child .vc_btn-content,body.rtl.compose-mode .vc_controls>.vc_controls-cc>:last-child .vc_btn-content{border-radius:0;border-bottom-left-radius:3px;border-top-left-radius:3px}body.rtl.compose-mode .vc_controls-column>div>.vc_parent>:first-child .vc_btn-content,body.rtl.compose-mode .vc_controls-container>div>.vc_parent>:first-child .vc_btn-content,body.rtl.compose-mode .vc_controls-row>div>.vc_parent>:first-child .vc_btn-content,body.rtl.compose-mode .vc_controls>.vc_controls-cc>:first-child .vc_btn-content,body.rtl.compose-mode .vc_controls>.vc_controls-out-tl>.vc_element>:first-child .vc_btn-content{border-radius:0;border-bottom-right-radius:3px;border-top-right-radius:3px}body.rtl.compose-mode .vc_child-element-move .vc_btn-content,body.rtl.compose-mode .vc_element-move .vc_btn-content{padding-left:12px !important;padding-right:30px !important}body.rtl.compose-mode .vc_child-element-move .vc-c-icon-dragndrop,body.rtl.compose-mode .vc_element-move .vc-c-icon-dragndrop{right:0;left:auto}body.rtl.compose-mode .vc_control-btn-append:before{left:auto;right:7px}body.rtl.compose-mode .vc_welcome .vc_ui-button .vc-composer-icon{padding:0 0 0 .5em}.compose-mode .vc_empty-shortcode-element.vc_vcex_divider,.compose-mode .vc_empty-shortcode-element.vc_vcex_divider_multicolor,.compose-mode .vc_empty-shortcode-element.vc_vcex_countdown{min-height:0}
