.hdi-clearfix:after,
.hdi-clearfix:before{
    content: "";
    display: table;
}

.hdi-clearfix:after{
    clear: both;
}

.hdi-demo-importer-wrap * {
    box-sizing: border-box;
}

.hdi-demo-importer-wrap img {
    max-width: 100%;
}

.hdi-tab-filter{
    background: #FFF;
    border: 1px solid #DDD;
    padding: 12px;
    margin-top: 20px;
}

.hdi-tab{
    display: inline-block;
    padding: 5px 15px;
    cursor: pointer;
    border-radius: 20px;
}

.hdi-tab.hdi-active{
    background: #0073aa;
    color: #FFF;
}

.hdi-tag-group{
    float: left;
}

.hdi-pagebuilder-group{
    float: right;
}

.hdi-demo-box-wrap {
    display: flex;
    flex-wrap: wrap;
    margin: 0 -20px;
    margin-top: 25px;
}

.hdi-demo-box {
    margin: 0 0 40px;
    padding: 0 20px;
}

.hdi-demo-elements{
    position: relative;
    border: 1px solid #ddd;
    -webkit-box-shadow: 0 1px 1px -1px rgba(0, 0, 0, .1);
    box-shadow: 0 1px 1px -1px rgba(0, 0, 0, .1);
}

.hdi-demo-box img {
    display: block;
    width: 100%;
}

.hdi-demo-box h4 {
    margin: 0;
    padding: 0 15px;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    font-size: 15px;
    font-weight: 600;
    background-color: #fafafa;
    line-height: 48px;
}

.hdi-ribbon {
    width: 75px;
    height: 75px;
    overflow: hidden;
    position: absolute;
    top: -8px;
    right: -8px;
}

.hdi-ribbon::before,
.hdi-ribbon::after {
    position: absolute;
    z-index: -1;
    content: '';
    display: block;
    border: 5px solid #b12222;
    border-top-color: transparent;
    border-right-color: transparent;
}

.hdi-ribbon span {
    position: absolute;
    display: block;
    width: 120px;
    padding: 8px 0;
    background-color: #d42929;
    box-shadow: 0 5px 10px rgba(0,0,0,.1);
    color: #fff;
    font-size: 12px;
    font-weight: bold;
    line-height: 12px;
    text-shadow: 0 1px 1px rgba(0,0,0,.2);
    text-transform: uppercase;
    text-align: center;
    left: -12px;
    top: 13px;
    transform: rotate(45deg);
}

.hdi-ribbon::before {
    top: 0;
    left: 1px;
}

.hdi-ribbon::after {
    bottom: 1px;
    right: 0;
}

.hdi-demo-actions {
    position: relative;
    border-top: 1px solid #ddd;
}

.hdi-demo-buttons {
    display: none;
    position: absolute;
    bottom: 0;
    right: 0;
    top: 0;
    height: 48px;
    padding: 10px;
    opacity: 1;
    background: rgba(244, 244, 244, 0.8);
}

.hdi-demo-box:hover .hdi-demo-buttons {
    display: block;
}

.hdi-demo-buttons a {
    margin: 0 2px;
}

.hdi-modal {
    border: 1px solid #eee;
    background: #fff;
    margin-top: 30px;
}

.hdi-modal-header {
    position: relative;
    padding: 15px 30px;
    font-size: 14px;
    margin: 0;
    line-height: 1.4;
    background: #ffffff;
    border-bottom: 1px solid #eee;
}

.hdi-modal-header h2 {
    margin: 0;
    padding: 0;
    font-size: 14px;
    line-height: 18px;
}

.hdi-modal-header .hdi-modal-back {
    position: absolute;
    right: 0;
    top: 0;
    border-left: 1px solid #EEE;
    height: 48px;
    width: 48px;
    text-align: center;
    cursor: pointer;
}

.hdi-modal-header .hdi-modal-back .dashicons {
    line-height: 48px;
    opacity: 0.8;
    display: inline-block;
    font-size: 22px;
}

.hdi-modal-wrap {
    padding: 30px;
}

.hdi-modal-wrap p {
    margin: 0 0 15px;
    padding: 0;
}

.hdi-modal-recommended-plugins h4,
.hdi-reset-checkbox h4,
.hdi-exclude-image-checkbox h4{
    margin: 30px 0 15px;
    font-size: 16px;
}

.hdi-modal-recommended-plugins ul {
    margin: 0 0 15px;
    padding: 0;
}

.hdi-modal-recommended-plugins ul li {
    margin-bottom: 10px;
}

.hdi-plugin-status li .dashicons-warning,
.hdi-plugin-status .hdi-inactive i{
    color: #ffb900;
}

.hdi-plugin-status li .dashicons-dismiss,
.hdi-plugin-status .hdi-install i{
    color: #c00;
}

.hdi-plugin-status li .dashicons-yes-alt,
.hdi-plugin-status .hdi-active i{
    color: #46b450;
}

.hdi-reset-checkbox {
    margin: 30px 0;
    border: 2px solid #EEE;
    padding: 20px;
}

.hdi-reset-checkbox h4{
    margin: 0 0 15px;
}

.hdi-reset-website-checkbox{
    color: #FF0000;
}

#hdi-import-progress {
    background: #FFF;
    text-align: center;
    margin-top: 25px;
}

#hdi-import-progress .hdi-import-progress-header {
    padding: 15px;
    border-bottom: 1px solid #EEE;
    margin: 0;
}

.hdi-import-progress-wrap {
    padding: 40px;
}

#hdi-import-progress .hdi-import-loader svg {
    display: none;
}

#hdi-import-progress.import-success .hdi-import-loader svg {
    display: block;
}

#hdi-import-progress.import-success .hdi-import-loader img {
    display: none;
}

#hdi-import-progress .hdi-import-progress-message {
    font-size: 20px;
    margin-top: 50px;
    line-height: 1.4;
}

.hdi-import-progress-message .button {
    margin: 0 4px;
}

body.hdi-modal-opened .hdi-tab-filter,
body.hdi-modal-opened .hdi-demo-box-wrap{
    display: none;
}

.hdi-loader-content {
    width: 100px;
    height: 100px;
    margin: 0 auto;
    border: 5px solid #00adff;
    border-radius: 100%;
}

.hdi-loader-content-inside {
    width: 100%;
    height: 100%;
    position: relative;
}

.hdi-loader-rotater {
    width: 100%;
    height: 100%;
    position: relative;
    animation: hdi-rotate 3s linear infinite 1s;
}

.hdi-loader-rotater:before {
    content: "";
    position: absolute;
    top: 0x;
    left: 50%;
    margin-left: -4px;
    height: 8px;
    width: 8px;
    background: #00adff;
    border-radius: 100%;
}

.hdi-loader-line-point {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    margin: auto;
    width: 24px;
    height: 24px;
    transition: height 0.15s ease 0.45s;
}

.hdi-loader-line-point:before,
.hdi-loader-line-point:after {
    content: "";
    position: absolute;
    width: 5px;
    height: 30px;
    bottom: -8px;
    background: #00adff;
    border-radius: 10px;
    transition: transform 0.1s ease 0.5s, left 0.1s ease 0.5s, right 0.1s ease 0.5s;
}

.hdi-loader-line-point:before {
    right: 0px;
    transform: rotate(45deg);
}

.hdi-loader-line-point:after {
    left: 0px;
    transform: rotate(-45deg);
}

.import-success .hdi-loader-content {
    animation: hdi-border-color 0.25s forwards 1s;
}

.import-success .hdi-loader-rotater {
    display: none;
}

.import-success .hdi-loader-line-point:after {
    transform: rotate(-90deg);
    left: -4px;
    animation: hdi-check-left 0.25s forwards 1s;
}

.import-success .hdi-loader-line-point:before {
    transform: rotate(90deg);
    right: -4px;
    animation: hdi-check-right 0.25s forwards 1s;
}

.import-error .hdi-loader-rotater {
    animation: none;
}

@keyframes hdi-check-left {
    0% {
        transform: rotate(-90deg);
        left: -4px;
        height: 30px;
        bottom: -8px;
    }
    100% {
        transform: rotate(-45deg);
        left: -5px;
        height: 20px;
        bottom: -5px;
        background: #4BB543;
    }
}

@keyframes hdi-check-right {
    0% {
        transform: rotate(90deg);
        right: -4px;
        height: 30px;
        bottom: -8px;
    }
    100% {
        transform: rotate(45deg);
        right: 4px;
        height: 40px;
        bottom: -10px;
        background: #4BB543;
    }
}

@keyframes hdi-border-color {
    0% {
        border: 6px solid #00adff;
    }
    100% {
        border: 6px solid #4BB543;
    }
}

@keyframes hdi-rotate {
    0% {
        transform: rotate(0deg);
    }
    100% {
        transform: rotate(360deg);
    }
}

.hdi-import-progress-message:after {
    content: '.';
    animation: dots 1s linear infinite;
}

.import-error .hdi-import-progress-message:after,
.import-success .hdi-import-progress-message:after {
    content: '';
    animation: none;
}

@keyframes dots {
    0%,
    20% {
        color: rgba(0, 0, 0, 0);
        text-shadow: .25em 0 0 rgba(0, 0, 0, 0), .5em 0 0 rgba(0, 0, 0, 0);
    }
    40% {
        color: #444;
        text-shadow: .25em 0 0 rgba(0, 0, 0, 0), .5em 0 0 rgba(0, 0, 0, 0);
    }
    60% {
        text-shadow: .25em 0 0 #444, .5em 0 0 rgba(0, 0, 0, 0);
    }
    80%,
    100% {
        text-shadow: .25em 0 0 #444, .5em 0 0 #444;
    }
}

.hdi-demo-box{
    width: 20%;
}

@media only screen and (max-width: 2000px){
    .hdi-demo-box{
        width: 25%;
    }
}

@media only screen and (max-width: 1640px){
    .hdi-demo-box{
        width: 33.33%;
    }
}

@media only screen and (max-width: 1120px){
    .hdi-demo-box{
        width: 50%;
    }
}

@media only screen and (max-width: 480px){
    .hdi-demo-box{
        width: 100%;
    }
}

@media only screen and (min-width: 1120px){
    .hdi-demo-importer-wrap{
        margin-right: 5%;
    }
}

@media screen and (max-width: 782px){
    .hdi-demo-box h4{
        line-height: 60px;
    }

    .hdi-demo-buttons{
        height: 60px;
    }
}
