<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

get_header();

$preview_width = get_post_meta( get_the_ID(), 'preview_width', true );

?>

	<div class="wpex-card-builder wpex-p-50">
		<?php if ( $preview_width ) {
			echo '<div class="wpex-mx-auto" style="max-width:' . esc_attr( wpex_sanitize_data( $preview_width, 'fallback_px' ) ) . '">';
		} else {
			echo '<div class="container">';
		} ?>
			<?php while ( have_posts() ) : the_post(); ?>
				<?php the_content(); ?>
			<?php endwhile; ?>
		</div>
	</div>

<?php
get_footer();