<?php
use TotalTheme\Mobile\Menu as Mobile_Menu;

/**
 * Elements used for the dynamic sidebar mobile menu which is generated via JS.
 *
 * @package Total WordPress theme
 * @subpackage Partials
 * @version 5.4
 */

defined( 'ABSPATH' ) || exit;

Mobile_Menu::search_form();

?>

<div class="wpex-sidr-overlay wpex-fixed wpex-inset-0 wpex-hidden wpex-z-9999 wpex-bg-black wpex-opacity-60"></div>

