<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Inner
$html .= '<div class="wpex-card-inner wpex-text-center">';

	// Thumbnail
	$html .= $this->get_thumbnail( array(
		'class' => 'wpex-mb-15 wpex-rounded-full-tl wpex-rounded-full-bl wpex-rounded-full-br',
		'image_class' => 'wpex-rounded-full-tl wpex-rounded-full-bl wpex-rounded-full-br'
	) );

	// Title
	$html .= $this->get_title( array(
		'class' => 'wpex-heading wpex-text-md wpex-font-bold',
	) );

	// Position
	$html .= $this->get_element( array(
		'content' => wpex_get_staff_member_position(),
		'class' => 'wpex-card-staff-member-position wpex-text-3',
	) );

$html .= '</div>';

return $html;