<?php
use TotalTheme\Integration\WPBakery\Shortcode_Inline_Style as WPB_Style;

defined( 'ABSPATH' ) || exit;

$html = '';

$content = get_the_content( null, false, $this->post_id );

if ( ! $content ) {
	return;
}

$html .= WPB_Style::instance()->get_style( $this->post_id );
$html .= apply_filters( 'wpex_the_content', $content );

return $html;