.wpb_templatera {
  &.wpb_content_element {
    .vct_cover {
      position: absolute;
      height: 100%;
      width: 100%;
      background-color: #ffffff;
      opacity: 0.6;
      z-index: 2;
      //display: none;
    }

    > .wpb_element_wrapper {
      height: auto;
      padding: 5px;
      background: #FCF8E3;
      border: 1px dashed #C09853;
    }

    .controls_row, .controls_column {
      display: none;
    }

    .wpb_column_container {
      padding-top: 0px;
      padding-bottom: 3px;

      .vc_controls {
        display: none;
      }
    }

    .empty_container {
      background-image: none;
    }
  }
}

#vas_template_settings_metabox {
  .inside {
    padding: 0;

    .vc_template_title {
      margin-bottom: 4px;
    }

    .vc_user_role {
      border-bottom: 0;
    }
  }
}

a.wpb_templates i.icon {
  background-image: url("../images/icon_12.gif");
}

.vc_templatera_button {
  display: block;
  width: 32px;
  height: 32px;
  padding: 28px 30px;
  background-color: transparent;
  background-position: center center !important;
  background-repeat: no-repeat !important;
  background-image: url(../images/templatera_32.png) !important;
}

// @deprecated since 4.4 used modal window
#vc-templatera-editor {
  display: none;
  position: fixed;
  z-index: 100003;
  top: 74px;
  left: 50%;
  width: 500px;

  .vc_title_name {
    width: 317px;
  }

  #vc-template-save {
    vertical-align: top;
  }

  .wpb_templates_list {
    margin-top: 10px;
    overflow-y: auto;
    height: 234px;

    .wpb_template_li {
      display: block;
      margin: 0 0 1px 0;
      background: #eeeeee;
      padding: 10px;

      .vct_template-title {
        display: inline-block;
        width: 80%;
      }

      a {
        color: #1b6bb0;
      }
    }

    .wpb_remove_template {
      display: block;
      float: right;
      cursor: pointer;

      .icon {
        display: inline-block;
        background-image: url('../images/controls.png');
        background-repeat: no-repeat;
        background-position: -16px -64px;
        width: 16px;
        height: 16px;
      }
    }

    .wpb_edit_template {
      display: block;
      float: right;
      cursor: pointer;
      margin-right: 10px;

      .icon {
        display: inline-block;
        background-image: url('../images/controls.png');
        background-repeat: no-repeat;
        background-position: -16px -32px;
        width: 16px;
        height: 16px;
      }
    }
  }
}

//edit icon in backend
#wpb_visual_composer-elements {
  .wpb_edit_template {
    display: block;
    float: right;
    cursor: pointer;
    border: none;

    .icon {
      display: inline-block;
      background-image: url('../images/edit.png');
      background-repeat: no-repeat;
      background-position: center center;
      width: 11px;
      height: 16px;
    }
  }
}

//@since 4.4 modal window
.vc_panel.vc_templates-panel, #vc_ui-panel-templates {
  .vc_templates-template-type-templatera_templates {
    .vc_template-icon.vc_template-edit-icon {
      .vc_icon {
        background-image: url('../images/controls.png');
        background-position: -16px -32px;
      }
    }
  }
}