<?php
/**
 * Card: Product 2
 *
 * @package TotalTheme
 * @subpackage Cards
 * @version 5.0
 */

defined( 'ABSPATH' ) || exit;

$html = '';

$html .= '<div class="wpex-card-inner wpex-relative wpex-text-center wpex-p-15 wpex-surface-1 wpex-border wpex-border-solid wpex-border-gray-200">';

	// Media
	$html .= $this->get_media( array(
		'class' => 'wpex-mb-15',
	) );

	// Details
	$html .= '<div class="wpex-card-details wpex-last-mb-0">';

		// Title
		$html .= $this->get_title( array(
			'class' => 'wpex-heading wpex-text-md wpex-mb-5',
			'link_class' => 'wpex-inherit-color-important',
		) );

		// Price
		$html .= $this->get_price( array(
			'class' => 'wpex-text-accent wpex-font-semibold',
		) );

	$html .= '</div>';

$html .= '</div>';

return $html;