<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Thumbnail
$html .= $this->get_thumbnail( array(
	'class' => 'wpex-mb-10',
) );

// Title
$html .= $this->get_title( array(
	'class' => 'wpex-heading wpex-text-md',
) );

// Position
$html .= $this->get_element( array(
	'content' => wpex_get_staff_member_position(),
	'class' => 'wpex-card-staff-member-position wpex-text-3',
) );

return $html;