window.addEventListener( 'elementor/frontend/init', () => {

     elementorFrontend.hooks.addAction( 'frontend/element_ready/global', function() {

        if ( 'object' === typeof wpex ) {

            if ( 'function' === typeof wpex.hoverStyles ) {
                wpex.hoverStyles();
            }

            if ( 'function' === typeof wpex.customSelects ) {
                wpex.customSelects();
            }

        }
    } );

} );