<?php
use TotalTheme\Portfolio\Single_Blocks as Blocks;

/**
 * Portfolio single layout.
 *
 * @package Total WordPress theme
 * @subpackage Partials
 * @version 5.5
 */

defined( 'ABSPATH' ) || exit;

?>

<div id="single-blocks" <?php Blocks::wrapper_class(); ?>><?php

	/**
	 * Renders the single portfolio post blocks.
	 *
	 * @see inc/portfolio/single-blocks.php
	 *
	 * If you wish to create a custom page design please see the "Dynamic Templates" documentation.
	 *
	 * @link https://wpexplorer-themes.com/total/docs/dynamic-templates/
	 */
	Blocks::render();

?></div>