<?php
/**
 * Blog single post audio format media
 *
 * @package Total WordPress theme
 * @subpackage Partials
 * @version 5.0
 */

defined( 'ABSPATH' ) || exit;

?>

<div class="blog-post-audio wpex-clr">
	<?php wpex_blog_post_thumbnail() ?>
	<?php wpex_post_audio_html(); ?>
</div>