/**************************************************************************
 * tp-color-picker.css - Color Picker Plugin for Revolution Slider
 * @version: 2.0 (01.01.2018)
 * @author ThemePunch
**************************************************************************/


/*
  Default Picker Widget
*/
.revbuilder-colorpicker {
	
	display: inline-block; 
	height: 27px; 
	line-height: 27px;
	cursor: pointer; 		
	box-sizing: border-box;	
	
}

.revbuilder-cpicker-master-wrap,
.revbuilder-cpicker-master-wrap input
 {
	
	cursor: pointer;
	
}

#revbuilder-cpicker-gradients,
#revbuilder-cpicker-colors {
	line-height: 30px;
	vertical-align: top;
}
#revbuilder-cpicker * {
	
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
	-webkit-touch-callout: none;
	text-rendering: optimizeLegibility;
	
}



#revbuilder-cpicker i {
	
	line-height: normal;
	
}

.revbuilder-colorpicker span,
.revbuilder-cpicker-preview {
	
	display: inline-block; 
	height: 100%; 
	vertical-align: middle;
	
}

.revbuilder-colorpicker .revbuilder-colorbox,
.revbuilder-cpicker-preview {
	
	width: 13px;
	height: 13px;
	background: url(../images/trans_tile.png);
	border-radius: 2px;
	border: 1px solid #414448;	
	box-sizing: border-box;
	
}

#revbuilder-cpicker-preview-gradient {
	
	background: #FFF;
	
}

.revbuilder-cpicker-preview {
	
	width: 17px;
	height: 17px;
	vertical-align: top;
	margin: 0 10px 0 10px;
	position: relative;
	top: 7px;
	border-radius: 0 !important;
	border: none !important;
	
}

.revbuilder-colorpicker .revbuilder-colorbtn,
.revbuilder-cpicker-input {
	
	font-family: 'Roboto';
	font-size: 17px;
	line-height: 27px;
	padding-left: 4px;
	background: transparent !important;
	position: relative;	
	font-weight: 500;
	color: #b7bbc0 !important;
}

.revbuilder-cpicker-input:focus {
	
	background: transparent !important;
	border: 0 !important;
	box-shadow: none !important;
	
}

.revbuilder-cpicker-input {
	
	font-size: 13px;
	line-height: 18px;
	border: 0 !important;
	width: 125px;
	margin-left: 3px;
	padding: 3px 0;
	margin-top: 0px;
	
}

.revbuilder-cpicker-hex {
	
	width: 106px;
	margin-left: 0;
	
}

.revbuilder-cpicker-input-wrap {
	
	overflow: hidden;
	
}

.revbuilder-cpicker-input-wrap,
.revbuilder-cpicker-btn {
	
	width: 145px;
	height: 30px;
	display: inline-block;
	vertical-align: top;
	background: #2a2c2f;
	border-radius: 2px;
	padding-top: 0px;
	text-align: left;
	line-height: 30px;
	vertical-align: top;
	
}

.revbuilder-cpicker-btn-small {
	
	width: 31px;
	float: right;
	margin-right: 31px;
	
}

.revbuilder-cpicker-input-wrap.focus {
	
	background: #3a3e44;
	
}

.revbuilder-cpicker-input-basic {
	
	width: 50px;
	margin-left: 5px;
	
}

.revbuilder-cpicker-input-small {
	
	width: 45px;
	margin-left: 5px;
	
}

.revbuilder-cpicker-input-basic.first,
.revbuilder-cpicker-input-small.first,
.revbuilder-cpicker-input-medium.first {
	
	margin-left: 0;
	
}

.revbuilder-cpicker-input-small .revbuilder-cpicker-input {
	
	width: 40px;
	margin-left: 3px;
	
}

#revbuilder-cpicker-radial-wrap,
#revbuilder-cpicker-radial-wrap .revbuilder-cpicker-input {
	
	width: 45px;
	text-align: left;
	
}

.revbuilder-cpicker-input-medium {
	
	width: 70px;
	margin-left: 5px;
	
}

.revbuilder-cpicker-input-medium .revbuilder-cpicker-input {
	
	width: 59px;
	margin-left: 10px;
	
}

.revbuilder-colorpicker-open .tipsy-inner {
	
	max-width: none;
	
}

.revbuilder-cpicker-wrap {
	
	position: fixed;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 2099999;
	display: none;
	
}

#revbuilder-cpicker-back {
	
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	background: transparent; /*rgba(50, 52, 56, 0.5);*/
	
}

#revbuilder-cpicker {

	position: absolute;
	top: 50%;
	left: 50%;
	font-family: 'Roboto', 'Roboto';
	font-size: 12px;
	white-space: nowrap;
	display: block; 
	cursor: default; 	
	color: #777c80; 
	box-shadow: 0px 10px 20px 0px rgba(0,0,0,0.5);

}

#revbuilder-cpicker-container {
	
	display: table;
	background: #323438;
	
}

#revbuilder-cpicker-head {
	
	background: #2a2c2f;
	width: 560px;
	height: 70px;
	position: relative;
	
}

.revbuilder-cpicker-candrag {
	
	pointer-events: none;
	
}

.revbuilder-cpicker-column {
	
	display: table-cell;
	vertical-align: top;
	
}

#revbuilder-cpicker-right {
	
	position: relative;
	background: #323438;
	width: 70px;
	height: 100%;
	
}

#revbuilder-cpicker-toggle {
	
	position: absolute;
	bottom: 0;
	right: 0;
	
}

.revbuilder-cpicker-hover {
	
	transition: background 0.2s ease;
	
}

.revbuilder-cpicker-btn-large {
	
	width: 70px;
	height: 70px;
	cursor: pointer;
	text-align: center;
	
}

.revbuilder-cpicker-btn-large i {
	
	font-size: 30px;
	margin-top: 19px;
	
}

.revbuilder-cpicker-palette-open,
.revbuilder-cpicker-wrap.palette-open .revbuilder-cpicker-palette-closed {
	
	display: none !important;
	
}

.revbuilder-cpicker-wrap.palette-open .revbuilder-cpicker-palette-open {
	
	display: inline-block !important;
	
}

.revbuilder-cpicker-wrap.color-view.palette-open #revbuilder-cpicker-color-presets,
.revbuilder-cpicker-wrap.gradient-view.palette-open #revbuilder-cpicker-gradient-presets {
	
	display: block;
	
}

.revbuilder-cpicker-wrap.color-view #revbuilder-cpicker-gradients,
.revbuilder-cpicker-wrap.gradient-view #revbuilder-cpicker-colors {
	
	display: none;
	
}

.revbuilder-cpicker-wrap.gradient-view #revbuilder-cpicker-gradients {
	
	margin-bottom: -48px;
	
}

.revbuilder-cpicker-wrap.gradient-view.palette-open #revbuilder-cpicker-gradients {
	
	margin-bottom: 0;
	
}

#revbuilder-cpicker-gradients .revbuilder-cpicker-row.first {
	
	padding-bottom: 20px;
	
}

#revbuilder-cpicker-gradients #revbuilder-cpicker-gradient-presets .revbuilder-cpicker-row.first {
	
	padding-bottom: 0;
	
}

.revbuilder-cpicker-btn-large:hover {
	
	background: #006dd2;
	
}

.revbuilder-cpicker-btn-large:hover i {
	
	color: #FFF;
	
}

#revbuilder-cpicker-type-wrap {
	
	margin-top: 20px;
	
}

#revbuilder-cpicker-type-wrap > * {
	
	display: inline-block;
	vertical-align: middle;
	
}

.revbuilder-cpicker-side {
	
	display: inline-block;
	position: relative;
	
}

#revbuilder-cpicker-base .revbuilder-cpicker-side {
	
	vertical-align: top;
	
}

.revbuilder-cpicker-left {
	
	width: 306px;
	
}

#revbuilder-cpicker-left {
	
	padding-bottom: 40px;
	
}

#revbuilder-cpicker-base {
	
	margin-top: 30px;
	
}

#revbuilder-cpicker-editing {
	
	position: relative;
	display: inline-block;
	
}

.revbuilder-cpicker-main-btn {
	
	color: #b7bbc0;
	width: 50px;
	height: 31px;
	background: #3f444a;
	text-align: center;
	cursor: pointer;
	pointer-events: all;
	position: relative;
	display: inline-block;
	border-radius: 2px;
	z-index: 0;
	
}

.revbuilder-cpicker-title,
.revbuilder-cpicker-spacer {
	
	width: 116px;
	margin-right: 15px;
	text-align: right;
	display: inline-block;
	
}

.revbuilder-cpicker-title:not(.revbuilder-cpicker-candrag) {
	
	position: relative;
	top: 0px;
	
}

#revbuilder-cpicker-gradients .revbuilder-cpicker-side:not(.revbuilder-cpicker-left) .revbuilder-cpicker-title {

	width: auto;
	text-align: left;

}

#revbuilder-cpicker-btn-wrap {
	
	display: inline-block;
	background: #3f444a;
	line-height: 0;
	
}

.revbuilder-cpicker-txt-space-left {
	
	margin-left: 15px;
	
}

.revbuilder-cpicker-wrap.color-view #revbuilder-cpicker-color-btn {
	
	border-radius: 2px 0 2px 2px;
	
}
.revbuilder-cpicker-wrap.gradient-view #revbuilder-cpicker-gradient-btn {
	
	border-radius: 0 2px 2px 2px;
	
}

.revbuilder-cpicker-wrap.color-view #revbuilder-cpicker-color-btn,
.revbuilder-cpicker-wrap.gradient-view #revbuilder-cpicker-gradient-btn {
	
	color: #FFF;
	cursor: default;
	border-radius: 2px;
	background: #006dd2;
	z-index: 1;
	
}

.revbuilder-cpicker-wrap.color-view #revbuilder-cpicker-gradient-btn:hover,
.revbuilder-cpicker-wrap.gradient-view #revbuilder-cpicker-color-btn:hover {

	color: #FFF;
	
}

.revbuilder-cpicker-main-btn i {
	
	margin-top: 4px;
	
}

.revbuilder-cpicker-bright {
	
	color: #b7bbc0;
	
}

.revbuilder-cpicker-row {
	
	margin-top: 10px;
	
}

.revbuilder-cpicker-row.extended {
	
	margin-top: 19px;
	
}

.revbuilder-cpicker-no-margin {
	
	margin-top: 0;
	
}

#revbuilder-cpicker-gradients .revbuilder-cpicker-iris {
	
	margin-top: 26px;
	
}

#revbuilder-cpicker-gradients .iris-slider {
	
	margin-left: -7px !important;
	
}

.revbuilder-cpicker-label {
	
	top: 1px !important;
	
}

.revbuilder-cpicker-row.first {
	
	margin-top: 0;
	
}

.revbuilder-cpicker-btn,
.revbuilder-cpicker-btn-large {
	
	background: #3f444a;
	color: #b7bbc0;
	cursor: pointer;
	text-align: center;
	
}

.revbuilder-cpicker-btn:hover,
.revbuilder-cpicker-btn-large:hover,
#revbuilder-cpicker-check {
	
	background: #006dd2;
	color: #FFF !important;
	
}

#revbuilder-cpicker-check:hover i {
	
	margin-left: 5px;
	
}

.revbuilder-cpicker-btn * {
	
	display: inline-block;
	vertical-align: top;
	
}

.revbuilder-cpicker-btn span {
	
	position: relative;	
	margin-left: 9px;
	vertical-align: top;
	
}

.revbuilder-cpicker-btn i {
	
	font-size: 17px;
	position: relative;
	line-height: 30px !important;
	vertical-align: top;
	
}

#revbuilder-cpicker .iris-strip {	

	width: 10px !important;
	height: 152px !important;
	box-shadow: none;
	border: none;
	border-radius: 0px;
	margin-left: 1px;
	
}

#revbuilder-cpicker .iris-picker .iris-strip .ui-slider-handle:focus, 
#revbuilder-cpicker .iris-picker .ui-square-handle:focus {
	
	box-shadow: 0px 5px 5px 0px rgba(0, 0, 0, 0.35);
	
}

#revbuilder-cpicker .iris-picker .iris-square,
#revbuilder-cpicker .iris-picker .iris-square-inner {
	
	width: 154px !important;
	height: 154px !important;
	box-shadow: none !important;
	border-radius: 0;
	
}

#revbuilder-cpicker .iris-slider.iris-strip .ui-slider-handle,
#revbuilder-cpicker-scroller .iris-slider-offset { 
	
	background: #fff; 
	border-radius: 2px; 
	height: 3px;
	border: none; 
	outline:none !important;
	box-shadow: 0px 5px 5px 0px rgba(0, 0, 0, 0.35);
	
}

#revbuilder-cpicker .iris-slider.iris-strip .ui-slider-handle:before {
	
	display: none;
	
}

#revbuilder-cpicker .iris-slider-offset {
	
	top: 2px !important; 
	bottom: 0 !important;
	
}

#revbuilder-cpicker .wp-color-result,
#revbuilder-cpicker .wp-picker-input-wrap {
	
	display: none;
	
}

#revbuilder-cpicker .wp-picker-container .iris-picker {
	
	margin-top: 0;
	
}

#revbuilder-cpicker .iris-border {
	
	border: 0;
	background: transparent;
	
}

#revbuilder-cpicker .iris-border .iris-picker-inner {
	
	position: static;
	
}

.revbuilder-cpicker-iris .wp-picker-container {
	
	display: inline-block !important;
	vertical-align: top !important;
	width: auto !important;
	margin: 0px !important;
	
}

#revbuilder-cpicker #revbuilder-cpicker-scroller {
	
	position: relative;
	display: inline-block;
	margin-left: 14px;
    vertical-align: top;
	height: 150px !important;
	border-radius: 0;
	box-sizing: border-box;
	box-shadow: inset 0 0 5px rgba(0,0,0,0.4);
    background: url(../images/trans_tile.png);
	
}

#revbuilder-cpicker-scroller div {
	
	box-sizing: border-box;
	
}

#revbuilder-cpicker-scroll-bg {
	
	position: absolute;
	top: 0 !important;
	left: 0;
	width: 100% !important;
	height: 100% !important;
	background: linear-gradient(to bottom, #000 0%, rgba(0, 0, 0, 0) 100%) !important;
	
}

#revbuilder-cpicker-scroll {
	
	position: relative;
	height: 100% !important;
	background: transparent !important;
	
}

#revbuilder-cpicker-scroller .ui-slider-handle {
	
	position: absolute;
    background: 0 0;
    margin: 0;
    right: -3px;
    left: -3px;
    border: 4px solid #aaa;
    border-width: 4px 3px;
    width: auto;
    height: 6px;
    border-radius: 4px;
    box-shadow: 0 1px 2px rgba(0,0,0,.2);
    opacity: .9;
    z-index: 5;
    cursor: ns-resize;
	
}

#revbuilder-cpicker-scroller .ui-slider-handle:before {
	
	content: " ";
    position: absolute;
    left: -2px;
    right: -2px;
    top: -3px;
    bottom: -3px;
    border: 2px solid #fff;
    border-radius: 3px;
	
}

.revbuilder-cpicker-wrap.is-basic #revbuilder-cpicker-scroller,
.revbuilder-cpicker-wrap.is-basic .revbuilder-cpicker-hideable {
	
	display: none;
	
}

.revbuilder-cpicker-presets {
	
	margin-top: 21px;
	display: none;
	
}

#revbuilder-cpicker-gradient-presets {
	
	margin-top: -18px;
	
}

.revbuilder-cpicker-presets-group {
	
	position: relative;			
	line-height: 0;
	white-space: normal;
	padding: 0;	
	width: 173px;
	height: 114px;
	overflow: hidden;
	
}

.revbuilder-cpicker-color,
.revbuilder-cpicker-direction {

	width: 29px;
	height: 29px;
	display: inline-block;
	position: relative;
	margin: 0 12px 12px 0;
	box-sizing: border-box;
	border-radius: 2px;
	overflow: hidden;

}

.revbuilder-cpicker-color.selected,
.revbuilder-cpicker-direction.selected  {
	
	border: 2px solid #FFF;
	cursor: auto;
	
}

.revbuilder-cpicker-color:not(.selected),
.revbuilder-cpicker-direction {
	
	cursor: pointer;
	
}

.revbuilder-cpicker-color.blank {

	cursor: auto;
	background: #3f444a;
	
}

.revbuilder-cpicker-preset-bg,
.revbuilder-cpicker-preset-tile {
	
	display: block;
	width: 100%;
	height: 100%;
	
}

.revbuilder-cpicker-preset-tile {
	
	background: url(../images/trans_tile.png);
	border-radius: 4px; /* Hide strange Radius Failure */
	
}

.revbuilder-cpicker-preset-bg {
	
	position: absolute;
	top: 0;
	left: 0;
	
}

#revpicker-easing-row.active .revbuilder-cpicker-input-wrap {

    width: 90px !important;

}

#revbuilder-cpicker #revpicker-easing-row.active .ddTP_C {
	
	width: 70px !important;
	min-width: 70px !important;
	
}

#revpicker-easing-row.active .revbuilder-cpicker-input-basic {

    width: 50px !important;

}

#revbuilder-cpicker #revpicker-easing-row.active .ddTP_C .ddTP_S {

    width: 55px !important;

}

#revpicker-easing-row.active .revbuilder-cpicker-easing-strength,
#revpicker-easing-row.active #revbuilder-cpicker-strength-title {
	
	display: inline-block;
	
}

.revbuilder-cpicker-easing-strength,
#revpicker-easing-row.active #revbuilder-cpicker-easing-title,
#revbuilder-cpicker-strength-title {
	
	display: none;
	
}


/***********************************
  - PERFECT SCROLLBAR -
************************************/
/* perfect-scrollbar v0.7.1 */
.ps{-ms-touch-action:auto;touch-action:auto;overflow:hidden !important;-ms-overflow-style:none}@supports (-ms-overflow-style: none){.ps{overflow:auto !important}}@media screen and (-ms-high-contrast: active), (-ms-high-contrast: none){.ps{overflow:auto !important}}.ps.ps--active-x>.rs__scrollbar-x-rail,.ps.ps--active-y>.rs__scrollbar-y-rail{display:block;background-color:transparent}.ps.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail{background-color:#eee;opacity:.9}.ps.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail>.rs__scrollbar-x{background-color:#999;height:11px}.ps.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail{background-color:#eee;opacity:.9}.ps.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail>.rs__scrollbar-y{background-color:#999;width:11px}.ps>.rs__scrollbar-x-rail{display:none;position:absolute;opacity:0;-webkit-transition:background-color .2s linear, opacity .2s linear;-o-transition:background-color .2s linear, opacity .2s linear;-moz-transition:background-color .2s linear, opacity .2s linear;transition:background-color .2s linear, opacity .2s linear;bottom:0px;height:15px}.ps>.rs__scrollbar-x-rail>.rs__scrollbar-x{position:absolute;background-color:#aaa;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px;-webkit-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;-o-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;-moz-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -webkit-border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;bottom:2px;height:6px}.ps>.rs__scrollbar-x-rail:hover>.rs__scrollbar-x,.ps>.rs__scrollbar-x-rail:active>.rs__scrollbar-x{height:11px}.ps>.rs__scrollbar-y-rail{display:none;position:absolute;opacity:0;-webkit-transition:background-color .2s linear, opacity .2s linear;-o-transition:background-color .2s linear, opacity .2s linear;-moz-transition:background-color .2s linear, opacity .2s linear;transition:background-color .2s linear, opacity .2s linear;right:0;width:15px}.ps>.rs__scrollbar-y-rail>.rs__scrollbar-y{position:absolute;background-color:#aaa;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px;-webkit-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;-o-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;-moz-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -webkit-border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;right:2px;width:6px}.ps>.rs__scrollbar-y-rail:hover>.rs__scrollbar-y,.ps>.rs__scrollbar-y-rail:active>.rs__scrollbar-y{width:11px}.ps:hover.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail{background-color:#eee;opacity:.9}.ps:hover.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail>.rs__scrollbar-x{background-color:#999;height:11px}.ps:hover.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail{background-color:#eee;opacity:.9}.ps:hover.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail>.rs__scrollbar-y{background-color:#999;width:11px}.ps:hover>.rs__scrollbar-x-rail,.ps:hover>.rs__scrollbar-y-rail{opacity:.6}.ps:hover>.rs__scrollbar-x-rail:hover{background-color:#eee;opacity:.9}.ps:hover>.rs__scrollbar-x-rail:hover>.rs__scrollbar-x{background-color:#999}.ps:hover>.rs__scrollbar-y-rail:hover{background-color:#eee;opacity:.9}.ps:hover>.rs__scrollbar-y-rail:hover>.rs__scrollbar-y{background-color:#999}

#revbuilder-cpicker .ps-container .ps-scrollbar-x-rail {
	
	display: none;
	
}

#revbuilder-cpicker .ps-container .ps-scrollbar-y-rail {
	
	display: block;
	
}

#revbuilder-cpicker .ps-container .ps-scrollbar-y {
	
	border-radius: 3px !important;
	
}

#revbuilder-cpicker .ddTP_S__rendered {
	
	padding-left: 0 !important;
	
}

#revbuilder-cpicker .ps-active-y:hover .ps-scrollbar-y-rail {
	
	opacity: 1;
	
}

#revbuilder-cpicker .ps-active-y .ps-scrollbar-y-rail:hover {
	
	background-color: transparent;
	
}

#revbuilder-cpicker .ps-container:hover > .ps-scrollbar-y-rail:hover > .ps-scrollbar-y {
	
	background-color: #b7bbc0;
	
}

#revbuilder-cpicker .ps > .rs__scrollbar-y-rail {
	
	width: auto !important;
	
}

#revbuilder-cpicker .ps > .rs__scrollbar-y-rail:hover > .rs__scrollbar-y, 
#revbuilder-cpicker .ps > .rs__scrollbar-y-rail:active > .rs__scrollbar-y {
	
	width: 6px !important;
	
}

.revbuilder-picker-color-custom:hover span,
.revbuilder-picker-color-custom:hover .revbuilder-cpicker-delete:before {
	
	display: block;

}

.revbuilder-colorpicker-open .ddTP_C--open {
	
	z-index: 9999999;
	
}

.revbuilder-colorpicker-open .ddTP_C .ddTP_S {
	
	box-shadow:none;
	outline:none;
	border: none;
	border-radius: 3px; 
	width:185px;
	padding:0px; 
	margin:0px; 
	margin-bottom: 10px; 
	
}

.revbuilder-cpicker-wrap.onajax {
	
	pointer-events: none;
	
}

.revbuilder-cpicker-wrap.onajax:before {
	
	width: 100%;
	height: 100%;
	background: rgba(0, 0, 0, 0.5);
	position: absolute;
	top: 0;
	left: 0;
	z-index: 2099998;
	content: "";
	
}

.revbuilder-cpicker-wrap.onajax:after {
	
	position: absolute;
	top: 50%;
	left: 50%;
	z-index: 2099999;
	font-size: 36px;
	color: #FFF;
	margin-top: -10px;
	pointer-events: all;
	
}

.revbuilder-cpicker-wrap.onajaxdelete:after {
	
	content: "Deleting Preset...";
	margin-left: -135px;
	
}

.revbuilder-cpicker-wrap.onajaxsave:after {
	
	content: "Saving Preset...";
	margin-left: -123px;
	
}

#revbuilder-cpicker *:not(input) {
	
	-moz-user-select: none;
	-ms-user-select: none;
	-webkit-user-select: none;
	user-select: none;
	
}

#revbuilder-cpicker-drag {
	
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	cursor: move;
	
}

.revbuilder-cpicker-gradient-block {
	
	width: 236px;
	height: 50px;
	background: url(../images/trans_tile.png);
	
}

#revbuilder-cpicker-gradient-input .ui-draggable {
	
	cursor: default;
	
}

.revbuilder-cpicker-wrap .ui-draggable .revbuilder-cpicker-section {
	
	cursor: auto;
	
}

.revbuilder-cpicker-gradient-builder {
	
	width: 100%;
	height: 100%;
	position: relative;
	
}

#revbuilder-cpicker-hit-top {
	
	top: -17px;
	
}

#revbuilder-cpicker-hit-bottom {
	
	bottom: -17px;
	
}

.revbuilder-cpicker-builder-hit {
	
	position: absolute;
	left: 0;
	width: 100%;
	height: 17px;
	cursor: copy;
	z-index: 0;
	
}

.revbuilder-cpicker-builder-hit.full {
	
	pointer-events: none;
	cursor: auto;
	
}

#revbuilder-cpicker-point-wrap {
	
	width: 246px;
	height: 100%;
	position: absolute;
	top: 0;
	left: -5px;
	z-index: 99;
	
}

#revbuilder-cpciker-point-container {
	
	width: 234px;
	height: 100%;
	position: absolute;
	top: 0;
	left: 0;
	
}

.revbuilder-cpicker-left .revbuilder-cpicker-gradient-block {
	
	margin-left: 39px;
	
}

#revbuilder-cpicker-wheel {
	
	display: inline-block;
	vertical-align: top;
	position: relative;
	top: -10px;
	width: 47px;
	height: 47px;
	cursor: default;
	margin: 0 5px 0 10px;
	
}

#revbuilder-cpicker-wheel-inner {
	
	position: absolute;
	left: 5px;
	top: 5px;
	width: 37px;
	height: 37px;
	border-radius: 50%;
	border: 1px solid #3f444a;
	border-box: border-box;
	
}

#revbuilder-cpicker-wheel-point {
	
	position: absolute;
	left: 50%;
	top: 0;
	display: block;
	position: relative;
	width: 3px;
	height: 20px;
	margin-left: -2px;
	transform-origin: bottom center;
	background-color: #006dd2;
	
}

#revbuilder-cpicker-wheel-point:after {
	
	width: 7px;
	height: 7px;
	border-radius: 50%;
	background-color: #b7bbc0;
	position: absolute;
	top: -2px;
	left: 50%;
	margin-left: -4px;
	display: block;
	content: "";
	
}

.revbuilder-cpicker-point  {
	
	position: absolute;
	display: block;
	width: 12px;
	height: 17px;
	
}

.revbuilder-cpicker-point.active {
	
	z-index: 999;
	background-position: left bottom;
	
}

.revbuilder-cpicker-point.warning {
	
	transition: 0.1s transform linear;
	
}

.revbuilder-cpicker-point-top.warning {

	transform: translate(0, -5px) scale(0.75);

}

.revbuilder-cpicker-point-bottom.warning {

	transform: translate(0, 5px) scale(0.75);

}

.revbuilder-cpicker-point-top {
	
	top: -17px;
	background: url(../images/point_top.png) left top no-repeat;
	
}

.revbuilder-cpicker-point-bottom {
	
	bottom: -17px;
	background: url(../images/point_bottom.png) left top no-repeat;
	
}

.revbuilder-cpicker-point-square {
	
	display: block;
	width: 10px;
	height: 10px;
	position: absolute;
	top: 1px;
	left: 1px;
	
}

.revbuilder-cpicker-point-triangle {
	
	display: block;
	width: 0; 
	height: 0; 
	
}

.revbuilder-cpicker-point-top .revbuilder-cpicker-point-triangle {
	
	border-left: 5px solid transparent;
	border-right: 5px solid transparent;
	border-top: 5px solid transparent;
	position: absolute;
	top: 11px;
	left: 1px;
	
}

.revbuilder-cpicker-point-bottom .revbuilder-cpicker-point-triangle {
	
	border-left: 5px solid transparent;
	border-right: 5px solid transparent;
	border-bottom: 5px solid transparent;
	position: absolute;
	top: 1px;
	left: 1px;
	
}

.revbuilder-cpicker-point-bottom .revbuilder-cpicker-point-square {
	
	top: 6px;
	
}

.revbuilder-cpicker-hideable,
.revbuilder-cpicker-point-delete,
.revbuilder-cpicker-input-wrap.disabled {
	
    opacity: 0.35;
    pointer-events: none;
	
}

.revbuilder-cpicker-point-delete.active {
	
    opacity: 1;
    pointer-events: auto;
	
}

.revbuilder-cpicker-onoff-wrap, .revbuilder-cpicker-onoff-wrap * {
	
	-webkit-touch-callout:none;  
	-webkit-user-select:none; 
	-khtml-user-select:none;  
	-moz-user-select:none;  
	-ms-user-select:none; 
	user-select:none;
	
}

.revbuilder-cpicker-onoff-wrap { 

	cursor: pointer;
	display: inline-block; 
	vertical-align: top; 
	position: relative; 
	width: 50px;
	height: 20px;
	line-height: 20px; 
	border-radius: 10px;  
	overflow: hidden; 
	box-sizing: border-box;
	transform: translateZ(0.001px);
	text-align: center;
	overflow: hidden;
	background: #2a2c2f;
	margin-top: 7px;
	
}

.revbuilder-cpicker-onoff-inner {
	
	width: 100px;
	white-space: nowrap;
	transform: translateX(0px);
	transition: transform 0.2s ease;
	
}

.revbuilder-cpicker-onoff {
	
	position: relative;
    display: block;
	float: left;
    width: 50px;
    height: 20px;
    background: #2a2c2f;
    padding: 0px 8px;
    color: #777c80;
    font-weight: 400;
    box-sizing: border-box;
    font-size: 11px;
    line-height: 22px;
    text-transform: uppercase;
	overflow: hidden;
	
}

.revbuilder-cpicker-onoff:after {
	
    content: " ";
    width: 12px;
    height: 12px;
    position: absolute;
    left: 32px;
    top: 4px;
    border-radius: 50%;
    background: #3f444a;
    box-sizing: border-box;
	
}

.revbuilder-cpicker-on {
	
	color: #FFF;
	background: #006dd2;
	
}

.revbuilder-cpicker-on:after {
	
	left: auto;
	right: 32px;
	background: #FFF;
	
}

.revbuilder-cpicker-off span {
	
	position: relative;
	right: 7px;
	
}

.revbuilder-cpicker-on span {
	
	position: relative;
	left: 7px;
	
}

.revbuilder-cpicker-onoff-wrap.checked .revbuilder-cpicker-onoff-inner {
	
	transform: translateX(-50px);
	
}

.revbuilder-cpicker-wrap.gradient-view.open .revbuilder-cpicker-hideable {
	
	opacity: 1;
	pointer-events: all;
	
}

.revbuilder-cpicker-presets-custom {
	
	display: none;
	
}

.revbuilder-picker-color-custom:hover i,
.revbuilder-picker-color-custom:hover i:before {
	
	display: block;
	color: #FFF;

}

.revbuilder-picker-color-custom.selected .revbuilder-cpicker-delete {
	
	cursor: pointer;
	
}

.revbuilder-cpicker-delete i {

	position: absolute;
	top: 0;
	right: 0;
	font-size: 12px;
	display: none;
	opacity: 0.65;
	transition: opacity 0.2s ease;

}

.revbuilder-cpicker-delete:before {
	
	position: absolute;
	top: -1px;
	right: -1px;
	width: 13px;
	height: 14px;
	background-color: #2a2c2f;
	content: "";
	display: none;
	
}

.revbuilder-cpicker-delete:hover i {
	
	opacity: 1;
	
}

#revbuilder-cpicker-remove-delete {

	display: none;
	
}

/****************************** ***
   SPECIAL SELECT2 SETTINGS  - 
**********************************/  
#revbuilder-cpicker .ddTP_C .ddTP_S {background-color: #2a2c2f;border: none;border-radius: 0px; font-size: 12px;color: #000;font-weight: 400;vertical-align: top;min-height: 30px; width:185px;}
#revbuilder-cpicker .input_with_buttonextenstion .ddTP_C .ddTP_S { width: 154px; }
#revbuilder-cpicker .ddTP_C .ddTP_S--single .ddTP_S__rendered { line-height: 30px }
#revbuilder-cpicker .__inmodal .ddTP_C .ddTP_S { width: 100%; }
#revbuilder-cpicker .ddTP_C .ddTP_S .ddTP_S__rendered {border-radius:0px;color: #b7bbc0; font-size:13px; font-weight: 500; }
#revbuilder-cpicker .ddTP_C .ddTP_S .ddTP_S__rendered:hover { color: #fff; }

#revbuilder-cpicker .ddTP_C .ddTP_S.ddTP_S--multiple .ddTP_S__rendered { line-height:20px; background:#2a2c2f;padding: 5px; box-sizing: border-box;margin-top: 0px; min-height: 20px; vertical-align: top }
#revbuilder-cpicker .ddTP_C .ddTP_S .ddTP_S__clear {cursor: pointer;float: right;font-weight: bold; }
#revbuilder-cpicker .ddTP_C .ddTP_S .ddTP_S__placeholder {color: #b7bbc0; }

#revbuilder-cpicker .ddTP_C .ddTP_S--single .ddTP_S__arrow {top: 0; right: -15px; height: 30px}
#revbuilder-cpicker .ddTP_C .ddTP_S--single .ddTP_S__arrow:after {
	
	position: absolute;
	content: "";
	top: -3px;
	right: 26px;
	width: 1px;
	height: 31px;
	background: #323438;
	
}

#revbuilder-cpicker .ddTP_C.ddTP_C--open .ddTP_S--single .ddTP_S__arrow b {
	
	border-color: transparent transparent #888 transparent;
	border-width: 0 4px 5px 4px;
	
}

/*
#revbuilder-cpicker .ddTP_C .ddTP_S .ddTP_S__arrow {display:none;  }
#revbuilder-cpicker .ddTP_C .ddTP_S .ddTP_S__arrow b {display:none;  }
*/

#revbuilder-cpicker .ddTP_C .ddTP_S {padding: 0px 10px;border-radius: 4px;}
#revbuilder-cpicker .ddTP_S.ddTP_S--multiple { padding: 0px; }
#revbuilder-cpicker .ddTP_C {min-width: 100px;margin-right: 5px; margin-bottom: 10px;}
#revbuilder-cpicker .ddTP_C .ddTP_SCH.ddTP_SCH--inline {  height: 20px; line-height: 20px; margin: 0px; }

#revbuilder-cpicker .ddTP_C .ddTP_S--multiple .ddTP_S__choice { margin:0px 5px 0px 0px; text-align:center; padding:0px 10px; line-height: 20px; border: none; border-radius: 3px; background: #006dd2; color: #fff;font-size: 11px; font-weight: 500;vertical-align: top;  }
#revbuilder-cpicker .ddTP_C .ddTP_S--multiple .ddTP_S__choice__remove { color: #fff; margin-right: 3px; font-size: 11px; font-weight: 400;line-height: 20px; vertical-align: top; }

.revbuilder-colorpicker-open .ddTP_C .ddTP_R > .ddTP_ROs { max-height: 250px }

.revbuilder-colorpicker-open .ddTP_C .ddTP_SCH--dropdown .ddTP_SCH__field,
#revbuilder-cpicker .ddTP_C .ddTP_SCH--inline .ddTP_SCH__field { line-height: 20px; border: none !important; border-radius: 0px; box-shadow: none !important; outline: none !important; margin:0px; padding:0px 0px 0px 5px;  color: #b7bbc0; font-size: 13px; font-weight: 500;  }
#revbuilder-cpicker .ddTP_C.ddTP_C--focus .ddTP_SCH--inline .ddTP_SCH__field {  max-width: 185px}

.revbuilder-colorpicker-open .ddTP_C .ddTP_SCH--dropdown .ddTP_SCH__field { background: #2a2c2f;line-height: 37px; padding: 0px 10px; }

#revbuilder-cpicker .ddTP_C .ddTP_S.ddTP_S--multiple ul li { margin-bottom: 0px; }

#revbuilder-cpicker .ddTP_C { margin-top:0px; margin-bottom: 0px; width:125px !important; margin-right:0px; display: inline-block}
#revbuilder-cpicker .__inmodal .ddTP_C { width: 100% !important; }
.revbuilder-colorpicker-open .ddTP_C .ddTP-dropdown { background-color: #2a2c2f; width: 145px !important; box-shadow: none; border:none;box-shadow: 0px 10px 20px 0px rgba(0,0,0,0.5);}
.revbuilder-colorpicker-open .ddTP_C .ddTP_RO { color:#b7bbc0; font-size: 13px; padding: 6px 10px; width: 100%;overflow: hidden;position: relative;box-sizing: border-box;white-space: nowrap;text-overflow: ellipsis;}
.revbuilder-colorpicker-open .ddTP_C .ddTP_RO.ddTP_RO--highlighted { color: #fff; background: #3f444a;  }
.revbuilder-colorpicker-open .ddTP_C .ddTP_RO.ddTP_RO--highlighted[aria-selected=true],
.revbuilder-colorpicker-open .ddTP_C .ddTP_RO[aria-selected=true] { color: #fff; background: #006dd2; }

.revbuilder-colorpicker-open .ddTP_C .ddTP_RO[aria-disabled=true] { display: none !important; }

#revbuilder-cpicker .ddTP_C--smalltos2,
#revbuilder-cpicker .ddTP_C--smalltos2 .ddTP-dropdown--below {min-width: 50px;  }
#revbuilder-cpicker .ddTP_C--smalltos2 .ddTP_S {width: 60px;}

#revbuilder-cpicker .ddTP_C--smalltos2-suffix,
#revbuilder-cpicker .ddTP_C--smalltos2-suffix .ddTP-dropdown--below {min-width: 56px;  }

#revbuilder-cpicker .ddTP_C--smalltos2-suffix .ddTP_S {width: 56px; border-radius: 0px 4px 4px 0px; }

.revbuilder-colorpicker-open .ddTP_R__group { background: #343639;color: #777c80; font-size: 13px; font-weight: 500;  text-transform: capitalize; padding:6px 15px; margin-bottom:5px}

#revbuilder-cpicker .ddTP_C { vertical-align: top;  margin-right: 0; box-sizing: content-box; padding-right: 0; height:31px; font-weight: 500}
#revbuilder-cpicker .ddTP_C.ddTP_C--nomargin { margin-right: 0px; }

/*
#revbuilder-cpicker .ddTP_C .ddTP_S--single .ddTP_S__arrow { height: 50px; }
*/

#revbuilder-cpicker .ddTP_C .ddTP_S { box-shadow:none;outline:none;border: none; padding:0px; margin:0px; display: inline-block;font-size: 17px; color: #797b7e; background: transparent  }

#revbuilder-cpicker .ddTP_S__rendered { color:#797b7e; line-height: 50px; vertical-align: top; margin-left: 10px }
#revbuilder-cpicker .ddTP_C .ddTP_S--single .ddTP_S__arrow b { border-color: #797b7e transparent transparent transparent }

#revbuilder-cpicker .ddTP_C:hover .ddTP_S--single .ddTP_S__arrow b {border-color: #b7bbc0 transparent transparent !important}
#revbuilder-cpicker .ddTP_C.ddTP_C--open:hover .ddTP_S--single .ddTP_S__arrow b { border-color: transparent transparent #b7bbc0 transparent !important}
#revbuilder-cpicker .ddTP_C:hover .ddTP_S__rendered { color: #FFF !important; }

/* BLUE STYLE */
#revbuilder-cpicker .ddTP_C.ddTP_C--blue { width: 100% !important; background: #00529d; line-height: 20px; border-radius: 4px; box-sizing: border-box; height: auto; padding:0px !important; margin:0px;}
#revbuilder-cpicker .ddTP_C.ddTP_C--blue  .selection,
#revbuilder-cpicker .ddTP_C.ddTP_C--blue .ddTP_S{ width: 100% !important; }
#revbuilder-cpicker .ddTP_C.ddTP_C--blue .ddTP_SCH__field { color: #fff !important; line-height: 20px;  }

#revbuilder-cpicker .ddTP_C.ddTP_C--blue .ddTP_S { box-shadow:none;outline:none;border: none; padding:0px; margin:0px; display: inline-block;font-size: 12px; color: #fff; background: transparent  }
#revbuilder-cpicker .ddTP_C--blue .ddTP_S__rendered { color:#fff; line-height: 20px; vertical-align: top ; }
#revbuilder-cpicker .ddTP_C--blue .ddTP_S--single .ddTP_S__rendered { color:#fff; line-height: 22px; vertical-align: top ; padding:5px 10px 0px; display: block}

#revbuilder-cpicker .ddTP_C--blue .ddTP_S__rendered .ddTP_S__choice { color:#fff; line-height: 20px; vertical-align: top; background: #006dd2; border-radius: 4px; border: none; }
#revbuilder-cpicker .ddTP_C--blue .ddTP_S__rendered .ddTP_S__choice__remove { color:#fff; line-height: 20px; vertical-align: top;  }

.revbuilder-colorpicker-open .ddTP_C.ddTP_C--blue.ddTP_C--open .ddTP-dropdown.ddTP-dropdown--below,
.revbuilder-colorpicker-open .ddTP_C.ddTP_C--blue.ddTP_C--open .ddTP-dropdown.ddTP-dropdown--above { width: 290px !important; min-width:290px; background: #006dd2; margin-left:-5px; margin-top:5px;}

.revbuilder-colorpicker-open .ddTP_C.ddTP_C--blue.ddTP_C--open .ddTP_ROs {  }
.revbuilder-colorpicker-open .ddTP_C.ddTP_C--blue.ddTP_C--open .ddTP_RO { color: rgba(255,255,255,0.65); }
.revbuilder-colorpicker-open .ddTP_C.ddTP_C--blue.ddTP_C--open .ddTP_RO.ddTP_RO--highlighted { background: #00529c; color: #fff; }
.revbuilder-colorpicker-open .ddTP_C.ddTP_C--blue.ddTP_C--open .ddTP_RO.ddTP_RO--highlighted[aria-selected=true], .ddTP_C .ddTP_RO[aria-selected=true] { background: #1a7cd7;color: #fff; }

/*
#revbuilder-cpicker .ddTP_C.ddTP_C--blue .ddTP_S--single .ddTP_S__arrow { height: 30px; ;}
*/

#revbuilder-cpicker .ddTP_C.ddTP_C--blue .ddTP_S--single .ddTP_S__arrow b { border-color: #fff transparent transparent transparent  }

.revbuilder-colorpicker-open .ddTP_C.ddTP_C--blue .ddTP_SCH--dropdown .ddTP_SCH__field { background: #00529d; color: #fff; }

/* AUTOWIDTH CHANGES */
.revbuilder-colorpicker-open .ddTP.ddTP_C.ddTP_C--autowidth { width: auto !important; }
.revbuilder-colorpicker-open .ddTP_C.ddTP_C--autowidth .ddTP-dropdown { min-width: 150px; }

.revbuilder-cpicker-dropdown {display: none}
/*.clearfix {clear: both}*/
.clearfix:before,
.clearfix:after {
    content: " ";
    display: table;
}

.clearfix:after {
    clear: both;
}

#revbuilder-cpicker-left { direction: ltr !important }


/************************************
  - COLORPICKER GLOBAL SETTINGS  -
************************************/

#revbuilder-cpicker-gactive { line-height: 30px; color: #fff; font-weight: 900; font-size: 14px; text-transform: uppercase; display: inline-block; margin-right: 15px; width: 185px; text-align: right; }
#revbuilder-cpicker-globals { line-height:30px; vertical-align:top; display:block; position: relative; background:#323438; height:30px;  padding:20px 28px;border-top:1px solid #3f444a;}
#inp_SkinPicker { display: inline-block }
.skin_mini_color { width: 15px; height: 15px; border-radius: 4px; display: inline-block;margin-right: 10px; margin-top: 2px; vertical-align: top; }

.ddTP.ddTP_C.ddTP-fake .skin_mini_color { margin-top: 7px; }
#revbuilder-cpicker-globals  .tponoffwrap.off .tponoff_inner { transform: translateX(0px); }

#edit_skin_colors i.material-icons { line-height: 30px !important; vertical-align: top; }



