<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Media.
$html .= $this->get_media( array(
	'class' => 'wpex-mb-20',
) );

// Title.
$html .= $this->get_title( array(
	'class' => 'wpex-heading wpex-text-lg wpex-mb-10',
) );

$html .= '<div class="wpex-card-meta wpex-flex wpex-flex-wrap wpex-mb-15 wpex-child-inherit-color">';

	// Date.
	$html .= $this->get_date( array(
		'class' => 'wpex-mr-20',
		'icon' => 'ticon ticon-clock-o wpex-mr-5',
	) );

	// Author.
	$html .= $this->get_author( array(
		'class' => 'wpex-mr-20',
		'link_class' => 'wpex-hover-underline',
		'icon' => 'ticon ticon-user-o wpex-mr-5',
	) );

	// Primary Term.
	$html .= $this->get_primary_term( array(
		'class' => 'wpex-mr-20',
		'term_class' => 'wpex-mr-5 wpex-hover-underline',
		'icon' => 'ticon ticon-folder-o wpex-mr-5',
	) );

	// Comment Count.
	$html .= $this->get_comment_count( array(
		'class' => 'wpex-child-inherit-color',
		'link_class' => 'wpex-hover-underline',
		'icon' => 'ticon ticon-comment-o wpex-mr-5',
	) );

$html .= '</div>';

// Excerpt.
$html .= $this->get_excerpt( array(
	'class' => 'wpex-mb-20',
) );

// More Button.
$html .= $this->get_more_link( array(
	'link_class' => 'theme-button',
	'text' => esc_html__( 'Read more', 'total' ),
) );

return $html;