.fancybox-container{color:#666}.fancybox-bg{background:#fff}.fancybox-toolbar{background:#fff}.fancybox-infobar{color:#666;mix-blend-mode:normal;background:#fff}.fancybox-button,.fancybox-button:hover{background:none}.fancybox-button,.fancybox-button:link,.fancybox-button:visited{color:#666}.fancybox-button:hover{color:#000}.fancybox-button[disabled],.fancybox-button[disabled]:hover{color:#ddd}.fancybox-navigation .fancybox-button div{background-color:#fff}.fancybox-caption{background:none;color:#888}.fancybox-caption a,.fancybox-caption a:link,.fancybox-caption a:visited{color:currentColor;text-decoration:underline}.fancybox-caption a:hover{color:#000}.fancybox-caption__title{color:#666}.fancybox-thumbs{background:#fff !important}
