<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Primary Term
$html .= $this->get_primary_term( array(
	'class' => 'wpex-mb-5',
	'term_class' => 'wpex-text-3 wpex-hover-underline',
) );

// Title
$html .= $this->get_title( array(
	'class' => 'wpex-heading wpex-text-xl',
) );

return $html;