<?php
namespace TotalTheme\Filters;

defined( 'ABSPATH' ) || exit;

/**
 * Hooks into "the_password_form".
 *
 * @package TotalTheme
 * @subpackage Filters
 * @version 5.4
 */
final class The_Password_Form {

	/**
	 * Callback method.
	 */
	public static function callback( $form ) {
		ob_start();
			include( locate_template( 'partials/password-protection-form.php' ) );
		$form = ob_get_clean();
		return $form;
	}

}