body #wrap #tribe-events-content .tribe-events-calendar div[id*=tribe-events-event-] h3.tribe-events-month-event-title,#tribe-events-content .tribe-events-tooltip h4{font-weight:inherit;font-weight:600}#tribe-events-content .tribe-events-tooltip h4{color:inherit}#tribe-events .tribe-events-button,#tribe-events .tribe-events-button:hover,#tribe_events_filters_wrapper input[type=submit],.tribe-events-button,.tribe-events-button.tribe-active:hover,.tribe-events-button.tribe-inactive,.tribe-events-button:hover,.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-],.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-]>a{font-weight:var(--wpex-btn-font-weight);background-color:var(--wpex-accent);transition:0.15s all ease}#tribe-events .tribe-events-button:hover,#tribe-events .tribe-events-button:hover:hover,#tribe_events_filters_wrapper input[type=submit]:hover,.tribe-events-button:hover,.tribe-events-button.tribe-active:hover:hover,.tribe-events-button.tribe-inactive:hover,.tribe-events-button:hover:hover,.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-]:hover,.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-]>a:hover{background-color:var(--wpex-accent-alt)}.tribe-events-notices{margin-top:0;margin-bottom:30px;text-align:center;font-size:1.077em;text-shadow:none;padding:0.6em}h2.tribe-events-page-title{margin-top:0;font-weight:600}.tribe-events-calendar thead th{font-weight:600}#tribe-events-footer{margin-bottom:20px}#tribe-events-footer .tribe-events-sub-nav a,#tribe-events-header .tribe-events-sub-nav a{font-weight:normal;font-size:1em}#tribe-events-footer .tribe-events-sub-nav a:hover,#tribe-events-header .tribe-events-sub-nav a:hover{text-decoration:underline}#tribe-bar-form .tribe-bar-submit input[type=submit]{font-weight:600}.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-],.tribe-events-calendar td.tribe-events-present div[id*=tribe-events-daynum-]>a{background-color:var(--wpex-accent)}.tribe-events-list .tribe-events-event-cost span{background-color:#f7f7f7;color:#777;border-color:#eee;font-weight:normal}.tribe-events-list-separator-month:after{border-color:#eee}.tribe-events-list-separator-month{color:#777;font-weight:600}.tribe-events-list .tribe-events-event-image{width:30%}.tribe-events-photo-event-wrap .tribe-events-event-image{width:100%}.tribe-events-list .tribe-events-content{padding-right:0}.tribe-events-list .tribe-events-venue-details{margin-bottom:20px}.single-tribe_events .tribe-events-single-event-title{font-size:var(--wpex-text-3xl);margin:0 0 10px;font-weight:400}.tribe-events-schedule{margin-top:0}.tribe-events-schedule h2{margin:0 0 20px;font-weight:400;font-size:var(--wpex-text-lg)}.single-tribe_events .tribe-events-schedule h3{font-size:var(--wpex-text-md)}.single-tribe_events #tribe-events-content{margin-bottom:0}.single-tribe_events .tribe-events-event-meta{background-color:var(--wpex-surface-2);font-size:1em}.single-tribe_events #tribe-events-content .tribe-events-event-meta dt,.single-tribe_events #tribe-events-content .tribe-events-event-meta dd.tribe-venue{color:var(--wpex-text-1);font-weight:var(--wpex-bold)}.tribe-events-meta-group .tribe-events-single-section-title{margin:30px 0 20px;padding-bottom:10px;border-bottom:1px solid var(--wpex-gray-300);font-weight:var(--wpex-bold);font-size:1.15em}.single-tribe_events #tribe-events-content .tribe-events-event-meta dd{margin-bottom:15px}.tribe-events-back{display:none}.single-tribe_events .tribe-events-schedule .tribe-events-divider{color:var(--wpex-gray-300)}.single-tribe_events .tribe-events-schedule h3,.single-tribe_events .tribe-events-schedule{color:var(--wpex-gray-600);font-weight:normal}.single-tribe_events .tribe-events-venue-map{background:none;width:100%}body.tribe-page-header-details .tribe-events-schedule,body.tribe-page-header-details .tribe-events-single-event-title{display:none}.events-list #tribe-events-footer,.single-tribe_events #tribe-events-footer,.tribe-events-day #tribe-events-footer,.tribe-events-map #tribe-events-footer,.tribe-events-photo #tribe-events-footer{border-color:var(--wpex-surface-3);padding-top:20px}.events-list #tribe-events-footer a,.single-tribe_events #tribe-events-footer a,.tribe-events-day #tribe-events-footer a,.tribe-events-map #tribe-events-footer a,.tribe-events-photo #tribe-events-footer a{color:var(--wpex-text-3)}@media only screen and (max-width: 768px){#tribe-events-footer .tribe-events-sub-nav li a{color:var(--wpex-white)}#tribe-events-footer .tribe-events-sub-nav li a:hover{text-decoration:none}}.tribe-events-list-widget-events .tribe-event-title{margin:0 0 5px}.tribe-events-list-widget ol li{margin:0 0 20px}.tribe-events-list-widget .tribe-event-duration{font-size:0.923em}@media only screen and (max-width: 768px){.single-tribe_events .tribe-events-schedule{background:none;border:0;margin:1em 0 1.5em;padding:0}.tribe-event-schedule-details{padding:0 10px}}
