// Front end editor
@import "config/variables.less";
// Base file
// TODO: might be a problems with box-shadow stronger selector Make stronger css selectors for theme fixes box-shadow #219074397069323
// Note: Option vc_tta-o-non-responsive on parent should work correctly
@import "shortcodes/vc_tta.less";
