<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Title
$html .= $this->get_title( array(
	'class' => 'wpex-heading wpex-text-2xl wpex-mb-10',
) );

// Date
$html .= $this->get_date( array(
    'class' => 'wpex-text-3 wpex-text-sm wpex-uppercase wpex-tracking-wider',
) );

return $html;