// Social widgets
.wpex-social-widget-services-list {
    margin: 5px 0 0 !important;
	padding: 0 !important; // note important tags are to fix gutenberg issues.
    list-style: none;

	li {
		cursor: move;
		background: #f8f9f9;
		padding: 10px;
        border: 1px dashed #a2aab2;
		margin: 0 0 10px !important;
        list-style: none;

		p {
			margin: 0 !important;
		}

		label {
			margin-bottom: 3px;
			display: block;
			color: #222;

			.ticon {
				margin-right: 8px;
			}

		}

        input[type="text"] {
            background: #fff;
        }

	}

	.placeholder {
		background: transparent !important;
        border: 1px dashed #aba9a9;
	}

}

/* Repeatable Field */
.wpex-widget-settings-form .wpex-rpf-clone {
    display: none;
}

.wpex-widget-settings-form .wpex-repeater-field li {
    cursor: move;
    padding: 10px 15px;
    margin-bottom: 15px;
    position: relative;
    background: #f6f7f7;
    border: 1px solid #c3c4c7;
    &:last-child {
        margin-bottom: 0;
    }
}

.wpex-widget-settings-form .wpex-repeater-field label {
    display: block;
    margin-bottom: 2px;
}

.wpex-widget-settings-form .wpex-repeater-field select,
.wpex-widget-settings-form .wpex-repeater-field input {
    width: 100%;
}

.wpex-widget-settings-form .wpex-repeater-field p {
    margin: 5px 0;
}

.wpex-widget-settings-form .wpex-repeater-field .wpex-rpf-remove {
    position: absolute;
    right: 10px;
    top: 5px;
    color: #a00;
    font-size: 22px;
    cursor: pointer;
}

.wpex-widget-settings-form li.wpex-rpf-placeholder {
    background: transparent !important;
    border: 1px dashed #aba9a9;
}

.wpex-widget-settings-form .wpex-upload-field,
.wpex-widget-settings-form .wpex-repeater-field .wpex-upload-field {

    input[type=text] {
        width: 70%;
    }

    .button {
        width: 28%;
        text-align: center;
    }

}

/*
// Custom toggles
.wpex-widget-toggle {
    display: flex;
    justify-content: space-between;
    align-items: center;
    min-height: 36px;

    label {
        margin-right: 12px;
        flex-shrink: 0;
        max-width: 75%;
    }

    &__btn {
        position: relative;
        display: inline-block;
    }

    &__track {
        content: "";
        display: inline-block;
        box-sizing: border-box;
        vertical-align: top;
        background-color: #fff;
        border: 1px solid #1e1e1e;
        width: 36px;
        height: 18px;
        border-radius: 9px;
        transition: background .2s ease;
    }

    &__thumb {
        display: block;
        position: absolute;
        box-sizing: border-box;
        top: 3px;
        left: 3px;
        width: 12px;
        height: 12px;
        border-radius: 50%;
        transition: transform .1s ease;
        background-color: #1e1e1e;
        border: 5px solid #1e1e1e;
    }

    input[type="checkbox"] {
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        opacity: 0;
        margin: 0;
        padding: 0;
        z-index: 1;
        border: none;
        &::before {
            content: "";
        }
        &:checked {
            background: none;
        }
        &:focus + .wpex-widget-toggle__track {
            box-shadow: 0 0 0 2px #fff,0 0 0 4px var(--wpex-widget-admin-accent);
            outline: 2px solid transparent;
            outline-offset: 2px;
        }
    }

    &--checked {
        .wpex-widget-toggle__track {
            background-color: var(--wpex-widget-admin-accent);
            border: 9px solid transparent;
        }
        .wpex-widget-toggle__thumb {
            background-color: #fff;
            border-width: 0;
            transform: translateX(18px);
        }
    }

}
*/