<?php
namespace TotalTheme\Actions;

defined( 'ABSPATH' ) || exit;

/**
 * Hooks into "after_switch_theme".
 *
 * @package TotalTheme
 * @subpackage Actions
 * @version 5.4
 */
final class After_Switch_Theme {

	/**
	 * Callback method.
	 */
	public static function callback() {
		// Flush rewrite rules.
		flush_rewrite_rules();

		// Delete tgma plugin activation script user meta data to make sure notices display correctly.
		delete_metadata( 'user', null, 'tgmpa_dismissed_notice_wpex_theme', null, true );
	}

}