<?php
/**
 * Mobile Menu alternative.
 *
 * @package TotalTheme
 * @subpackage Partials
 * @version 5.4
 */

defined( 'ABSPATH' ) || exit;

?>

<div id="mobile-menu-alternative" class="wpex-hidden"<?php wpex_aria_landmark( 'mobile_menu_alt' ); ?><?php wpex_aria_label( 'mobile_menu_alt' ); ?>><?php
	wp_nav_menu( array(
		'container'      => false, // important to prevent extra div wrapper around menu ul.
		'theme_location' => 'mobile_menu_alt',
		'menu_class'     => 'dropdown-menu', // keep.
		'fallback_cb'    => false,
	) );
?></div>