<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Thumbnail
$html .= $this->get_thumbnail();

$html .= '<div class="wpex-card-details wpex-text-center wpex-p-20">';

	// Title
	$html .= $this->get_title( array(
		'class' => 'wpex-heading wpex-text-xl',
	) );

	// Position
	$html .= $this->get_element( array(
		'content' => wpex_get_staff_member_position(),
		'class' => 'wpex-card-staff-member-position wpex-my-15 wpex-text-sm',
	) );

	// Excerpt/Content
	$html .= $this->get_excerpt( array(
		'length' => '-1',
		'class' => 'wpex-mt-15',
	) );

$html .= '</div>';

return $html;