<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Media
$html .= $this->get_media( array(
	'class' => 'wpex-mb-15',
) );

// Title
$html .= $this->get_title( array(
	'class' => 'wpex-heading wpex-text-xl wpex-font-medium',
) );

// Date
$html .= $this->get_date( array(
	'type' => 'published',
	'class' => 'wpex-mt-10 wpex-text-2xs wpex-uppercase wpex-font-medium wpex-text-3 wpex-tracking-widest',
) );

return $html;