<?php
/**
 * Blog single post video format media
 *
 * @package Total WordPress theme
 * @subpackage Partials
 * @version 5.0
 */

defined( 'ABSPATH' ) || exit;

?>

<div id="blog-post-video"><?php wpex_post_video_html(); ?></div>