body #wpex-add-widget h3{text-align:center !important;padding:15px 7px;font-size:1.3em;margin-top:5px}body div#widgets-right .sidebar-wpex-custom .widgets-sortables{padding-bottom:45px}body div#widgets-right .sidebar-wpex-custom.closed .widgets-sortables{padding-bottom:0}body .wpex-widget-area-footer{display:block;position:absolute;bottom:0;left:0;height:40px;line-height:40px;width:100%;border-top:1px solid #eee}body .wpex-widget-area-footer>div{padding:8px 8px 0}body .wpex-widget-area-footer .wpex-widget-area-id{display:block;float:left;overflow:hidden;position:relative;top:-4px}body .wpex-widget-area-footer .wpex-widget-area-id input{width:100%;max-width:150px}body .wpex-widget-area-footer .wpex-widget-area-buttons{float:right}body .wpex-widget-area-footer .description{padding:0 !important;margin:0 !important}body div#widgets-right .sidebar-wpex-custom.closed .widgets-sortables .wpex-widget-area-footer{display:none}body .wpex-widget-area-footer .wpex-widget-area-delete{display:block;float:right;margin:0}body .wpex-widget-area-footer .wpex-widget-area-delete-confirm{display:none;float:right;margin:0 5px 0 0}body .wpex-widget-area-footer .wpex-widget-area-delete-cancel{display:none;float:right;margin:0}body .activate_spinner{display:block !important;position:absolute;top:10px;right:4px;background-color:#ececec}body #wpex-add-widget form{text-align:center}body #widget_area-wpex-custom,body #widget_area-wpex-custom h3{position:relative}body #wpex-add-widget p{margin-top:0}body #wpex-add-widget{margin:10px 0 0;position:relative}body #wpex-add-widget-input{max-width:95%;padding:8px;margin-bottom:14px;margin-top:3px;text-align:center}
