<?php
namespace TotalThemeCore\Vcex\Blocks\Newsletter_Form;

use TotalThemeCore\Vcex\Block as Vcex_Block;

defined( 'ABSPATH' ) || exit;

/**
 * Registers the vcex/newsletter Block.
 *
 * @package TotalThemeCore
 * @version 1.4
 */
final class Block extends Vcex_Block {

	/**
	 * Block setup.
	 */
	public function setup() {
		$this->block_name = 'newsletter-form';
		$this->json_path  = __DIR__;
	}

	/**
	 * Block display.
	 */
	public function render_callback( $atts ) {
		return $this->do_shortcode( 'vcex_newsletter_form', $atts );
	}

}