<?php
use TotalTheme\Header\Logo as Header_Logo;

/**
 * Displays the header logo.
 *
 * @package TotalTheme
 * @subpackage Partials
 * @version 5.4.3
 */

defined( 'ABSPATH' ) || exit;

/**
 * Renders the header logo html.
 *
 * @see inc/header/logo.php
 */
Header_Logo::render();