#wpex-metabox .wp-tab-panel{display:none}#wpex-metabox .wp-tab-panel-active{display:block}#wpex-metabox .wp-tab-panel{max-height:none !important}#wpex-metabox ul.wp-tab-bar{-webkit-touch-callout:none;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}#wpex-metabox ul.wp-tab-bar{padding-top:5px}#wpex-metabox ul.wp-tab-bar::after{content:"";display:block;height:0;clear:both;visibility:hidden;zoom:1}#wpex-metabox ul.wp-tab-bar li{padding:5px 12px;font-size:14px}#wpex-metabox ul.wp-tab-bar li a:focus{box-shadow:none}#wpex-metabox ul.wp-tab-bar li .ticon{margin-right:6px}#wpex-metabox .inside .form-table tr:not(:first-child){border-top:1px solid #eee}#wpex-metabox .inside .form-table th{width:240px;padding:10px 30px 10px 0;border:0}#wpex-metabox .inside .form-table td{padding:10px 0;border:0}#wpex-metabox .inside .form-table label.wpex-label{display:block}#wpex-metabox .inside .form-table th label .ticon{margin-right:10px}#wpex-metabox .wpex-mb-uploader{margin-left:5px}.rtl #wpex-metabox .wpex-mb-uploader{margin-left:0;margin-right:5px}#wpex-metabox .inside .form-table th p.wpex-mb-description{font-size:12px;font-weight:normal;margin:0;padding:0;padding-top:4px;color:#555}#wpex-metabox .inside .form-table .wpex-input,#wpex-metabox .inside .form-table .wpex-mb-textarea-code{width:50%}#wpex-metabox .inside .form-table textarea{width:100%}#wpex-metabox .inside .form-table select{width:50%}#wpex-metabox .wpex-mb-hidden{display:none}#wpex-metabox .wpex-mb-btn-group button{display:block;float:left;text-decoration:none;font-size:13px;line-height:30px;height:30px;color:#555;border:0;background:#f7f7f7;vertical-align:top;margin:0;padding:0 10px 1px;cursor:pointer;border:1px solid #ccc;-webkit-appearance:none;white-space:nowrap;-webkit-box-shadow:none;box-shadow:none}#wpex-metabox .wpex-mb-btn-group button.active,#wpex-metabox .wpex-mb-btn-group button:focus,#wpex-metabox .wpex-mb-btn-group button:active{background:#eaeaea;outline:none}#wpex-metabox .wpex-mb-btn-group button.wpex-on,#wpex-metabox .wpex-mb-btn-group button.wpex-off{border-left:0}#wpex-metabox .wpex-mb-btn-group button.wpex-default{border-right:0;border-top-left-radius:3px;border-bottom-left-radius:3px}#wpex-metabox .wpex-mb-btn-group button.wpex-on{border-left:1px solid #ccc;border-right:1px solid #ccc}#wpex-metabox .wpex-mb-btn-group button.wpex-off{border-left:0;border-top-right-radius:3px;border-bottom-right-radius:3px}#wpex-metabox .wpex-mb-btn-group button.wpex-on.active{background:#6DAB3C;color:#fff;border-color:transparent}#wpex-metabox .wpex-mb-btn-group button.wpex-off.active{background:#e14d43;color:#fff;border-color:transparent}#wpex-metabox .wpex-img-holder{padding-top:6px}#wpex-metabox .wpex-img-holder img{width:auto;height:50px}.wpex-metabox__footer{display:flex;justify-content:space-between;align-items:center;flex-wrap:wrap;margin-top:7px}.wpex-metabox__reset{display:flex;align-items:center}.wpex-metabox__reset .button{margin-right:10px}.wpex-metabox__reset-checkbox:not(.wpex-metabox__reset-checkbox--active){display:none}.wpex-metabox__reset-checkbox{display:flex;align-items:center}.wpex-metabox__reset-checkbox input[type=checkbox]{margin:0 .25rem 0 0}.wpex-metabox__label{display:flex;align-items:center;font-weight:600}.wpex-metabox__label>span{display:flex;align-items:center;min-width:22px;margin-right:5px}.wpex-metabox__label svg{height:1em}
