<?php
defined( 'ABSPATH' ) || exit;

$html = '';

// Date
$html .= $this->get_date( array(
	'class' => 'wpex-mb-5 wpex-text-3',
) );

// Title
$html .= $this->get_title( array(
	'class' => 'wpex-heading wpex-text-lg wpex-mb-15',
) );

// Excerpt
$html .= $this->get_excerpt();

return $html;