/* *********************
  - HELP MODE STYLES -
***********************/

.help-mode-activated .help_wrap {
	
	color: #FFF;
	background-color: #006dd2;
	
}

.help-mode-activated .help_wrap:after {
	
	content: "";
	position: absolute;
	top: 7px;
	right: 7px;
	width: 15px;
	height: 15px;
	color: #FFF;
	background: url(../images/check.png) center center/15px 15px no-repeat transparent;
	
}

#help_mode_modal {
	
	top: 50px;
	right: 100%;
	width: 580px;
	z-index: 99999;
	position: absolute;
	background: #006dd2;
	visibility: hidden;
	opacity: 0;
	margin-right: 51px;
	transition: all 0.3s ease;
	transition-property: opacity, visibility;
	
}

.help-mode-activated.help-mode-active #help_mode_modal {
	
	visibility: visible;
	opacity: 1;
	
}

.help-mode-dialog {
	
	display: none;
	overflow: hidden;
	width: 170px;
	cursor: auto;
	
}

.help-mode-title,
.help-mode-description {
	
	color: #FFF;
	line-height: normal;
	padding: 30px;
	position: relative;
	font-size: 14px;
	font-weight: normal;
	
}

.help-mode-title {
	
	font-weight: bold;
	z-index: 1;
	top: -3px;
	cursor: move;
	padding-bottom: 0;
	
}

.help-mode-section {
	
	margin-top: 10px;
	
}

#help-mode-buttons {
	
	padding: 0;
	margin-top: 24px;
	background-color: transparent;
		
}

.help-mode-section:first-child {
	
	margin-top: 0;
	
}

.help-mode-section i {
	
	font-size: 15px;
    position: relative;
    left: -5px;
	border-radius: 2px;
	
}

.help-mode-section a,
.help-mode-section a:hover {
	
	color: white;
	
}

.help-mode-button {

	float: left;
	margin-left: 10px;
	padding: 6px 20px;
	background-color: #1a7cd7;
	cursor: pointer;
	display: none;
	transition: filter 0.3s ease-in-out;
	border-radius: 2px;
	
}

.help-mode-button:first-child {

	margin-left: 0;
	
}

.help-mode-button:hover {
	
	filter: brightness(110%);
	
}

#help_mode_title {

	position: relative;
	background: white;
	color: #005abd;
	text-transform: uppercase;
	font-size: 11px;
	padding: 1px 4px 0 4px;
	border-radius: 2px;
	vertical-align: top;
	position: relative;
	top: 3px;
	left: 7px;
	font-weight: 900;
	
}

#help_mode_main_title {
	
	font-size: 30px;
	color: white;
	display: block;
	font-weight: 500;
	margin: 16px 0 20px 0;
	
}

#help_mode_video_wrap {
	
	margin: 3px 0 33px 0;
	display: none;
	line-height: 0;
	box-shadow: 5px 5px 20px 0px rgba(0,0,0,0.3);
	
}

#help_mode_title_wrap {margin-top: 2px}
#help_mode_title_wrap i {font-size: 18px}

.help-icon-default i {display: none !important}
.help-icon-default i:nth-child(1) {display: inline-block !important}

.help-icon-faq i:nth-child(2),
.help-icon-faq i:nth-child(3),
.help-icon-faq i:nth-child(4),
.help-icon-faq i:nth-child(5) {display: none !important}

.help-icon-slider i:nth-child(1),
.help-icon-slider i:nth-child(3),
.help-icon-slider i:nth-child(4),
.help-icon-slider i:nth-child(5) {display: none !important}

.help-icon-navigation i:nth-child(1),
.help-icon-navigation i:nth-child(2),
.help-icon-navigation i:nth-child(4),
.help-icon-navigation i:nth-child(5) {display: none !important}

.help-icon-slide i:nth-child(1),
.help-icon-slide i:nth-child(2),
.help-icon-slide i:nth-child(3),
.help-icon-slide i:nth-child(5) {display: none !important}

.help-icon-layer i:nth-child(1),
.help-icon-layer i:nth-child(2),
.help-icon-layer i:nth-child(3),
.help-icon-layer i:nth-child(4) {display: none !important}

#help-mode-search {
	
	white-space: nowrap;
	
}

#help_mode_search {

	position: relative;
	
}

#help_mode_search_wrap {
	
	background: #0051b2;
	padding: 18px 10px 18px 30px;
	
}

#help_mode_search input {

	background: transparent !important;
	line-height: inherit !important;
	height: 100% !important;
	box-sizing: border-box !important;
	font-size: 20px !important;
	color: white !important;
	font-weight: inherit !important;
	vertical-align: top !important;
	background: inherit !important;
	padding: 0 !important;
	margin: 0 !important;
	box-shadow: none !important;
	border: 0 !important;
	width: calc(100% - 50px) !important;
	margin: 0;
	
}

#help_mode_search ::-webkit-input-placeholder {

	color: white !important;
	
}

#help_search_results {
	
	margin-top: 16px;
	padding-top: 21px;
	display: none;
	position: relative;
	
}

#help_search_results:before {
	
	position: absolute;
	top: 0;
	left: -30px;
	width: calc(100% + 40px);
	height: 1px;
	content: "";
	background: #266bbd;
	z-index: 9999999;
	
}

.help-results-container {

	float: left;
	width: 50%;
	
}

#the_right_toolbar .help-results-wrap .rs__scrollbar-y-rail {
	
	display: block !important;
	right: -1px !important;
	
}

#the_right_toolbar .help-results-wrap .rs__scrollbar-y {
	
	background: #266bbd !important;
	
}

#the_right_toolbar .help-results-wrap .rs__scrollbar-y-rail {
	
	background: transparent !important;
	
}

#the_right_toolbar .help-results-wrap .rs__scrollbar-y {
	
	display: block !important;
	opacity: 1 !important;
	
}

.help-results-wrap.ps:hover>.rs__scrollbar-y-rail {
	
	opacity: 1 !important;
	
}

#help_options_results {
	
	width: calc(100% - 20px);
	
}

.help-faqs-empty .help-results-container {

	display: none;
	
}

.help-faqs-empty .help-results-container:first-child {

	display: block;
	width: 100%;
	
}

.help-options-empty .help-results-container {

	display: block;
	width: 100%;
	
}

.help-options-empty .help-results-container:first-child {

	display: none;
	
}

.help-results-wrap {
	
	overflow: hidden;
	position: relative;
	
}

.help-results .help-button {
	
    border-radius: 2px;
    width: 100%;
    text-align: left;
    padding: 8px 0 12px 0;
    line-height: 14px;
    font-size: 12px;
    font-weight: inherit;
	
}

.help-results .help-button:first-child {

	margin-top: 0;
	
}

.help-results .help-button i {
	
    font-size: 19px;
	position: relative;
	top: 2px;
	left: 10px;
	margin: 0 5px;
	
}

#help_faq_results {
	
	width: calc(100% - 20px);
	
}

#help_faq_results .help-button {

	padding: 29px 0 30px 0;
	
}

#help_faq_results .help-button i {

	font-size: 22px;
	
}

.help-results .help-button span {
	
    margin-left: 20px;
	
}

.help-mode-description {
	
	padding: 0 30px 30px 30px;
	line-height: 1.5em;
	display: none;
	margin-top: -9px;
	
}

#help_modal_close {
	
	position: absolute;
	top: 0;
	right: 0;
	width: 50px;
	height: 50px;
	cursor: pointer;
	color: #FFF;
	z-index: 99;
	
}

#help_modal_close i {
	
	position: absolute;
    top: 16px;
    right: 16px;
	font-size: 18px;
	
}

#help_modal_close:hover {
	
	opacity: 0.4;
	
}

.help-mode-link {
	
	font-weight: bold;
	font-size: 12px;
	color: #FFF;
	border-bottom: 1px solid transparent;
	margin: 0 10px 0 0;
	cursor: pointer;
	display: none;
	
}

.help-mode-link:hover {
	
	border-bottom-color: #FFF;
	
}

.help-input-focus:not([type="radio"]),
.help-input-focus + label_sub:before,
.help-input-focus + .ddTP .ddTP_S,
.rev-colorpicker.help-input-focus {
	
	box-shadow: 0 0 20px 5px #006dd2 !important;
	
}

.lal_group_member.help-input-focus {

	box-shadow: none !important;
	color: #FFF;
	background: #006dd2;
	
}

.help-input-focus + label_sub {
	
	overflow: visible;
	
}

#help_input_clear {
	
	position: absolute;
	top: 0;
	right: 0;
	width: 32px;
	text-align: center;
	border-radius: 0;
	box-sizing: border-box;
	height: 100%;
	padding: 0;
	margin: 0 !important;
	line-height: 20px;
	border: none;
	font-size: 11px;
	font-weight: 500;
	vertical-align: top;
	cursor: pointer;
	background-color: #2a2c2f;
	visibility: hidden;
	
}

#help_input_clear {
	
	width: 50px;
	height: 50px;
	background: transparent;
	position: absolute;
	right: -10px;
	top: -14px;
	
}

#help_input_clear i {
	
	position: relative;
    top: 5px;
    margin: 0;
	font-size: 12px;
	color: #FFF;
	
}

#help_input_clear i {
	
    top: 14px;
	left: 0;
	font-size: 18px;
	
}

#help_input_clear:hover i {
	
	opacity: 0.4;
	
}

.help-button {
	
	margin: 5px 5px 0px 0px;
    text-align: center;
    padding: 0px 10px;
    line-height: 20px;
    border: none;
    border-radius: 3px;
    background: #0d5ab6;
    color: #fff;
    font-size: 11px;
    font-weight: 500;
    vertical-align: top;
	display: inline-block;
	cursor: pointer;
	transition: background 0.3s ease-in-out;
	
}

.help-button:hover {
	
	background: #266bbd;
	
}

.help-button span {
	
	position: relative;
	top: 1px;
	
}

.help-mode-activated .help_wrap {
	
    background-color: #3f444a;
	
}

#add_layer_main_wrap > div {position: relative}
.toolbar_btn.help-hover .tool_dd_wrap { display: block; min-width: 100%;}
.toolbar_btn.help-hover { color: #fff}

.toolbar_btn.help-hover-text .add_layer[data-type="text"],
.toolbar_btn.help-hover-image .add_layer[data-type="image"],
.toolbar_btn.help-hover-video .add_layer[data-type="video"],
.toolbar_btn.help-hover-audio .add_layer[data-type="audio"],
.toolbar_btn.help-hover-object .add_layer[data-type="object"],
.toolbar_btn.help-hover-row .add_layer[data-type="row"],
.toolbar_btn.help-hover:not(.help-hover-staticlayers) #newslide,
.toolbar_btn.help-hover-staticlayers .do_not_sort_slide_list_element {background: #3f444a !important; z-index: 99999}

.toolbar_btn.help-hover:not(.help-hover-slideorder) #newslide:after,
.toolbar_btn.help-hover-staticlayers .do_not_sort_slide_list_element:after,
.toolbar_btn.help-hover-slideorder .slide_list_element.selected:after,
#add_layer_toolbar_wrap.help-hover-text #add_layer_main_wrap > div:first-child:after,
#add_layer_toolbar_wrap.help-hover-image #add_layer_main_wrap > div:nth-child(2):after,
#add_layer_toolbar_wrap.help-hover-video #add_layer_main_wrap > div:nth-child(5):after,
#add_layer_toolbar_wrap.help-hover-audio #add_layer_main_wrap > div:nth-child(6):after,
#add_layer_toolbar_wrap.help-hover-object #add_layer_main_wrap > div:nth-child(7):after,
#add_layer_toolbar_wrap.help-hover-row #add_layer_main_wrap > div:nth-child(8):after,
#add_layer_toolbar_wrap.help-hover-column #add_layer_main_wrap > div:nth-child(8):after {
	
	position: absolute;
	bottom: -5px;
	left: 65%;
	margin-left: 10px;
	width: 17px;
	height: 22px;
	background: url(../images/hand.png) no-repeat center center;
	content: "";
	z-index: 99999;
	
}

.toolbar_btn.help-hover-slideorder .slide_list_element.selected:after {
	
	width: 18px;
	height: 18px;
	background: url(../images/move.png) no-repeat center center;
	background-size: 18px 18px;
	bottom: -5px;
	left: -14px;
	
}

.toolbar_btn.help-hover-staticlayers #newslide:after {display: none}
.add_frame_after.help-input-focus {display: block}



/*************** RTL MODE SETTINGS ********************/
body.rtl #help_mode_title {
	left: auto;
	right: 7px;
}

body.rtl .help-mode-section i {
	left: auto;
	right: -5px;
}

body.rtl #help_input_clear {
	right: auto;
	left: -10px;
}