/************************************************
 * REVOLUTION 6.0.0 BUILDER CLASSES
 * @version: 1.0 (12.06.2017)
 * @author ThemePunch
************************************************/

.toplevel_page_revslider,
.toplevel_page_revslider #wpwrap,
.toplevel_page_revslider #wpwrap #wpcontent,
.toplevel_page_revslider #rs_overview  { background: #202224; }

/* overflox-x added because applying a blur filter to the #wpwrap causes an unexpected horizontal scrollbar */
#wpwrap.blurred { filter: blur(10px); overflow-x: hidden}

.toplevel_page_revslider #wpfooter { position: relative }

.toplevel_page_revslider .material-icons { line-height: inherit;}


.rs-builder-mode .ps__rail-y { position: absolute !important }
.rs-builder-mode.hideallwp #adminmenumain { display: none; }
.rs-builder-mode.hideallwp #wpfooter,
.rs-builder-mode.hideallwp #wpcontent { padding-left: 0px;margin-left: 0px; }


.rs-builder-mode.hideallwp .tp-plugin-version {  display:none; ; padding: 20px 20px 0px; }
.rs-builder-mode.hideallwp #wpbody-content { padding-bottom: 0px; } 
.rs-builder-mode.hideallwp #wpfooter      { display:none; }

.rs-builder-mode.hideallwp #wpadminbar { display: none }

.rs-builder-mode.hideallwp #wpwrap { background: #202224; }

.rs-builder-mode.hideallwp { overflow: hidden }

.rs-builder-mode.hideallwp.showwpmenus #adminmenumain,
.rs-builder-mode.hideallwp.showwpmenus #wpadminbar { display: block; z-index: 10000050}
.rs-builder-mode.hideallwp.showwpmenus #wpadminbar {     height: 40px;padding-top: 10px;}

.rs-builder-mode.hideallwp.showwpmenus #wpadminbar #wp-admin-bar-wp-logo>.ab-item { padding-left: 15px; }

.rs-builder-mode.hideallwp.showwpmenus #adminmenumain { position: relative; }

.rs-builder-mode.hideallwp.showwpmenus #adminmenumain #adminmenuback { box-shadow: 5px 0px 10px rgba(0,0,0,0.15) }

#builderView { z-index: 100000; transform: translateX(100%); }

#hidden_video_container { display: none; }

#wp_overlay { z-index: 99999; position: fixed;top: 0px;left: 0px; width: 100%;height: 100%; background: #323438; }

/* DISABLE CONTAINERS IF LAYER TYPE SET TO X */
._column_sel_ ._nfc_,
._row_sel_ ._nfr_,
._text_sel_ ._nft_,
._video_sel_ ._nfv_,
._shape_sel_ ._nfs_,
._image_sel_ ._nfi_,
._image_sel_ ._nsfi_,
._group_sel_ ._nfg_,
._audio_sel_ ._nfa_,
._button_sel_ ._nfb_,
._object_sel_ ._nfo_,
._svg_sel_ ._nfsvg_  { position: relative; opacity: 0.3;  pointer-events: none;}


/* HIDE CONTAINERS IF LAYER TYPE SET TO X */
#the_container._column_sel_ .form_collector .form_inner._nsfc_,
#the_container._row_sel_ .form_collector .form_inner._nsfr_,
#the_container._text_sel_ .form_collector .form_inner._nsft_,
#the_container._video_sel_ .form_collector .form_inner._nsfv_,
#the_container._shape_sel_ .form_collector .form_inner._nsfs_,
#the_container._image_sel_ .form_collector .form_inner._nsfi_,
#the_container._group_sel_ .form_collector .form_inner._nsfg_,
#the_container._audio_sel_ .form_collector .form_inner._nsfa_,
#the_container._button_sel_ .form_collector .form_inner._nsfb_,
#the_container._object_sel_ .form_collector .form_inner._nsfo_,
#the_container._layer_in_column_sel_._text_sel_ ._nsftbsic_,
#the_container._layer_in_column_sel_._shape_sel_ ._nsftbsic_,
#the_container._layer_in_column_sel_._button_sel_ ._nsftbsic_,
#the_container._layer_in_column_sel_._object_sel_ ._nsftbsic_,

._column_sel_ ._nsfc_,
._row_sel_ ._nsfr_,
._text_sel_ ._nsft_,
._video_sel_ ._nsfv_,
._shape_sel_ ._nsfs_,
._image_sel_ ._nsfi_,
._group_sel_ ._nsfg_,
._audio_sel_ ._nsfa_,
._button_sel_ ._nsfb_,
._object_sel_ ._nsfo_,
._svg_sel_ ._nsfsvg_  { display: none !important; }



#ezoomer_wrap {     
    position: relative;    
    width: auto;
    padding: 15px;
    font-size: 14px;       
    line-height: 35px;
    background: #2a2c2f;    
    white-space: nowrap;      
    box-shadow: 0px 10px 20px 0px rgba(0,0,0,0.5);    
  }
#ezoomer { width: 200px; height: 10px; background: #202224; border-radius: 4px; overflow: visible; position: relative; /*cursor:pointer;*/}
#ezoomer_pin { background: #006dd2; height: 10px !important; left: 0px; position: absolute; top: 0px; width: 100px; border-radius: 4px }
#zoomer_factor { font-size: 12px; color: #b7bbc0; font-weight: 600; width: 20px; line-height: 35px;display: inline-block; vertical-align: top}
#zoomer_factor {     position: absolute;
    bottom: -4px;
    left: 0px;
    width: 100%;
    text-align: center;  }


#zoomer_wrap_toolbar:hover #zoomer_factor { color: #fff; }
#ezoomer_pin:after { content: ""; pointer-events: none; background:#b8bbc0; width: 16px;height: 16px;border-radius: 8px; position: absolute;right: -8px;top: -3px;  }
#ezoomer_pin:hover:after { background: #fff; }
#ezoomer_pin .ui-resizable-handle.ui-resizable-e { cursor: pointer }
#ezoomer_pin .ui-resizable-handle.ui-resizable-e:hover:after{ background: #fff }
.ezzomer_marks { position: absolute;top: -15px; width: 1px; height: 5px; background:#40444a; }

#zoomer_wrap_toolbar .tool_dd_wrap { padding-top: 0px; background: transparent; box-shadow: none}

#zoomer_wrap_toolbar .selected_placeholder { cursor: pointer }

/*HIDE LETTER TRANSLATION PRESETS */
._column_sel_ #lal_in_lettran,
._row_sel_ #lal_in_lettran,
._video_sel_ #lal_in_lettran,
._audio_sel_ #lal_in_lettran,
._object_sel_ #lal_in_lettran,
._svg_sel_ #lal_in_lettran,
._image_sel_ #lal_in_lettran,
._shape_sel_ #lal_in_lettran { display: none !important; }


/* SHOW CONTAINERS ONLY IF LAYER TYPE SET TO X*/

#the_container .form_collector .form_inner ._shfc_,
#the_container .form_collector .form_inner._shfc_,
#the_container .form_collector .form_inner ._shfg_,
#the_container .form_collector .form_inner._shfg_,
#the_container .form_collector .form_inner ._shflic_,
#the_container .form_collector .form_inner._shflic_,
#the_container .form_collector .form_inner ._shft_,
#the_container .form_collector .form_inner._shft_,
#the_container .form_collector .form_inner ._shoft_,
#the_container .form_collector .form_inner._shoft_,
#the_container .form_collector .form_inner ._shfb_,
#the_container .form_collector .form_inner._shfb_,
#the_container .form_collector .form_inner ._shofb_,
#the_container .form_collector .form_inner._shofb_,
#the_container .form_collector .form_inner ._shfi_,
#the_container .form_collector .form_inner._shfi_,
#the_container .form_collector .form_inner ._shfv_,
#the_container .form_collector .form_inner._shfv_,
#the_container .form_collector .form_inner ._shfr_,
#the_container .form_collector .form_inner._shfr_,
#the_container .form_collector .form_inner ._shfa_,
#the_container .form_collector .form_inner._shfa_,
#the_container .form_collector .form_inner ._shfs_,
#the_container .form_collector .form_inner._shfs_,

#the_container._layer_in_column_sel_ .form_collector .form_inner._nflic_,
#the_container._layer_in_column_sel_ .form_collector .form_inner ._nflic_,

#the_container .form_collector .form_inner ._shfsvg_,
#the_container .form_collector .form_inner._shfsvg_ { display: none !important; }

#the_container._svg_sel_ .form_collector .form_inner ._shfsvg_,
#the_container._svg_sel_ .form_collector .form_inner._shfsvg_,

#the_container._column_sel_ .form_collector .form_inner ._shfc_,
#the_container._column_sel_ .form_collector .form_inner._shfc_,

#the_container._group_sel_ .form_collector .form_inner ._shfg_,
#the_container._group_sel_ .form_collector .form_inner._shfg_,

#the_container._shape_sel_ .form_collector .form_inner ._shfs_,
#the_container._shape_sel_ .form_collector .form_inner._shfs_,

#the_container._row_sel_ .form_collector .form_inner ._shfr_,
#the_container._row_sel_ .form_collector .form_inner._shfr_,

#the_container._image_sel_ .form_collector .form_inner ._shfi_,
#the_container._image_sel_ .form_collector .form_inner._shfi_,

#the_container._video_sel_ .form_collector .form_inner ._shfv_,
#the_container._video_sel_ .form_collector .form_inner._shfv_,

#the_container._audio_sel_ .form_collector .form_inner ._shfa_,
#the_container._audio_sel_ .form_collector .form_inner._shfa_,

#the_container._layer_in_column_sel_ .form_collector .form_inner._shflic_,
#the_container._layer_in_column_sel_ .form_collector .form_inner ._shflic_,

#the_container._text_sel_ .form_collector .form_inner._shoft_,
#the_container._button_sel_ .form_collector .form_inner._shofb_,

#the_container._text_sel_ .form_collector .form_inner ._shoft_,
#the_container._button_sel_ .form_collector .form_inner ._shofb_,

#the_container._text_sel_ .form_collector .form_inner._shft_,
#the_container._button_sel_ .form_collector .form_inner._shft_ { display: block !important; }

#the_container.multiple_layers_selected._button_sel_._row_sel_ .form_collector .form_inner._homs_,
#the_container.multiple_layers_selected._button_sel_._column_sel_ .form_collector .form_inner._homs_,
#the_container.multiple_layers_selected._text_sel_._row_sel_ .form_collector .form_inner._homs_,
#the_container.multiple_layers_selected._text_sel_._column_sel_ .form_collector .form_inner._homs_ { display: none !important;}

i.material-icons { text-align: center; }
#responsive_infos_toolbar .material-icons,
#rb_tlw .material-icons,
#rs_overview .material-icons,
#filedrop .material-icons,
.material-icons {
  font-family: 'Material Icons';
  font-weight: normal;
  font-style: normal;  
  display: inline-block;  
  text-transform: none;
  letter-spacing: normal;
  word-wrap: normal;
  white-space: nowrap;
  direction: ltr;
  vertical-align: top;
  line-height: inherit;  
  -webkit-font-smoothing: antialiased;  
  text-rendering: optimizeLegibility;
  -moz-osx-font-smoothing: grayscale;
  font-feature-settings: 'liga'; 

}

#the_container.multiple_layers_selected #form_layercontent_convert { display: none !important; }

#rs_overview {  padding:96px 55px 66px;}

#layer_video_poster { display: none; }

#slide_bg_image_path {     
    /* visibility: hidden; */
    height: 29px !important;
    width: 10px !important;
    /* opacity: 0; */
    padding: 0;
    margin: 0;
    font-size: 0px;
    float: left;
    line-height: 29px;
    background: transparent;
    border: none;
    outline: none;
    box-shadow: none;}



#rb_tlw .material-icons.mirrorhorizontal,
.material-icons.mirrorhorizontal { transform:scaleX(-1);}


/* UNSELECTABLES */
._lc_,
.layerlist_element *,
.basic_action_button,
#main_hor_toolbar, #main_hor_toolbar *,
.tponoffwrap *, .tponoffwrap,
#timeline_settings *,
label_a,label_info,
.material-icons,
.form_menu_level_2_li,
.form_menu_level_1_li,
.radiooption,
.input_left,
.input_middle,
.fake_input,
.rsle_tool,
#form_slideradvanced_perf *  { -webkit-touch-callout:none;  -webkit-user-select:none; -khtml-user-select:none;  -moz-user-select:none;  -ms-user-select:none; user-select:none; }

._lc_ input[type="text"],
.layerlist_element * input[type="text"],
.basic_action_button input[type="text"],
#main_hor_toolbar, #main_hor_toolbar * input[type="text"],
.tponoffwrap *, .tponoffwrap input[type="text"],
#timeline_settings * input[type="text"],
label_a,label_info input[type="text"],
.material-icons input[type="text"],
.form_menu_level_2_li input[type="text"],
.form_menu_level_1_li input[type="text"],
.radiooption input[type="text"],
.input_left input[type="text"],
.input_middle input[type="text"],
.fake_input input[type="text"],
.rsle_tool input[type="text"],
#form_slideradvanced_perf * input[type="text"] { -webkit-touch-callout:auto;  -webkit-user-select:auto; -khtml-user-select:auto;  -moz-user-select:auto;  -ms-user-select:auto; user-select:auto; }

.material-icons.vmi { transform: scaleX(-1); }


/********************************* 
    DEFAULT AND BASIC SETTINGS 
**********************************/


.layer_grid.layersInDragorResize:after {content:" ";position: absolute;top:0px;left:0px;width:100%;height:100%;background:transparent;z-index: 450;}

#rs_overview,
#rb_tlw,
#timeline { font-family: "Roboto" }

#quick_style *,
.rb_modal *,
.eg-toolbox,
#rs_overview *,
#rs_overview_menu,
#rb_tlw *,
#timeline * { -webkit-font-smoothing: antialiased;-moz-osx-font-smoothing: grayscale;-webkit-touch-callout: none;text-rendering: optimizeLegibility;}

.notselectable  {-webkit-user-select: none;-khtml-user-select: none;-moz-user-select: none;-ms-user-select: none;user-select: none;}
linebreak,
.linebreak {display: block;height: 0px;width: 100%;clear:both;}
.rightaligned   { text-align: right}
.vertical_medium_wrap   {     top: 50%;transform: translateY(-50%);position: absolute;}

row             { line-height: 30px;display: table; margin-bottom:10px; width:100%;box-sizing: border-box; position: relative}
row.direktrow,
row.directrow { margin-bottom: 0px; }

onethird { display: table-cell; vertical-align: top; width: 33.33%; padding-right: 0px; box-sizing: border-box; line-height: inherit; margin-bottom:-10px;}
onefourth { display: table-cell; vertical-align: top; width: 25%; padding-right: 20px; box-sizing: border-box; line-height: inherit; margin-bottom:-10px}
onefifth { display: table-cell; vertical-align: top; width: 20%; padding-right: 9px; box-sizing: border-box; line-height: inherit; margin-bottom:-10px}
onehalf { display: table-cell; vertical-align: top; width: 50%; padding-right: 30px; box-sizing: border-box; line-height: inherit; margin-bottom:-10px}

labelhalf   { display: table-cell; vertical-align: top; width: 100px; padding-right: 15px; box-sizing: border-box; line-height: inherit; margin-bottom:-10px; text-align: right}
contenthalf { display: table-cell; vertical-align: top; width: 180px; box-sizing: border-box; line-height: inherit; margin-bottom:-10px; text-align: left}


onelabel { display: table-cell; vertical-align: top; width: 97px; box-sizing: border-box; line-height: inherit; margin-bottom:-10px}
oneshort { display: table-cell; vertical-align: top; width: 115px; box-sizing: border-box; line-height: inherit; margin-bottom:-10px;}
onelong { display: table-cell; vertical-align: top; width: 175px; min-width: 175px; box-sizing: border-box;line-height: inherit; margin-bottom:-10px;padding-right:10px;}
onefull { display: table-cell; vertical-align: top; width: 200px; line-height: inherit; box-sizing: border-box;  }

oneshort.dyn_inp_wrap { position: relative; overflow: visible; max-width: 115px !important; white-space: nowrap; }
onelong.dyn_inp_wrap { position: relative; overflow: visible; max-width: 175px !important; white-space: nowrap;}


#rb_tlw .direktrow.active_onelong onelong.dyn_inp_wrap input[type=text] { width: 128px !important;}
#rb_tlw .direktrow.active_oneshort oneshort.dyn_inp_wrap input[type=text] { width: 133px !important;}

#rb_tlw .direktrow onelong.dyn_inp_wrap input[type=text],
#rb_tlw .direktrow oneshort.dyn_inp_wrap input[type=text] { transition: width 300ms; }

#rb_tlw .direktrow onelong.dyn_inp_wrap label_icon,
#rb_tlw .direktrow oneshort.dyn_inp_wrap label_icon,
#rb_tlw .direktrow onelong.dyn_inp_wrap .label_icon,
#rb_tlw .direktrow oneshort.dyn_inp_wrap .label_icon { transition: margin 300ms; }


#rb_tlw .direktrow.active_oneshort oneshort.dyn_inp_wrap label_icon,
#rb_tlw .direktrow.active_oneshort oneshort.dyn_inp_wrap .label_icon { margin-left:-65px }

#rb_tlw .direktrow.active_onelong onelong.dyn_inp_wrap label_icon,
#rb_tlw .direktrow.active_oneshort onelong.dyn_inp_wrap label_icon,
#rb_tlw .direktrow.active_onelong onelong.dyn_inp_wrap .label_icon,
#rb_tlw .direktrow.active_oneshort onelong.dyn_inp_wrap .label_icon { margin-left: 0px; }

#rb_tlw .direktrow.active_onelong onelong.dyn_inp_wrap,
#rb_tlw .direktrow.active_oneshort oneshort.dyn_inp_wrap { z-index: 10 }

#the_container onehalf { padding-right: 10px;min-width: 50%; }

onehalf:last-child,
onefourth:last-child,
onefifth:last-child,
onethird:last-child { padding-right: 0px; }

#the_container .showhide_hidden
#the_container .showhide_hidden.form_inner,
#the_container .form_collector .showhide_hidden.form_inner { display: none !important; }


/*******************
  EDITOR ICON SET 
*******************/

.near_me_addon { position: absolute; top:5px; left: 30px; color: inherit; font-size: 12px !important; }
.toolkit_selector .near_me_addon { left: 28px; }

.label_mi.material-icons { width:30px; height:30px; text-align:center; color: #b7bbc0; font-size: 20px; margin-left: 15px; vertical-align: top; line-height:30px; margin-right: 5px;}


label_icon,
label_bigicon {background: url(../images/UI-ICONS.png);  width: 30px;height: 30px; vertical-align: top; display: inline-block; color: transparent; background-size: 390px 420px; margin-right: 5px; }
label_bigicon {background: url(../images/UI-ICONS-BIG.png); width: 45px; height: 45px; background-size: 495px 225px; }
label_icon.singlerow,
onelong .label_mi.material-icons:first-child,
onelong label_icon:first-child { margin-left: 60px; }

oneshort .label_mi.material-icons { margin-left: 0px; }

longoption label_icon:first-child { margin-left: 10px; margin-top:5px; margin-right:0px; width:25px;}

longoption.centered_longoption { border: none;text-align: center; }
longoption.centered_longoption label_a { width: auto; min-width: 0px; font-size: 11px !important; }
longoption.centered_longoption i.material-icons { color: #787C80 !important; }
longoption.centered_longoption .tponoffwrap { float: none; }

#rb_tlw i.label_icon.material-icons { margin-left: 60px; color: #fff; line-height: 30px !important; margin-right: 5px; font-size: 20px; text-align: center; width:30px; color:#b7bbc0;}

#rb_tlw i.label_icon.material-icons.inshort { margin-left: 0px; margin-right: 5px; }


label_icon.ui_border_top      { background-position: -210px -240px; }
label_icon.ui_border_right     { background-position: -240px -240px; }
label_icon.ui_border_bottom   { background-position: -270px -240px; }
label_icon.ui_border_left     { background-position: -300px -240px; }

label_icon.ui_v_fade     { background-position: -60px -300px; }
label_icon.ui_v_scale     { background-position: -30px -300px; }
label_icon.ui_v_rotation     { background-position: -90px -300px; }

label_icon.ui_autoresponsive      { background-position: -120px -330px; }
label_icon.ui_offsetresponsive    { background-position: -150px -330px; }
label_icon.ui_childrenresponsive  { background-position: -180px -330px; }

label_icon.ui_max_rotation     { background-position: -180px -270px; }
label_icon.ui_max_fadedown     { background-position: -240px -270px; }
label_icon.ui_max_scaledown     { background-position: -300px -270px; }

label_icon.ui_bradius          { background-position: -150px -240px; }
label_icon.ui_bradius_topleft  { background-position: -30px -240px; }
label_icon.ui_bradius_topright     { background-position: -60px -240px; }
label_icon.ui_bradius_bottomleft   { background-position: -90px -240px; }
label_icon.ui_bradius_bottomright     { background-position: -120px -240px; }

label_icon.ui_fit       { background-position: -30px -180px; }
label_icon.ui_repeat   { background-position: -60px -180px; }

label_icon.ui_stopafterloop { background-position: -120px -180px; }
label_icon.ui_stopatslide   { background-position: -150px -180px; }
label_icon.ui_radius { background-position: -210px -390px; }

label_icon.ui_outofviewport { background-position: -180px -180px; }
label_icon.ui_viewportpercent   { background-position: -210px -180px; }
label_icon.ui_presetheight   { background-position: -210px -60px; }

label_icon.ui_x_start   { background-position: -30px -270px; }
label_icon.ui_x_end     { background-position: -60px -270px; }
label_icon.ui_y_start   { background-position: -90px -270px; }
label_icon.ui_y_end     { background-position: -120px -270px; }
label_icon.ui_rotate_start   { background-position: -150px -270px; }
label_icon.ui_rotate_end     { background-position: -180px -270px; }
label_icon.ui_blur_start   { background-position: -210px -270px; }
label_icon.ui_blur_end     { background-position: -240px -270px; }
label_icon.ui_scale_start   { background-position: -270px -270px; }
label_icon.ui_scale_end     { background-position: -300px -270px; }

label_icon.ui_x         { background-position: -30px -60px; }
label_icon.ui_bg         { background-position: -150px -30px; }
label_icon.ui_y         { background-position: -60px -60px; }
label_icon.ui_z         { background-position: -150px -390px; }

/*SPLIT TEXT ICONS */
label_icon.ui_textsplit          { background-position: -60px -390px }
label_icon.ui_splitdirection     { background-position: -90px -390px }
label_icon.ui_splitdelay     { background-position: -120px -390px }

/*SVG ICONS */
label_icon.ui_strokewidth         { background-position: -210px -330px; }
label_icon.ui_strokedasharray     { background-position: -240px -330px; }
label_icon.ui_strokedashoffset    { background-position: -180px -30px; }

/*FILTER ICONS */
label_icon.ui_blur          { background-position: -330px -330px; }
label_icon.ui_grayscale     { background-position: -360px -330px; }
label_icon.ui_brightness    { background-position: -270px -330px; }
label_icon.ui_blendmode     { background-position: -300px -330px; }
label_icon.ui_blendmodeshow { background-position: -330px -30px; }

/* TRANSFORM ICONS */
label_icon.ui_opacity     { background-position: -150px -150px; }
label_icon.ui_scalex      { background-position: -180px -150px; }
label_icon.ui_scaley      { background-position: -210px -150px; }
label_icon.ui_skewx       { background-position: -240px -150px; }
label_icon.ui_skewy       { background-position: -270px -150px; }
label_icon.ui_perspective { background-position: -300px -150px; }
label_icon.ui_transformz  { background-position: -330px -150px; }
label_icon.ui_rotatex     { background-position: -240px -180px; }
label_icon.ui_rotatey     { background-position: -270px -180px; }
label_icon.ui_rotatez     { background-position: -300px -180px; }
label_icon.ui_origox      { background-position: -330px -180px; }
label_icon.ui_origoy      { background-position: -360px -180px; }
label_icon.ui_origoz      { background-position: -180px -390px; }

label_icon.ui_loop      { background-position: -240px -390px; }



/* STYLE ICONS */
label_icon.ui_fontsize   { background-position: -30px -30px; }
label_icon.ui_lineheight   { background-position: -60px -30px; }
label_icon.ui_fontweight   { background-position: -90px -30px; }
label_icon.ui_letterspacing   { background-position: -120px -30px; }
label_icon.ui_fontstyle        { background-position: -210px -30px; }
label_icon.ui_textdecoration   { background-position: -240px -30px; }
label_icon.ui_uppercase   { background-position: -270px -30px; }
label_icon.ui_selectable   { background-position: -300px -30px; }

/*HIDE ON .... */
label_icon.ui_hide_on_mobile  { background-position: -30px -330px }
label_icon.ui_hide_in_nav     { background-position: -90px -330px }
label_icon.ui_hide_after_loop { background-position: -60px -330px }

/*PUBLISHSED */
label_icon.ui_published         { background-position: -330px -300px }
label_icon.ui_published_from    { background-position: -270px -300px }
label_icon.ui_published_until   { background-position: -300px -300px }

/*TRANSITION */
label_icon.ui_duration        { background-position: -120px -300px }
label_icon.ui_easing          { background-position: -30px -390px }
label_icon.ui_easing_in       { background-position: -150px -300px }
label_icon.ui_easing_out      { background-position: -180px -300px }

label_icon.ui_slotamount      { background-position: -210px -300px }
label_icon.ui_slotrotation    { background-position: -240px -300px }

/*VIDEO ICON*/
label_icon.ui_speed         { background-position: -60px -360px }
label_icon.ui_volume        { background-position: -30px -360px }
label_icon.ui_startat       { background-position: -90px -360px }
label_icon.ui_endat       { background-position: -120px -360px }

/*ANIMATION ICONS*/
label_icon.ui_yoyo          { background-position: -180px -360px }
label_icon.ui_startangle    { background-position: -210px -360px }
label_icon.ui_curviness     { background-position: -240px -360px }
label_icon.ui_xradius     { background-position: -270px -360px }
label_icon.ui_yradius     { background-position: -300px -360px }
label_icon.ui_zradius     { background-position: -330px -360px }


/* HORIZONTAL ALIGN*/
label_icon.ui_leftalign               { background-position: -35px -90px; margin-right:0px; width:25px; cursor: pointer}
label_icon.ui_leftalign:hover,
label_icon.ui_leftalign.selected      { background-position: -35px -120px;}

label_icon.ui_centeralign             { background-position: -65px -90px; margin-right:0px;width:25px; cursor: pointer}
label_icon.ui_centeralign:hover,
label_icon.ui_centeralign.selected    { background-position: -65px -120px;}

label_icon.ui_rightalign              { background-position: -95px -90px; margin-right:0px;width:25px;cursor: pointer}
label_icon.ui_rightalign:hover,
label_icon.ui_rightalign.selected     { background-position: -95px -120px;}

/*VERTICAL ALIGN*/
label_icon.ui_topalign                { background-position: -125px -90px; margin-right:0px;width:25px;cursor: pointer}
label_icon.ui_topalign:hover,
label_icon.ui_topalign.selected       { background-position: -125px -120px;}

label_icon.ui_middlealign             { background-position: -155px -90px; margin-right:0px;width:25px;cursor: pointer}
label_icon.ui_middlealign:hover,
label_icon.ui_middlealign.selected    { background-position: -155px -120px;}

label_icon.ui_bottomalign             { background-position: -185px -90px; margin-right:0px;width:25px;cursor: pointer}
label_icon.ui_bottomalign:hover,
label_icon.ui_bottomalign.selected   { background-position: -185px -120px;}




/* LAYER GROUP FILTERS */
label_icon.ui_free_layers { background-position: -210px -90px; }
label_icon.ui_magnet { background-position: -270px -390px; }
label_icon.ui_top_row_layers { background-position: -240px -90px }
label_icon.ui_middle_row_layers { background-position: -270px -90px }
label_icon.ui_bottom_row_layers { background-position: -300px -90px }

label_icon.ui_free_layers.selected,
label_icon.ui_free_layers:hover { background-position: -210px -120px }

.tl_magnifying_wrap:hover label_icon.ui_magnet,
.tl_magnifying_wrap.selected label_icon.ui_magnet { background-position: -300px -390px; }

label_icon.ui_top_row_layers.selected,
label_icon.ui_top_row_layers:hover { background-position: -240px -120px }
label_icon.ui_middle_row_layers.selected,
label_icon.ui_middle_row_layers:hover { background-position: -270px -120px }
label_icon.ui_bottom_row_layers.selected,
label_icon.ui_bottom_row_layers:hover { background-position: -300px -120px }


label_icon.rowtop { background-position: -237px -118px !important; }
label_icon.rowmiddle { background-position: -267px -118px !important; }
label_icon.rowbottom { background-position: -297px -118px !important; }

.triggerselect.selected label_icon.rowtop,
.triggerselect.selected label_icon.rowbottom,
.triggerselect.selected label_icon.rowmiddle { filter: brightness(100); }

/* BIG ICONSET */
label_bigicon.ui_onecol { background-position: -45px -45px; }
label_bigicon.ui_twocol { background-position: -90px -45px; }
label_bigicon.ui_threecol { background-position: -135px -45px; }
label_bigicon.ui_fourcol { background-position: -180px -45px; }
label_bigicon.ui_sixcol { background-position: -225px -45px; }
label_bigicon.ui_onefourth_half_onefourth_col { background-position: -270px -45px; }
label_bigicon.ui_onesixth_foursixth_onesixts_col { background-position: -315px -45px; }
label_bigicon.ui_twothird_onethird_col { background-position: -360px -45px; }
label_bigicon.ui_threefourth_onefourth_col { background-position: -405px -45px; }
label_bigicon.ui_fivesixth_onesixth_col { background-position: -450px -45px; }

.colselector.selected label_bigicon.ui_onecol,
.colselector:hover label_bigicon.ui_onecol { background-position: -45px -90px; }
.colselector.selected label_bigicon.ui_twocol,
.colselector:hover label_bigicon.ui_twocol { background-position: -90px -90px; }
.colselector.selected label_bigicon.ui_threecol,
.colselector:hover label_bigicon.ui_threecol { background-position: -135px -90px; }
.colselector.selected label_bigicon.ui_fourcol,
.colselector:hover label_bigicon.ui_fourcol { background-position: -180px -90px; }
.colselector.selected label_bigicon.ui_sixcol,
.colselector:hover label_bigicon.ui_sixcol { background-position: -225px -90px; }

.colselector.selected label_bigicon.ui_onefourth_half_onefourth_col,
.colselector:hover label_bigicon.ui_onefourth_half_onefourth_col { background-position: -270px -90px; }
.colselector.selected label_bigicon.ui_onesixth_foursixth_onesixts_col,
.colselector:hover label_bigicon.ui_onesixth_foursixth_onesixts_col { background-position: -315px -90px; }
.colselector.selected label_bigicon.ui_twothird_onethird_col,
.colselector:hover label_bigicon.ui_twothird_onethird_col { background-position: -360px -90px; }
.colselector.selected label_bigicon.ui_threefourth_onefourth_col,
.colselector:hover label_bigicon.ui_threefourth_onefourth_col { background-position: -405px -90px; }
.colselector.selected label_bigicon.ui_fivesixth_onesixth_col,
.colselector:hover label_bigicon.ui_fivesixth_onesixth_col { background-position: -450px -90px; }



#form_slidegeneral_params row onehalf:first-child {  width:75%;}
#form_slidegeneral_params row onehalf:nth-child(2) {  width:25%;}



.lp10 { padding-left: 10px; }
.mr10 { margin-right: 10px; }

i.emptyspace20 { display: inline-block; width: 20px; }

.iblocktop { vertical-align: top; display: inline-block }
.dcenter { display: block; text-align: center; margin: 0px auto; list-style: none; padding:0px;}

.disablecontainer { position: relative; opacity: 0.3;  pointer-events: none;}
.main_mode_selector.disablecontainer { opacity: 1 }
.main_mode_selector.disablecontainer i { opacity: 0.3 }
.unavailablecontainer { display: none !important; height: 0px;width: 0px;visibility: hidden;position: absolute;z-index: -1; }

.rfloated { float: right; }

.lp30bb { padding-left: 30px !important; box-sizing: border-box !important }
.lp40bb { padding-left: 40px !important; box-sizing: border-box !important }


/**************************
   BG ALIGN SELECTOR 
***************************/
.bg_alignselector_wrap { display: inline-block; position: relative; vertical-align: top;margin-bottom:10px;}
.bg_align_row { width: 55px;height: 15px;display: block;margin-bottom: 5px;position: relative; }
.bg_alignselector { width: 14px; height: 14px;  background: #2a2c2f; border-radius: 3px; display:block; cursor:pointer;}
.bg_alignselector:first-child { position: absolute; top: 0px;left: 0px; }
.bg_alignselector:nth-child(2) { position: absolute; top: 0px;left: 20px; }
.bg_alignselector:nth-child(3) { position: absolute; top: 0px;left: 40px; }
.bg_alignselector.selected { background: #006dd2; }
.bg_align_xy { position: absolute; left: 68px; top:-10px; width:85px;}
.bg_align_xy .bg_alignselector { position: relative; top: auto; left: auto; display: inline-block ; margin-top:10px;margin-right:5px;}

/**************************
    INPUT FIELDS 
***************************/

.input_with_buttonextenstion { width: 185px; position: relative;display: inline-block }
.buttonextenstion { position: absolute; right: 0px; top: 0px; }

#rb_tlw input[type=text],
#rb_tlw input[type=number],
#rb_tlw textarea { box-shadow:none;outline:none;border: none;border-radius: 3px; width:185px;padding:0px; margin:0px 0px 10px; }

#rb_tlw longoption input[type=text],
#rb_tlw longoption input[type=number] { margin: 5px 0px; }

#rb_tlw longoption input[type=text],
#rb_tlw longoption input[type=number],
#rb_tlw longoption textarea  { width: 60px; }

#rb_tlw .input_with_buttonextenstion input[type=text],
#rb_tlw .input_with_buttonextenstion input[type=number] { width: 154px; margin-right: 1px }

#rb_tlw .input_with_buttonextenstion.extrashort input[type=text] { width: 122px; margin-right: 1px }

#rb_tlw #form_slidergeneral_advanced_api .input_with_buttonextenstion input[type=text], 
#rb_tlw #form_slidergeneral_advanced_api .input_with_buttonextenstion input[type=number]{ width: 150px !important; }

#rb_tlw input[type=text].tqinput,
#rb_tlw input[type=number].tqinput { width: 130px; margin-right: 5px }

#rb_tlw input[type=text].oqinput,
#rb_tlw input[type=number].oqinput { width: 50px;}

#rb_tlw oneshort input[type=text],
#rb_tlw oneshort input[type=number],
#rb_tlw oneshort textarea,
#rb_tlw input[type=text].shortfield,
#rb_tlw input[type=number].shortfield,
#rb_tlw onelong input[type=text],
#rb_tlw onelong input[type=number],
#rb_tlw onelong textarea {width:68px !important; min-width: 68px !important}


#rb_tlw onethird input[type=text],
#rb_tlw onethird input[type=number],
#rb_tlw onethird textarea { width: 50px !important; }

#rb_tlw input::-webkit-outer-spin-button,
#rb_tlw input::-webkit-inner-spin-button {-webkit-appearance: none;margin: 0; }

.fake_input,
#rb_tlw input[type=text],
#rb_tlw input[type=number] {line-height: 30px;height:30px; box-sizing:border-box; font-size: 13px;color: #b7bbc0;font-weight: 500;vertical-align: top; background: #2a2c2f; padding:0px 10px;}


#rb_tlw textarea {line-height: 17px;height:30px; box-sizing:border-box; font-size: 13px;color: #b7bbc0;font-weight: 500;vertical-align: top; background: #2a2c2f; padding:5px 10px;}

#layer_action_extension_wrap textarea { height: 90px; }

#layer_action_type { cursor: pointer }
#layer_action_type i.material-icons { width: 30px !important; }
#layer_action_type input { pointer-events: none ;display: none}
#layer_action_type #layer_action_fake { width:185px; margin-bottom:10px; line-height: 30px;height: 30px;box-sizing: border-box;font-size: 13px;color: #b7bbc0;font-weight: 500;vertical-align: top;background: #2a2c2f;padding: 0px 10px; }

#layer_action_type:hover #layer_action_fake,
#layer_action_type:hover i.material-icons { color: #fff !important; }


#rb_tlw input[type=text]:hover,
#rb_tlw input[type=number]:hover,
#rb_tlw textarea:hover { color: #fff; }


#rb_tlw #form_template_skin .revbuilder-colorpicker.visible-cp-input { width: 120px; margin-left: 5px; margin-right: 5px; }
#rb_tlw #form_template_skin .revbuilder-colorpicker.visible-cp-input input{ width: 80px; }

#rb_tlw textarea.rsmaxtextarea { width: 100%; height: 180px; padding: 20px;box-sizing: border-box; color: #b7bbc0; font-size: 14px; line-height: 20px; }

#rb_tlw #form_slidergeneral_advanced_api_events textarea { margin-bottom: 25px; }

.fake_input { margin-bottom: 20px }

#rb_tlw input.nmarg { margin-bottom: 5px; }

#rb_tlw input[type=text].badvalue,
#rb_tlw input[type=number].badvalue { color:#f82c90;  }

#rb_tlw input[type=checkbox].simplechkbx { display: inline-block; vertical-align: top; line-height: 28px; border-radius: 3px; border: 1px solid #d4dce4; box-shadow: none; margin:4px 10px 0px 0px; background-color: #f3f7fa; width:20px;height:20px;}
#rb_tlw input[type=checkbox].simplechkbx:before { color: #1e8cbe;float: none;text-align: left;line-height: 25px;vertical-align: top;margin-left: -5px; }


#rb_tlw input[type=radio] {vertical-align: middle;line-height: 30px; width: 20px;height: 20px; border:none; box-shadow: none;margin:5px 10px 0px -2px;}

#rb_tlw .radiooption input[type=radio] { line-height: 25px; margin:5px 10px 0px -2px; vertical-align: top; opacity: 0; z-index: 2; position: absolute; border-radius: 0px; width:100%;}

#rb_tlw input[type=radio]:before { width:10px; height:10px; margin: 5px; }
#rb_tlw input[type=text].digit3,
#rb_tlw input[type=number].digit3 {width: 50px;}
#rb_tlw textarea {resize: none;}

#rb_tlw textarea.api_area { width: 100%; }

#rb_tlw #form_slidergeneral_advanced_api textarea.api_area { height: 0px !important; overflow: hidden; padding: 0px !important; position: absolute; }


#rb_tlw input.ralign { text-align: right; }


#rb_tlw  textarea.info {
    height: 56px;
    line-height: 16px;
    padding: 4px 5px;
    color: #8095a3;
    background: transparent;
    word-break: break-all;
    font-style: italic;
}

#rb_tlw  ::-webkit-input-placeholder  { color: #b7bbc0;}
#rb_tlw  ::-moz-placeholder            { color: #b7bbc0;}
#rb_tlw  :-ms-input-placeholder       { color: #b7bbc0;}
#rb_tlw  :-moz-placeholder            { color: #b7bbc0;}

#rb_tlw  input:hover::-webkit-input-placeholder  { color: #fff !important;}
#rb_tlw  input:hover::-moz-placeholder            { color: #fff !important; }
#rb_tlw  input:hover:-ms-input-placeholder       { color: #fff !important;}
#rb_tlw  input:hover:-moz-placeholder            { color: #fff !important;}

#rb_tlw  input:focus::-webkit-input-placeholder  { color: transparent !important;}
#rb_tlw  input:focus::-moz-placeholder            { color: transparent !important; }
#rb_tlw  input:focus:-ms-input-placeholder       { color: transparent !important;}
#rb_tlw  input:focus:-moz-placeholder            { color: transparent !important;}


#rb_tlw  input[type=radio]:before { background-color: #006dd2; width: 10px;height:10px; }
#rb_tlw  input[type=radio],
#rb_tlw  input[type=radio]:hover,
#rb_tlw  input[type=radio]:focus,
#rb_tlw  input[type=radio]:checked {  border:none;background: #2a2c2f;}

#rb_tlw  input[type=checkbox] { background-color: #222a34; border-color: #222a34; }
#rb_tlw  input[type=checkbox].simplechkbx:before{ color:#8095a3 }


#rb_tlw .__inmodal input[type=text],
#rb_tlw .__inmodal input[type=number],
#rb_tlw .__inmodal textarea {   display:block; width:100%;}

.radiooption { position: relative; box-sizing: border-box;display: inline-block; line-height: 25px }




#api_methods                  { position: relative }
#rb_tlw #api_methods textarea { height: auto; overflow-y: hidden }
#rb_tlw #api_methods .basic_action_button { position: absolute; float: none; right: 0px;  border: none; }
#rb_tlw #api_events .basic_action_button { border: none; }

/* DATE PICKER */
#ui-datepicker-div                      { padding:15px; background:#323438; border:none;z-index:1119999 !important;margin-left:-25px; color:#fff;    box-shadow: 0px 10px 20px 0px rgba(0,0,0,0.5);}
 #ui-datepicker-div,
 #ui-datepicker-div *     { -webkit-font-smoothing: antialiased;
                            -moz-osx-font-smoothing: grayscale;
                            -webkit-touch-callout: none;
                            text-rendering: optimizeLegibility; 
                            font-family: "Roboto";
                          }

.ui-datepicker-title                    { color: #777c80;font-size: 15px;display: block;text-align: center;margin-bottom: 10px; font-weight: 600; }
.ui-datepicker-header                   { font-size:15px;vertical-align: top; line-height:20px;}
#ui-datepicker-div .ui-icon             { text-indent: 0px;display: inline-block;margin-right: 15px;font-size: 12px;text-align: center; cursor: pointer;}

#ui-datepicker-div a,
#ui-datepicker-div a:visited { color: #777c80; }
#ui-datepicker-div a:hover { color: #006dd2; }

.ui-datepicker-prev.ui-corner-all     { float: left; }
.ui-datepicker-next.ui-corner-all     { float: right; }

.ui-datepicker-next.ui-corner-all .ui-icon.ui-icon-circle-triangle-e { margin-right: 0px !important; }

.ui-datepicker-calendar tbody                               { text-align: center;}
.ui-datepicker-calendar tbody .ui-state-default             { text-decoration: none;color:#777c80; font-weight:500; }
.ui-datepicker-calendar tbody .ui-datepicker-week-end .ui-state-default { text-decoration: none;color:#777c80; font-weight:500; }

.ui-datepicker-calendar tbody .ui-datepicker-unselectable.ui-state-disabled .ui-state-default { color: #777c80; opacity: 0.5; }

.ui-datepicker-calendar tbody .ui-state-default.ui-state-highlight    { text-decoration: none; font-weight: 500; color:#fff;  min-width:15px; display: inline-block;}


/* BUILDER BUTTONS BASICS */
#rb_tlw button { outline:none;border: none; background: #777; vertical-align:top; color: #fff; font-weight: 500; font-size: 12px; line-height: 28px; box-shadow: none; box-sizing: border-box; padding: 0px 10px; cursor: pointer; }
#rb_tlw button:hover { background-color: #555; }
#rb_tlw button:focus,
#rb_tlw button:visited { outline: none; box-shadow: none; }
#rb_tlw .form_opener_btn .material-icons,
#rb_tlw button .material-icons { margin-right: 5px; line-height: 28px;font-size: 16px; }

#rb_tlw labelhalf .material-icons { font-size: 20px; color: #777c80; }

#rb_tlw .material-icons.bpdevices { font-size: 25px; color: #777c80; margin-left: 15px; }

#rb_tlw .material-icons.big-mi { font-size: 40px; line-height: 50px }

#rb_tlw .form_opener_btn {background: #3e4a5a; line-height: 40px; font-size: 14px; font-weight: 400; color: #8095a3; padding:0px 15px; border-radius: 4px; margin-right: 6px; display:inline-block; cursor: pointer; margin-bottom: 10px;} 
#rb_tlw .form_opener_btn .material-icons { color: #8095a3; font-size:24px; line-height: 40px;}
#rb_tlw .form_opener_btn:hover,
#rb_tlw .form_opener_btn:focus,
#rb_tlw .form_opener_btn:visited,
#rb_tlw .form_opener_btn:hover .material-icons,
#rb_tlw .form_opener_btn:focus .material-icons,
#rb_tlw .form_opener_btn:visited  .material-icons{ color: #fff; background: #2a3441}

#slbpoints_overall onelong { position: relative; width: 80px;min-width: 80px;padding-right: 0px }
#slbpoints_overall label_icon.singlerow, 
#slbpoints_overall onelong label_icon:first-child { margin-left: 12px;  }

#rb_tlw #slbpoints_overall onelong input[type=text] { min-width: 66px !important; width:66px !important;}
#slbpoints_overall .bpdevices { margin-left: 13px !important; margin-right: 12px }
#slbpoints_overall label_a { width: 250px; text-align: left; font-size: 11px;}

#slbpoints_overall .tponoffwrap,
#slbpoints_overall .fake_on_button { margin-left: 10px !important }


.global_size_miniinfo { display: inline-block; margin-left: 5px}

.highlight_arrow { display: block; position: absolute; bottom: 5px;left: 25px; margin-left: -5px; width: 0;height: 0;border-style: solid;border-width: 5px 5px 0 5px;border-color: #006dd2 transparent transparent transparent; }

#screen_selector_ph_icon_sr { display: none; }

.toolbar_selector_icons .selected_placeholder,
#screen_selector_ph_icon_sr { width: 50px; height: 50px; line-height: 50px; background: #323438; color: #b7bbc0; font-size: 20px; text-align: center}

.toolbar_listelement,
.toolkit_selector,
.screen_selector {  clear: both; position:relative;display: block;line-height: 30px;  font-size: 13px;  color: #b7bbc0; cursor:pointer; min-width:250px;box-sizing: border-box; text-align: left; background:#2a2c2f; padding:0px 16px; white-space: nowrap}
.ssnotavailable, .screen_selector.selected {cursor: auto}

#redolist .toolbar_listelement { color: #777c80; }

.toolbar_selector_icons:hover .selected_placeholder i { color: #fff; }


#undo.toolbar_listelement,
#redo.toolbar_listelement {  background:#323438;}

.toolbar_listelement.no_rm,
.toolkit_selector.no_rm,
.screen_selector.no_rm { margin-right: 0px;}

.toolbar_listelement .material-icons,
.toolkit_selector .material-icons,
.screen_selector .material-icons {  font-size: 17px; line-height: 30px; margin-right:15px;}


#zoomer_wrap_toolbar.inzoommove .tool_dd_wrap,
.toolbar_selector_icons:hover .tool_dd_wrap { display: block;top: 50px; }


#undo.toolbar_listelement:hover,
#redo.toolbar_listelement:hover,
#redolist .toolbar_listelement:hover,
.toolbar_listelement:not(.disabled):hover,
.toolkit_selector:hover,
.screen_selector:hover { color: #fff; background:#3F444D; }

.toolbar_listelement.selected,
.toolkit_selector.selected,
.screen_selector.selected { color: #fff; background: #006dd2; }



.screen_selector .tponoffwrap { position:absolute; right:10px; margin-bottom: 0px !important;box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.25); }


.shortcuttext { text-align:right;  line-height: 30px; color:inherit; float:right; top:0px; font-size: 12px;}
.shortcut_cmdctrl { line-height: 30px; color:inherit; display: inline-block; margin-right: 5px; font-size:12px;}
.osx .shortcut_cmdctrl  { font-size: 13px }

/* .osx.shortcuttext { width: 25px } */

.clipboard_wrap { vertical-align: top; margin-right: 35px; display: inline-block; margin-top: 5px; }


.basic_action_button_inactive { pointer-events: none !important; color:#777c80;}
.basic_action_button_inactive i { color: #777c80; }
#rbm_globalsettings_savebtn,
#rbm_configpanel_savebtn { 
    display: none;
     width: 375px;
    height: 50px;
    line-height: 50px;
    color: #fff;
    font-size: 15px;
    font-weight: 500;
    position: absolute;
    bottom: 0px;
    right: 0px;
    text-align: center;
    z-index: 10000;
    background: #006dd2;
    cursor: pointer; 
}

#rbm_globalsettings_savebtn { display: block; width:auto; padding:0px 20px;}

#rbm_globalsettings label_a a { color:#777c80; outline: none !important; box-shadow: none !important;}
#rbm_globalsettings label_a a:hover { color:#fff;}

._TPRB_ oneshort .basic_action_coloredbutton,
._TPRB_ oneshort  .basic_action_button { width: 105px; }

/* BUTTON EXTENSIONS FROM BASIC */

.basic_action_button.onlyicon { width: 30px; padding: 0px; text-align: center }
.basic_action_button.onlyicon i { margin-right: 0px }

.moretoseebutton.basic_action_button.onlyicon { position: absolute; top: 0px; left: 146px; line-height: 30px !important;vertical-align: top;top: 0px;color: #777c80;font-size: 14px !important;border-left: 1px solid #323438;width: 15px !important;height: 30px !important;text-align: center;background: #2a2c2f;border-radius: 0px 4px 4px 0px;cursor: pointer; }
 
 .basic_action_button.selected i { color: #fff; }

.rightfloat_action_button { float: right; margin-right: 0px }

.input_with_buttonextenstion .getVideoFromObjectLibrary.onlyicon { margin-left:2px;}

.next_previous_wizzard_steps .basic_action_coloredbutton,
.next_previous_wizzard_steps .basic_action_button,
.cancel_accept .basic_action_coloredbutton,
.cancel_accept .basic_action_button { margin-bottom: 0px; }  


.copy_clipboard_result {  display:none;font-size:14px; margin-left: 10px; line-height: 40px;}
.next_previous_wizzard_steps { position:absolute; bottom:0px; left:0px; line-height: 40px;z-index:10;}

.__inmodal .next_previous_wizzard_steps { left: 220px; }
.cancel_accept { position:absolute; bottom:0px; right:0px; line-height: 40px;z-index:10;}

.cancel_accept .close_and_accept { margin-left: 1px }

/* ADVANCED BUTTONS */

#rb_tlw .toolbar_btn> .icon_switcher >i.material-icons { font-size: 17px; line-height: 50px; opacity: 1; color:inherit;}
#rb_tlw .toolbar_btn> .icon_switcher {width:auto;height:auto;overflow:visible;}
#add_layer_toolbar_wrap { margin-right: 80px; }
#rb_tlw .layertoolbar_wrap .toolbar_btn i.material-icons.norightmargin { margin-right: 0px; }
#current_width_height i.material-icons { color: #236dd2; font-size: 17px;vertical-align:top;margin-right: 5px;font-weight: 500; }
#current_width_height { display: inline-block; }
#show_c_width, #show_c_height { color: #b7bbc0; font-size: 14px; margin-right: 20px; }


 #current_sel_display {width: 50px;margin: 0px;padding: 0px;min-width: 0px;display: inline-block;vertical-align:top;}

#slide_picker_wrap { max-width: 300px; }
#slide_picker_wrap #slidelist { max-height: 300px; position: relative; overflow: hidden; }
#slide_picker_wrap #slidelist.ps .rs__scrollbar-y-rail { right: auto !important; left: 0px !important; z-index:10; background: transparent !important}
#slide_picker_wrap #slidelist.ps .rs__scrollbar-y-rail .rs__scrollbar-y { background: #b7bbc0; opacity:0.3; width:7px !important;}

.toolbar_rightoriented .tool_dd_wrap { margin-left: -99px; }
.toolbar_rightoriented #toolkit_selector_wrap .tool_dd_wrap { margin-left: -49px; }
.toolbar_rightoriented #main_screenselector .tool_dd_wrap { margin-left: -149px; }

.visiblestep_main,
.lockstep_main { background: #323438 }

.outicon_dd_rwap .visiblestep,
.outicon_dd_rwap .lockstep { background:#2a2c2f }

.visiblestep_main.selected .hhb_a,
.visiblestep_main .hhb_b { display: none !important}
.visiblestep_main.selected .hhb_b { display: inline-block !important; }

/* UNDO REDO CONTAINER */
#undoredowrap { max-height: 225px; overflow: hidden;  position: relative}

.undo_redo_wrap .tool_dd_wrap:before { z-index:10; content: " "; position: absolute;right: 0px;top: 0px;width: 30px;height: 100%; background: linear-gradient(to right, rgba(41,44,46,0) 0%,rgba(41,44,46,1) 100%); z-index: 5 }
#undo,#redo { z-index: 20; }

.rb-modal-wrapper .rs__scrollbar-y-rail,
#undoredowrap .rs__scrollbar-y-rail { right: 0px;width: 12px; background: transparent !important; }
.rb-modal-wrapper .rs__scrollbar-y,
#undoredowrap .rs__scrollbar-y { background: #fff;
    width: 7px;
    border-radius: 7px;
    right: 5px !important;
    cursor: pointer;
    opacity: 0.15;
}

.rb-modal-wrapper .rs__scrollbar-x-rail {display: none !important}

#undolist,
#redolist   { margin: 0px;padding: 0px;list-style: none; }




/*SOURCE SELECTOR*/
.source_selector {  box-sizing: border-box;  display:inline-block; color: #b7bbc0; font-size: 17px; line-height: 31px; font-weight: 500; cursor: pointer; margin-right: 28px; vertical-align: top;}
.source_selector:hover,
.source_selector.selected {  color: #006dd2;  }


/* SUFFIX FOR INPUTS */
#rb_tlw .inputsuffix { line-height: 20px; display: inline-block; margin-left: -30px; font-size: 12px;color: #263d52;font-weight: 400; width:30px; border-left:1px solid #006dd2; box-sizing: border-box; text-align:center;}

#rb_tlw  .inputsuffix {color: #eee; border-left-color: #354151; line-height: 29px;}

.left_right_row { position: relative; height: 25px; }



/*ICON SWITCHER*/
#rb_tlw .icon_switcher,
#rb_tlw .icon_trigger { padding:0px 5px; height: 30px; overflow: hidden; position: relative; display: inline-block;  color:#b7bbc0; vertical-align: top; line-height: 25px !important; }
#rb_tlw .icon_trigger_wrap .icon_trigger,
#rb_tlw .icon_trigger_wrap .icon_switcher { height: 25px; background: #3a3e44; cursor: pointer; }

#rb_tlw .icon_trigger_wrap .icon_trigger:hover,
#rb_tlw .icon_trigger_wrap .icon_switcher:hover { color: #fff; }

#rb_tlw .icon_trigger i,
#rb_tlw .icon_switcher i { font-size: 17px; color: #b7bbc0; cursor: pointer;    }

#rb_tlw .icon_trigger_wrap .icon_trigger i,
#rb_tlw .icon_trigger_wrap .icon_switcher i { font-size: 16px !important; vertical-align: top; line-height: 25px !important; margin-right: 5px;  }

#rb_tlw #reset_lock_media_size_layer .icon_trigger_wrap .icon_switcher i,
#rb_tlw #reset_lock_media_size_layer .icon_trigger_wrap  .icon_trigger i { margin-right: 0px; }

#rb_tlw .icon_switcher .tponoffwrap { display: none; }

#rb_tlw .triggerselect.twostatetrigger,
#rb_tlw .icon_trigger:hover i,
#rb_tlw .icon_switcher i.icon_state_on { color: #b7bbc0; }

#rb_tlw .icon_trigger:hover i,
#rb_tlw .icon_switcher i.icon_state_on  { color: #fff; }

#rb_tlw .icon_switcher i.icon_state_on { display: none; }
#rb_tlw .icon_switcher i.icon_state_off { display: inline-block; }

#rb_tlw .icon_switcher.icsw_on i.icon_state_off { display: none; }
#rb_tlw .icon_switcher.icsw_on i.icon_state_on  { display: inline-block; }


#rb_tlw .triggerselect.twostatetrigger,
#rb_tlw oneabsolute .icon_switcher { background-color: #3a3e44; width: 35px; height: 35px; line-height: 35px; text-align: center; border-radius: 4px; font-size: 17px; cursor: pointer; padding:0px;}

#rb_tlw .triggerselect.twostatetrigger.selected,
#rb_tlw oneabsolute .icon_switcher.icsw_on { background-color: #006dd2; }

#rb_tlw oneabsolute .icon_switcher i                { line-height: 35px !important }
#rb_tlw oneabsolute .icon_switcher i.icon_state_on { color: #fff; }

#rb_tlw .triggerselect.twostatetrigger.selected,
#rb_tlw .triggerselect.twostatetrigger:hover,
#rb_tlw oneabsolute .icon_switcher:hover i { color: #fff; }

#rb_tlw .triggerselect.layer_rowposition_icons { margin-right: 5px; }

#rb_tlw .revbuilder-colorpicker {vertical-align: top;margin-bottom: 5px; line-height: 30px; background: #2a2c2f; box-sizing: border-box; padding:7px; width:30px;height:30px; border-radius: 3px; border:none;}
#rb_tlw .revbuilder-colorpicker .revbuilder-colorbox {  width:16px; height:16px; border:1px solid rgba(255,255,255,0.15); border-radius: 0px; vertical-align: top} 
#rb_tlw .revbuilder-colorpicker .revbuilder-colorbtn { display: none; }

#rb_tlw .revbuilder-colorpicker .visiblecolorfield { display: inline-block !important }



#rb_tlw onelong .revbuilder-colorpicker.revbuilder-cpicker-master-wrap.visible-cp-input { width: 67px; display: inline-block; position: relative}
#rb_tlw onelong .revbuilder-colorpicker.revbuilder-cpicker-master-wrap.visible-cp-input  input {     position: absolute;top: 7px;left: 23px;white-space: nowrap;overflow: hidden;width: 40px !important;min-width: 45px !important;  }

#builderView.staticlayersview #form_slidebg {
  display: none !important
 }

 #builderView:not(.staticlayersview) #form_slidestatic {
  display: none !important;
 }

 #builderView:not(.staticlayersview) #form_staticlayerposition_basic { 
 display: none !important; 
}

/*********************************
   LABELS AND SECTION TITELS 
**********************************/
#video_id_wrap { position: relative }

longoption { display: block; border: 1px solid #3f444a; border-radius:3px; line-height: 38px; box-sizing: border-box; margin-bottom:5px;}

.material-icons.rcw { transform: rotate(90deg); }

.section_title {  font-size: 16px; line-height: 28px;font-weight: 500;color: #000;}
.setia { margin-bottom: 20px;}

.description,
label_info,
.label_info,
.function_info { color: #777c80;  font-size:14px; font-weight: 400; line-height: 20px; display:inline-block;}

.function_info a { color: inherit !important; }
.function_info a:hover { color: #fff !important; }

label_title,
.label_title { line-height: 28px;vertical-align: top;min-width: 180px;display: inline-block; cursor: default;color: #222;font-weight: 800;text-transform: uppercase;margin-bottom: 10px;font-size: 14px;}

label_value_info,
.label_value_info { line-height: 28px;vertical-align: top;min-width: 30px;display: inline-block; cursor: default;color: #222; text-align:center;font-weight: 800;text-transform: uppercase;margin-bottom: 10px;border-radius: 4px; padding: 0px 10px;font-size: 12px;}

label_sub, .label_sub,
label_short,.label_short,
label_a_left,.label_a_left,
label_a_right,.label_a_right,
xy_label,.xy_label,
label_full,.label_full,
label_a, .label_a { line-height: 17px; padding:7px 0px; vertical-align: top;display: inline-block; cursor: default;color: #222;font-weight: 500;  margin-bottom: 0px;font-size: 12px;color:#777c80; width:80px; text-align: right;margin-right:15px; overflow: hidden; white-space: nowrap}
label_sub, .label_sub { text-align: left; margin-right: 0px; width: auto;  }

#layer_with_action_wrap label_a { width: 120px; }
#action_inputs label_a { width: 140px; }

#rb_tlw .radiooption label_sub,
#rb_tlw .radiooption .label_sub { line-height: 25px; vertical-align: top; padding: 2px 0px 0px; z-index:0; padding-left: 30px; position: relative; cursor: pointer;}

#rb_tlw .radiooption label_sub:before, 
#rb_tlw .radiooption .label_sub:before { content: " "; width:20px;height:20px; background:#2a2c2f; position: absolute;left:0px;top:5px; border-radius: 100%; box-sizing: border-box; border:5px solid #2a2c2f;}

#rb_tlw input[type=radio]:checked + label_sub { color: #fff !important; }
#rb_tlw input[type=radio]:checked + label_sub:before { background: #006dd2;  }

label_full,.label_full { width: 100%;display: block;  text-align: left}

#form_slidergeneral_advanced_api label_full,
#form_slidergeneral_advanced_api .label_full { width: 235px; display: inline-block; }





xy_label,
.xy_label {  width: auto; display: inline-block; text-align: left; min-width: 30px; margin-right: 3px}

.__inmodal label_short,
.__inmodal .label_short,
.__inmodal label_a_left,
.__inmodal .label_a_left,
.__inmodal label_a_right,
.__inmodal .label_a_right,
.__inmodal label_a,
.__inmodal .label_a { display: block; width: 100%; text-align: left; }

label_a span { line-height: 17px; display: inline-block; margin-top: 4px; }


label_b,
.label_b { line-height: 28px;vertical-align: top; display: inline-block; cursor: default;margin-right: 20px;}

label_x,
.label_x {line-height: 28px;vertical-align: top;  display: inline-block; cursor: default;margin-right: 15px;}

 

label_center,
.label_center {line-height: 14px; cursor: default; font-size:12px; text-transform: uppercase; display: block; text-align: center; margin-bottom: 10px; letter-spacing: 1px;}

.labelunderline { color: #414448; border-bottom:1px solid #4a4c4e; margin-bottom:28px; text-transform: uppercase; font-size: 14px; font-weight: 700; line-height: 20px; padding-bottom: 10px; letter-spacing: 3px}


label_a.auto,
.label_a.auto  { min-width:auto; margin-right: 15px}


label_a.long,
.label_a.long { min-width: 250px; }

label_a.halflong,
.label_a.halflong { min-width: 150px; }

longoption label_a { min-width: 150px; text-align: left; margin-left: 15px;vertical-align: top; line-height: 38px; padding: 0px; margin-right: 10px; }
longoption label_a.longlabellength { min-width: 220px }

longoption i.material-icons { color: #b7bbc0; font-size: 20px; margin-left: 15px; vertical-align: top; line-height:38px;}
longoption .tponoffwrap, 
longoption .fake_on_button { margin: 9px 10px 0px 0px;  float:right;}

.verticaldiv {  width:100%;height:1px;border-top:1px solid #3e4a5a ;margin-bottom:10px;}

 
/* EXTRA GROUP SETTINGS */
label_title,
.label_title { color: #bcc9d2; }

label_value_info,
.label_value_info { color: #b7bbc0; background:#2a2c2f; }

label_short,
.label_short  { min-width: 22px; width:22px; max-width: 22px; text-align: left; margin-right:0px;}

label_a_left,
.label_a_left   { min-width: 230px; width:230px; max-width: 230px; text-align: center; margin-right:0px;}
label_a_right,
.label_a_right   { min-width: 60px; width:60px; max-width: 60px;text-align: center;margin-right:0px;}

label_b,
.label_b { color: #bcc9d2; }

label_x,
.label_x { color: #bcc9d2; }

label_center { color:#8095a3;  }


oneshort label_a,
oneshort .label_a { max-width: 25px;box-sizing: border-box; margin-right: 10px}

onethird label_a,
onethird .label_a { min-width: 28px; max-width: 28px; }

oneabsolute { position: absolute; left: 0px;top: 10px; width: 80px; }



.verticaldiv { border-color: #3e4a5a; margin-top: 10px; margin-bottom: 10px }


#slide_ddd_depth_info { margin-bottom: 0px; }

/** LIGHT MAIN LABELS **/

.space_to_left { margin-left: 10px; }
.space15 { display: inline-block; width: 15px;height: auto; line-height: inherit; vertical-align: top; }

#selected_slide_source { text-transform: capitalize; margin-right: 5px; display:inline-block;}


/** BREAK POINTS */
.bpoints_wrap { vertical-align: bottom;  line-height: 50px;}

.input_left,
.input_right { display: inline-block; vertical-align: top; width:65px;}
.input_middle {display: inline-block; vertical-align: top; font-weight: 500; font-size: 17px; line-height: 27px; margin:0px 10px 0px 0px;}

.auto_dimension_la { display: none; }

/*****************************
  -   MOUSE INFO BOX  -
******************************/
#mouseInfoBox { position:absolute; z-index:101000;white-space:nowrap;background: #222a34; color: #fff; font-weight: 300; font-size: 11px; padding: 5px 5px; line-height: 13px; display: none;border-radius: 4px; pointer-events: none}
#mouseInfoBox .mouselabel { min-width:5px; position: relative; display: inline-block; color: #8095a3;line-height: 12px; margin-right: 5px; vertical-align: top}

#mouseInfoBox.purplemouseinfo { height:auto; background: #5e35b1; color:#fff; }
#mouseInfoBox.purplemouseinfo .mouselabel { color: #fff; }


.mouse_info_coor { width: 40px; height: 24px; display: inline-block; margin-right: 5px; vertical-align: top; line-height: 12px; }
#mouseInfoBox.purplemouseinfo .mouse_frame_label  {color: #fff; font-size:12px; line-height: 12px; font-weight: 600; vertical-align: top; margin-bottom: 2px}

.mouse_frame_label {  font-size: 13px;line-height: 23px; font-weight: 600 }
.mouse_info_align { width: 27px; height: 24px; display: inline-block;  vertical-align: top; margin-top: 0px; }
.mia_tl,.mia_tc,.mia_tr,
.mia_ml,.mia_mc,.mia_mr,
.mia_bl,.mia_bc,.mia_br { width: 6px; height: 6px; margin-right: 3px; margin-bottom: 3px; background: #3f444a; float:left;}

.mia_tr,.mia_mr, .mia_br { margin-right: 0px; }
.mia_bl,.mia_bc,.mia_br { margin-bottom: 0px; }

.top.left .mia_tl,
.top.center .mia_tc,
.top.right .mia_tr,
.middle.left .mia_ml,
.middle.center .mia_mc,
.middle.right .mia_mr,
.bottom.left .mia_bl,
.bottom.center .mia_bc,
.bottom.right .mia_br { background: #006dd2 }


/********************************
  - MAIN CONTAINERS -
*********************************/
#builderView                {  position: fixed;top:0px;left:0px;width:100%;height:100%;background:#111; overflow: hidden;}

#the_container              { display: block;width: 100%;height: 100%;position: absolute;top: 0px;left: 0px;min-width: 1071px}
#builder_header             { background:#006dd2; line-height: 70px; margin-top:20px;min-height: 70px;padding:0px 20px;}
#builder_header_navigation  { background:#0b5fab; min-height: 70px; line-height: 70px; margin-bottom: 20px }




#rb_editor_logo { display: inline-block; height:50px;line-height: 50px;  vertical-align: middle; /*padding:0px 15px; */ }
#rb_editor_logo i.material-icons { font-size: 20px; color: #b7bbc0; transform: rotate(180deg); }


.main_mode_selector { cursor:pointer; display: block; height:50px;line-height: 25px; background:#3f444a; padding: 10px; box-sizing: border-box; color:#777c80; font-size: 13px; margin-bottom:0px; width:25%;float:left; text-align: center; /*border-bottom:1px solid #323438;*/}
.main_mode_selector:first-child { border-left: none; }
.main_mode_selector i.material-icons { font-size: 25px; display: block !important; text-align: center; margin:5px 0px 3px;}
.main_mode_selector:hover { color: #b7bbc0; background: #3f444a; } 

.main_mode_breadcrumb_wrap,
#mmbw_loptions  { border-bottom: 1px solid #323438; padding: 15px; background: #202224; }
.main_mode_submode  { color: #777c80; font-size: 14px; font-weight: 900; line-height: 26px;  text-align: center; text-transform: uppercase}

.main_mode_submode.left  { float: left; }
.main_mode_submode.right { float: right; }

.main_mode_submode.blue { background: #006dd2; color: #fff; padding: 0px 6px; border-radius: 4px; font-size: 13px;line-height: 23px;margin-top:2px;}
.main_mode_submode.lila { background: #5e35b1; color: #fff; padding: 0px 6px; border-radius: 4px; font-size: 13px;line-height: 23px;margin-top:2px;}

#stylemode_layeroption,
#hovermode_layeroption,
#animationmode_layeroption { display: none; }

.mmbw_idle #stylemode_layeroption           { display: block; }
.mmbw_hover #hovermode_layeroption          { display: block;}
.mmbw_animation #animationmode_layeroption  { display: block; }


#glob_settings_header,
#glob_slide_selector_header { border: 1px solid #d8e1e9; margin-bottom: 30px;border-radius: 4px; background:#fff;}

/* FAKE CAROUSELS */
#fake_carousel_elements { position: absolute; z-index: 0; }
.fakecarouselslide { position: absolute; box-sizing: border-box; background:rgba(120,140,165,1);}


#slide_settings,
#layer_settings,
#timeline_settings   { display: none; }

#rev_builder_wrapper { position: relative; background: #111111; box-sizing: border-box; width:100%;height:100%;}

#rev_builder        { box-sizing: border-box;width: 100%; height: 100%; background:url(../images/medium_pattern_2x.png); background-size:16px 16px; background-repeat: repeat; display:block;position:absolute; overflow: hidden; }
#rev_builder *      { box-sizing: border-box; }

#layout_slide       { width:100%;height:100%;position: absolute;top:0px;left:0px;z-index:2;}

#rev_slider_ul { opacity: 0 }
#rev_slider_ul,
#rev_slider_inbuild   { z-index:3;width: 100%; height: auto; /* KRIKI HEIGHT AUTO !? */ display: block; /*background:#2a3441;*/; position:relative;margin:auto;}
#rev_slider_ul_inner {  width:100%;height:100%;overflow:hidden;position: absolute; display:block; top:0px;left:0px;perspective: 1200px; transform-style: flat; }

#rev_builder>.ui-resizable-e { width: 4px;right: -4px;background: #999; display: block; }
#rev_builder>.ui-resizable-e:after  { content: " "; height: 50px;width: 10px;top: 50%;margin-top: -25px; position: absolute;left: 0px;background: #888; border-radius: 0px 4px 4px 0px; }
#rev_builder>.ui-resizable-e:hover,
#rev_builder>.ui-resizable-e:hover:after{ background:#006dd2; }
#layer_grid                { z-index:5;width: 100%; height: auto; display: block; position: absolute; background:rgba(255,255,255,0.85);margin:auto;box-sizing: border-box; opacity: 0; pointer-events: none}
#layer_grid.hovered .ui-resizable-handle:hover { background: rgba(23,141,247,0.5); }
#layer_grid .ui-resizable-s {  bottom: 0px; }
#layer_grid .ui-resizable-n {  top:0px; }
#layer_grid .ui-resizable-w {  left:0px; }
#layer_grid .ui-resizable-e {  right:0px; }

#rev_slider_ul.hovered>.ui-resizable-handle:hover { background: rgba(23,141,247,0.5);}

#main_hor_toolbar     { background:#323438;width:100%;display: block; padding:5px 0px;box-sizing: border-box; position:absolute;height: 50px;top: 0px;left: 0px;padding: 0px 320px 0px 0px;z-index: 2000; }
.mht_inner            { display: inline-block; vertical-align: top; margin-right:10px;height:50px;  }

.mht_inner {  border-left:1px solid #202224;}
.layer_settings_collector { border-right: 1px solid #202224; }

.toolbar_selector_icons .toptoolbaricon.material-icons { font-size: 20px; }

.quick_style_wrap  { border-right:1px solid #202224; }

.quick_style_dep { position: relative }

.quick_colorchange_dark,
.quick_colorchange_light { box-sizing:border-box; cursor:pointer; width: 15px; height: 15px; background: #000; position: absolute; top: 9px; right: 40px; z-index: 1000; border-radius: 8px; border: 2px solid #000; }
.quick_colorchange_light { background: #fff; right:18px; border-color:#fff;}

.quick_colorchange_dark:hover,
.quick_colorchange_light:hover,
.quick_colorchange_light.selected,
.quick_colorchange_dark.selected { border-color: #006dd2; }





.toolbar_rightoriented { position: absolute ; right:320px; top:0px; height:50px; line-height: 50px;}

.zoomer_wrap,
.undo_redo_wrap,
.drawselector_wrap,
#main_screenselector  { position: relative; display:inline-block}


#undo_redo_wrap { cursor: pointer; width: 50px; height: 50px; }



#the_right_toolbar { display: block; position:absolute; top:0px; left:0px; background:#323438; width: 320px; height: 100%; box-sizing: border-box;  z-index: 2500;}
#the_right_toolbar { left: auto;right: 0px; }
#the_right_toolbar_inner { overflow: hidden; position: relative; width: 100%; display: block;  height: 100%; box-sizing: border-box; padding:0px;}





#the_editor {  width: 100%;height: 100%;position: absolute; top:0px;left:0px;padding: 65px 320px 0px 15px; box-sizing: border-box }


.layertoolbar_wrap { background: #323438; padding: 0px 10px 0px 20px;margin-top:0px; line-height: 50px; height: 50px; position: relative; vertical-align: top; display:inline-block !important;     position: absolute; top: 0px;left: 50%;margin-left: -285px; }



/*#layer_rescaler { width: 100%; height: 30px; position: absolute;top: 65px; left:0px; background: #202123; box-sizing: border-box; }
#lresc_path { width: 301px;top: 13px; position: absolute; left: 40px; height: 5px; background: #323437; border-radius: 4px  }
#lresc_pin { width: 1px; height: 14px; position: absolute; top: 50% !important; transform:translateY(-7px) !important;left: 50%;  cursor: pointer}
#lresc_pin:before { position: absolute;content: " "; width: 14px;height: 14px; top:0px; left: -7px; background: #026dd2; border-radius: 7px; }
.multiple_layers_selected #layer_rescaler,
.no_layers_selected #layer_rescaler { display: none; }
*/

._lc_reScaler { display:none; pointer-events: none; position: absolute; top:0px; left:0px; z-index: 100; width:100%;height:100%;background:transparent;}
._lc_reScaler_pin { position: absolute;top: 0px;left: 0px;z-index: 10; background: transparent; width:100%;height:100%; pointer-events: none;}
._lc_reScaler_pin .ui-resizable-se { bottom: -9px;right: -9px;width: 18px;height: 18px;pointer-events: auto;background: transparent;border-radius: 10px;}
._lc_reScaler_icon { background:url(../images/resize.png); width:18px;height:18px;position: absolute; background-size:contain;bottom:-9px;right:-9px;}


._lc_.selected >._lc_reScaler { display: block; }

#rev_builder.inAnimationMode ._lc_.selected >._lc_reScaler,
.multiple_layers_selected ._lc_.selected >._lc_reScaler { display: none !important; }

#do_title_layer,
#do_title_slide,
#do_title_layer_not_selected { font-size: 14px; color: #b7bbc0; font-weight: 500; display: inline-block; margin-right: 20px; width: 150px; white-space: nowrap; overflow: visible; position: relative; vertical-align: top }

#no_layer_selected { font-size: 15px; color: #b7bbc0; font-weight: 400; display: inline-block;  white-space: nowrap; overflow: hidden; position: relative; vertical-align: top; padding: 20px; box-sizing: border-box; text-align: center}
#no_layer_selected .material-icons { vertical-align: top; font-size: 20px; margin-right: 10px; }

#do_lock_layer,
#do_show_layer { display: inline-block }

#do_title_slide input[type="text"],
#do_title_layer input[type="text"]  {  line-height: 50px !important;height: 50px !important;background: transparent !important; padding: 0px !important; max-width:130px;font-size: 14px !important}

#do_title_slide input[type="text"]:focus,
#do_title_layer input[type="text"]:focus { color: #fff !important;  }

#do_title_layer,
#do_title_slide { display: inline-block; }
#no_layer_selected,
#do_title_layer_not_selected { display: none; }


#the_container.no_layers_selected #do_title_layer { display: none; }
#the_container.no_layers_selected #no_layer_selected,
#the_container.no_layers_selected #do_title_layer_not_selected { display: inline-block; }

#the_container .do_title_layer_icon,
#the_container .do_title_slide_icon { color: #006dd2; font-size: 17px; margin-right: 10px; line-height: 51px }

#layer_lock_iconswitch:after,
#layer_visibility_iconswitch:after { display:none;content:""; position: absolute; bottom: 5px;left: 50%;margin-left: -5px;width: 0;height: 0;border-style: solid;border-width: 5px 5px 0 5px;border-color: #53565a transparent transparent transparent; }
#layer_lock_iconswitch.listIsFilled:after,
#layer_visibility_iconswitch.listIsFilled:after { display: block; }

#ui_preset_toggle { padding: 0px; text-align: center;  width:40px;}
#ui_preset_toggle .material-icons { margin: 0px !important; }

#_layer_settings { padding-left: 10px }
#_layer_settings .tool_drop { padding-left: 20px; }

.undoredostep span { text-transform: capitalize }


#do_background_layer .material-icons,
#do_foreground_layer .material-icons { font-size: 30px }

.multiple_layers_selected #do_background_layer,
.multiple_layers_selected #do_foreground_layer,
.no_layers_selected #do_background_layer,
.no_layers_selected #do_foreground_layer { opacity: 0.25; pointer-events: none }

/* NORMAL LAYER GRIDS */
.layer_grid                { z-index:5;width: 100%; height: auto; display: block; position: absolute; margin:auto;box-sizing: border-box; transform:translateX(-50%) translateY(-50%); top:50%;left:50%;}


/* SLIDE LI STYLES */
.slide_li                 { width:100%;height:100%;position: absolute;top:0px;left:0px;}
.slide_li.showunderstatic { pointer-events: none; display: block !important; z-index: 3 !important; }
.slide_li.hideslotsinslide rs-sbg-px { display: none !important; }
#slide_li_template        { display: none !important; }
.slide_li.aable.markable  { z-index: 5 }

rs-sbg-px { width: 100%;height: 100%;position: absolute;z-index: 0;top: 0px;left: 0px; display: block; overflow:hidden;}
rs-sbg-wrap { width:100%;height:100%;position:absolute;top:0px;left:0px;z-index:0; display:block;}
rs-sbg-wrap canvas { width: 100%;height: 100%;position: absolute;top:0px;left:0px; }

/*.ssbg_prev { background:url(../images/light_pattern_2x.png); background-size:16px 16px; background-repeat:repeat; }*/


/* STATIC SLIDE SETTINGS */
/*.staticlayersview .layer_group_filter_wrap,*/
.staticlayersview #slide_menu_gso_wrap,
#gst_slide_10,
#gst_layer_14,
.staticlayersview #the_slide_timeline,
#the_global_layers_timeline { display: none !important; }

.staticlayersview #the_global_layers_timeline { display: block !important; }

.staticlayersview #module_navigation_trigger { pointer-events: none; opacity: 0.5 }

/*.static_slide_li rs-sbg-px { display: none !important;  }*/

.staticlayersview #gst_layer_14 { display: inline-block !important; }
.static_slide_li.slide_li { z-index: 50 !important }

/*************************
 - SELECT BY DRAW -
*************************/
#selectbydraw { position: absolute;z-index: 10000;width:100%;height: 100%; position: absolute; top: 0px; left: 0px; background: transparent; cursor: crosshair}
#selectbydraw_box { border: 1px dashed #fff; position: absolute; background:rgba(0,109,210,0.3);}
#selectbydraw_box:after { content: " "; position: absolute; top: 0px;left: 0px;padding: 1px; box-sizing:border-box; width: 100%;height: 100%;border: 1px dashed rgba(0,109,210);   }

/**************************
  -  SAVE SLIDER -
 *************************/
#save_slider { width: 160px; height:50px; line-height:50px; color:#fff; font-size:15px; font-weight:500; position: fixed; bottom: 0px; right: 160px; text-align: center; z-index: 10000; background: #006dd2; cursor: pointer }
#save_slider:hover { background: #0a447a; }
#save_slider i { margin-right: 5px; line-height: 50px !important; font-size: 20px }

#optimizeslider { display:none; width: 320px; height:50px; line-height:50px; color:#fff; font-size:15px; font-weight:500; position: fixed; bottom: 50px; right: 0px; text-align: center; z-index: 10000; background: #22a46e; cursor: pointer }
#optimizeslider:hover { background: #166b48; }
#optimizeslider i { margin-right: 5px; line-height: 50px !important; font-size: 20px }



#preview_slider { border-left:1px solid #2883d9; width: 160px; height:50px; line-height:50px; color:#fff; font-size:15px; font-weight:500; position: fixed; bottom: 0px; right: 0px; text-align: center; z-index: 10000; background: #006dd2; cursor: pointer }
#preview_slider:hover { background: #0a447a; }
#preview_slider i { margin-right: 5px; line-height: 50px !important; font-size: 20px }

/**************************
  -  MAIN VIEW MODES -
 *************************/

#timeline_settings { display: block;  }

/* HIDE NAVIGATION IN LAYER MODE */
.mode__slidelayout #tp-thumbs,
.mode__slidelayout #tp-tabs,
.mode__slidelayout #tp-bullets,
.mode__slidelayout #tp-leftarrow,
.mode__slidelayout #tp-rightarrow,
.mode__slidelayout #rev_progress_bar_wrap { display: none !important; }


/* HIDE LAYERS AND SLIDE ON NAVIGATION SETTINGS */
.mode__navlayout ._lc_ { display: none !important; } 


/* HIDE LAYER SETTINGS UNDER SLIDE EDITOR, AND SLIDE SETTINGS UNDER LAYER EDITOR */
.mode__slidelayout.mode__slidestyle .layer_settings_collector,
.mode__slidelayout.mode__slidecontent .slide_settings_collector,
.mode__slidelayout .slider_general_collector,
.mode__slidelayout .slider_nav_layout_collector,


.mode__navlayout .slide_settings_collector,
.mode__navlayout .layer_settings_collector,
.mode__navlayout .slider_general_collector,

.mode__sliderlayout .slide_settings_collector,
.mode__sliderlayout .layer_settings_collector,
.mode__sliderlayout .slider_nav_layout_collector  { display:none !important;}


/*SHOW TIMELINE WHEN NEEDED */
#timeline_settings { display: block !important; }
/*.mode__slidelayout.mode__slidestyle #timeline_settings */

.mode__navlayout .nav_collector,
.mode__sliderlayout .slider_general_collector { display: block; }

/*SHOW SLIDE LAYOUT SETTINGS*/
.mode__slidelayout.mode__slidestyle .slide_settings_collector { display: block; }

/*SHOW LAYOUT SETTINGS*/
.mode__slidelayout.mode__slidecontent .layer_settings_collector { display: block; }

.mode__sliderlayout #module_settings_trigger,
.mode__navlayout #module_navigation_trigger,
.mode__slidelayout.mode__slidestyle #module_slide_trigger,
.mode__slidelayout.mode__slidecontent #module_layers_trigger { color: #fff; background: #006dd2; } 




.no_layers_selected#the_container .form_collector.layer_settings_collector .form_inner { display: none !important; }

/*****************************
 - LAYERS LIST CONTAINER -
******************************/

.mainLayerListWrap      { padding:0px; position: relative; height:100%; box-sizing: border-box }  

.the_layers_in_slide    { display: none !important; padding:0px; position: relative; overflow: hidden;  height:auto;    width: 100%; vertical-align: top; box-sizing: border-box; top: 0px;left: 0px;z-index: 10;}
.opened_slidetab .the_layers_in_slide { display: block;  border-top:15px solid #161617;  border-bottom:15px solid #161617; }


.resizeMainLayerListWrap {  display: none !important;}

.layerListContainer { margin: 0px; padding: 0px 0px 50px; }


.all_layer_tool,
.layerlist_toolbar_icon   { display: inline-block; vertical-align: top; cursor:pointer; line-height: 34px; width:25px; text-align:left; color:#777c80;}
#rb_tlw #timeline_settings .slide_timeline .slide_timeline_element input[type=checkbox].simplechkbx   { margin-right: 5px; }


.layerlist_toolbar_icon:hover,
.layerlist_toolbar_icon.checked,
#timeline_settings .all_layer_tool:hover .material-icons { color: #fff;  }


#layerlist_element_template { display: none !important; }

.layerlist_element_innerwrap { display: block;width: 100%;height: 36px; position:relative; cursor: pointer; padding-left: 5px}
#timeline .layerlist_element_innerwrap { padding-left: 0px }
.layerlist_element_innerwrap ul { padding: 0px; margin: 0px; }

.layerlist_element {  color:#b7bbc0; list-style: none; margin:0px; position: relative; line-height: 34px}

.layerlist_element_id,
.layerlist_element_mover,
.layerlist_element_type,
.layerlist_element_alias { display: inline-block; vertical-align: top; line-height: 34px; margin-right: 0px; }

#timeline .tllayerlist_element_zone >.layerlist_element_innerwrap { display: none !important; }
#timeline.layer_in_drag .tllayerlist_element_zone >.layerlist_element_innerwrap { display: block !important; }

.layer_in_drag.outlined { outline: 1px dashed #006dd2; }



.layerlist_element_id { width: 13px; text-align: right; margin-right: 6px; }
.layerlist_element_mover { margin-right: 5px;cursor: pointer }
.layerlist_element_alias { font-size: 14px; white-space: nowrap; text-transform: capitalize; font-weight: 500; }
.layerlist_element_type { margin-right: 5px; }

#timeline .layerlist_element_type .material-icons,
#rb_tlw .layerlist_element_type .material-icons { color: #006dd2;  font-size:17px;}
#rb_tlw .layerlist_element_innerwrap:hover .layerlist_element_type .material-icons { color: #fff !important; }

#rb_tlw .layerlist_element_innerwrap:hover { background: #0d0d0e; }

.layerordertypewrap { background:#161617;padding:5px 5px 2px 5px !important; font-size:16px; line-height: 34px;}
.layerordertypewrap_title { color: #777c80;letter-spacing: 1px;text-transform: uppercase;font-weight: 500; line-height: 34px;font-size: 11px; display: inline-block; padding-left:20px; vertical-align: top}

.layerlist_toolbar  { display:none; /*background: linear-gradient(to right, rgba(0,109,210,0) 0%,rgba(0,109,210,1) 20%,rgba(0,109,210,1) 100%);*/ position: absolute;top:0px;right:23px;z-index:5;padding:0px 5px 0px 40px;}

.tllayerlist_element .layerlist_toolbar { display:none;  position: absolute;top:0px;right:0px;z-index:5;padding:0px 5px 0px 10px; height:35px; width:25px;}

.tllayerlist_element .layerlist_element_innerwrap:hover .layerlist_toolbar { display: block }
.layerlist_toolbar_icon_wrap {  position: absolute;right:0px;top:0px;width:auto;height:36px; z-index: 6}

#rb_tlw .material-icons.layer_current_visibility { display:none;font-size: 13px !important; position: absolute; right: 30px; cursor: pointer; top: 0px; z-index: 20; opacity: 0.5}
#rb_tlw .material-icons.layer_current_locked   {  display:none;font-size: 13px !important; position: absolute; right: 50px; cursor: pointer; top: 0px; z-index: 20; opacity: 0.5;}

#rb_tlw .material-icons.layer_current_visibility:hover,
#rb_tlw .material-icons.layer_current_locked:hover { opacity: 1 }


#rb_tlw .tllayerlist_element >.layerlist_element_innerwrap:hover .material-icons.layer_current_visibility,
#rb_tlw .tllayerlist_element._unvisible_ >.layerlist_element_innerwrap .material-icons.layer_current_visibility { display: block;}

#rb_tlw .tllayerlist_element >.layerlist_element_innerwrap .material-icons.layer_current_visibility { opacity: 0.35; }
#rb_tlw .tllayerlist_element >.layerlist_element_innerwrap .material-icons.layer_current_visibility:hover { opacity: 0.65; }
#rb_tlw .tllayerlist_element._unvisible_ >.layerlist_element_innerwrap .material-icons.layer_current_visibility { opacity: 1; }

#rb_tlw .tllayerlist_element >.layerlist_element_innerwrap:hover .material-icons.layer_current_locked,
#rb_tlw .tllayerlist_element._locked_ >.layerlist_element_innerwrap .material-icons.layer_current_locked { display: block; }

#rb_tlw .tllayerlist_element >.layerlist_element_innerwrap .material-icons.layer_current_locked { opacity: 0.35 }
#rb_tlw .tllayerlist_element >.layerlist_element_innerwrap .material-icons.layer_current_locked:hover { opacity: 0.65 }
#rb_tlw .tllayerlist_element._locked_ >.layerlist_element_innerwrap .material-icons.layer_current_locked { opacity: 1 }


.layerordertypewrap .all_layer_tool_wrap { display: none; }
.layerordertypewrap:hover .all_layer_tool_wrap { display: block; }
#rb_tlw .layerordertypewrap .material-icons { cursor: pointer;font-size: 13px; width:16px;margin-right: 1px; position: relative; z-index: 100}


.layerlist_toolbar_icon { visibility: hidden }
.layerlist_toolbar_icon.checked,
.layerlist_toolbar_icon.endswithslide,
.layerlist_element_innerwrap:hover .layerlist_toolbar_icon { visibility: visible}

.layerlist_element_innerwrap:hover .layerlist_toolbar { display: block; }
.layerlist_element_innerwrap:hover .layerlist_element_alias { color: #fff; }

.nolayeravailable  { padding: 0px 10px; border-bottom: 1px solid #222a34; }

.layerlist_element_level  { margin-left: 0px; display:inline-block;}

ul.layerListContainer >li >.layerlist_element_innerwrap .layerlist_element_type { margin-left: 10px; }
.tllayerlist_element_group>.layerlist_element_innerwrap>.context_left>.layerlist_element_type { margin-left: 0px; }

.layerListContainer>.layerlist_element.not_zone_layer>ul>li.layerlist_element>.layerlist_element_innerwrap>.context_left>.layerlist_element_type,
.layerlist_element ul li ul li ul li .layerlist_element_type { margin-left: 25px; }

.layerListContainer .collapsed ul { display: none; }
.layerListContainer .collapsed .layerlist_element_level i { transform: rotateZ(-90deg); }


.layerlist_element .indeplayerinput {display:none; width: 200px;
    height: 30px;
    position: absolute;
    left: 38px;
    padding: 0px 30px 0px 15px !important;
    background: #0d0d0e !important;
    top: 1px;
    z-index: 30;
    border: none;
    color: #fff;
    box-shadow: none !important;
    border-radius: 4px; 
}
.layerlist_element .layerlist_element_innerwrap.directedit .indeplayerinput { display: inline-block;  }
.layerlist_element .layerlist_element_innerwrap.directedit .layerlist_element_alias { display: none; }

.tllayerlist_element_zone.beforeitemdrop:before {content:" ";height:3px;background:#006dd2; position:absolute; width:100%; top:-1px; left:0px;z-index: 15}  

.layerlist_element.beforeitemdrop>.layerlist_element_innerwrap:after { content:" ";height:1px;background:#006dd2; position:absolute; width:100%; top:-1px; left:0px;z-index: 15}
.layerlist_element.incolumntopdrop>.layerlist_element_innerwrap:after,
.layerlist_element.afteritemdrop>.layerlist_element_innerwrap:after { content:" ";height:1px;background:#006dd2; position:absolute; width:100%; bottom:-1px; left:0px;z-index: 15}

.layerlist_element.afterzonedrop:after { content:" ";height:1px;background:#006dd2; position:absolute; width:100%; bottom:-1px; left:0px;z-index: 15}

.layerlist_element.ui-draggable-dragging { z-index: 1600; }

.layerListContainer.sortToTheEnd { border-bottom: 3px solid #006dd2; }

.layerlist_element.incolumndrop .layerlist_element_innerwrap,
.layerlist_element.incolumntopdrop .layerlist_element_innerwrap {background:#2f3a49}


#rb_tlw .layerordertypewrap .layerlist_element_level,
.tllayerlist_element_zone >.layerlist_element_innerwrap .layerlist_element_level  { position: absolute; width: 100% }

#rb_tlw .layerordertypewrap,
.clayerlist_element_zone >.layerlist_element_innerwrap { padding-top:2px; padding-bottom:3px;  }

.tllayerlist_element_zone >.layerlist_element_innerwrap .layerlist_element_alias {letter-spacing: 1px;text-transform: uppercase;font-weight: 500;line-height: 34px;font-size: 11px;display: inline-block; }

.tllayerlist_element_zone >.layerlist_element_innerwrap .layerlist_element_alias {color: #777c80; font-size: 11px; padding-left: 20px; }

.tllayerlist_element_zone >.layerlist_element_innerwrap .layerlist_element_type { display: none; }

.tllayerlist_element_zone >.layerlist_element_innerwrap:hover  { background: transparent; }

.tllayerlist_element_zone >.layerlist_element_innerwrap .layerlist_toolbar  { background: transparent;padding-left: 0px;top: 5px; }

.tllayerlist_element_zone >.layerlist_element_innerwrap.directedit .layerlist_element_alias  { display: inline-block !important; }

.tllayerlist_element_zone >.layerlist_element_innerwrap .layerlist_toolbar,
.tllayerlist_element_zone >.layerlist_element_innerwrap .fclayer_withslideend,
.tllayerlist_element_zone >.layerlist_element_innerwrap .layerlist_element_selector { display: none !important; }



/** LAYERLIST ELEMENT LEVEL **/

#rb_tlw .layerlist_element_level i,
#timeline .layerlist_element_level i { width: 20px; display: none; font-size: 22px !important;  cursor: pointer; }

#rb_tlw  .layerlist_element_level i,
#timeline .layerlist_element_level i {  color: #b7bbc0 }

#rb_tlw .layerordertypewrap .layerlist_element_level i,
#timeline .tllayerlist_element_zone >.layerlist_element_innerwrap .layerlist_element_level i,
#rb_tlw .clayerlist_element_zone >.layerlist_element_innerwrap .layerlist_element_level i { margin-left:0px; display: inline-block; color:#777c80; opacity: 1; }

#rb_tlw  .layerlist_element_innerwrap:hover .layerlist_element_level i,
#timeline .layerlist_element_innerwrap:hover .layerlist_element_level i { color:#fff;opacity: 1; }


/*#rb_tlw .layerordertypewrap:hover .layerordertypewrap_title,
#rb_tlw .clayerlist_element_zone >.layerlist_element_innerwrap:hover .layerlist_element_alias,
#timeline .tllayerlist_element_zone >.layerlist_element_innerwrap:hover .layerlist_element_alias,*/

#rb_tlw .layerordertypewrap:hover .layerordertypewrap_title,
#rb_tlw .clayerlist_element_zone >.layerlist_element_innerwrap:hover .layerlist_element_alias,
#timeline .tllayerlist_element_zone >.layerlist_element_innerwrap:hover .layerlist_element_alias,
#rb_tlw .layerordertypewrap:hover .layerlist_element_level i,
#rb_tlw .clayerlist_element_zone >.layerlist_element_innerwrap:hover .layerlist_element_level i,
#timeline .tllayerlist_element_zone >.layerlist_element_innerwrap:hover .layerlist_element_level i { color: #b7bbc0; }


.tllayerlist_element_group>.layerlist_element_innerwrap>.context_left>.layerlist_element_level,
.layerlist_element ul li .layerlist_element_level { margin-left: 5px; }
.layerlist_element ul li ul li .layerlist_element_level { margin-left: 15px; }

#timeline .layerordertypewrap .layerlist_element_level i,
#rb_tlw .layerordertypewrap .layerlist_element_level i,
#timeline  .layerlist_element.withchildren>.layerlist_element_innerwrap .layerlist_element_level i,
#rb_tlw .layerlist_element.withchildren>.layerlist_element_innerwrap .layerlist_element_level i { display: inline-block; }



/* HIDE / SHOW LAYER GROUPS BASED ON SELECTED STATE */
.hide_top_row_layers .zone_top { display: none; }
.hide_middle_row_layers .zone_middle { display: none; }
.hide_bottom_row_layers .zone_bottom { display: none; }

.hide_free_layers .layerListContainer >li.not_zone_layer { display: none; }

.staticlayersview .hide_free_layers .layerListContainer >li.not_zone_layer { display: block !important; }


 /******************************
  - TIMELINE SETTINGS  -
******************************/
#timeline_settings {    display: none; vertical-align: top; position: absolute; left: 0px;z-index: 920; top:auto;bottom:0px;padding: 0px 320px 0px 0px; height:auto;; width:100%; box-sizing: border-box; min-width: 1071px}

#timeline {  height:75px; background:#202224;}

#timeline >.ui-resizable-n { height: 10px; }
#timeline.inResize >.ui-resizable-n:after,
#timeline >.ui-resizable-n:hover:after { content: " "; position: absolute;top: 3px;left:0px; width: 100%;height: 3px; background: #777b80; }
#tlLayerListWrap { height: 134px; box-sizing: border-box; position: relative;  }
#timeline_top_toolbar { position: relative; height: 36px;  z-index: 1600; background: #202224; }

.timeline_left_container,
.timeline_right_container { display: block; box-sizing: border-box; min-height: 36px; }

.timeline_left_container { width: 290px; position: absolute; top: 0px;left: 0px;padding-left: 10px; background: #202224;z-index: 1500}
.timeline_right_container { width: 16380px; margin-left: 310px;position: relative; }

#time_linear { height: 35px; background: #202224;position: relative; bottom:0px; width: 100%; vertical-align: bottom; border-bottom:8px solid transparent; box-sizing: border-box;}
#time_linear_canvas { height: 35px; width: 16380px; position: absolute;top: 0px;left: 0px; }
#time_linear:before { width: 20px; height: 1px; background: #323438; content: " "; position: absolute; left: -20px;bottom: -9px; }
#time_linear_offset { position: absolute;top: 0px;left: 0px; height:30px; width: 2400px; }


#timeline_top_toolbar .timeline_left_container  { height: 36px; vertical-align: bottom;  padding:0px 0px; line-height: 36px;border-bottom:1px solid #323438;}
#timeline_top_toolbar .timeline_right_container { height: 36px; vertical-align: bottom; line-height: 36px; border-bottom:1px solid #323438; background:#202224;}
#time_linear .rm_ms,
#time_linear .rm_sec,
#time_linear .rm_twosec { width: 1px;height: 4px; border-left: 1px solid #414244; position: absolute;bottom:1px; color: rgba(183,187,192,0.5); font-size: 10px; margin-bottom: 0px;   } 
#time_linear .rm_sec    { height: 16px;  vertical-align: bottom;  margin-bottom: 0px; }
#time_linear .rm_twosec { height: 16px;  vertical-align: bottom;  margin-bottom: 0px; }
#time_linear .rulertxt { position: absolute;top: -2px; left:11px;line-height: 15px; font-size:11px; width: auto;transform: translateX(-50%);}
#time_linear_hor_marker   { width:1px;height:100%;background:#ff0000;  position: absolute; top:0px;left:100px;z-index:800;}

.tl_gridmanagement_wrap,
.tl_magnifying_wrap,
.tl_multip_wrap,
.tl_playstop_wrap,
.tl_toolbar_wrap,
.layer_group_filter_wrap { display: inline-block; position:absolute; }


.tl_gridmanagement_wrap { right: 85px; top: 0px; }
.tl_magnifying_wrap { right: 55px; top: 0px; }
.tl_multip_wrap { right:25px; top:0px;}
.tl_playstop_wrap { right:0px; top:0px;}
.tl_toolbar_wrap {  right:25px;}
.layer_group_filter_wrap { left: 9px; top: 3px;  }

.tl_magnifying_wrap label_icon.ui_magnet { position: relative; top: 3px; }

#general_gridmanagement_wrap { display: none; position: absolute; top: -97px; width:300px; height: 63px;line-height: 35px;background: #202224;padding: 15px 15px;white-space: nowrap;border-radius: 4px; transform: translateX(-100px);}
#general_frame_magnif_wrap { display: none; position: absolute; top: -120px; width:250px; height: 95px;line-height: 35px;background: #202224;padding: 10px 15px;white-space: nowrap;border-radius: 4px; transform: translateX(-50%);}
#general_speed_factor_wrap { display: none; position: absolute; top: -55px; width:220px; height: 30px;line-height: 35px;background: #202224;padding: 10px 15px;white-space: nowrap;border-radius: 4px; transform: translateX(-50%);}
#general_speed_factor_wrap input[type="text"] { width: 60px; }

.closeme_tl_miniwrapper {     position: absolute; top: 2px;right: 2px;cursor: pointer;    height: 20px;width: 20px;line-height: 20px;text-align: center;}
.closeme_tl_miniwrapper i.material-icons { color: #fff; font-size: 15px; line-height: 20px !important; opacity: 0.5; }
.closeme_tl_miniwrapper:hover i.material-icons {  opacity: 1; }

.tl_gridmanagement_wrap.selected #general_gridmanagement_wrap,
.tl_magnifying_wrap.selected #general_frame_magnif_wrap,
.tl_multip_wrap.selected #general_speed_factor_wrap { display: block; }


#general_frame_magnif_wrap .radiooption,
#general_frame_magnif_wrap .radiooption div { display: block;position: relative}

#general_frame_magnif_wrap .radiooption .shortcuttext { right: 20px;color: #777c80;     position: absolute;width: 35px;text-align: left;}

.tl_multip_wrap.selected #tl_multiplicator i{ color: #fff; opacity: 1; }

#timeline_settings .basic_action_button#gsf_ok {  height: 30px;border-radius: 4px; margin-left: 5px; line-height: 30px; }
#timeline_settings .basic_action_button#gsf_ok:hover { background: #006dd2; }

.layer_g_filter label_icon { width: 25px; margin: 0px; cursor: pointer }
.layer_allcollaps,
.layer_g_filter { display: inline-block; }

.tl_gridmanagement_wrap.selected #tl_gridmanagement i { color: #fff !important; }


.layer_allcollaps { line-height: 30px !important; vertical-align: top; margin-left: 7px; cursor: pointer;color: #b7bbc0;   }
.layer_allcollaps:hover { color: #fff; }
.layer_allcollaps i { font-size: 20px;  }


#timeline_settings .basic_action_button { background: transparent;  border:none; border-radius: 0px;  width:30px; text-align:center; height:35px; line-height:35px; text-align:center; color:#777c80; text-transform: uppercase; font-weight: 400; font-size: 12px;box-sizing: border-box;margin:0px; padding:0px;}
#timeline_settings .basic_action_button i { font-size: 20px; margin:0px;}
#timeline_settings .basic_action_button:hover { color: #b7bbc0; border: none; }
#timeline_settings .basic_action_button:hover i.material-icons { color: #fff; }

.action_collection_wrap { position: relative; cursor: pointer; display:block;}
.action_collections { position: absolute; background: #2a2c2f;  top: 100%;left: 0px; display: none; width: 100%; box-shadow: 0px 10px 20px 0px rgba(0,0,0,0.5); padding: 5px; box-sizing: border-box }

.action_collection_wrap.showmore .action_collections { display: block; }

.action_collection_wrap.showmore {z-index:1000;}

.slide_timeline,
#tlLayerListWrap .layerListContainer { padding-left: 0px; }


.slide_timeline .slide_timeline_element,
.tllayerlist_element { background: #202224; line-height: 36px;  }

.nolayeravailable { background: #202224; min-height: 29px; line-height: 29px;  }
.slide_timeline_element .layerlist_element_innerwrap,
.tllayerlist_element .layerlist_element_innerwrap  { width: 16380px;min-height:36px;  border-bottom:1px solid #323438;box-sizing: border-box}

.slide_timeline_element .layerlist_element_innerwrap .context_left,
.tllayerlist_element .layerlist_element_innerwrap .context_left {  width: 290px; line-height: 36px; position: relative; background:#202224;z-index:1500;box-sizing: border-box; padding-left: 15px;height:35px;}
.tllayerlist_element .layerlist_element_innerwrap .context_left:after,
#the_fake_cl:after,
#the_st_cl:after,
.timeline_left_container:after { content: " "; right: -1px;top: 0px; height: 100%; background: #3f444a;width: 1px; position: absolute }


#timeline .layerlist_element_id,
#timeline .layerlist_element_mover,
#timeline .layerlist_element_type,
#timeline .layerlist_element_alias  { line-height: 36px;margin-right: 10px; max-width: 150px; overflow: hidden; white-space: nowrap}

/* NO LAYERS AVAILABLE TEXT */
.tllayerlist_element.nolayeravailable { margin-left: 10px; }
.tllayerlist_element.nolayeravailable .context_left { padding-left: 36px; }



.slide_timeline .layerlist_element_type {  margin-left:0px;}
.slide_timeline .slide_timeline_element .layerlist_element_alias,
.nolayeravailable .layerlist_element_alias {color:#b7bbc0; white-space: nowrap}

#rb_tlw .slide_timeline_element input[type=checkbox].simplechkbx,
#rb_tlw .tllayerlist_element input[type=checkbox].simplechkbx  { line-height: 36px;margin-top: 10px; }

#timeline_settings .slide_timeline .slide_timeline_element .material-icons,
#timeline_settings .layerListContainer .material-icons { line-height: 36px; font-size: 17px;  }


#timeline_settings #tl_trigger_slide_options { font-size: 15px; line-height: 36px; position: absolute; top: 0px; right: 8px; color: #777c80; cursor: pointer}
#timeline_settings #tl_trigger_slide_options:hover { color: #fff; }
/*#timeline_settings .slide_timeline .slide_timeline_element .material-icons { color: #5e35b1 !important; }*/

.stimeline { position: absolute;left: 310px; top: 0px;height: 35px;  background: #202224;width: 100%; border-bottom:1px solid #323438;  /**/}

.slide_timeline_element>.layerlist_element_innerwrap:hover .context_left,
.fake_tllayerlist_element>.layerlist_element_innerwrap:hover .context_left,
.tllayerlist_element>.layerlist_element_innerwrap:hover .context_left,
.slide_timeline_element.checked>.layerlist_element_innerwrap .context_left,
.tllayerlist_element.checked>.layerlist_element_innerwrap .context_left { color:#fff;}


.slide_timeline_element>.layerlist_element_innerwrap:hover .context_left,
.fake_tllayerlist_element>.layerlist_element_innerwrap:hover .context_left,
.tllayerlist_element>.layerlist_element_innerwrap:hover .context_left,
.slide_timeline_element.checked>.layerlist_element_innerwrap .context_left,
.tllayerlist_element.checked>.layerlist_element_innerwrap .context_left,

.slide_timeline_element .layerlist_element_innerwrap:hover .stimeline,
.tllayerlist_element .layerlist_element_innerwrap:hover .stimeline,
.tllayerlist_element.checked >.layerlist_element_innerwrap .stimeline,
.tllayerlist_element .layerlist_element_innerwrap:hover,
#the_slide_timeline:hover>.layerlist_element_innerwrap,
.tllayerlist_element.checked>.layerlist_element_innerwrap {  background: #0d0d0e; /*hoveredtimelinebg*/ }

.tllayerlist_element_zone >.layerlist_element_innerwrap:hover .context_left,
.tllayerlist_element_zone >.layerlist_element_innerwrap:hover .stimeline { background:#0d0d0e  }


 .tllayerlist_element .layer_has_action { width: 8px;height: 8px; position: absolute; top: 13px; left: 11px; border-radius: 4px; background: #f82c8e; display: none; }
 .tllayerlist_element.actionmarked .layer_has_action { display: block }

.timebox,
.timebox_idle { width: 60px;height: 17px; box-sizing: border-box; vertical-align: top; line-height: 17px; background: #121314; color: #fff; font-size: 12px;  text-align: center; top:10px; position: absolute; left:0px;}

.timebox_idle {
    background: #202224;
    box-shadow: 0px 0px 0px 1px #4f565f;
}

.inmove.timebox,
#currenttime.inmove .timebox,
.timebox span { display: inline-block; font-size: 12px; color: #fff; }
.timebox_marker { width: 0px; height: 4000px; border-left:1px solid rgba(255,255,255,0.1); background:transparent; position: absolute;left: 0px;top: 26px; }

#currenttime .timebox_idle { display: inline-block; }
#currenttime .timebox { display: none }
#currenttime.inmove .timebox_idle { display: none }
#currenttime.inmove .timebox { display: inline-block }


.slidelooptimemarker,
.fixedscrolltimemarker{  display:none; height:100%; width: 200px; background: rgba(63, 68, 74, 0.15); pointer-events: none; z-index: 1000; position: absolute; top: 0px;left:200px; }

#time_linear .slidelooptimemarker,
#fixedscroll_linear .fixedscrolltimemarker { height: 35px; }

#fixedscrolltimestart .timebox_marker,
#fixedscrolltimeend .timebox_marker,
#slidelooptimestart .timebox_marker,
#slidelooptimeend .timebox_marker { border-left: 1px solid #323438; top: 0px; z-index: 2; }

#slidelooptimestart .timebox_marker:after,
#fixedscrolltimestart .timebox_marker:after { content:" "; width: 0; height: 0; border-style: solid; border-width: 10px 10px 0 0; border-color: #3f444a transparent transparent transparent;  position:absolute; top:0px;left:0px;}
#slidelooptimeend .timebox_marker:after,
#fixedscrolltimeend .timebox_marker:after { content:" "; width: 0;height: 0;border-style: solid;border-width: 0 10px 10px 0;border-color: transparent #3f444a transparent transparent;  position:absolute; top:0px;right:0px;}

#hovertime .timebox_marker,
#frametime .timebox_marker { border-left-color: #006dd2; }
#hovertime .timebox,
#frametime .timebox { background: #006dd2; }

#currenttime .timebox { background: #202224;box-shadow: 0px 0px 0px 1px #4f565f; }
#currenttime .timebox_marker { border-left-color: transparent; }

#currenttime.inmove .timebox { background: #5e35b1; box-shadow: none; }
#currenttime.inmove .timebox_marker { border-left-color: #5e35b1; }


.covered .timebox_marker { display: none; }

#fixedscrolltimestart .timebox,
#fixedscrolltimeend .timebox,
#slidelooptimestart .timebox,
#slidelooptimeend .timebox,
#maxtime .timebox { color: #fff; background: #202224;box-shadow: 0px 0px 0px 1px #4f565f; top: 10px; line-height: 17px; height: 17px; left: 0px; position: absolute; }

#fixedscrolltimestart .timebox,
#fixedscrolltimeend .timebox,
#slidelooptimestart .timebox,
#slidelooptimeend .timebox {  display:none }

#fixedscrolltimeend .timebox
#slidelooptimeend .timebox { left: -60px; }

#fixedscrolltimestart .timebox,
#fixedscrolltimeend .timebox,
#slidelooptimestart .timebox,
#slidelooptimeend .timebox { z-index: 4; }

#fixedscrollimestart .timebox span,
#fixedscrollimeend .timebox span,
#slidelooptimestart .timebox span,
#slidelooptimeend .timebox span
#maxtime .timebox span { color: #fff; }

#fixedscrolltimestart,
#fixedscrolltimeend,
#slidelooptimestart,
#slidelooptimeend { pointer-events: none; display: none; }


#timeline.fixedscrollon .fixedscrolltimemarker,
#timeline.fixedscrollon #fixedscrolltimestart,
#timeline.fixedscrollon #fixedscrolltimeend,
#timeline.slideloopon .slidelooptimemarker,
#timeline.slideloopon #slidelooptimestart,
#timeline.slideloopon #slidelooptimeend { display: block; z-index:1;}

/* SLIDE LOOP EDIT MODE */
#timeline.fixedscrolledit #fixedscrolltimestart,
#timeline.fixedscrolledit #fixedscrolltimeend,
#timeline.slideloopedit #slidelooptimestart,
#timeline.slideloopedit #slidelooptimeend { pointer-events: auto; z-index: 10}

#timeline.fixedscrolledit #fixedscrolltimestart .timebox_marker,
#timeline.fixedscrolledit #fixedscrolltimeend .timebox_marker,
#timeline.slideloopedit #slidelooptimestart .timebox_marker,
#timeline.slideloopedit #slidelooptimeend .timebox_marker {border-color: #5e35b1; }

#timeline.fixedscrolledit #fixedscrolltimestart .timebox_marker:after,
#timeline.slideloopedit #slidelooptimestart .timebox_marker:after {border-color: #5e35b1 transparent transparent transparent}

#timeline.fixedscrolledit #fixedscrolltimeend .timebox_marker:after,
#timeline.slideloopedit #slidelooptimeend .timebox_marker:after {border-color:transparent #5e35b1 transparent transparent;}

#timeline.fixedscrolledit .fixedscrolltimemarker,
#timeline.slideloopedit .slidelooptimemarker {  background: rgba(94, 53, 177, 0.15); }

#timeline.fixedscrolledit #fixedscrolltimestart .timebox,
#timeline.fixedscrolledit #fixedscrolltimeend .timebox,
#timeline.slideloopedit #slidelooptimestart .timebox,
#timeline.slideloopedit #slidelooptimeend .timebox { display: block; }



/*#time_linear .rm_twosec:first-child { height: 26px; bottom: -10px; border-left: none}  310 insted of 290*/

#hovertime,
#frametime,
#currenttime,
#maxtime,
#fixedscrolltimestart,
#fixedscrolltimeend,
#slidelooptimestart,
#slidelooptimeend { position:absolute; left:0px; top:0px; cursor:pointer; z-index: 5}

#fixedscrolltimestart,
#slidelooptimestart { left: 200px; }
#fixedscrolltimeend,
#slidelooptimeend { left: 400px; }

#maxtime { z-index: 4; }

#fixedscrolltimeend,
#fixedscrolltimestart,
#slidelooptimeend,
#slidelooptimestart { z-index: 15; }

#frametime { pointer-events: none; z-index: 6; display: none}
#hovertime { pointer-events: none; z-index: 2; display: none}

#hovertime.hideme,
#frametime.hideme { display: none !important; }


/*** SINGLE TIMELINES ****/

.stimeline .frameswrap { position: absolute !important;height: 16px;top: 10px;left: 0px;  }
.stimeline .frameswrap framebg { position: absolute !important; top: 0px;left: 0px; height: 16px;/*background: #323438;*/ cursor: ew-resize;}

.frame_unvisible_start { position: absolute;top: -11px;left: -20px; width: 300px; background: #202224; opacity: 0.75; height: 37px; z-index: 100; pointer-events: none;  display:none;}
.tllayerlist_element.frame_1_indrag >ul .frame_unvisible_start { display: block; }

.frameswrap framewrap { position: absolute !important; top: 0px !important;left: 0px; min-width: 0px;height: 16px;background: #4f5660; border-radius:2px; cursor: ew-resize}
#the_slide_timeline .stimeline .frameswrap framebg,
#the_slide_timeline .stimeline .frameswrap framewrap { cursor: default; }
.frameswrap framewrap marker { background: #3f444a;position: absolute; left:auto;right:0px; top: 0px; height: 16px; border-radius:2px;}
.frameswrap framewrap.frame_frame_1 marker,
.frameswrap framewrap.frame1 marker,
.frameswrap framewrap:first-child marker { left: 0px; right:auto;}

.enable_on_frame_0,
.enable_on_frame_1,
.enable_on_frame_999 { visibility: hidden; height: 0px; width: 0px; opacity: 0; }

.show_on_frame_0,
.show_on_frame_1,
.show_on_frame_999 { display: none !important; }
.selected_frame_0 .hide_on_frame_0 { display: none !important; }
.selected_frame_0 .show_on_frame_0,
.selected_frame_1 .show_on_frame_1,
.selected_frame_999 .show_on_frame_999 { display: inline-block !important; }


.selected_frame_0 .enable_on_frame_0,
.selected_frame_1 .enable_on_frame_1,
.selected_frame_999 .enable_on_frame_999 { visibility: visible !important; height: auto; width: auto; opacity: 1; }

.selected_frame_0 #remove_keyframe,
.selected_frame_1 #remove_keyframe,
.selected_frame_999 #remove_keyframe { display: none; }
#le_keyframes_list_innerwrap { position: relative }


#remove_keyframe:hover { color: #fff !important; }

.frameswrap frameinfo { position: absolute;top: 2px;left: 50%;color: #fff;line-height: 12px;font-size: 11px;transform: translateX(-50%); font-weight: 400; pointer-events: none; z-index: 5}
.frameswrap framedelay { position: absolute; display:none;top: -17px;padding:0px 3px; border:1px solid transparent; color: #b7bbc0;line-height: 14px;font-size: 11px;transform: translateX(-100%); font-weight: 400; z-index: 3; pointer-events: none; background:#3f444a;}

.frameswrap endloop,
.frameswrap startloop { display:none; position: absolute; pointer-events: none; top: 0px; left:0px; line-height: 16px; font-size: 11px;background: #3f444a; color:#b7bbc0; border:1px solid #777c80;box-sizing: content-box; z-index:8; width:14px; height:14px;}
.frameswrap endloop { left:auto; right:0px;}

.frameswrap starloop.shifted { left: 17px !important; }

#timeline_settings .layerListContainer .frameswrap endloop i.material-icons,
#timeline_settings .layerListContainer .frameswrap startloop i.material-icons { line-height: 14px !important; font-size: 14px !important; width:14px;}

.frameswrap  framedelay.coloredbgover,
.frameswrap  framedelay.coloredbg { top: 0px !important;  display: block; }

.stimeline:hover .frameswrap framedelay,
.frameswrap framewrap.ui-draggable-dragging framedelay { display: block; }

framedelay.coloredbg { background: #3f444a; color:#b7bbc0; border:1px solid #777c80;box-sizing: border-box; font-weight: 600}
framedelay.coloredbgover { color:#b7bbc0; border:1px solid #777c80; }


#slide_frame_container framedelay { display: none !important; opacity: 0 !important; }

.checked >.layerlist_element_innerwrap .stimeline framedelay.coloredbg,
.checked >.layerlist_element_innerwrap .stimeline startloop,
.checked >.layerlist_element_innerwrap .stimeline endloop     {  background:#4f5660;border:1px solid #fff; color:#fff;}

framewrap:hover  startloop,
framewrap:hover  endloop,
.checked >.layerlist_element_innerwrap .stimeline framedelay.coloredbgover {  border:1px solid #fff; color:#fff;}

.frameswrap framewrap:hover startloop,
.frameswrap framewrap:hover endloop,
.frameswrap framewrap.selected startloop,
.frameswrap framewrap.selected endloop,
.frameswrap framewrap.selected,
.frameswrap framewrap.selected marker,
.frameswrap framewrap:hover,
.frameswrap framewrap:hover marker { background: #006dd2 !important; }


.inAnimationMode .frameswrap framewrap.frame_frame_1 { background: transparent !important; }



.inAnimationMode .frameswrap framewrap.frame_frame_1 ffafter  {  z-index:2; content:" "; position: absolute; top:0px; left:50%; height: 100%; width: 50%; background:#4f5660; border-radius: 0px 2px 2px 0px; box-sizing: border-box;}
.inAnimationMode .frameswrap framewrap.frame_frame_1 ffbefore {  z-index:2; content:" "; position: absolute; top:0px; left:0; height: 100%; width: 50%; background:#4f5660; border-radius: 2px 0px 0px 2px; box-sizing: border-box;margin-right:1px;}

.inAnimationMode .frameswrap framewrap.frame_frame_1.selected_0.selected ffbefore,
.inAnimationMode .frameswrap framewrap.frame_frame_1 ffbefore:hover {  background: #006dd2; }
.inAnimationMode .frameswrap framewrap.frame_frame_1.selected ffafter,
.inAnimationMode .frameswrap framewrap.frame_frame_1 ffafter:hover {  background: #006dd2; }

.inAnimationMode .frameswrap framewrap.frame_frame_1.selected_0.selected ffafter { background: #4f5660; border: none; }
.inAnimationMode .frameswrap framewrap.frame_frame_1.selected_0.selected ffafter:hover {  background: #006dd2 !important; }



.frameswrap framewrap.selected framedelay.coloredbg,
.frameswrap framewrap.selected framedelay.coloredbgover,
.frameswrap framewrap:hover  framedelay.coloredbg,
.frameswrap framewrap:hover framedelay.coloredbgover { border-color: #fff; background: #006dd2 !important; color: #fff; } 


/*#slide_frame_container .frameswrap framewrap {  background: #5e35b1; cursor:default;}*/
#slide_frame_container .frameswrap framewrap marker { background: #5e35b1; cursor:default;}





#timeline_collapser { display:none; z-index: 1700;line-height: 35px; background-color:#202224; font-size:11px; position: absolute; right: 0px;top: 0px; width: 35px;height: 35px; text-transform: uppercase; color: #777c80; cursor: pointer; text-align: center; }
#timeline_collapser i { margin: 0px; padding: 0px; width: 35px;height: 35px; font-size: 24px}
#timeline_collapser:hover { color: rgba(183,187,192,1); }
.inResize #timeline_collapser { display: none !important; }

#timeline > .ui-resizable-n { cursor: ns-resize; }

#timeline_settings #frametime { display: none; }
/*#timeline_settings.frame_in_drag #currenttime,*/
#timeline_settings.frame_in_drag #hovertime,
#timeline_settings.frame_in_drag #maxtime { display: none !important; }
#timeline_settings.frame_in_drag #frametime { display: block !important; }



/***********************************
 - LAYER ANIMATION PROGRESS  -
************************************/
#le_keyframes_list { position: relative; }
#layer_animation_progressbar { position: absolute; left: -14px; top: 0px; width: 6px; height: 100%; border: 1px solid #777c80; border-right: none; }
#layer_animation_progressarrow { position:absolute; left:0px; top:0px; transform:translateY(-50%); width: 0;height: 0;border-style: solid;border-width: 5px 0 5px 5px;border-color: transparent transparent transparent #ffffff; }
#layer_simulator_time { color: #777c80; display: inline-block; font-size: 12px; font-weight: 400; margin-left: 10px; line-height: 30px; vertical-align: top }

#layer_simulator { margin-top: 5px; margin-bottom: 0px; margin-right: 10px}
#layer_simulator i.material-icons { width: 30px !important; }

.group_loopsettings { display: none; }

.settingsmenu_wrapbtn,
.ts_wrapbrtn,
.loop_wrapbrtn { line-height: 30px;  text-align: center; color:#b7bbc0; font-size: 14px; font-weight: 400; display:inline-block; box-sizing: border-box; cursor:pointer; vertical-align: top;min-width: 69px; height: 30px; width:69px;margin-right:1px; margin-bottom:1px;background:#3a3e44;}  
.ts_wrapbrtn.notinuse,
.loop_wrapbrtn.notinuse { background:#35383d; color: rgba(183,187,192,0.4); }

#slide_maintranssettings_wrap .ts_wrapbrtn,
.settingsmenu_wrapbtn { width: 92px; }

#slide_maintranssettings_wrap .ts_wrapbrtn.disabled { opacity: 0.5; pointer-events: none; display: none; }

#layer_looping_wrap .settingsmenu_wrapbtn { width: 139px; }

.ssmbtn:hover,
.ssmbtn.selected,
.transtarget_selector:hover,
.transtarget_selector.selected,
.looptarget_selector:hover,
.looptarget_selector.selected { color: #fff; background: #006dd2; }


.ssm_content { display: none }

.ssm_content.selected { display: block; }

.ts_wrapbrtn.notinuse .transtarget_selector:hover,
.ts_wrapbrtn.notinuse .transtarget_selector.selected,
.loop_wrapbrtn.notinuse .looptarget_selector:hover,
.loop_wrapbrtn.notinuse .looptarget_selector.selected { background: transparent; }


.form_collector .form_inner_header #add_ltsel i { margin: 0px !important;  font-size: 20px; }


#layerframespeed_wrap,
#slideframespeed_wrap { position: relative }
#layerframespeed_sub,
#slideframespeed_sub { position: absolute; background: #2a2c2f; color: #777c80; height: 30px; top: 0px; right: 0px; width: 70px; line-height: 30px; z-index: 5; border-radius: 0px 4px 4px 0px; text-align: right; padding: 0px 10px; }


/***********************************
 - SLIDE BACKGROUND TRANSITIONS -
************************************/


#rb_tlw .transgroup,
#rb_tlw .latransgroup { width: 100%;height: auto;  cursor: pointer; position: relative;}
#rb_tlw .latransgroup .latransgroup_name,
#rb_tlw .transgroup .transgroup_name { line-height: 30px; background: #2a2c2f; color: #b7bbc0; font-size: 13px;  display: block; padding:0px 20px; border-radius: 4px; margin-bottom: 1px}

#rb_tlw .latransgroup.selected .latransgroup_name,
#rb_tlw .latransgroup:hover .latransgroup_name,
#rb_tlw .transgroup.selected .transgroup_name,
#rb_tlw .transgroup:hover .transgroup_name { color: #fff; }

#rb_tlw .latransgroup .inner_latransitions,
#rb_tlw .transgroup .inner_transitions { padding: 0px 0px; }

.animation_drop_arrow { display: block; position: absolute; right:0px; top: 0px; height: 30px; width: 30px;  border-left:1px solid #323438; text-align: center;}
.animation_drop_arrow i { color: #b7bbc0;  line-height: 30px !important; font-size: 20px;  transform: rotateZ(-90deg)}
#rb_tlw .latransgroup.selected .animation_drop_arrow i,
#rb_tlw .transgroup.selected .animation_drop_arrow i { color:#fff;transform: rotateZ(0deg) }


#transition_groups { margin-bottom: 25px; }


.dark_btn       { position: relative; border: none; background: transparent; color:#777c80; font-size: 13px; line-height: 23px; cursor: pointer;padding-left:5px;margin-bottom:5px; overflow: hidden; white-space: nowrap; }
.dark_btn.selected,
.dark_btn:hover {  color:#fff;}


.slide_trans_liste,
#layer_trans_targets,
.layer_trans_liste,
.layer_transliste,
.added_slide_transition { background:#3a3e44; color:#b7bbc0; border-radius: 4px; line-height: 30px;padding:0px 10px;margin-bottom:1px;position: relative; cursor: pointer}

.slide_trans_liste { padding-right: 0px; padding-left:30px;}

.slide_trans_liste i.material-icons { float:right;margin-right:6px; font-size:18px }

.layer_transliste { background: #5e35b1; }

#layer_trans_targets,
.layer_transliste { padding: 0px; }

.layer_transliste >.right-divided-icon { font-size: 20px !important; }

.layer_trans_liste { padding: 0px 20px; }


.keyframe_list_title { text-transform: uppercase; font-size: 14px; color: #b7bbc0; font-weight: 800; line-height: 30px; display: inline-block; vertical-align: top;}
.keyframe_infotext { font-size: 12px; line-height: 30px; vertical-align: top; text-align: right; float:right; color:#777c80; font-weight: 400; margin-left: 15px; }
.keyframe_infotext i { font-size: 14px; margin-left: 5px }



#remove_keyframe,
#copy_keyframe,
#paste_keyframe  { cursor: pointer; }

#copy_keyframe:hover,
#paste_keyframe:hover  { color: #b7bbc0; }

#paste_keyframe { display: none; }

#rb_tlw .latransgroup.selected .inner_latransitions { display: block; }


.load_anim_value_wrap {  padding: 10px 20px 0px; }
.keyframe_liste  .load_anim_value_wrap { margin-left: -20px; }

.layer_trans_liste:hover,
.layer_trans_liste.selected,
.slide_trans_liste:hover,
.slide_trans_liste.selected,
.added_slide_transition.selected { background: #006dd2;}

.layer_transliste:hover { color: #fff; }

i.material-icons.rotateleft,
.layer_transliste i,
.latransgroup i { transform: rotateZ(-90deg) }


.layer_transliste_inner { background:#323438 }

.layer_transliste.open .layer_transliste_head i,
.latransgroup.open i { transform: rotateZ(0deg) }

.layer_transliste_head i.right-divided-icon { font-size: 20px !important }

.layer_transliste .layer_transliste_inner,
.latransgroup .lainner_transitions { display: none; }

.layer_transliste.open .layer_transliste_inner,
.latransgroup.open .lainner_transitions { display: block; }


#rb_tlw .layer_trans_liste .material-icons.right-divided-icon { display: none}
#rb_tlw .layer_trans_liste.selected .material-icons.right-divided-icon { display: block}

 
.right-divided-icon {  width: 30px; text-align: center; float: none;position: absolute; right: 0px;top: 0px; z-index: 3; font-size: 15px !important; border-left: 1px solid #323438; }
.added_slide_transition .right-divided-icon:hover { transform: scale(1.2); transform-origin: 50% 50%; }

li.added_slide_transition.selected>i.transition-remove { border:none !important;}

li.added_slide_transition >i.transition-replace { color:rgba(255,255,255,0.75); position: absolute;right: 30px;width: 50px; text-align: right; opacity: 0; cursor: pointer; border-right: 1px solid rgba(0,0,0,0.2);padding-right: 10px;background: transparent; opacity:0;}
li.added_slide_transition:hover >i.transition-replace { opacity:1;}
li.added_slide_transition >i.transition-replace:hover { color:rgba(255,255,255,1);}

.dark_btn .material-icons { font-size: 14px }

.sm-updown {     width: 10px;height: 23px;vertical-align: top;display: inline-block;line-height: 23px;margin-right: 5px}


#latransition_selector_in .sm-updown,
#latransition_selector_out .sm-updown,
#transition_selector .sm-updown { display: none; }


#latransition_selector_in,
#latransition_selector_out { display: none; }

#layer_transliste_0,
#layer_transliste_999 { width: 280px;  display:none;}

.keyframe_liste.open #layer_transliste_0,
.keyframe_liste.open #layer_transliste_999 { display: block; }


.keyframe_CP_wrap { opacity: 0; background: transparent; width: 18px; height:30px; position: absolute; right: 100%; top:0px; color: #b7bbc0; }
.keyframe_CP_toggle { background: #3a3e44; width: 10px; height: 30px; border-radius:4px; position: absolute; left: 0px; top: 0px; text-align: center;   line-height:30px; cursor: pointer; }
#rb_tlw .keyframe_CP_wrap i.material-icons { transform: translateX(-4px); font-size: 16px;  }
#rb_tlw .keyframe_CP_wrap:hover i.material-icons { color: #fff; }

#frame_copypaste_tool { background: transparent; width: auto; padding-right:275px ; height: 30px; right: 20px; box-shadow: 5px 5px 10px rgba(0,0,0,0.5); position: fixed; display: none; z-index: 100000; border-radius: 4px; }
.copyframe,
.pasteframe { padding: 0px 10px 0px 15px; background:#3a3e44; display: inline-block; vertical-align: top; line-height: 30px; color: #b7bbc0; font-size: 12px; font-weight: 500; border-radius:4px 0px 0px 4px; cursor: pointer; }

.pasteframe { color: #777c80; pointer-events: none; padding:0px 20px 0px 0px; border-radius:0px;}
.copy_and_paste .pasteframe { pointer-events: auto; color: #b7bbc0; }

.copyframe:hover,
.pasteframe:hover { color: #fff; }
.keyframe_liste:hover .keyframe_CP_wrap { opacity: 1; }


#keyframe_list_el_frame_1 .keyframe_CP_wrap { display: none !important;}
 

.keyframe_liste_inner { color:#b7bbc0; line-height: 30px;padding:0px 0px;margin-bottom:1px; z-index: 1; position: relative; display: block !important; box-sizing: border-box}
.keyframe_liste:first-child .keyframe_liste_inner,
.keyframe_liste:last-child .keyframe_liste_inner { width: 280px; }
.keyframe_liste { z-index: 1; position: relative; cursor: pointer}
.keyframe_liste { padding-left: 0px; margin-bottom: 0px; position: relative }
.frame_list_id { background: #3a3e44; display: inline-block; width: 60px; font-weight: 800; vertical-align: top; line-height: 30px;  text-align: center; font-size:13px; border-radius: 4px}
.frame_list_id i.material-icons { font-size: 20px !important; margin-left: 5px}
.frame_list_eview { border-radius: 4px;display: inline-block; width: 30px; vertical-align: top; line-height: 30px; text-align: center; font-size: 13px; position: absolute;right:0px;top:0px; background: #3a3e44; cursor: pointer}
.frame_list_eview i.material-icons { line-height: 30px !important;  font-size: 14px; color:#777c80;}



#le_keyframes_list_innerwrap .frame_list_id { text-align: right }

.frame_list_id:hover,
.slideanim_preset:hover { color: #fff; }

.keyframe_liste.keyframe_liste_dyn:nth-child(1) .keyframe_liste_inner .frame_list_title { text-align: center;width: 108px;box-sizing: border-box;  white-space: nowrap;overflow: hidden;}
.keyframe_liste.keyframe_liste_dyn:nth-child(2) .keyframe_liste_inner .frame_list_title { text-align: center;width: 107px;box-sizing: border-box; white-space: nowrap;overflow: hidden; border-radius: 0px 4px 4px 0px}

.frame_list_title i.material-icons {position: absolute;left: 10px;font-size: 14px !important;}


.keyframe_liste.keyframe_liste_dyn:nth-child(1),
.keyframe_liste.keyframe_liste_dyn:nth-child(1) .keyframe_liste_inner {  width: 173px !important;   }
.keyframe_liste.keyframe_liste_dyn:nth-child(2),
.keyframe_liste.keyframe_liste_dyn:nth-child(2) .keyframe_liste_inner {  width: 107px !important;  }

#le_keyframes_list_innerwrap li:nth-child(2) { position: absolute; left: 173px; top: 0px; }
#le_keyframes_list_innerwrap li:nth-child(2) .frame_list_id { display:none !important;}

#le_keyframes_list_innerwrap li:nth-child(1) .frame_list_title { border-radius: 4px 0px 0px 4px }
#le_keyframes_list_innerwrap li:nth-child(2) .frame_list_title { margin: 0 !important;  border-radius:0px 4px 4px 0px; border-left:2px solid #323438}


.frame_list_eview:hover  i.material-icons,
.frame_list_eview.selected  i.material-icons { color: #b7bbc0;}

.frame_list_eview.selected  i.material-icons { font-size:16px;}

.frame_list_title { overflow:hidden; padding: 0px 10px; display: inline-block; vertical-align: top; line-height: 30px;  font-weight: 400; font-size:13px; background: #3a3e44; width:215px; box-sizing: border-box; margin-left:5px; border-radius: 4px; text-align: center; position: relative}
.frame_list_title.with_icon { padding: 0px 10px 0px 30px; }
.keyframe_liste_inner .frame_list_title { display: inline-block; }

._TPRB_ .add_frame_after,
._TPRB_ .add_frame_before { display:none; cursor:pointer; position: absolute; padding:0px; right: 0px; bottom: -10px; width: 20px;height: 20px;  border-radius: 10px; background:#006dd2;  line-height: 20px; text-align: center; color:#fff; margin:0px; box-shadow: 0px 0px 10px 1px rgba(0,0,0,0.35)}

._TPRB_ .add_frame_after:after,
._TPRB_ .add_frame_before:after { content: " ";  width: 0;height: 0;border-style: solid;border-width: 10px 13px 10px 0;border-color: transparent #006dd2 transparent transparent; position: absolute;left:-7px;top:0px;z-index: 1;}
._TPRB_ .add_frame_before { top: -11px; bottom: auto; }

._TPRB_ .add_frame_after i.material-icons,
._TPRB_ .add_frame_before i.material-icons { line-height: 20px !important; font-size: 16px;  margin:0px; color:#fff;z-index: 2;position: relative}


._TPRB_ .add_frame_after:hover,
._TPRB_ .add_frame_before:hover { background: #006dd2;}

#le_keyframes_list_innerwrap,
#le_keyframes_list_innerwrap_in,
#le_keyframes_list_innerwrap_out { margin: 0px; padding: 0px; }

.frame_list_title:hover { color: #fff; }
.keyframe_liste.selected .keyframe_liste_inner .frame_list_title,
.slideanim_preset:hover,
.slideanim_preset.selected { background: #006dd2; color: #fff; }

.keyframe_liste:hover { z-index: 30 !important; overflow: visible; }

.keyframe_liste_inner:hover .add_frame_after,
.keyframe_liste_inner:hover .add_frame_before { display: block; }

#form_layer_animation .blocksfxanim { display: none; }
#form_layer_animation .nosfxanim { display: block; }


#form_layer_animation .blockfromleft .blocksfxanim,
#form_layer_animation .blockfromright .blocksfxanim,
#form_layer_animation .blockfromtop .blocksfxanim,
#form_layer_animation .blockfrombottom .blocksfxanim,
#form_layer_animation .blocktoleft .blocksfxanim,
#form_layer_animation .blocktoright .blocksfxanim,
#form_layer_animation .blocktotop .blocksfxanim,
#form_layer_animation .blocktobottom .blocksfxanim { display: block; }

#form_layer_animation .blockfromleft .nosfxanim,
#form_layer_animation .blockfromright .nosfxanim,
#form_layer_animation .blockfromtop .nosfxanim,
#form_layer_animation .blockfrombottom .nosfxanim,
#form_layer_animation .blocktoleft .nosfxanim,
#form_layer_animation .blocktoright .nosfxanim,
#form_layer_animation .blocktotop .nosfxanim,
#form_layer_animation .blocktobottom .nosfxanim { display: none; }


/* CUSTOM ANIAMTION SAVING PROCESSES */

.custom_layer_animation_toolbar { position: absolute; top: 0px; right: 5px; height: 30px; text-align:right; z-index: 10; display:none;}
.presets_listelement:hover .custom_layer_animation_toolbar,
.layer_trans_liste:hover .custom_layer_animation_toolbar  { display: block }

.custom_layer_animation_toolbar .material-icons { line-height:  30px !important; width:25px; text-align: center; display: inline-block; cursor: pointer; font-size: 16px; color:rgba(255,255,255,0.5);}
.custom_layer_animation_toolbar .material-icons:hover { color: #fff; }

.cla_message,
.cla_entername,
#rb_tlw .custom_layer_animation_toolbar .material-icons.cla_answer_yes,
#rb_tlw .custom_layer_animation_toolbar .material-icons.cla_answer_no { display: none; }

.cla_message,
.cla_entername { width:200px; top:0px; left:0px; height: 30px; line-height: 30px; position: absolute;}

.cla_message { padding: 0px 20px; box-sizing: border-box; background: #006dd2; width: 100%; z-index: 2; }

.cla_showmessage .cla_message,
#rb_tlw .cla_showmessage .custom_layer_animation_toolbar .material-icons.cla_answer_yes,
#rb_tlw .cla_showmessage .custom_layer_animation_toolbar .material-icons.cla_answer_no  { display: inline-block; }

.cla_showentername .custom_layer_animation_toolbar,
.cla_showmessage .custom_layer_animation_toolbar { display: block; }

.cla_showentername .cla_entername,
#rb_tlw .cla_showentername .custom_layer_animation_toolbar .material-icons.cla_answer_yes,
#rb_tlw .cla_showentername .custom_layer_animation_toolbar .material-icons.cla_answer_no  { display: inline-block; z-index: 5;}

#rb_tlw .cla_showmessage .custom_layer_animation_toolbar .material-icons.edit_custom_layeranimation,
#rb_tlw .cla_showmessage .custom_layer_animation_toolbar .material-icons.save_custom_layeranimation,
#rb_tlw .cla_showmessage .custom_layer_animation_toolbar .material-icons.delete_custom_layeranimation,
#rb_tlw .cla_showentername .custom_layer_animation_toolbar .material-icons.edit_custom_layeranimation,
#rb_tlw .cla_showentername .custom_layer_animation_toolbar .material-icons.add_custom_layeranimation,
#rb_tlw .cla_showentername .custom_layer_animation_toolbar .material-icons.save_custom_layeranimation,
#rb_tlw .cla_showentername .custom_layer_animation_toolbar .material-icons.delete_custom_layeranimation { display: none }


 #rb_tlw .cla_showentername input.cla_entername { width: 100%; padding: 0px 20px; box-sizing: border-box; box-shadow: none; border: none; outline: none; color: #fff; background: #006dd2 !important; z-index: 2;}


#all_layer_loop_animation .frame_list_id { display: none; }
#all_layer_loop_animation .frame_list_title { width: 100%; margin: 0px; }

#layer_simulator_loop { position: absolute }


/**************************
  COMMON PRESET ELEMENTS
**************************/

.presets_liste { background: #3a3e44;
    color: #b7bbc0;
    border-radius: 4px;
    line-height: 30px;
    padding: 0px;
    margin-bottom: 1px;
    position: relative;
    cursor: pointer;
    margin-bottom: 20px;
}

.presets_liste_title { padding: 0px 10px;
    display: inline-block;
    vertical-align: top;
    line-height: 30px;
    font-weight: 400;
    font-size: 13px;
    background: #3a3e44;
    width: 100%;
    box-sizing: border-box;
    /*margin-left: 5px;*/
    border-radius: 4px;
    text-align: center; 
}

.presets_liste.open  .presets_liste_title { color: #fff; }

.presets_liste i, .presetssgroup>i { transform:rotateZ(-90deg); border-top: 1px solid #323438; border-left:none;}

.custom_layer_animation_toolbar i { transform: rotateZ(0deg);border: none; }
.presets_liste.open .presets_liste_head>i { transform:rotateZ(0deg); border-left: 1px solid #323438; border-top:none;}
.presetssgroup.open>.presetssgroup_head>.animation_drop_arrow>i { transform:rotateZ(0deg); border:none;}


.presets_liste_head i.right-divided-icon { font-size:20px !important}
.presets_liste_inner { background: #323438; display:none}
.presets_liste.open .presets_liste_inner,
.presets_liste_inner.open { display:block}
#rb_tlw .presetssgroup { width: 100%;
    height: auto;
    cursor: pointer;
    position: relative;
}

.presetssgroup_name {
      line-height: 30px;
    background: #2a2c2f;
    color: #b7bbc0;
    font-size: 13px;
    display: block;
    padding: 0px 20px;
    border-radius: 4px;
    margin-bottom: 1px;
}

.presets_listelements { display:none}
.presetssgroup.open .presets_listelements { display:block}

.slide_trans_templates .presetssgroup_name {
  padding-left: 10px;
}


.modern_presets {
  width: 92px; display: inline-block; height: 60px; line-height: 20px; box-sizing: border-box; 
  margin-right: 1px; margin-bottom: 1px; text-align: center; border-radius: 6px;
}

.modern_presets .presets_liste_head { padding: 10px; box-sizing: border-box; }

.modern_presets .presets_liste_head .right-divided-icon  {  display: none !important; }
.modern_presets .presets_liste_head i.presets_liste_icon.material-icons { display: block !important;  font-size: 25px !important; line-height: 25px !important; transform: none !important; border: none !important; }
.modern_presets .presets_liste_head .presets_liste_title  {  display: block; text-align: center;  line-height: 18px; font-size:12px;}


.modern_presets:hover,
.modern_presets.open { background:#006dd2 !important; color: #fff; cursor: pointer}
.modern_presets.open .presets_liste_title,
.modern_presets:hover .presets_liste_title {  background:#006dd2 !important;}

.presets_listelement {     
  background: #3a3e44;
    color: #b7bbc0;
    border-radius: 4px;
    line-height: 30px;
    padding: 0px 20px;
    margin-bottom: 1px;
    position: relative;
    cursor: pointer;
}

.presets_liste_inner.modern_preset_list .presets_listelement {
    width: 139px;
    box-sizing: border-box;
    display: inline-block;
    vertical-align: middle;    
    padding: 5px 10px;
    font-size: 11px;
    /*white-space: normal;*/
    margin-right: 1px;
    line-height: 20px;
    margin-bottom: 1px;
    height: 30px;
    text-align: center;
    /*background: #232425;*/
}

.presets_liste_inner.modern_preset_list .presets_listelement.onefourth {
  width: 69px;
}


.presets_listelement:hover {
  background: #006dd2;
  color: #fff;
}

.preset_help_icon { font-size: 17px !important; line-height: 20px !important;  transform: none !important; border: none !important; }

.presetssgroup_head:hover .presetssgroup_name,
.presetssgroup_head:hover i { color: #fff; }


.modern_preset_list .nosubpresetlevel .presets_listelements,
.modern_preset_list .custompresetgroup .presets_listelements { display: block !important; }
.modern_preset_list .custompresetgroup .presets_listelements .presets_listelement { width: 100%; display: block; text-align: left; padding-left: 20px; }
.modern_preset_list .nosubpresetlevel .presetssgroup_head .animation_drop_arrow,
.modern_preset_list .custompresetgroup .presetssgroup_head .animation_drop_arrow { display: none; }
.blankpagelink { color: #b7bbc0; text-decoration: none; line-height: 25px; }
.blankpagelink:hover { color: #fff; text-decoration: underline }

#rb_tlw .selected_preset.material-icons { border:none !important; display: none; width: 20px; height: 20px; box-shadow: 0px 5px 15px 0px rgba(0,0,0,0.5); color: #fff; background: #006dd2; border-radius: 4px; position: absolute; pointer-events: none; top:5px; left:5px; transform:none !important; font-size: 15px;line-height: 20px;text-align: center;}

#rb_tlw .s_s_preset .presets_liste_head .selected_preset.material-icons { display: block }

.modern_preset_list .presets_listelement.dark_btn:hover { background: #40444A;  }

.modern_presets.presets_liste.slide_trans_templates.s_s_preset,
.modern_presets.presets_liste.slide_trans_templates.s_s_preset .presets_liste_title { background: #40444A; }
.modern_preset_list .presets_listelement.dark_btn.s_s_preset:hover,
.presets_listelement.dark_btn.s_s_preset { background: #006dd2; }

.modern_preset_list .presets_listelement.dark_btn:hover {  z-index: 20; box-shadow: 0px 0px 15px rgba(0,0,0,0.5); overflow: visible;}


#rb_tlw .s_s_preset .presets_liste_head { color: #fff !important; }

#rb_tlw .s_s_preset .presetssgroup_head .presetssgroup_name,
#rb_tlw .s_s_preset.presets_listelement.dark_btn,
#rb_tlw .s_s_preset .presets_liste_head { color: #fff !important }

.modern_preset_list .presets_listelement.dark_btn .preset_favorite { display:none !important;width: 20px; height: 30px; line-height:30px !important; font-size: 15px; text-align:center; background: #40444A; color: #fff; position: absolute;left: -18px; top: 0px; border-radius:4px 0px 0px 4px; border:none !important; transform:none !important;filter:brightness(110%);}
.modern_preset_list .presets_listelement.dark_btn.s_s_preset .preset_favorite { background: #006dd2; }
.modern_preset_list .presets_listelement.dark_btn.favright .preset_favorite { left:auto; right: -18px; top: 0px; border-radius:0px 4px 4px 0px; border:none !important; transform:none !important;}
.modern_preset_list .presets_listelement.dark_btn:hover .preset_favorite { display: block !important;  }

.modern_preset_list .presets_listelement.dark_btn .preset_favorite:hover { filter:brightness(130%); }


.showonlyfavoritpresets .modern_presets { pointer-events: none; opacity: 0.5; }
.showonlyfavoritpresets .modern_preset_list .presetssgroup { display: none; }

.showonlyfavoritpresets .modern_presets.prs_is_favorit { pointer-events: auto; opacity: 1;  }
.showonlyfavoritpresets .modern_preset_list .presetssgroup.prs_is_favorit { display: block; }

.showonlyfavoritpresets .presetelement.presets_listelement.dark_btn:not(.prs_is_favorit) { display: none }

/***********************
 - SLIDE LIST PICKER - 
************************/

#slidelist { padding: 0px; margin: 0px; list-style: none }

.slide_list_element {  display:block;box-sizing:border-box; position: relative; cursor: pointer; z-index:1; min-height:30px; width:300px; margin-bottom: 0px; line-height: 30px }
.slide_list_element i { display: inline-block; }
#slide_thumb_repeater { position: absolute; left: 300px; top: 0px; }
.sle_thumb          { display: none; box-sizing:border-box;width: 200px;height: 110px; background-size: contain; background-position: center center; /*position: absolute; top: 0px;left: 300px;*/ position: relative; box-shadow:0px 3px 10px 0px rgba(0,0,0,0.25);z-index: 1500;}
.sle_description    { white-space:nowrap; box-sizing:border-box;position:relative; display:inline-block; line-height:30px; font-weight:500; vertical-align:top; background:transparent;color:#b7bbc0;font-size: 13px;text-align:left; width: 180px; overflow: hidden }


#slide_thumb_repeater .sle_thumb { display: block !important }
.sle_description i.material-icons { font-size: 16px; margin-right: 10px; }


#theslidermodule { background: #2a2c2f }

#theslidermodule .sle_thumb,
#newslide .sle_thumb { display: none !important; }


#theslidermodule,
#newslide { display: block; }

#theslidermodule .sle_thumb { background-position: center center; background-size: 108px 68px; background-repeat: no-repeat }

.sle_thumb i { position: absolute; left: 50%;top: 50%;  color: #006dd2; font-size: 40px; margin-left: -20px;margin-top: -5px; }

.slidetab_toolbox .addchildslide,
.slidetab_toolbox .editslide,
.slidetab_toolbox .deleteslide,
.slidetab_toolbox .publishedslide,
.slidetab_toolbox .unpublishedslide,
.slidetab_toolbox .duplicateslide { display:inline-block; font-size:13px; width:16px; margin-right:5px; color:#fff; opacity:0.5;}

.slidetab_toolbox .addchildslide { margin-right: 0px; font-size: 15px; }

.slidetab_toolbox i.material-icons { font-size: 13px; }
.slidetab_toolbox .addchildslide i.material-icons { font-size: 15px }


.slidetab_toolbox {  display:none; width:85px; height:30px;text-align:right; position: absolute;right: 0px; padding-right:10px;line-height: 30px;top: 0px;  z-index:1020;}
.rs-multilanguage_on .slidetab_toolbox { width: 102px; }
.slide_list_child_element .slidetab_toolbox, 
.slide_list_element .slidetab_toolbox {  background: linear-gradient(to right, rgba(63,68,74, 0) 0%,rgba(63,68,74,1) 20%,rgba(63,68,74,1) 100%);}
.slide_list_element.selected >.slide_elemenet_content .slidetab_toolbox,
.slide_list_child_element.selected >.slide_elemenet_content .slidetab_toolbox {  background: linear-gradient(to right, rgba(0,109,210, 0) 0%,rgba(0,109,210,1) 20%,rgba(0,109,210,1) 100%);}
.slide_list_child_element >.slide_elemenet_content:hover .slidetab_toolbox,
.slide_list_element >.slide_elemenet_content:hover .slidetab_toolbox { display: block; }
.slide_list_element:hover   { z-index: 15;}
.slide_list_element.selected {z-index: 10;}


.do_not_sort_slide_list_element.slide_list_element.selected >.sle_description,
.slide_list_child_element.selected >.slide_elemenet_content .sle_description,
.slide_list_child_element:hover >.slide_elemenet_content .sle_description,
.slide_list_element.selected >.slide_elemenet_content .sle_description,
.slide_list_element:hover >.slide_elemenet_content .sle_description  { color: #ffffff; }

.do_not_sort_slide_list_element.slide_list_element:hover,
#newslide:hover,
.slide_list_child_element >.slide_elemenet_content:hover,
.slide_list_element:hover >.slide_elemenet_content { background: #3f444a; }

.slide_elemenet_content { padding: 0px 20px;display:block;box-sizing:border-box; position: relative; cursor: pointer; z-index:1; min-height:30px; width:300px; margin-bottom: 0px; line-height: 30px }

.do_not_sort_slide_list_element.slide_list_element.selected,
.slide_list_child_element.selected >.slide_elemenet_content,
.slide_list_element.selected >.slide_elemenet_content { background: #006dd2; color: #fff; }

.main_mode_selector:hover { background: #3f444a; }

/*.slide_list_child_element:hover>.sle_thumb,
.slide_list_element>.slide_elemenet_content:hover>.sle_thumb { display:block;}*/

.addchildslide:hover,
.editslide:hover,
.deleteslide:hover,
.publishedslide:hover,
.unpublishedslide:hover,
.duplicateslide:hover { color:#fff !important; opacity: 1; }

.publishedslide i.material-icons.publishedicon { display: inline-block !important}
.publishedslide i.material-icons.unpublishedicon { display: none !important}

.unpublishedslide i.material-icons.publishedicon { display: none !important }
.unpublishedslide i.material-icons.unpublishedicon { display: inline-block !important}

#newslide,
.do_not_sort_slide_list_element.slide_list_element {  padding: 0px 20px; }
.slide_list_child_element >.slide_elemenet_content { background: #2a2c2f; margin-bottom: 0px;padding-left: 48px; }
.ui-sortable-helper .slide_list_child_element_wrap { display: none; }
.slide_list_element:hover .slide_list_child_element_wrap { display: block; }

li.slide_list_child_element { margin-bottom: 0px }


#builderView.slides_in_sort .slide_list_element .sle_thumb,
#builderView.slides_in_sort .slide_list_child_element { display: none }

#builderView.slides_in_sort .slide_list_element {height:30px; overflow: hidden;}


/**************************************
    HOVERED AND MARKED CONTAINERS
     - CRUMBS - 
**************************************/
.aable.hovered,
.markable.marked  { outline:1px solid #006dd2}


.layer_grid>.lg_topborder { width: 100%;height: 0px; z-index: 10000; position:absolute; top:-2px;left:0px; border-top:2px dashed #006dd2;}
.layer_grid>.lg_bottomborder { width: 100%;height: 0px; z-index: 10000; position:absolute; bottom:-2px;left:0px;border-bottom:2px dashed #006dd2;}
.layer_grid>.lg_leftborder { height: 100%;width: 0px; z-index: 10000; position:absolute; top:0px;left:-2px;border-left:2px dashed #006dd2;}
.layer_grid>.lg_rightborder { height: 100%;width: 0px; z-index: 10000; position:absolute; top:0px;right:-2px;border-right:2px dashed #006dd2;}

.nohiglightboxes .layer_grid>.lg_topborder,
.nohiglightboxes .layer_grid>.lg_bottomborder,
.nohiglightboxes .layer_grid>.lg_leftborder,
.nohiglightboxes .layer_grid>.lg_rightborder { opacity: 0 !important }

.tp-dialog { display: none; }

/********************
 - PROGRESS BAR -
********************/
#rev_progress_bar_wrap {width:100%;height:10px; position: absolute;top:auto;left:0px;bottom:0px;z-index:10; }
.rev_progress_bar { display:block;z-index: 20;box-sizing: border-box;background-clip: content-box;position: absolute; line-height:0px;width:100%;height:100%; }
.rev_progress_bgs { z-index: 15; box-sizing: border-box; width: 100%; position: absolute; height: 100%; top: 0px; left: 0px; }
.rev_progress_bg {  display:block;background-clip: content-box; position: absolute;width:100%;height:100%; }
.rev_progress_gap {  display:block;background-clip: content-box; position: absolute;width:100%;height:100%; }
#rev_progress_bar_wrap.deactivated { display: none !important; }



/********************************
  - FORM CONTAINERS -
**********************************/
/* FORM COLLECTOR */
.form_collector {  display: none; position: relative; cursor: default; width: 100%; z-index:100 }
.form_collector.hiddencollector { display: none !important }


#form_collector_flexible_modal.form_collector  { position: fixed; top: 50% !important; left: 50% !important; transform:translate(-50%, -50%) !important;z-index:100000;}
.form_collector.dropover:before { padding:1px;content:" ";position:absolute; top:-2px;left:-2px;width:100%;height:100%;border: 2px solid #006dd2;box-sizing: content-box}
.form_collector.removingtab:before { padding:1px;content:" ";position:absolute; top:-2px;left:-2px;width:100%;height:100%;border: 2px solid #ff0000;box-sizing: content-box}


.formcontainer            { z-index: 100; display: block; }


.form_collector .drag_handle_icon { cursor: context-menu;  }

.collectortabwrap { position: relative; z-index: 1000; width: 100%;height:40px; line-height: 50px;top: 0px;left: 0px;  cursor: move; }
.collectortab     { position: relative; display: inline-block; height:40px; line-height: 40px; color:#fff; padding:0px 10px;cursor: pointer; vertical-align: top; font-size: 15px; font-weight: 400}

.collectortab,
.form_collector .form_inner_header { padding-left: 15px; box-sizing: border-box; }
.form_inner_header.innerwrap_breakout { margin: 0px -20px; }

.collectortabwrap i {  font-size: 17px;margin-right: 10px; }


#addon_configuration_subpanel { display: block !important; padding: 30px 42px; box-sizing: border-box}
 
.incollector_mode .collectortabwrap { display: block; }

/* FORM CONTAINER */
.formcontainer{ width:100%;height:auto;vertical-align: top; position:relative;   box-sizing: border-box; border-radius:3px; top:0px;left:0px; z-index: 10;}


#__inmodal_formcontainerunderlay { display:none;position: fixed; top: 0px;left: 0px;width: 100%;height: 100%;background: #1b1c1d; opacity: 0.85; z-index: 999; }
.form_inner   { padding:30px;background:#ff0000;}

.form_header  { display:none;z-index:1;width:100%;line-height: 30px; padding:0px; font-size: 13px; color:#fff;  box-sizing: border-box; font-weight: 400; border-radius:3px 3px 0px 0px; white-space: nowrap; cursor: move} 


.open_close_slide,
.form_intoaccordion { display: block;  font-size:20px; width:100%; height:40px; position: absolute; top:0px; left:0px; text-align:left;  cursor: pointer; color:#000;z-index:1005;line-height: 40px; box-sizing: border-box; padding-left:6px;}


/***********************************************
 - GENERAL MODULE SETTINGS SPECIAL DROPDOWNS  -
************************************************/
.layer_settings_collector .collectortab,
.slide_settings_collector .collectortab,
.slider_general_collector .collectortab,
.nav_collector .collectortab { display: none }

.layer_settings_collector.collapsed .form_intoaccordion,
.slide_settings_collector.collapsed .form_intoaccordion,
.slider_general_collector.collapsed .form_intoaccordion,
.nav_collector.collapsed .form_intoaccordion { display: none }

.layer_settings_collector .collectortabwrap,
.slide_settings_collector .collectortabwrap,
.slider_general_collector .collectortabwrap,
.nav_collector .collectortabwrap { display: none }

.gso_wrap { background: #202224; padding: 20px 10px 15px; }
 
 .slide_submodule_trigger,
 .layer_submodule_trigger,
 .general_submodule_trigger,
 .nav_submodule_trigger {  width: 25%; display: inline-block; box-sizing: border-box; text-align: center; height: 35px; vertical-align: top; margin-bottom: 20px;color: #777c80; cursor: pointer; max-width:74px;}

 .slide_submodule_trigger i.material-icons,
 .layer_submodule_trigger i.material-icons,
 .general_submodule_trigger i.material-icons,
 .nav_submodule_trigger i.material-icons { font-size: 20px;  display: block !important; margin-bottom: 5px;  max-width: 74px}

 .gso_title {font-size: 12px; line-height: 13px; white-space: nowrap}

 .layer_submodule_trigger:hover,
 .layer_submodule_trigger.selected,
 .slide_submodule_trigger:hover,
 .slide_submodule_trigger.selected,
 .general_submodule_trigger:hover,
 .general_submodule_trigger.selected,
 .nav_submodule_trigger:hover,
 .nav_submodule_trigger.selected { color: #fff; }

  .layer_submodule_trigger:hover i,
 .layer_submodule_trigger.selected i,
 .slide_submodule_trigger:hover i,
 .slide_submodule_trigger.selected i,
 .general_submodule_trigger:hover i ,
 .general_submodule_trigger.selected i,
 .nav_submodule_trigger:hover i ,
 .nav_submodule_trigger.selected i{ color: #006dd2; }


.form_header_title {  line-height: 40px;padding:0px 10px;display: inline-block;border-right:1px solid #eee;border-bottom:1px solid #eee;margin-bottom: -1px;}
.form_inner_header { display: none; font-size: 14px; line-height: 40px; text-transform: capitalize; color:#777c80;padding: 0px 10px; background: #2a2c2f;  font-weight: 500;}

.layer_settings_collector .form_inner_header,
.slide_settings_collector .form_inner_header,
.slider_general_collector .form_inner_header,
.nav_collector .form_inner_header {  background: #3f444a; color: #b7bbc0; }


/*******************
- VALUE SLIDERS -
*******************/
.withvalslider { position: relative; display: inline-block;}
.rs_vswrap {border-radius:4px; height:5px; padding:10px 0px; width:100%; bottom:-2px; position:absolute; display: block; opacity:0; left:0px;box-sizing: border-box;}
.rs_vsdone { width: 0px; height: 2px; border-radius: 4px; background: #006dd2;position: absolute; left: 0px;top: 10px; }
.rs_vsrail { width: 100%; pointer-events:none; height:2px; border-radius: 4px; background: #2a2c2f;position: absolute; left: 0px;top: 10px; }
.rs_vspin { width: 9px; height: 9px; position: absolute; left: -2px;top: 6px; border-radius: 5px; background: #b7bbc0; cursor: pointer}

.withvalslider:hover .rs_vswrap,
.withvalslider.indrag .rs_vswrap { opacity:1}

.rs_vswrap:hover .rs_vspin,
.withvalslider.indrag .rs_vspin { background:#fff;}


/*******************+******
 - KEN BURN SIMULATION -
**************************/
#ken_burn_bg_setting_on #slide_bg_and_repeat_fit_wrap { display: none !important; }
#kenburn_timeline { background: #2a2c2f; border-radius:4px; height:5px; width:200px; position:relative; display: inline-block;  margin-top:10px; margin-bottom:10px;}
.pz_timedone { width: 0px; height: 5px; border-radius: 4px; background: #006dd2;position: absolute; left: 0px;top: 0px; }
.pz_pin { width: 9px; height: 9px; position: absolute; left: -2px;top: -2px; border-radius: 5px; background: #b7bbc0; cursor: pointer}
#kenburn_timeline:hover .pz_pin,
#kenburn_timeline.indrag .pz_pin { background: #fff; }
#kenburn_timeline { margin-right: 9px; }
#kenburn_simulator { margin-right: 4px; }

rs-pzimg-wrap { display: block; position: absolute }


/* FIXED POSITIONED FORMCOLLECTORS HAS DIFFERENT BEHAVIOR */


.form_collector .form_inner .form_intoaccordion { height: 40px; line-height: 40px;}
.form_collector .form_intoaccordion i { transform: rotate(0deg); position: absolute; right:4px; }

.open_close_slide i,
.form_collector .collapsed .form_intoaccordion i { transform: rotate(-90deg); }

.opened_slidetab .open_close_slide i { transform: rotate(0deg); }

.form_collector  .form_inner .form_intoaccordion i { transform: rotate(-90deg); }
.form_collector  .form_inner.open .form_intoaccordion i { transform: rotate(0deg); }



#the_container .form_collector .collectortabwrap { cursor: pointer; }
#the_container .form_collector .form_inner { display: block !important; padding:0px;position: relative; margin-bottom: 1px}

#the_container ._just_carousel_ .form_collector .form_inner._nvojcm_ { display: none !important;}
#the_container ._just_carousel_ .form_collector .form_inner ._nvojcm_ { display: none !important;}
#the_container .form_collector .form_inner.hide_while_empty { display: none !important; }


#the_container ._just_carousel_ .form_collector .form_inner #sr_size_width_d,
#the_container ._just_carousel_ .form_collector .form_inner #sr_size_width_n,
#the_container ._just_carousel_ .form_collector .form_inner #sr_size_width_t,
#the_container ._just_carousel_ .form_collector .form_inner #sr_size_width_m  { opacity: 0.3 !important; pointer-events: none !important; }

#the_container .form_collector .form_inner .collapsable { padding: 20px;display:none; position: relative}
#the_container .form_collector .form_inner.open .collapsable {  display:block;}

.form_collector .form_inner_header { display: block!important; cursor: pointer; }
.form_collector .form_inner_header .material-icons { font-size: 17px; margin-right: 15px; line-height: 40px }
#the_container .form_collector .form_menu_level_1 { display: none !important; }
#the_container .form_collector .form_closer { display: none !important; }

#the_container .form_collector .formcontainer.collapsed .form_inner { display: none !important; }

/* FORM MENUS */
.form_menu_level_1 { list-style: none; margin: 0px 0px 0px 0px; line-height: 20px; border-bottom: 1px solid #333;  display:block; padding:25px 25px 6px;border-top:1px solid #333;}
.form_menu_level_1 li { text-transform:uppercase;list-style: none; display: inline-block; line-height: 20px; color: #333; cursor: pointer;  font-weight: 400; margin: 0px 15px 0px 0px;padding: 0px 0px 0px;}

.form_menu_level_1 li:hover,
.form_menu_level_1 li.selected { color: #006dd2;  }

.form_menu_level_2 { list-style: none; padding: 0px;margin: 0px 0px 30px 0px; line-height: 20px;  display:block;}
.form_menu_level_2 li { box-sizing:border-box;position:relative;list-style: none; z-index:1;display: inline-block; line-height: 40px; font-size: 14px; font-weight: 500; border:1px solid #d4dce4; cursor: pointer; font-weight: 500; padding: 0px 20px; margin-right:-1px;}

.form_menu_level_2 li:first-child {  border-radius:3px 0px 0px 3px;}
.form_menu_level_2 li.last {  border-radius:0px 3px 3px 0px;}
.form_menu_level_2 li:hover,
.form_menu_level_2 li.selected { color: #006dd2; border-color: #7597b7; z-index:2;}

.form_menu_level_2 li>i { margin-right: 10px; font-size: 25px;  }


/* DISABLED THINGS */
.form_menu_level_2 li.disabled { opacity: 0.5; cursor: default }
.form_level_2_inner.disabled { position: relative; }
.form_level_2_inner.disabled:after { position: absolute; content: " "; width: 100%;height: 100%;top: 0px;left: 0px; background: rgba(255,255,255,0.5); cursor: default }


/* DARK FORMMENUS */
 .form_menu_level_1 {  border-color: #2a3441; background: #2f3a49}
 .form_menu_level_1 li { color: #8095a3;border-bottom:1px solid #2a3441; padding-bottom:6px;margin-bottom: -7px;}
 .form_menu_level_1 li:hover,
 .form_menu_level_1 li.selected { color: #fff;border-color: #006dd2; }

 .form_menu_level_2 { border-bottom: 1px solid #3e4a5a; display: inline-block; margin-bottom:15px;}
 .form_menu_level_2 li { color: #6d808e;border-color: #6d808e; font-size:12px; font-weight:600;padding:0px; border:none; border-bottom:1px solid transparent;margin-right:15px; line-height: 25px; margin-bottom:-1px;}
 .form_menu_level_2 li:last-child { margin-right: 0px; }
 .form_menu_level_2 li:hover,
 .form_menu_level_2 li.selected { color: #fff;border-color: #006dd2; }

.form_collector { border:none }

 .collectortab {color:rgba(183,187,192,1);}

.open_close_slide i,
 .collapsed .form_intoaccordion i,
 .collapsed .collectortab i,
 .collapsed .collectortab  { color:rgba(183,187,192,1); }

.slide_list_element:hover .open_close_slide i,
.open_close_slide:hover i { color: #fff; }

 .form_inner     { background: #202224 }
 #the_right_toolbar .form_inner { background: #323438; }

 .form_header_title,

 .collectortabwrap,
.form_collector:after { background: #3f444a; }


 .form_intoaccordion { color:#777c80; }

 .formcontainer>.form_intoaccordion { color: #b7bbc0; }

#the_container .formcontainer[data-hovered='on'] .collectortabwrap,

#the_container .formcontainer[data-hovered='on'] >.form_intoaccordion,
#the_container .form_collector div[data-hovered='on'] >.form_intoaccordion,
#the_container .formcontainer[data-hovered='on'] .collectortabwrap .collectortab {  color:#fff;}

#the_container .form_collector div[data-hovered='on']>.form_inner_header,
 #the_container .form_collector div[data-hovered='on']>.form_inner_header { color: #b7bbc0; }

 .collectortab:after { background: #2a3441; }
 .collectortab:hover:after,
 .collectortab.selected:after{ background:#202224 }
 .form_menu_inside.collectortab.selected:after { background: #2f3a49; }

.form_menu_inside { margin-bottom: 50px; }

.form_menu_inside.collapsed { margin-bottom: 0px; }
/* MAIN LIGHT FORMSETTINGS*/

#form_slidergeneral_module { height: 700px; background:#202224;box-sizing: border-box;   padding-top:48px;}

.__inmodal .form_header { display: block; background: #006dd2; height: 60px;line-height: 60px; }
.__inmodal .form_menu_level_1 {  border:none; background:#2a2c2f;width:220px; height:100%; position: absolute; top:0px;left:0px;box-sizing: border-box; padding:30px; z-index: 5}
.__inmodal .form_menu_level_1 li { display:block; color: #777c80; text-transform: capitalize; font-size: 17px; font-weight: 500; margin:0px; padding:0px; line-height:20px; margin-bottom: 22px; border: none; }
.__inmodal .form_menu_level_1 li:hover,
.__inmodal .form_menu_level_1 li.selected { color: rgba(183,187,192,1);}

.__inmodal .form_menu_level_2 { border: none; padding: 0px; background: transparent; margin-bottom: 20px; }
.__inmodal .form_menu_level_2 li { box-sizing: border-box;display: inline-block;color: #b7bbc0;font-size: 17px;line-height: 30px;font-weight: 500;cursor: pointer;margin-right: 28px;vertical-align: top; }
.__inmodal .form_menu_level_2 li:hover,
.__inmodal .form_menu_level_2 li.selected { color: #006dd2; border: none; }

.__inmodal .form_menu_level_2 li>i { color: #7597b7; }
.__inmodal .form_menu_level_2 li:hover >i,
.__inmodal .form_menu_level_2 li.selected >i {color:#006dd2}

.__inmodal.form_collector { border:none; width: 1040px; box-shadow: none; max-width: none; }

.__inmodal .collectortab   { background:#2a3441;  color:#8095a3; border-color:#2a3441;border-bottom-color:#2a3441;}

.__inmodal .form_inner { height: 595px; padding:30px; box-sizing: border-box; position: relative}

.__inmodal .form_header_title { padding: 0px 30px }
.__inmodal .form_header_title,
.__inmodal .collectortab:hover,
.__inmodal .collectortab.selected { background: #006dd2; border:none}

.__inmodal .form_header_title,
.__inmodal .form_menu_inside.collectortab.selected { background: #006dd2; border:none; line-height: 60px; font-size: 19px; font-weight: 500 }

.__inmodal .collectortabwrap,
.__inmodal.form_collector:after { background: #2a3441; }

.__inmodal .form_intoaccordion { color: #fff; font-size: 30px; top: 5px;right: 10px;}

.__inmodal .form_intoaccordion:hover { color: #fff; }

.__inmodal .collectortab:after { background: #2a3441; }
.__inmodal .collectortab:hover:after,
.__inmodal .collectortab.selected:after{ background:#354151 }
.__inmodal .form_menu_inside.collectortab.selected:after { background: #2f3a49; }



/* QUICK GUIDE*/
#rbm_quickguide .mcg_page {display: none;width: 100%;height: 100%;position: absolute;top: 0px;left: 0px;box-sizing: border-box; padding:75px 120px;background-color:#212226;}
#rbm_quickguide .mcg_page.mcg_selected { display: block; }

#mcg_page_0_blurredbox,
#mcg_page_0 { background-image: url(../images/guide/guide.jpg); background-size:1202px 752px; background-position:center top; background-repeat: no-repeat;}
#mcg_page_0_blurredbox { z-index:2;filter: blur(10px);  border-radius:6px; overflow: hidden; opacity:0.90; position: absolute;top:-50px;left:-50px;width: 820px; height: 220px;  background-position: -190px -530px;}
.mcg_page_footer { z-index:2;position: absolute; border-radius:6px; overflow:hidden; top:580px; left: 240px; width: 720px;height: 120px; box-shadow: 0px 20px 25px rgba(0,0,0,0.4);}

.mcg_o_title { color: #fff; font-size: 20px; line-height: 25px; font-weight: 600; text-align: left;margin-bottom:25px;}
.mcg_o_title_gray { color: #767c80; font-size: 17px; line-height: 25px; font-weight: 500; text-align: left;margin-bottom:15px;}
.mcg_page_title { color: #fff; font-size: 30px; line-height: 35px; font-weight: 600; text-align: center;margin-bottom:55px;}
.mcg_o_descp { color: #777c80; font-size: 14px; line-height: 20px; font-weight: 400; text-align: left;}
.mcg_page_subtitle { color: #777c80; font-size: 20px; line-height: 25px; font-weight: 400; text-align: center;}

.mcg_option_third { width: 280px; margin-right: 50px; display: inline-block; text-align: left; vertical-align: top}

#rbm_welcomeModal .mcg_option_third { width: 296px; }
.mcg_option_third.last { margin-right: 0px; }

.mcg_video_preview { width: 280px; height: 160px; box-shadow: 0px 20px 40px rgba(0,0,0,0.35); background: #2e3033}

.mcg_footer_btns_right { position: absolute; bottom: 20px; left: 20px; width: 500px; text-align: left; display: block}
.mcg_footer_btns { position: absolute; bottom: 20px; right: 20px; width: 500px; text-align: right; display: block}
.mcg_page_minititle,.mcg_page_pagination { color:#767c80; font-size: 15px; display:inline-block;line-height: 30px; margin-right: 20px; font-weight: 400 }

i.rbm_close.material-icons:hover { color: #fff; }

#rbm_quickguide grayiconbox { background: #313437; }
#rbm_quickguide grayiconbox,
#rbm_quickguide blueiconbox { color: #fff !important; box-shadow: 0px 5px 10px rgba(0,0,0,0.3) }

/* LAYER ACTIONS */
#rbm_layer_action .rbm_content { min-height: 530px; display: table; width: 100%;  position: relative;background:#323438;}
#layeraction_list { display:none; height: 100%;width: 100%;  position: relative; background: #323438; z-index: 10; position: absolute; top:0px;left:0px;overflow: hidden;}
#action_inputs { display:none; position: absolute; top: 0px; left: 0px;padding: 30px; }

#no_action_added,
#no_action_selected { font-size: 15px; color: #b7bbc0; font-weight: 400; display: inline-block;  white-space: nowrap; overflow: hidden; position: relative; vertical-align: top; padding: 30px 20px; box-sizing: border-box; text-align: center}
#no_action_added .material-icons,
#no_action_selected .material-icons { vertical-align: top; font-size: 20px; margin-right: 10px; }

.mdl_group,
.lal_group { margin-bottom: 1px; padding-bottom: 5px; }



.mdl_group_header,
.lal_group_header { display: block; line-height: 30px; background: #3f444a; color:#b7bbc0; font-size: 14px; position: relative; padding:0px 10px; cursor: pointer; margin-bottom:5px;}

#rev_builder.inAnimationMode ._group_head_ { background: #5e35b1; }

.mdl_group_header i.fa__icons,
.mdl_group_header i.material-icons,
.lal_group_header i.material-icons { line-height: 30px; font-size: 17px; color: #b7bbc0; margin-right: 10px; cursor: pointer; }
.mdl_group_header i.material-icons.accordiondrop,
.lal_group_header i.material-icons.accordiondrop { margin: 0px; position: absolute; transform-origin: 50% 50%; right: 5px;top: 0px; width:23px; text-align:center; font-size: 22px; cursor:pointer; transform: rotate(180deg);}

.mdl_group_member,
.lal_group_member { display: block; line-height: 30px;  color:#b7bbc0;background: #3f444a; font-size: 14px; position: relative; padding:0px 10px; cursor: pointer}

.mdl_group .mdl_group_member,
.lal_group .lal_group_member { padding-left: 25px;background: #323438; }

.mdl_group_member i.material-icons,
.mdl_group_member i.fa__icons,
.lal_group_member i.material-icons { line-height: 30px; font-size: 17px;  margin-right: 10px; color:inherit;}

.mdl_group_member:hover,
.mdl_group_member.selected,
.lal_group_member:hover,
.lal_group_member.selected { background: #006dd2; color: #fff; cursor: pointer }

.mdl_group.closed .mdl_group_member,
.lal_group.closed .lal_group_member { display: none }

.mdl_group.closed .mdl_group_header i.material-icons.accordiondrop,
.lal_group.closed .lal_group_header i.material-icons.accordiondrop { transform: rotate(0deg); }

.la_settings { display: none; }

.mdl_placeholder_content,
.mdl_left_content,
.mdl_right_content { display: inline-block; width: 33%; vertical-align: top; }


 .mdl_placeholder_content {     height: 30px;overflow: hidden;position: relative; white-space: nowrap}
 
#mdl_group_wrap_menu { display: block; position: absolute; width: 700px; height: 50px; top: 0px; right: 50px; text-align: right; }
.mdl_group_wrap_menuitem { display: inline-block; line-height: 50px; height: 50px; padding: 0px 10px; cursor: pointer; vertical-align: top; }

.mdl_group_wrap_menuitem:hover { color: #fff; }
.mdl_group_wrap_menuitem.selected { background: #006dd2; color: #fff; }


.mdl_group_wrap { display: none; }
.mdl_group_wrap.selected { display: block; }

.mdl_group .mdl_group_member:last-child{ margin-bottom: 15px; }

#rbm_layer_metas .rbm_content { height: 400px; overflow: hidden; position: relative }


#layeractions_overview_innerwrap { padding: 20px 30px; height: 530px; display: block; box-sizing: border-box; position: relative; overflow:hidden;}
#layer_with_action_wrap { border: 1px dashed #006dd2; font-size: 14px; line-height: 25px; }
#layer_with_action { line-height: 30px; padding: 0px 10px;  }
#layer_with_action .lwa_layername { line-height: 30px; color: #fff; font-size: 14px; }
.lwa_icon.material-icons { color: #006dd2; font-size: 17px; margin-right: 10px; margin-left: 5px}


ul.layer_depending_wrap .drop_dependencies i { position: relative; transform-origin: "50% 50%" }

#layer_width_action_inner_wrap { padding: 0px;border-top: 1px dashed #006dd2; display: none }
ul.layer_depending_wrap { margin:0px !important; display: none; padding-bottom: 10px} 
.opendeps ul.layer_depending_wrap { display: block; }
.opendeps #layer_width_action_inner_wrap { display: block; }
.opendeps .drop_dependencies i.material-icons { transform: rotateZ(180deg); }

li.layer_depending_on { line-height: 35px; padding: 0px 15px; margin: 0px;border-bottom: 1px dashed #006dd2; }
.layer_depending_on .ldo_layername { line-height: 35px; color: #b7bbc0; font-size: 14px; display: inline-block;width: 120px;overflow: hidden;vertical-align: top;padding-right: 10px }
.drop_dependencies { line-height: 30px; color: #b7bbc0; font-size: 14px;  float:right; vertical-align: top; cursor: pointer;}
.layer_depending_on .ldo_actionname { line-height: 35px; color: #777c80; font-size: 14px;float: right;overflow: hidden;vertical-align: top;}
.ldo_icon.material-icons { color: #777c80; font-size: 17px; margin-right: 10px; }

ul#selected_layer_actions { margin: 10px 0px 0px; padding: 0px; }
li.single_layer_action { border: 1px dashed #f82c90; line-height: 30px; display: block; position: relative; padding: 0px 10px; cursor:pointer; margin-bottom:10px; margin-right:70px; box-sizing: border-box; height: 30px;}
.sla_icon.material-icons { color: #f82c90; font-size: 17px; margin-right: 10px; margin-left:5px; line-height: 30px; vertical-align: top }
.sla_layername { line-height: 30px; color: #fff; font-size: 14px; display: inline-block;vertical-align: top;     max-width: 130px;overflow: hidden;white-space: nowrap;}
.sla_actionname { line-height: 30px; color: #f82c90; font-size: 14px;  float:right; vertical-align: top;max-width: 130px;overflow: hidden;white-space: nowrap;}

.single_layer_action:hover,
.single_layer_action.selected { background:#f82c90; border:1px solid #f82c90;}

.frameActionOnOffOverview { padding-left: 15px; }
.frameActionOnOffOverview label_a { width: 151px !important; overflow: hidden; padding-right: 10px;  }

.single_layer_action.selected .sla_icon.material-icons,
.single_layer_action.selected .sla_layername,
.single_layer_action.selected .sla_actionname,
.single_layer_action:hover .sla_icon.material-icons,
.single_layer_action:hover .sla_layername,
.single_layer_action:hover .sla_actionname { color: #fff; }

i.material-icons.icon_in_dropdown { margin-right: 5px; color: #f82c90;font-size: 15px; vertical-align: top; line-height: 18px }

.single_layer_toolbar {  z-index:2; position: absolute; left: 100%;  top: -1px; line-height: 30px; width:70px;}

.single_layer_toolbar i.material-icons { vertical-align:top; color:#f82c90; height:30px; line-height:30px; width:30px; text-align:center; box-sizing:border-box;  margin-left: 5px; font-size: 17px; cursor: pointer; vertical-align: top; display: inline-block; border: 1px dashed #f82c90;display: inline-block }
.single_layer_toolbar i.material-icons:hover { border: 1px solid #f82c90; background:#f82c90; color:#fff;}

.single_layer_action:hover .single_layer_toolbar { display: block; }



/****************************************
  - RS LAYER IMPORT/EXPORT MANAGEMENT -
*****************************************/
#rbm_layerimport .rbm_content {  background: #2a2c2f; }
#rbm_layerimport_buttonwrap  { height: 30px; line-height: 30px; background: #2a2c2f; padding: 10px;position: relative }
#rbm_layerimport_list { position: relative; width: 100%; max-height: 500px; overflow: hidden;}

.layimpli_main_wrap { position: relative; display: block; width: 100%; }
.layimpli_group_wrap { position: relative; display: block; width:100%;}
.layimpli_element { background: #202224; line-height: 36px; border-bottom: 1px solid #323438; box-sizing: border-box; display: block; color: #b7bbc0; padding-left:20px; cursor: pointer}
.layimpli_element.disabled { opacity: 0.75; pointer-events: none }

.layimpli_element:hover { color: #fff; background: #3F444D }
.layimpli_level_0 { padding-left: 20px; }
.layimpli_level_1 { padding-left: 40px; }
.layimpli_level_2 { padding-left: 60px; }
.layimpli_icon { color: #006dd2; font-size: 17px; line-height: 36px; margin-right: 10px;  display: inline-block; }
.layimpli_icon_title,
.layimpli_icon_required,
.layimpli_icon_dimension { width: 200px;  font-size: 13px; font-weight: 500; display: inline-block; }

.layimpli_icon_required { color: #e8388f; }

.layimpli_icon_checbox { position: absolute; right: 10px; line-height: 36px !important; font-size:15px !important; width: 50px; text-align: center; vertical-align: top; display: inline-block;}


.layimpli_element.selected { background: #006dd2 !important; color: #fff !important; }

.layimpli_element.selected .layimpli_icon { color: #fff; }

#layers_import_feedback { position: absolute;left: 15px; line-height: 50px; font-size: 13px; color: #b7bbc0; top: 0px; }

/**********************************
  - RS ADDON MANAGEMENT -
***********************************/

#addon_overviewheader_wrap { padding:20px 55px 0px;width: 820px;position: absolute;top: 50px;left: 0px;z-index: 100;background: #000;box-sizing: border-box;background-color: #212226;}
#addon_overviewheader { border-bottom: 1px solid #333438;}

#rbm_addons { width: 1195px; }
#rbm_addonlist { width: 820px; height: 800px; background: #212226; position: relative;overflow: hidden; box-sizing: border-box; padding:100px 30px 30px; }
#rbm_addon_details {  width:375px; position: absolute; right:0px; top:50px; height:750px; overflow: hidden; box-sizing: border-box; }

.rs_ale { display: inline-block; width:190px; height:215px; position: relative; box-sizing: border-box; cursor: pointer;}

.rs_alethumb { width: 190px;height: 190px; position: absolute; top: 0px; left: 0px;box-sizing: border-box; z-index:2;}
.rs_alethumb_notinstalledimg,
.rs_alethumb_img { width: 190px; height: 190px; position: absolute; top: 0px; left: 0px; z-index: 10; background-size: 190px; background-position: top; background-repeat: no-repeat; }

.rs_alethumb_notinstalledimg { z-index: 12; background-position: bottom }

.rs_alecbg { width: 140px; height: 140px; position: absolute; top: 25px; left: 25px; background: #2b2c30; border-radius: 10px; box-sizing: border-box;} 
.rs_ale_title { font-size: 17px; color: rgba(255,255,255,0.5); font-weight: 500; width:100%; text-align: center; display: block; position: absolute; top: 183px; line-height: 30px; text-align: center; }
.rs_ale.selected .rs_ale_title { color: #fff; }

.rs_alethumb_title { font-size: 40px; line-height: 40px; color: #fff; position: absolute; top: 50%; left: 50%; transform: translateX(-50%) translateY(-50%); font-weight: 900 }

.rs_ale_notinstalled,
.rs_ale_enabled { background: #006dd2; line-height: 25px; padding: 0px 5px; font-size: 13px; color: #fff; font-weight: 800; position: absolute; top:15px; right:5px; z-index: 15; text-transform: uppercase; border-radius: 4px;}
.rs_ale_actionneeded { background: #ff0000; line-height: 25px; padding: 0px 5px; font-size: 13px; color: #fff; font-weight: 800; position: absolute; top:15px; right:5px; z-index: 15; text-transform: uppercase; border-radius: 4px;}

.rs_ale_notinstalled {  background: #3f444a; color: #74797d;  }

.rs_lib_premium_wrap  { position: absolute; top:5px; right:5px; z-index:300; width:auto !important; height:auto !important; font-family: "Roboto"}

#rs_premium { background:#2a2c2f;  padding:30px; margin:30px -20px 0px;display:none}
#rs_premium .rs_lib_premium_red,
#rs_premium .rs_lib_premium_red_hover,
#rs_premium .rs_lib_premium_lila { display:inline-block; margin-bottom:20px; padding:0px 8px}
.rs_premium_content{
    color: #777c80;
    font-size: 14px;
    font-weight: 400;
    line-height: 20px;
    display: block;
}

#rs_premium a { color:#777c80; opacity:1; text-decoration: underline;}
#rs_premium a:hover { color:#fff; opacity:1;}
.rs_lib_premium_lila,
.rs_lib_premium_red,
.rs_lib_premium_red_hover { display:none;background:#ff2021; line-height: 23px; padding: 0px 6px; font-size: 13px; color: #fff; font-weight: 600; position: relative; z-index: 15; text-transform: uppercase; border-radius: 4px;}
.rs_lib_premium_lila { background: #5c30af; display:block }

.sliderImage.tp_premium,
.noSliderImage.tp_premium { position:relative}
.noSliderImage.tp_premium { background:#e3e5e8; padding:15px;}
.sliderImage.tp_premium .rs_lib_premium_lila,
.noSliderImage.tp_premium .rs_lib_premium_lila,
.sliderImage.tp_premium .rs_lib_premium_red,
.noSliderImage.tp_premium .rs_lib_premium_red { 
  width:auto !important;
  height:auto !important;
  display:inline-block !important;
  vertical-align:top;
}

.tp_premium .rs_lib_premium_red { cursor: pointer;}

.noSliderImage.tp_premium .rs_lib_premium_wrap { position:relative; top:auto;right:auto; height:25px !important; vertical-align:top;}
.rs_n_ac_n .rs_lib_premium_lila { display:none}
.rs_n_ac_n .rs_lib_premium_red { display:block}
.rs_n_ac_n .rs_library_element:hover .rs_lib_premium_red,
.olibrary_item:hover .rs_n_ac_n .rs_lib_premium_red { display:none}
.rs_n_ac_n .rs_library_element:hover .rs_lib_premium_red_hover,
.olibrary_item:hover .rs_n_ac_n .rs_lib_premium_red_hover { display:block}

.rs_lib_premium_red_hover,
.rs_lib_premium_red  {  cursor: pointer; }

.rs_lib_premium_red_hover .material-icons,
.rs_lib_premium_red  .material-icons { margin-right:5px;  }

.rs_lib_premium_red:hover { filter:brightness(110%);}

.rbm_addon_details_inner { padding:30px 42px 30px;position: relative }

#decmod_maintxt,
.decmod_maintxt,
.ale_i_title { color: #fff; font-size: 15px; font-weight: 600; line-height: 35px;  }

#decmod_maintxt { line-height: 22px; margin-bottom: 10px; }

.ale_i_environment,
#decmod_subtxt,
.decmod_subtxt,
.ale_i_content { color: #777c80; line-height: 20px; font-weight: 400; font-size: 14px; }


#decmod_subtxt,
.decmod_subtxt { color:#b7bbc0 ; }


#decmod_subtxt strong { color: #fff; font-weight: 500 }

.ale_i_environment { margin-top: 15px; text-decoration: underline }

.ale_i_line { width: 100%; height: 1px; background: #3f444a;  }

.rbm_addon_details_inner row onehalf { padding-right: 10px; }

.ale_i_content i.material-icons { font-size: 14px;margin-right: 5px; }

.ale_yellow,
.ale_yellow i { color: #e67600; }

.ale_i_errorbutton { color: #fff; background: #e67600;  white-space: nowrap; cursor: default; pointer-events: none; }
.ale_i_errorbutton i { color: #fff; }

.ale_i_updateaddon.basic_action_coloredbutton { background: #5d36ad; }
.ale_i_allupdateaddon.basic_action_coloredbutton { background: #5d36ad; }

#check_addon_updates_wrap { position: absolute;left: 820px;top: 10px; }
#check_addon_updates,
#process_all_addon_updates { position: relative;display:inline-block;margin-right:10px }

.addonlist_to_update { display: block; font-size: 14px; line-height: 30px; position: relative; }
.addonlist_to_update_single_status { position: absolute; right: 4px; font-size: 16px; top:7px;}

.addonlist_to_update_single_status.circle-loader {  
  border: 1px solid rgba(255, 255, 255, 0.40);
   
  display: inline-block;
  vertical-align: top;
  border-radius: 50%;
  width: 15px;
  height: 15px;
}

.addonlist_to_update_single_status.circle-loader.inload {animation: loader-spin 1.2s infinite linear; border-left-color: #fff; }

.addonlist_to_update_single_status.load-complete {
  -webkit-animation: none;
  animation: none;
  border-color: rgba(255, 255, 255, 0.40);
  transition: border 500ms ease-out;
}

.addonlist_to_update_single_status .checkmark {display: none;}
.addonlist_to_update_single_status.load-complete .checkmark { display: block; }
.addonlist_to_update_single_status .checkmark.draw:after {
    animation-duration: 800ms;
    animation-timing-function: ease;
    animation-name: checkmark;
    transform: scaleX(-1) rotate(135deg);
  }
  
.addonlist_to_update_single_status .checkmark:after {
    opacity: 1;
    height: 8px;
    width: 3px;
    transform-origin: left top;
    border-right: 1px solid #fff;
    border-top: 1px solid #fff;
    content: '';
    left: 3px;
    top: 8px;
    position: absolute;
  }

.addonlist_to_update_single_status.failure .checkmark:after {
  content: "x";
  border: none;
  color: #ff0000;
  font-weight: 300;
  transform: scaleX(1.4) scaleY(1) rotate(0deg);
  top: -9px;
  left: 2px;
}

@keyframes loader-spin {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(360deg);
  }
}

@keyframes checkmark {
  0% {
    height: 0;
    width: 0;
    opacity: 1;
  }
  20% {
    height: 0;
    width: 3px;
    opacity: 1;
  }
  40% {
    height: 8px;
    width: 3px;
    opacity: 1;
  }
  100% {
    height: 8px;
    width: 3px;
    opacity: 1;
  }
}


/**********************************
  - REAL INPUT FIELD DEFAULTS -
***********************************/
.customsizes_chkbox   { display: none }



/**********************************
  - PREDROPS FIELD DEFAULTS -
***********************************/
.predrop_wrap { position: relative }
.predrop { width: 150px; position: absolute; top: 100%; background: #2b2c30; }
.predrop_ul { padding: 0px;margin: 0px; }
.predrop_li { line-height: 34px; display: block;height: 34px; padding: 0px 15px; margin: 0px; }
.predrop_unitselector { padding: 0px; }
.predrop_li .radiooption { float:left; width:50%; background: #35363a; display: block;  color: #b7bbc0; margin: 0px; text-align: center;box-sizing: border-box;  line-height: 34px}
.predrop_li .radiooption:first-child { border-right: 1px solid #2b2c30; }
.predrop_li .radiooption.selected { color: #fff; }

/***************************
  -   SLIDE THUMBNAILS  -
****************************/
.miniprevimage_wrap { width: 70px;height: 70px; position: relative; display: inline-block; box-sizing: border-box; background:#3a3e44; line-height: 70px; text-align: center; }
#rb_tlw .miniprevimage_wrap i.material-icons { color: #777c80; font-size: 45px }
.resettodefault.onlyicon { position: absolute; top: 0px;right: 0px; width: 20px;height: 20px; background:#2a2c2f; border-radius: 0px 0px 0px 5px !important }
#rb_tlw .miniprevimage_wrap .resettodefault.onlyicon i.material-icons { font-size: 15px; line-height: 20px !important; width: 20px;    }
#rb_tlw .miniprevimage_wrap .resettodefault.onlyicon:hover  i.material-icons { color: #fff !important; background: #006dd2; border-radius: 0px 0px 0px 5px !important}

#rb_tlw .miniprevimage_wrap.withimage i.material-icons { display: none; }
#navigation_purpose_thumbnail,
#layer_bg_image,
#slider_bg_image,
#layer_image_src,
#admin_purpose_thumbnail,
#admin_purpose_thumbnail_slider { width: 70px;height: 70px;display: block; box-sizing: border-box; position: absolute; top:0px; left:0px;}

#layer_image_src { background-size: contain; background-repeat: no-repeat; background-position: center center; }

/*************************
  - RULER STYLES -
*************************/
#ruler_top { width: 100%;height: 15px; background: #202224;position: absolute;left: 0px;top: -15px; overflow: hidden;z-index: 30; }
#ruler_top_offset { position: absolute;top: 0px;left: -1200px; height:15px; width: 3600px; }
#ruler_top .rm_five,
#ruler_top .rm_ten,
#ruler_top .rm_hundred { width: 1px;height: 4px; border-left: 1px solid #414243;; position: absolute;bottom:0px; color: rgba(183,187,192,0.5); font-size: 10px;  font-weight: 600;  } 
#ruler_top .rm_ten  { height: 4px;}
#ruler_top .rm_hundred { height: 15px;  line-height: 14px; vertical-align: bottom; width: 15px; padding-left: 2px; }
#ruler_hor_marker   { width:1px;height:15px;background:#f82c90;  position: absolute; top:-15px;left:100px;z-index:946;}


#ruler_left           { height: 100%;width: 15px; background: #202224;position: absolute;top: 0px;left: -15px; overflow: hidden; z-index:50;}
#ruler_left_top_cover { width:15px;height:15px;top:-15px;left:-15px;background:#202224;position: absolute ;z-index:65;}
#ruler_left_offset    { position: absolute;left: 0px;top: -1200px; width:15px; height: 3600px; text-align: right;}
#ruler_left .rm_five,
#ruler_left .rm_ten,
#ruler_left .rm_hundred { height: 1px;width: 4px; border-top: 1px solid #414243; position: absolute;right:0px; color: rgba(183,187,192,0.5); font-size: 10px;  font-weight: 600; } 
#ruler_left .rm_ten     { width: 4px;}
#ruler_left .rm_hundred { width: 15px;  line-height: 12px; vertical-align: top; padding-right: 6px; box-sizing: border-box;}
#ruler_ver_marker       { height:1px;width:15px;background:#f82c90;  position: absolute; left:-15px;top:100px;z-index:946;}

/*************************
 - GRID CANVAS -
 *************************/
 canvas#gridcanvas { pointer-events: none; width: 100%;height: 100%; z-index: 1000;position: absolute;top: 0px;left: 0px;  }

/********************************
  - DOTTED OVERLAYS -
*********************************/
._lc_video_overlay,
#slider_overlay                     { background-repeat:repeat;width:100%;height:100%;position:absolute;top:0px;left:0px;z-index:300; pointer-events: none;}



/***********************************
  -   NAVIGATION OVERWRITES  -
***********************************/
#rev_builder .tp-bullets,
#rev_builder .tp-bullets *{ box-sizing: content-box; }


/***********************************
  -   SLIDER UL SHADOWS  -
***********************************/
#shadow_faker   { width:100%;height:100%;top:0px;left:0px;background: transparent;z-index: -1;position: absolute;margin:auto;left:50%;transform:translateX(-50%); }


/***********************************
  - PERFECT SCROLLBAR -
************************************/
/* perfect-scrollbar v0.7.1 */
/*
.ps{-ms-touch-action:auto;touch-action:auto;overflow:hidden !important;-ms-overflow-style:none}@supports (-ms-overflow-style: none){.ps{overflow:auto !important}}@media screen and (-ms-high-contrast: active), (-ms-high-contrast: none){.ps{overflow:auto !important}}.ps.ps--active-x>.rs__scrollbar-x-rail,.ps.ps--active-y>.rs__scrollbar-y-rail{display:block;background-color:transparent}.ps.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail{background-color:#eee;opacity:.9}.ps.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail>.rs__scrollbar-x{background-color:#999;height:11px}.ps.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail{background-color:#eee;opacity:.9}.ps.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail>.rs__scrollbar-y{background-color:#999;width:11px}.ps>.rs__scrollbar-x-rail{display:none;position:absolute;opacity:0;-webkit-transition:background-color .2s linear, opacity .2s linear;-o-transition:background-color .2s linear, opacity .2s linear;-moz-transition:background-color .2s linear, opacity .2s linear;transition:background-color .2s linear, opacity .2s linear;bottom:0px;height:15px}.ps>.rs__scrollbar-x-rail>.rs__scrollbar-x{position:absolute;background-color:#aaa;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px;-webkit-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;-o-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;-moz-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -webkit-border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;bottom:2px;height:6px}.ps>.rs__scrollbar-x-rail:hover>.rs__scrollbar-x,.ps>.rs__scrollbar-x-rail:active>.rs__scrollbar-x{height:11px}.ps>.rs__scrollbar-y-rail{display:none;position:absolute;opacity:0;-webkit-transition:background-color .2s linear, opacity .2s linear;-o-transition:background-color .2s linear, opacity .2s linear;-moz-transition:background-color .2s linear, opacity .2s linear;transition:background-color .2s linear, opacity .2s linear;right:0;width:15px}.ps>.rs__scrollbar-y-rail>.rs__scrollbar-y{position:absolute;background-color:#aaa;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px;-webkit-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;-o-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;-moz-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -webkit-border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;right:2px;width:6px}.ps>.rs__scrollbar-y-rail:hover>.rs__scrollbar-y,.ps>.rs__scrollbar-y-rail:active>.rs__scrollbar-y{width:11px}.ps:hover.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail{background-color:#eee;opacity:.9}.ps:hover.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail>.rs__scrollbar-x{background-color:#999;height:11px}.ps:hover.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail{background-color:#eee;opacity:.9}.ps:hover.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail>.rs__scrollbar-y{background-color:#999;width:11px}.ps:hover>.rs__scrollbar-x-rail,.ps:hover>.rs__scrollbar-y-rail{opacity:.6}.ps:hover>.rs__scrollbar-x-rail:hover{background-color:#eee;opacity:.9}.ps:hover>.rs__scrollbar-x-rail:hover>.rs__scrollbar-x{background-color:#999}.ps:hover>.rs__scrollbar-y-rail:hover{background-color:#eee;opacity:.9}.ps:hover>.rs__scrollbar-y-rail:hover>.rs__scrollbar-y{background-color:#999}
*/

/* perfect-scrollbar v0.8.1 */
/*.ps{-ms-touch-action:auto;touch-action:auto;overflow:hidden !important;-ms-overflow-style:none}@supports (-ms-overflow-style: none){.ps{overflow:auto !important}}@media screen and (-ms-high-contrast: active), (-ms-high-contrast: none){.ps{overflow:auto !important}}.ps.ps--active-x>.rs__scrollbar-x-rail,.ps.ps--active-y>.rs__scrollbar-y-rail{display:block;background-color:transparent}.ps.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail{background-color:#eee;opacity:.9}.ps.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail>.rs__scrollbar-x{background-color:#999;height:11px}.ps.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail{background-color:#eee;opacity:.9}.ps.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail>.rs__scrollbar-y{background-color:#999;width:11px}.ps>.rs__scrollbar-x-rail{display:none;position:absolute;opacity:0;-webkit-transition:background-color .2s linear, opacity .2s linear;-o-transition:background-color .2s linear, opacity .2s linear;-moz-transition:background-color .2s linear, opacity .2s linear;transition:background-color .2s linear, opacity .2s linear;bottom:0px;height:15px}.ps>.rs__scrollbar-x-rail>.rs__scrollbar-x{position:absolute;background-color:#aaa;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px;-webkit-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;-o-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;-moz-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -webkit-border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;bottom:2px;height:6px}.ps>.rs__scrollbar-x-rail:hover>.rs__scrollbar-x,.ps>.rs__scrollbar-x-rail:active>.rs__scrollbar-x{height:11px}.ps>.rs__scrollbar-y-rail{display:none;position:absolute;opacity:0;-webkit-transition:background-color .2s linear, opacity .2s linear;-o-transition:background-color .2s linear, opacity .2s linear;-moz-transition:background-color .2s linear, opacity .2s linear;transition:background-color .2s linear, opacity .2s linear;right:0;width:15px}.ps>.rs__scrollbar-y-rail>.rs__scrollbar-y{position:absolute;background-color:#aaa;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px;-webkit-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, -webkit-border-radius .2s ease-in-out;-o-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;-moz-transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out;transition:background-color .2s linear, height .2s linear, width .2s ease-in-out, border-radius .2s ease-in-out, -webkit-border-radius .2s ease-in-out, -moz-border-radius .2s ease-in-out;right:2px;width:6px}.ps>.rs__scrollbar-y-rail:hover>.rs__scrollbar-y,.ps>.rs__scrollbar-y-rail:active>.rs__scrollbar-y{width:11px}.ps:hover.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail{background-color:#eee;opacity:.9}.ps:hover.ps--in-scrolling.ps--x>.rs__scrollbar-x-rail>.rs__scrollbar-x{background-color:#999;height:11px}.ps:hover.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail{background-color:#eee;opacity:.9}.ps:hover.ps--in-scrolling.ps--y>.rs__scrollbar-y-rail>.rs__scrollbar-y{background-color:#999;width:11px}.ps:hover>.rs__scrollbar-x-rail,.ps:hover>.rs__scrollbar-y-rail{opacity:.6}.ps:hover>.rs__scrollbar-x-rail:hover{background-color:#eee;opacity:.9}.ps:hover>.rs__scrollbar-x-rail:hover>.rs__scrollbar-x{background-color:#999}.ps:hover>.rs__scrollbar-y-rail:hover{background-color:#eee;opacity:.9}.ps:hover>.rs__scrollbar-y-rail:hover>.rs__scrollbar-y{background-color:#999}
*/

/*!
 * perfect-scrollbar v1.4.0  b7bbc0
 * (c) 2018 Hyunje Jun
 * @license MIT
 */
.rs__scrollbar-x-rail,.rs__scrollbar-y-rail{display:none;opacity:0;position:absolute}.ps{overflow:hidden!important;overflow-anchor:none;-ms-overflow-style:none;touch-action:auto;-ms-touch-action:auto}.rs__scrollbar-x-rail{transition:background-color .2s linear,opacity .2s linear;-webkit-transition:background-color .2s linear,opacity .2s linear;height:15px;bottom:0}.rs__scrollbar-y-rail{transition:background-color .2s linear,opacity .2s linear;-webkit-transition:background-color .2s linear,opacity .2s linear;width:15px;right:0}.ps--active-x>.rs__scrollbar-x-rail,.ps--active-y>.rs__scrollbar-y-rail{display:block;background-color:transparent}.ps--focus>.rs__scrollbar-x-rail,.ps--focus>.rs__scrollbar-y-rail,.ps--scrolling-x>.rs__scrollbar-x-rail,.ps--scrolling-y>.rs__scrollbar-y-rail,.ps:hover>.rs__scrollbar-x-rail,.ps:hover>.rs__scrollbar-y-rail{opacity:.6}.ps .rs__scrollbar-x-rail.ps--clicking,.ps .rs__scrollbar-x-rail:focus,.ps .rs__scrollbar-x-rail:hover,.ps .rs__scrollbar-y-rail.ps--clicking,.ps .rs__scrollbar-y-rail:focus,.ps .rs__scrollbar-y-rail:hover{background-color:#eee;opacity:.9}.rs__scrollbar-x,.rs__scrollbar-y{background-color:#aaa;border-radius:6px;position:absolute}.rs__scrollbar-x{transition:background-color .2s linear,height .2s ease-in-out;-webkit-transition:background-color .2s linear,height .2s ease-in-out;height:6px;bottom:2px}.rs__scrollbar-y{transition:background-color .2s linear,width .2s ease-in-out;-webkit-transition:background-color .2s linear,width .2s ease-in-out;width:6px;right:2px}.rs__scrollbar-x-rail.ps--clicking .rs__scrollbar-x,.rs__scrollbar-x-rail:focus>.rs__scrollbar-x,.rs__scrollbar-x-rail:hover>.rs__scrollbar-x{background-color:#999;height:11px}.rs__scrollbar-y-rail.ps--clicking .rs__scrollbar-y,.rs__scrollbar-y-rail:focus>.rs__scrollbar-y,.rs__scrollbar-y-rail:hover>.rs__scrollbar-y{background-color:#999;width:11px}@supports (-ms-overflow-style:none){.ps{overflow:auto!important}}@media screen and (-ms-high-contrast:active),(-ms-high-contrast:none){.ps{overflow:auto!important}}

#rev_builder .rs__scrollbar-x-rail { z-index:10; height:0px; background: transparent !important;opacity: 0.2;}
#rev_builder .ps--active-x .rs__scrollbar-x-rail { display: block; }
#rev_builder .rs__scrollbar-x { background: rgb(32, 34, 36); opacity:0.3; height: 9px; border-radius: 7px;  cursor: pointer;bottom: 8px; }
#rev_builder .rs__scrollbar-x:hover { opacity: 1; }


#rev_builder .rs__scrollbar-y-rail { z-index:10; height:0px; background: transparent !important; opacity: 0.2}
#rev_builder .ps--active-y .rs__scrollbar-x-rail { display: block; }
#rev_builder .rs__scrollbar-y { background: rgb(32, 34, 36); opacity:0.3; width: 9px; border-radius: 7px; right: 4px; cursor: pointer; }
#rev_builder .rs__scrollbar-y:hover { opacity: 1; }

#rev_builder:hover .rs__scrollbar-x-rail,
#rev_builder:hover .rs__scrollbar-y-rail { opacity: 1; }


#the_right_toolbar .rs__scrollbar-y-rail {   z-index: 1500; width: 15px; background: transparent !important; display: none !important; }
#the_right_toolbar .ps--active-y .rs__scrollbar-x-rail { display: block; }
#the_right_toolbar .rs__scrollbar-y {background: #b7bbc0; opacity:0.3; width: 9px; border-radius: 7px; right:7px; cursor: pointer;}
#the_right_toolbar .rs__scrollbar-y:hover { opacity: 1; }

#tlLayerListWrap .rs__scrollbar-x-rail { z-index: 1600;height:30px;opacity: 1 !important;background: linear-gradient(to bottom, rgba(32,34,36,0) 0%,rgba(32,34,36,1) 75%) !important;}
#tlLayerListWrap .ps--active-x .rs__scrollbar-x-rail { display: block; }

#tlLayerListWrap .rs__scrollbar-x {background: #b7bbc0; opacity:0.5; height: 8px; border-radius: 7px; bottom: 6px; cursor: pointer;display: block !important;  }
#tlLayerListWrap .rs__scrollbar-x:hover { opacity: 1; }


#rbm_layerimport_list .rs__scrollbar-y-rail,
#tlLayerListWrap .rs__scrollbar-y-rail {   z-index: 1600; width: 20px; background: #202224 !important;  }
#tlLayerListWrap .ps--active-y .rs__scrollbar-x-rail { display: block; }
#tlLayerListWrap .rs__scrollbar-y { background: #b7bbc0; opacity:0.5; width: 8px; border-radius: 7px; right:6px; cursor: pointer;}
#tlLayerListWrap .rs__scrollbar-y:hover { opacity: 1; }


#timeline .ui-resizable-handle.ui-resizable-s { background: #2a3441 !important; height: 10px; bottom: 0px; }







/*************************************************************
  -  PRESET WRAP AND PRESET CONTAINER FOR INPUT FIELDS  -
*************************************************************/
.input_presets_wrap { display: inline-block;position: relative; }
.input_presets_wrap.infocus { z-index: 200 }
.input_presets      { position: absolute; min-width: 100%; top:100%; margin-top:-10px; left:0px; background:#2a2c2f; display:none;box-shadow: 0px 10px 20px 0px rgba(0,0,0,0.5)}
.input_preset       { font-size: 13px; color: #b7bbc0; padding:6px 13px;  top:100%;width:auto; line-height:18px; cursor: pointer; white-space: nowrap;}
.input_preset:hover { background: #3f444a; color: #fff; }

oneshort .input_presets { right: 0px !important; left:auto !important; }

.ipwborder { border-bottom: 1px solid #323438; }

.input_presets_wrap.infocus .input_presets { display: block; margin-bottom:65px;}

.input_preset i.material-icons { font-size: 17px; margin-right: 10px !important;  }

.input_presets_dropdown {
    position: absolute;
    right: 0px;
    line-height: 30px !important;
    vertical-align: top;
    top: 0px;
    color: #777c80;
    font-size: 14px !important;
    border-left: 1px solid #323438;
    width: 15px !important;
    height: 30px !important;
    text-align: center;
    background: #2a2c2f;
    border-radius: 0px 4px 4px 0px;
    cursor: pointer;
  }

#active_transitions_settings .input_presets_dropdown { width: 30px !important; }

#responsive_infos_toolbar { min-width: 100px;  border-radius: 4px;  height: auto; line-height: 30px; color: #b7bbc0; background: #2a2c2f; font-size: 13px; padding:10px; box-sizing: border-box; position: absolute; z-index: 1000000; box-shadow: 0px 10px 20px 0px rgba(0,0,0,0.5)}
#responsive_infos_toolbar .material-icons { font-size: 17px; line-height: 30px !important; width: 20px; text-align: center; vertical-align: top; margin-right: 5px; }
#responsive_infos_toolbar .responsive_info_value { color: #b7bbc0; margin-right: 15px; display: inline-block; line-height: 30px; vertical-align: top; }
#responsive_infos_toolbar .int_inher_title { color: #777c80; }
/******************************
  -  WAIT A MINUTE  -
******************************/

#waitaminute      { box-sizing:border-box; -moz-box-sizing:border-box; display:none;position:fixed; top:0px; left:0px; z-index:10000000; background:#000; background:rgba(32,34,36,0.7); width:100%;height:100%;}
.waitaminute-message  { position:absolute; top:50%;width:100%;text-align: center; color:#fff; font-size:50px; font-weight: 600; line-height:60px; transform: translateY(-50%); font-family: "Open Sans",sans-serif;}

.waitaminute-message i.eg-icon-emo-coffee,
.waitaminute-message i.eg-icon-emo-coffee:before {  color:#fff !important;margin-bottom:15px;}




/******************************
 -  MEDIA FILTER GRID -
*******************************/
#inst-filter-grid { display: block; margin-top: 20px;   }


.inst-filter-griditem:hover {
    border: 3px solid #fff;
    padding: 0;
    box-sizing: border-box;
}

.inst-filter-griditem.selected,
.inst-filter-griditem.selected:hover {
    border: 3px solid #006dd2;
    padding: 0;
    box-sizing: border-box;
}

.inst-filter-griditem {
    cursor: pointer;
    position: relative;
    width: 52px;  /*69*/
    height: 52px;
    display: inline-block;
    margin-right: 5px;
    margin-bottom: 1px;    
}

#inst-filter-grid .inst-filter-griditem:nth-child(5n) {
  margin-right: 0px;
}

.inst-filter-griditem .ifgname {
   display: none;
}

.inst-filter-griditem-img {
    z-index: 2;
    width: 100%;
    height: 100%;
    background-size: cover;
    background-position: center center;    
    position: relative;
}


/******************************
 -  HTML LAYER STYLING  -
*******************************/
/*ACCESSOIRESS*/
._borders_        { position: absolute;background: #000; display:none;}
._tb_             { top: 0px;left:0px;height: 1px; width: 100%; border-top:1px dashed #fff;}
._bb_             { bottom: 0px;left:0px;height: 1px; width:100%;border-bottom:1px dashed #fff}
._lb_             { top: 0px;left:0px;width: 1px; height:100%;border-left:1px dashed #fff}
._rb_             { top: 0px;right:0px;width: 1px; height:100%;border-right:1px dashed #fff}



/* COLUMN AND ROW PADDING AND MARGIN DISPLAY */

._c_paddings,
._c_margins       { position:absolute; background:rgba(0,109,210,0.25); display:block; visibility:hidden; background-clip: content-box; box-sizing: border-box; pointer-events: none; z-index: 20;}
._c_margins       {  background: rgba(248,44,144,0.25);background-clip: content-box; }

._topm_,
._topp_           { top:0px;left:0px; width:100%; height:10px;}
._botm_,
._botp_           { bottom:0px;left:0px; width:100%; height:10px;}
._lefm_,
._lefp_           { top:0px;left:0px; height:100%; width:10px; }
._rigm_,
._rigp_           { top:0px;right:0px; height:100%; width:10px;}


#rev_builder.inAnimationMode ._c_paddings,
#rev_builder.inAnimationMode ._c_margins { background-color: rgba(94,53,177,0.25); }

._lc_mask { transform:none}

/*._lc_.rs-linebreak ._lc_content_:before   { content: "linebreak";text-align: center;width: 100%;height: 1px;position: absolute;left: 0px;font-size: 12px;line-height: 0px;top: 50%;margin-top:-1px;vertical-align: top;display: block; color:#006dd2;}*/
._lc_.rs-linebreak ._lc_content_:after    { content: " "; width: 100%;height: 100%; position: absolute;top: 0px;left: 0px;  background:rgba(248,44,144,0.25); display:none;}  


._lc_._lc_type_column:hover ._lc_.rs-linebreak ._lc_content_:after,
._lc_._lc_type_row:hover ._lc_.rs-linebreak ._lc_content_:after,
._lc_._lc_type_column.selected ._lc_.rs-linebreak ._lc_content_:after,
._lc_._lc_type_row.selected ._lc_.rs-linebreak ._lc_content_:after { display: block; }

._lc_._lc_type_row:hover >._lc_loop_>._lc_mask_>._lc_iw_>._lc_content_>._c_paddings,
._lc_._lc_type_row.selected >._lc_loop_>._lc_mask_>._lc_iw_>._lc_content_>._c_paddings,

._lc_._lc_type_row:hover >._c_paddings,
._lc_._lc_type_row.selected >._c_paddings,
._lc_._lc_type_row:hover >._c_margins,
._lc_._lc_type_row.selected >._c_margins,

._lc_._lc_type_column:hover ._c_paddings,
._lc_._lc_type_column.selected ._c_paddings,
._lc_._lc_type_column:hover ._c_margins,
._lc_._lc_type_column.selected ._c_margins { display: block; visibility: visible }

._lc_hordistance,
._lc_verdistance  {position: absolute; display:none;z-index:1000; opacity:0.5;}

._lc_hordistance .material-icons,
._lc_verdistance .material-icons { color: #006dd2; position: absolute; font-size: 25px }
._lc_verdistance    { width: 1px;height: 100px; border-left:1px dotted #006dd2;}
._lc_hordistance    { height: 1px;width: 100px; border-top:1px dotted #006dd2;}

._lc_ >.ui-resizable-handle {  width:7px;height:7px; background:transparent; border:none; border-radius: 50%;display:none !important;}
._lc_.selected >.ui-resizable-handle { display: block !important; z-index:15;}


._lc_ >.ui-resizable-n { top:-3px;left:0;width:100%;height:6px;}
._lc_ >.ui-resizable-s { bottom:-3px;left:0;width:100%;height:6px;}
._lc_ >.ui-resizable-e { top:0;height:100%;right:-3px;width:6px;}
._lc_ >.ui-resizable-w { top:0;height:100%;left:-3px;width:6px;}

._lc_ >.ui-resizable-n:before,
._lc_ >.ui-resizable-s:before,
._lc_ >.ui-resizable-e:before,
._lc_ >.ui-resizable-w:before { position: absolute; top: 50%; left: 50%; transform: translateX(-50%) translateY(-50%); width: 7px; height: 7px; border-radius: 50%; background: #fff; border: 1px solid #000; content: " "; }

.dropSensorActive ._lc_ { /*filter: blur(5px); */opacity: 0.5; }
.dropSensorActive ._lc_.selected,
.dropSensorActive ._lc_.selected ._lc_,
.dropSensorActive ._lc_type_row ._lc_,
.dropSensorActive ._lc_.ui-draggable-dragging,
.dropSensorActive ._lc_.ui-draggable-dragging ._lc_,
.dropSensorActive ._lc_.dont_blur,
.dropSensorActive .drop_in_root>._lc_,
.dropSensorActive ._lc_.dont_blur ._lc_ { opacity: 1; }

._lc_video_title_ { width: 100%; height: 25px; line-height: 25px; color: #fff; background: #006dd2; font-size: 12px; padding: 0px 5px; position: absolute; bottom: 0px;left: 0px; z-index: 2; text-transform: uppercase; text-align: center; font-weight: 600 }
._lc_video_placeholder_ { position: absolute; display:block; width: 100%;height: 100%; top: 0px; left: 0px  }

#rev_builder.inAnimationMode ._lc_video_title_ { background:rgba(94,53,177,0.75); }

/*WRAP LEVEL 0*/
._lc_             { position:absolute; width:auto;height:auto;box-sizing: border-box; cursor:move; line-height: 0}
._lc_.hoveredinlist { z-index: 1500 !important;  visibility: visible !important; }


._lc_.closetotop .toolcrumb    { top: 100%; }

/* COMMON HOVERS */
._lc_.hoveredinlist>._borders_,
._lc_:hover>._borders_,
._lc_.selected>._borders_,
._lc_.ui-draggable-dragging>._borders_  { display: block; z-index: 10}

/* NONE SELECTED HOVERS */
.layersInDragorResize ._lc_type_group,
._lc_.selected._lc_type_group,
._lc_._lc_type_group:hover { box-shadow: 0px 0px 0px 1px #006dd2;}

#rev_builder.inAnimationMode .layersInDragorResize ._lc_type_group,
#rev_builder.inAnimationMode ._lc_.selected._lc_type_group,
#rev_builder.inAnimationMode ._lc_._lc_type_group:hover { box-shadow: none !important }

/*._lc_._lc_type_group.nocontent*/

.layersInDragorResize ._lc_type_row,
.layersInDragorResize ._lc_type_column,

._lc_._lc_type_row.nocontent,
._lc_._lc_type_row.nocontent ._lc_._lc_type_column { box-shadow:0px 0px 0px 1px #006dd2; }

._lc_._lc_type_row.nocontent>._lc_loop_> ._lc_mask_ > ._lc_iw_ > ._lc_content_ { min-height: 100px !important }

._lc_.hoveredinlist>._borders_,
._lc_:hover>._borders_ { background: transparent; border-color: transparent; }

#rev_builder.inAnimationMode ._lc_.hoveredinlist.selected>._borders_, 
#rev_builder.inAnimationMode ._lc_:hover>._borders_ {
    background: #000;
    border-color: #fff;
}

._lc_:hover._lc_type_group { box-shadow: 0px 0px 0px 2px #006dd2;}

._lc_:hover,
._lc_.nocontent:hover,
._lc_.hoveredinlist,
._lc_.nocontent.hoveredinlist,
._lc_._lc_type_row.nocontent ._lc_._lc_type_column:hover { box-shadow:0px 0px 0px 2px #006dd2;}


.nohiglightboxes ._lc_._lc_type_row.nocontent,
.nohiglightboxes ._lc_._lc_type_row.nocontent ._lc_._lc_type_column,
.nohiglightboxes ._lc_:hover._lc_type_group,
.nohiglightboxes ._lc_:hover,
.nohiglightboxes ._lc_.nocontent:hover,
.nohiglightboxes ._lc_.hoveredinlist,
.nohiglightboxes ._lc_.nocontent.hoveredinlist,
.nohiglightboxes ._lc_._lc_type_row.nocontent ._lc_._lc_type_column:hover { box-shadow:none !important}

.nohiglightboxes ._group_head_,
.nohiglightboxes ._c_paddings,
.nohiglightboxes ._c_margins { visibility: hidden !important }



._lc_.actionDependent { box-shadow:0px 0px 0px 1px #f82c90; }
._lc_.actionDependent.actionselected { box-shadow:0px 0px 0px 3px #f82c90; }

#rb_tlw ._lc_ i { font-size: inherit; line-height: inherit }

._lc_._lc_type_row:hover { z-index: 10000 !important }
._lc_._lc_type_column:hover { z-index: 10010 !important }


/* DROP SENSOR , MANIOULATE DROPPABLE TARGETS */
.dropSensorActive ._lc_.drop_over_layer ._lc_type_column { outline: 1px solid #006dd2; opacity: 0.5; vertical-align: top;}
.dropSensorActive ._lc_.drop_over_layer { box-shadow: 0px 0px 0px 5px #006dd2; }
.dropSensorActive ._lc_.drop_over_layer ._lc_group_placeholder { display: none; }
.dropSensorActive ._lc_.drop_over_layer ._lc_type_column.drop_over_layer { outline: 2px solid #006dd2; opacity:1;}

.dropSensorActive ._lc_type_column.drop_before_firstlayer >._lc_loop_ > ._lc_mask_ >._lc_iw_ >._lc_content_ >._lc_:first-child:before,
.dropSensorActive ._lc_type_column.drop_after_lastlayer >._lc_loop_ > ._lc_mask_ >._lc_iw_ >._lc_content_ >._lc_:last-child:after,

.dropSensorActive ._lc_type_row ._lc_.drop_before_layer:before { content: " "; position: absolute;  width: 100%; height: 5px;  background: #006dd2; z-index: 100; display:block; left: 0px; top:-5px;}
.dropSensorActive ._lc_type_row ._lc_.drop_before_layer:after { content: " "; position: absolute; width: 5px; height: 100%; left: -5px;  background:#006dd2; z-index:100; display: block;  top:0px;}

.dropSensorActive ._lc_type_row ._lc_.drop_after_layer:after { content: " "; position: absolute;  width: 100%; height: 5px; background: #006dd2; z-index: 100; display:block;  left:0px; bottom:-5px;}
.dropSensorActive ._lc_type_row ._lc_.drop_after_layer:before { content: " "; position: absolute; width: 5px; height: 100%; right: -5px;  background:#006dd2; z-index:100; display: block;  top:0px; }

 
 

.debug_coordinates span { display:inline-block;min-width:40px;color:#fff;line-height:15px; font-size:12px; margin-left:10px;}

/* SELECTED HOVERS */
._lc_.hoveredinlist.selected>._borders_,
._lc_.selected:hover>._borders_ { background: #000; border-color: #fff; }

/*._lc_.selected:hover,
._lc_.selected.hoveredinlist { outline:none; }*/

/*WRAP LEVEL 1*/
._lc_loop_,
._lc_mask_              { position: relative; width:auto;height:auto;box-sizing: border-box;z-index: 1; vertical-align: inherit;}

/*WRAP LEVEL 2*/
._lc_iw_                { position: relative; width:auto;height:auto;box-sizing: border-box; vertical-align: inherit;}

/*WRAP LEVEL 3*/
._lc_content_            { position: relative; width:auto;height:auto;box-sizing: border-box; vertical-align: inherit}
._lc_image_inside_       {  width: 100%;height:100%; z-index: 2; position: relative; vertical-align: top; 
                          -webkit-touch-callout: none; /* iOS Safari */
                            -webkit-user-select: none; /* Safari */
                             -khtml-user-select: none; /* Konqueror HTML */
                               -moz-user-select: none; /* Old versions of Firefox */
                                -ms-user-select: none; /* Internet Explorer/Edge */
                                    user-select: none;
                          }

._lc_img_placeholder     {  z-index: 1; position: absolute; width:100%;height:100%; background:rgba(0,109,210,0.75); display:none; top:0px; left:0px; overflow:hidden;}
._lc_img_placeholder i.material-icons { position: absolute; top: 50%;left: 50%; font-size: 50px !important; transform: translateX(-50%) translateY(-50%); color:#fff;}

._lc_stream_placeholder     {  z-index: 1; position: absolute; width:100%;height:100%; background:rgba(0,109,210,0.75); display:none; top:0px; left:0px; overflow:hidden;}
._lc_stream_placeholder i.material-icons { position: absolute; top: 50%;left: 50%; font-size: 50px !important; transform: translateX(-50%) translateY(-50%); color:#fff;}

.placeholder_on>._lc_stream_placeholder,
.placeholder_on>._lc_img_placeholder { display: block; }

._lc_type_shape ._lc_content_.placeholder_on { background: none !important; }



._lc_group_placeholder     {  z-index: 1; position: absolute; width:100%;height:100%; background:rgba(0,109,210,0.75); display:block; top:0px; left:0px;}
._lc_group_placeholder i.material-icons { position: absolute; top: 50%;left: 50%; font-size: 50px !important; transform: translateX(-50%) translateY(-50%); color:#fff;}
._lc_type_group>._lc_loop_>._lc_mask_>._lc_iw_>._lc_content_>._lc_+._lc_group_placeholder { display: none; }

#rev_builder.inAnimationMode ._lc_group_placeholder,
#rev_builder.inAnimationMode ._lc_img_placeholder { background:rgba(94,53,177,0.75); }

/* GROUP LAYER AND ITS LOCK/UNLOCK FEATURE */
._group_head_ { display:none; width: 100%; height: 25px; top: 0px; left: 0px; z-index: 80; background: #006dd2; line-height: 25px; font-size: 13px; color: #fff; padding: 0px 10px; position: absolute; opacity: 0.5; overflow: hidden; }
._group_head_title_ { overflow: hidden;white-space: nowrap; width:75%; position: absolute; top:0px; left:0px; padding: 0px 10px;}

._lc_type_group ._group_lock_ { display:none; z-index: 5000; width: 100%; height: 100%; background: transparent; position: absolute;top: 0px;left: 0px; cursor: move;  }
._group_lock_ i.material-icons { position: absolute;left: 50%;top: 50%;transform: translateX(-50%) translateY(-50%);font-size: 40px !important; line-height: 40px !important;  opacity: 0.5;}

._group_lock_toggle_ { width: 25px; height: 25px; position: absolute; right: 0px; top: 0px; cursor: pointer;  text-align: center;     border-left: 1px solid rgba(255,255,255,0.1);}
#rb_tlw i.material-icons.group_lock_icon      { display: none; }
#rb_tlw i.material-icons.group_lockopen_icon  { display: inline-block; }
#rb_tlw ._lc_type_group._group_locked_ i.material-icons.group_lockopen_icon { display: none }
#rb_tlw ._lc_type_group._group_locked_ i.material-icons.group_lock_icon { display: inline-block }
._lc_type_group.selected._group_locked_ ._group_lock_,
._lc_type_group._group_locked_:hover ._group_lock_ { display: block; }

.layersInDragorResize ._lc_type_group ._group_head_,
._lc_type_group:hover ._group_head_ { display: block; }

._group_head_:hover { opacity: 1 }




._lc_type_video ._lc_img_placeholder i { margin-top: -10px; }

._lc_type_audio audio { display: none; pointer-events: none; width: 100%; height: 100%; } 
._lc_type_audio .audio_controls_on audio { display: block; }

#media_audio_wave_wrap { position: relative; width: 100%; box-sizing: border-box;}
#media_audio_master {  border: 1px solid #3f444a;  height:30px; box-sizing: border-box; min-width:245px; max-width: 245px; width: 245px; position: absolute;top:0px; left:35px; border-radius: 3px}
#audio_simulator.disabled { pointer-events: none; opacity: 0.5; }

.wavesurfer-region { box-sizing: border-box; background:transparent;}
.wavesurfer-handle-start { width: 6px;  border-left: 2px solid #006dd2; border-top:2px solid #006dd2; border-bottom:2px solid #006dd2; height:25px !important;}
.wavesurfer-handle-end { width: 6px;  border-right: 2px solid #006dd2; border-top:2px solid #006dd2; border-bottom:2px solid #006dd2; max-width: 6px; left:auto !important; right:0px; height:25px !important;}


/* LC TYPES */

._lc_type_row { width: 100%;position: relative; cursor: pointer; pointer-events: auto}
._lc_type_row ._lc_ { position: relative;}
._lc_type_row>._lc_loop_>._lc_mask_>._lc_iw_>._lc_content_ { display: table; width: 100%; }
._lc_type_column { display: table-cell;width: 100%; vertical-align: top; cursor:pointer;}

._lc_extra_bg_wrap,
._lc_extra_bg  { position: absolute;z-index: 0; background: transparent;}

._lc_type_group ._lc_extra_bg { top: 0px; left: 0px; }
._lc_type_video ._lc_loop_,
._lc_type_video ._lc_mask_,
._lc_type_video ._lc_iw_,
._lc_type_shape ._lc_loop_,
._lc_type_shape ._lc_mask_,
._lc_type_shape ._lc_iw_,
._lc_type_image ._lc_loop_,
._lc_type_image ._lc_mask_,
._lc_type_image ._lc_iw_ { width: 100%; height: 100%; }

/*
ROW WRAPPERS
*/
.row_wrapper_top,
.row_wrapper_middle,
.row_wrapper_bottom { position: absolute;height: auto;left: 0px;width: 100%; z-index: 3; box-sizing: border-box; pointer-events: none;}

.row_wrapper_middle { top: 50%;transform: translateY(-50%);}
.row_wrapper_top { top: 0px;}
.row_wrapper_bottom { top: auto; bottom:0px;}

/* perfect scrollbar fix */
#rev_builder_inner {position: relative; height:auto; /*KRIKI*/}
#rev_builder_inner.hide_all_nonezone .layer_grid>._lc_,
#rev_builder_inner.hide_all_zone .row_wrapper_top,
#rev_builder_inner.hide_all_zone .row_wrapper_middle,
#rev_builder_inner.hide_all_zone .row_wrapper_bottom { pointer-events: none !important; opacity: 0.2 !important;  }



/* DRAGGING LAYERS */
._lc_.ui-draggable-dragging {  z-index: 500; opacity: 1; box-shadow: 0px 15px 50px 0px rgba(0,0,0,0.25);   }
#dropSensor { display: none; position: absolute; top: 0px;left: 0px;width: 100%;height: 100%; background: transparent }

#rev_slider_ul_inner.dropSensorActive #dropSensor { display: block;z-index:499  }

._lc_._locked_ { pointer-events: none; }

._lc_>._lc_locked_bg_{ display: none;  z-index:50; position:absolute; top:0px; left:0px; width:100%; height:100%; outline:1px solid rgba(255,0,0,0.25); background: transparent; /*url(../images/red_diag2x.png); background-size: 10px 10px; background-repeat: repeat; */}
._lc_>._lc_locked_ { z-index:51; display:none;position: absolute; left:50%;top:50%; margin-left: -10px; margin-top: -10px; color:#fff; text-shadow:0px 2px  rgba(0,0,0,0.5); font-size: 20px}

._lc_._locked_ >._lc_locked_bg_ { display: block; }
/*._lc_._locked_ >._lc_locked_ { display: block; }*/


._lc_._unvisible_ { visibility: hidden !important; pointer-events: none !important; opacity: 0 !important;}
._lc_._unvisible_.hoveredinlist { visibility: visible !important;opacity: 1 !important; }

/* LAYER INPOUT FIELDS -  EXTRAS */

#rev_builder.inAnimationMode ._lc_:hover>._lc_loop_>._lc_mask_>._lc_iw_>._lc_content_:before,
#rev_builder.inAnimationMode ._lc_.selected>._lc_loop_>._lc_mask_>._lc_iw_>._lc_content_:before,
#rev_builder.inAnimationMode ._lc_.hoveredinlist>._lc_loop_>._lc_mask_>._lc_iw_>._lc_content_:before { content:" "; width:100%;height:100%; box-sizing:border-box; top:0px; left:0px; border:2px solid #5e35b1; position: absolute;z-index:50; pointer-events: none}

 

#the_editor.nohiglightboxes #rev_builder.inAnimationMode ._lc_:hover>._lc_loop_>._lc_mask_>._lc_iw_>._lc_content_:before,
#the_editor.nohiglightboxes #rev_builder.inAnimationMode ._lc_.selected>._lc_loop_>._lc_mask_>._lc_iw_>._lc_content_:before,
#the_editor.nohiglightboxes #rev_builder.inAnimationMode ._lc_.hoveredinlist>._lc_loop_>._lc_mask_>._lc_iw_>._lc_content_:before { display: none !important; }

#rev_builder.inAnimationMode ._lc_:hover,
#rev_builder.inAnimationMode ._lc_.nocontent:hover,
#rev_builder.inAnimationMode ._lc_.hoveredinlist { box-shadow: none !important; }
#rev_builder.inAnimationMode ._lc_.selected>.ui-resizable-handle { display: none !important; }
/*#rev_builder.inAnimationMode ._lc_.selected>._borders_  */

 
/*******************************
    -IDLE / HOVER SWITCH -
 *******************************/

 .idle_hover_toggle { display: block; border-bottom: 1px solid #3f444a; line-height: 49px;  font-size:14px; font-weight: 400;}
 .idle_swap,
 .hover_swap { line-height: 49px; width: 50%; color: #797b7e; text-align: center; cursor: pointer; display: inline-block; box-sizing: border-box }

.idle_swap { border-right: 1px solid #3f444a; }

.__idle_selected__ .idle_swap,
.__hover_selected__ .hover_swap { color: #ffffff; }

.__hover_selected__ .__idle__,
.__idle_selected__ .__hover__ { display: none; }

 .__idle_selected__ .__idle__,
 .__hover_selected__ .__hover__ { display: block; }

 .left_right_row { padding: 0px 10px 5px; }
 .view-switch { color: #777c80; font-size: 12px; line-height: 25px; vertical-align: top; display: inline-block; height:25px;}
 .icon_trigger_wrap { display: inline-block; line-height: 25px; vertical-align: top; height: 25px; position: absolute; right: 0px; top: 0px; }
 #reset_lock_media_size_layer .icon_trigger_wrap { right: auto; left: 0px; top: 3px; }
 .vs-item { margin-right: 10px;  cursor: pointer; display: inline-block}
 .vs-item:hover,
 .vs-item.selected { color: #fff; }
 

/******************************
  - MONITOR ME  -
******************************/


.tp-monitor-list        { margin:0px 0px 20px; list-style: none;  font-weight:500; color:#777c80; line-height:17px; font-size: 13px;}
.tp-monitor-listli      { padding:2px 0px;margin:0px; list-style: none; }
.tp-monitor-size        { min-width: 100px;display: inline-block; }
.tp-monitor-file        { font-size:13px; font-weight:500;color:#777c80; width:500px; display:inline-block;line-height: 17px;}

.tp-monitor-performance-title { width:100%;}
.tp-monitor-warning,
.tp-monitor-well,
.tp-monitor-good,
.tp-monitor-neutral       { display:inline-block; line-height:17px;width:12px;height:12px;border-radius: 10px; margin:2px 10px 0px 0px;vertical-align: top}

.mo-slow-col,
.tp-monitor-warning       { background-color:#e44732;}
.mo-ok-col,
.tp-monitor-well        { background-color:#eec700;}
.mo-fast-col,
.tp-monitor-good        { background-color:#006dd2;}

.mo-neutral-col,
.tp-monitor-neutral       { background-color: #b7bbc0}

.tp-monitor-showimage,
.tp-monitor-linktoslide     { display:inline-block; width:25px; height:25px; opacity:0.5;cursor: pointer; vertical-align: top;line-height: 25px; color:#b7bbc0;}

.tp-monitor-showimage:hover,
.tp-monitor-linktoslide:hover { color: #fff; }

.tp-monitor-small-icon {     font-size: 25px;
    line-height: 30px;
    display: inline-block;
    vertical-align: top;
    margin-right: 10px;
}
.tp-monitor-showimage i,
.tp-monitor-linktoslide i { font-size: 20px; } 

.tp-monitor-showimage:hover,
.tp-monitor-linktoslide:hover { opacity: 1}

.tp-monitor-smalllabel      { font-weight:400; color:#4a4c4e; line-height:15px; font-size: 11px; display: block}
.tp-monitor-total-subsize   { line-height: 27px;height:27px; box-sizing:border-box; font-size: 17px;color: #b7bbc0;font-weight: 500;vertical-align: top; background: transparent; margin-bottom: 15px}


.tp-monitor-performace-wrap   { display: inline-block; width:287px;height:10px; background: #2a2c2f; position: relative;vertical-align: top; margin-right:15px; margin-top:6px; margin-bottom:35px;}

.tp-monitor-performace-wrap.fullpw { width: 100%; }

.tp-monitor-performance-bar   { position:absolute;top:0px;left:0px;height:10px;width:40%;}
.tp-monitor-slow,
.tp-monitor-ok,
.tp-monitor-fast        { position: absolute; line-height: 17px;display: block;cursor: default;color: #222;font-weight: 500;margin-bottom: 0px;font-size: 13px;color: #777c80;top: 15px;}



.tp-monitor-ok          { left:50%; margin-left:-8px;}
.tp-monitor-fast        { right:0px;}

.tp-monitor-loadedinfo { display: inline-block; width:116px;margin-right:10px;}

.tp-monitor-speed-table      { line-height:30px; box-sizing:border-box; font-size: 17px;color: #b7bbc0;font-weight: 500;vertical-align: top; background: transparent}
.tp-monitor-speed-cell    { width:165px; display: inline-block}



.tp-monitor-fullsize        { line-height: 30px;height:27px; box-sizing:border-box; font-size: 17px;color: #b7bbc0;font-weight: 500;vertical-align: top; background: transparent; margin-right: 15px}


.tp-monitor-smart-speed,
.tp-monitor-all-speed       { display: none;}
.tp-monitor-showdetails { margin-bottom: 10px; }




/*************************************************************
  
                      OVERVIEW PAGE                           
                      
*************************************************************/


/* WP CHANGES */
.toplevel_page_revslider,
.toplevel_page_revslider #wpwrap,
.toplevel_page_revslider #wpwrap #wpcontent { background: #202224; }
.toplevel_page_revslider #wpwrap.in_rs_preview { overflow: hidden; height: 100%; }

.notselectable  {-webkit-user-select: none;-khtml-user-select: none;-moz-user-select: none;-ms-user-select: none;user-select: none;}
.linebreak,
.tp-clearfix      {display: block;height: 0px;width: 100%;}
.tp-clearfix {  clear:both;}
.rightaligned   { text-align: right}
.vertical_medium_wrap   {     top: 50%;transform: translateY(-50%);position: absolute;}

/* WP MENU */
#adminmenuwrap .toplevel_page_revslider .wp-submenu a #revslider_premium_link { color: #ffb818!important}


/* SLIDER OVERVIEW MENU*/

#rs_overview_menu {  opacity:0; min-height: 50px; background: #202224; box-shadow: 0px 10px 20px 0px rgba(0,0,0,0.5); margin-left:-20px; box-sizing: content-box; position: fixed; z-index: 9880; padding-left:75px; overflow:visible;}
.rso_scrollmenuitem { line-height: 50px; color: #62666a; /*font-size: 17px;*/ font-size: 14px; font-weight: 600; display:inline-block; /*margin-right: 50px; */ margin-right:25px; cursor: pointer;}
.rso_scrollmenuitem i.material-icons { color: inherit; font-size: 20px; line-height: 50px; /*margin-right: 10px;*/ margin-right: 5px; }

#rso_menu_notices { right: 110px; top:0px; box-sizing: border-box; font-weight: 600; position:absolute; width:50px; height:50px;}
#rs_notice_bell,
#rs_notice_the_bell { width:50px;height:50px; text-align:center; position: absolute;top:0px;left:0px; margin:0; padding:0;}
#rs_notices_wrapper { display:none;width: auto; right: 0px; line-height: 30px; padding: 0px; margin: 0px; top: 50px; position: absolute;  box-shadow:0px 15px 15px 0px rgba(0,0,0,0.5);}
#rs_notices_wrapper li { min-width:300px; max-width:600px; padding: 0px 20px;  max-width: 400px; overflow: hidden; margin: 0px; line-height: 30px; font-size: 13px;vertical-align: top; }

#rso_menu_notices:hover #rs_notices_wrapper { display: block; }
#rs_notices_wrapper li i { font-size: 17px; line-height: 30px;vertical-align: top; margin-right: 10px; color: inherit !important; }
.no_notification_function { cursor: default;filter: none !important; }
#remove_notifications { cursor: pointer }
#remove_notifications:hover { background:#3f444c; color: #fff !important; }

#rs_notice_counter { background: #921e15; color: #fff; width: 20px;height: 20px;text-align: center; position: absolute; top: 5px;left: 25px; line-height: 20px;font-size: 13px; border-radius: 10px; }
.notice_level_0#rs_notice_counter  { background:#921e15 }
.notice_level_1#rs_notice_counter  { background:#ffb818; filter: brightness(90%); color: #000; }
.notice_level_2#rs_notice_counter  { background:#3f444c; color: #b7bbc0; }

.notice_level_0 { background:#c3281c; color:#fff !important; }
.notice_level_1 { background:#ffb818; color:#000 !important;}
.notice_level_2 { background:#292c2e; color:#b7bbc0 !important;}

li.notice_level_0:hover,
li.notice_level_1:hover { filter: brightness(110%); }

#rso_menu_notices span { display: inline-block;  font-weight: 600; margin-right: 10px}
#rso_menu_notices span:last-child { margin-right: 0px; }
#rso_menu_notices grayiconbox.warning { margin-right: 10px; }
#rso_menu_notices { margin-right: 0px !important; }

.rso_scrollmenuitem grayiconbox i.material-icons { margin-right: 0px; font-size:30px;}



.rso_scrollmenuitem.active,
.rso_scrollmenuitem:hover { color: #fff; }

.rso_scrollmenuitem.active i.material-icons,
.rso_scrollmenuitem:hover i.material-icons { color: #006dd2; }

.rso_scrollmenuitem:hover i.material-icons { color:inherit }

.box_with_icon:focus,
.box_with_icon { outline:none; display:block;border: 1px solid #323438; line-height: 40px;  padding: 0px 19px; font-size: 15px; color: #797b7e; text-decoration: none;  box-sizing: border-box;  text-align: left}
a.box_with_icon { cursor: pointer; }
.box_with_icon i.material-icons { font-size: 25px; margin-right: 10px }
a.box_with_icon:hover { background: #006dd2; color: #fff; }

#activated_ornot_box.box_with_icon { background: #22a46e; color: #fff; border: none; }

.featurebox .box_with_icon,
#activated_ornot_box.not_activated.box_with_icon {/* background: #d50000; color: #fff;*/ background: #ffb818; color: #000; font-weight: 500; border:none;}

/* BASIC STYLING*/
#rs_overview .title     { font-size: 30px; font-weight: 600; color: #fff; line-height: 40px; padding:0px; margin:0px;}
#rs_overview .subtitle  { font-size: 20px; font-weight: 500; color:#797b7e; line-height: 25px; padding:0px; margin:0px}


/*Main Creation Modules*/
#add_new_slider_wrap { margin-top: 90px; }
.new_slider_block { color: #b7bbc0; width: 267px; height: 150px; position: relative; display: inline-block; background: #2a2c2f; margin-right: 20px; margin-bottom: 20px; cursor:pointer; box-sizing: border-box; padding: 30px 0px; vertical-align: top; }

.new_slider_block .nsb_title,
.rootfolder .nsb_title {  font-size: 17px; text-align: center; display: block; line-height: 20px; font-weight: 500}

.rootfolder .nsb_title { color: #b7bbc0; }
.new_slider_block:hover { background: #006dd2; color: #fff; }


#rs_overview .new_slider_block i.material-icons         { font-size: 50px; text-align: center; color: #62666a;  display: block; line-height: 50px; margin-bottom:10px;}
#rs_overview .new_slider_block:hover  i.material-icons  { color: #fff; }

#rs_overview .new_elements_available { display:none; box-shadow: 0px 11px 30px 0px rgba(0,0,0,0.5); position: absolute; top: -20px;  right:-15px; line-height: 40px; height: 40px; padding: 0px 15px; color: #fff; background: #5e35b1; font-weight: 600; font-size: 18px; border-radius: 20px; overflow: hidden;z-index:20; }


/*#new_slider_import,*/
#add_on_management { margin-right: 0px }
/*INPUT AND TRIGGER FUNCTIONS*/


/* WPML FLAG */
.flag_container { display: inline-block;vertical-align: middle; }
.wpml-img-flag {  width: 18px;height: 12px;display: inline-block;vertical-align: middle;margin-right: 10px; }
.slide_elemenet_content .wpml_flag_wrap { display: inline-block; vertical-align: top; line-height: 27px;margin-right: 10px; }
.slide_elemenet_content .wpml-img-flag { margin-left: 0px; margin-right: 0px; }

body.rs-multilanguage_off .slide_list_child_element_wrap,
body.rs-multilanguage_off #gst_slide_13,
body.rs-multilanguage_off .wpml_flag_wrap,
body.rs-multilanguage_off .addchildslide { display: none !important }


/* KRIKI - DISPLAY NONE / INLINE BLOK NICHT GUT, EXTRA LINE IN LIST VON SUBSLIDERS */

/*************************************/
/* OVERVIEW LIST OF ELEMENTS WRAPPER */
/*************************************/
#existing_sliders { margin-top: 40px;  }

#slider_folders_wrap { position: fixed; top: 0px; left: 0px; width: 330px; height: 100%; background: #202224; box-shadow: 0px 10px 20px 0px rgba(0,0,0,0.5); z-index: 120000; box-sizing: border-box; padding:20px;overflow:hidden; display:none;}
#slider_folders_wrap_underlay { position: fixed; top: 0px; left: 0px; width: 100%; height: 100%; background: #23282d; opacity:0.65; z-index: 119999; cursor: pointer; display:none;}
#slider_folders_wrap .rs_library_element { margin-right: 0px; }

.folder_wrap_level_title { display: block; margin-bottom: 10px; margin-top:20px; color: #fff; z-index: 20;font-size: 17px;line-height: 40px;text-align: left; font-weight: 500; }
.folder_wrap_level_title.first_fwlt { margin-top: 0px; }
.action_button { display: inline-block; font-size: 17px; line-height: 50px; vertical-align: top; color: #797b7e;  cursor: pointer; font-weight: 500}
.action_button i.material-icons { line-height: 50px; margin-left: 5px; color: inherit; }

.action_button:hover { color: #fff; }

.overview_slide_elements,
.overview_elements { margin-right: -30px; position: relative }


.rs_library_element { width: 267px; height: 190px; display: inline-block; margin-right: 20px;margin-bottom: 20px; cursor: pointer; box-sizing: border-box; position: relative; background:#2a2c2f; z-index:50; vertical-align: top}
.rs_library_element .rsle_footer {  position: absolute; bottom: 0px; left: 0px;  width:100%;height:40px; background:#2a2c2f;z-index: 5}
.rs_library_element.selected,
.rs_library_element:hover{ z-index: 502 !important; }

.rs_library_element.ui-draggable-dragging { z-index: 200000 !important; position: absolute; pointer-events: none; opacity:0.80 !important;}

.rs_library_element.ui-draggable-dragging .rsle_tbar  {display: none !important;  }
.rs_library_element .link_to_slideadmin, 
.rs_library_element .image_container { width: 100%; height: 150px; position: absolute; top: 0px;left: 0px; display: block; z-index: 10; background-size:cover; background-position: center center; background-repeat: no-repeat}
.rs_library_element .image_container_underlay {  z-index: 9; background: #2a2c2f; top: 0px;left: 0px; width: 100%;height: 150px; position: absolute }
.rs_library_element .image_container_underlay .rootfolder {  background: #2a2c2f; top: 0px;left: 0px; width: 100%;height: 150px; position: absolute }
.rs_library_element .image_container_underlay .rootfolder i.material-icons { font-size: 50px;
    text-align: center;
    color: #62666a;
    display: block;
    line-height: 50px !important;
    margin-bottom: 10px; 
    width: 100%;
    margin-top: 45px;
  }


.rs_library_element .link_to_slideadmin_a { z-index: 4; position: absolute; background: #fff; width: 50px;height: 50px;top: 0px;left: 0px; border-radius: 50% }
.rs_library_element .link_to_quickeditor,
.rs_library_element .link_to_quickstyleeditor { z-index:3; transform:translateX(30px) translateY(30px); position: absolute; top: -23px; left: -23px; border-radius: 50%; width: 30px;height: 30px; background:#fff;}

.rs_library_element .link_to_slideadmin .link_to_quickeditor i.material-icons,
.rs_library_element .link_to_slideadmin .link_to_quickstyleeditor i.material-icons { font-size: 13px;  line-height: 30px !important; font-size: 20px !important; text-align: center; }

.rs_library_element .link_to_slideadmin:hover .link_to_quickeditor { display: block; }

.rs_library_element.unpublished .unpublishslide { display: none; }
.rs_library_element.unpublished .publishslide { display: inline-block; }
.rs_library_element .unpublishslide { display: inline-block; }
.rs_library_element .publishslide { display: none; }

.rs_library_element .iconofunpublished { display: none !important; color: #b7bbc0;font-size: 12px;position: absolute;right: 30px;top: 11px;}
.rs_library_element.unpublished .iconofunpublished { display: inline-block !important }

.rs_library_element.selected .iconofunpublished,
.rs_library_element:hover .iconofunpublished { color: #fff; }


.folder_library_element .image_container_underlay { background: #2a2c2f; }

.folder_library_element:hover,
.folder_library_element.selected,
.folder_library_element.menuopen {background:#006dd2; }

.folder_library_element:hover .image_container_underlay,
.folder_library_element.selected .image_container_underlay,
.folder_library_element.menuopen .image_container_underlay {background:#006dd2; }
.folder_img_placeholder { display: inline-block; width: 126px; height: 68px; background: #323438; vertical-align: top; background-size: cover; background-position: center center; background-repeat: no-repeat }

.folder_library_element.menuopen .folder_img_placeholder,
.folder_library_element.selected .folder_img_placeholder,
.folder_library_element:hover .folder_img_placeholder { background-color: #00529d; }

.rs_library_element.folder_library_element .link_to_slideadmin { background: transparent !important; opacity: 0; width: 100%;height: 150px;top: 0px;left: 0px; margin: 0px; }
.folder_img_1,
.folder_img_3 { margin-right: 5px; margin-left: 5px; }
.folder_img_1,
.folder_img_2 { margin-bottom: 5px; margin-top:5px;}

.folder_library_element .show_rsle { opacity: 0 !important }

.folder_library_element .rsle_tool.embedslider,
.folder_library_element .rsle_tool.exporthtmlslider,
.folder_library_element .rsle_tool.exportslider { display: none; }


.rs_library_element .link_to_slideadmin {text-align: center ; z-index: 20; width: 50px; height: 50px; position: absolute; top: 50px; left: 50%; margin-left: -25px; background: #fff; border-radius: 35px; display:none; box-shadow:0px 3px 10px 0px rgba(0,0,0,0.25);}
.rs_library_element:hover .link_to_slideadmin,
.rs_library_element.selected .link_to_slideadmin,
.rs_library_element.menuopen .link_to_slideadmin,
.rs_library_element:hover .link_to_slides_overview,
.rs_library_element.selected .link_to_slides_overview,
.rs_library_element.menuopen .link_to_slides_overview { display: block; }
.rs_library_element .link_to_slideadmin i.material-icons{ font-size: 30px; color: #006dd2; line-height: 50px !important;  }

.rs_library_element .slide_order_number { position: absolute; left: 10px; top: 13px; color: #b7bbc0; font-size: 10px; pointer-events: none;  }


.rs_library_element:hover .slide_order_number,
.rs_library_element.selected .slide_order_number { color: #fff; }

.rs_library_element .link_to_slideadmin.pull_icon_left { margin-left: -55px; }
.rs_library_element .link_to_slides_overview { margin-left: 5px; }



.rs_library_element .title_container,
.rs_library_element .rs_library_el_next {  width: 245px; height: 40px; font-weight:500; line-height: 40px; position: absolute; bottom: 0px; left: 0px; font-size: 15px; color: #b7bbc0; padding: 0px 10px; background: transparent;box-sizing: border-box; border:none; outline:none; box-shadow: none; z-index: 2; margin:0px;}
.rs_library_element .title_container.slide_with_number { left: 20px; width: 225px; }
.rs_library_element .title_container_overlay { width: 100%; height: 40px; line-height: 40px; position: absolute; bottom: 0px; left: 0px; background: transparent; z-index: 5; }


.rs_library_element .rs_library_el_next { background:#006dd2; display: none; z-index: 20; pointer-events: none; color: #fff; }
.rs_library_element.selected .title_container,
.rs_library_element.selected .rsle_folder,
.rs_library_element.menuopen .title_container,
.rs_library_element.menuopen .rsle_folder,
.rs_library_element:hover .title_container,
.rs_library_element:hover .rsle_folder { color: #fff; }

.rs_library_element .rsle_move_and_edit { position: absolute; top: 0px; left: 0px; width: 100%; height: 165px;  z-index: 15; background:transparent; cursor:move;}
.rs_library_element:hover .rsle_move_and_edit,
.rs_library_element.selected .rsle_move_and_edit,
.rs_library_element.menuopen .rsle_move_and_edit { background: #006dd2; opacity: 0.65; }

.rs_library_element.selected .rsle_footer,
.rs_library_element.menuopen .rsle_footer,
.rs_library_element:hover .rsle_footer {  position: absolute; bottom: 0px; left: 0px;  width:100%;height:40px; background:#006dd2; z-index: 5}

.show_rsle { position:absolute; color:#fff; font-size:20px; text-align: right !important; padding-right: 10px;  box-sizing: border-box;line-height:40px !important; width: 100%; background: transparent; height: 40px; bottom: 0px; right: 0px; z-index: 20; display: none !important; }

.rsle_folder {     position: absolute;bottom: 0px;right: 0px;width: 100%;height: 40px;color: #b7bbc0;z-index: 20;font-size: 20px;line-height: 40px;text-align: right; padding-right:10px;}


.rs_library_element.menuopen .show_rsle,
.rs_library_element:hover .show_rsle { display: block !important; }

.rs_library_element.selected .show_rsle { transform: scaleY(-1); transform-origin: "50% 50%"; width: 40px; }
.rs_library_element.selected .rsle_folder { width: 40px; }

.folder_library_element .rsle_tool.copyclipboard,
.folder_library_element .rsle_tool.exportslider, 
.folder_library_element .rsle_tool.duplicateslider, 
.folder_library_element .rsle_tool.previewslider { display: none; }


#wpadmin_overlay { width: 160px; height: 100%; position: fixed; top: 35px; left: 0px; background: rgba(35,40,45,0.6); z-index: 1000; pointer-events: none; opacity: 0;}
#wpadmin_overlay_top { width: 100%; height: 35px; position: fixed; top: 0px; left: 0px; background: rgba(35,40,45,0.6); z-index: 100000; pointer-events: none; opacity: 0;}


.overview_slide_elements_overlay,
.overview_elements_overlay { background: transparent; width: 100%;height: 100%; top: 0px; left: 0px; position: absolute; z-index: 500; display:none;}
.overview_slide_elements.infocus .overview_slide_elements_overlay,
.overview_elements.infocus .overview_elements_overlay { display: block; }

.overview_slide_elements_overlay.infocus .rs_library_element,
.overview_elements.infocus .rs_library_element { opacity: 0.4!important }
.overview_slide_elements_overlay.infocus .rs_library_element.selected,
.overview_elements.infocus .rs_library_element.selected { opacity: 1!important }
.rsle_tbar { position: absolute;top: 100%;width: 100%; height: auto; padding: 5px; background: #006dd2;  box-sizing: border-box; color:#fff;  display:none;box-shadow: 0px 10px 20px 0px rgba(0,0,0,0.5)}

.rs_library_element.selected .rsle_tbar { display: block; }

.rsle_tool { width: 64px; height: 50px; display: inline-block; text-align: center; color: rgba(255,255,255,0.65); cursor: pointer;  }
.rsle_tool:hover { color: #fff; }
.rsle_tool i.material-icons { font-size: 17px;  display: block; }
.rsle_tool span { font-size: 12px; font-weight: 400; display:block;}


.rsle_tool_tagwrap{ display: none; }
.rs_library_element.in_tag_view .rsle_tool_tagwrap { display: block; }
.rs_library_element.in_tag_view .tagsslider { color:#fff !important;}
.rs_library_element .title_container:focus { z-index: 200; }


.rootlevel_wrap.rs_library_element {  height:165px;}
.rootlevel_wrap.rs_library_element .rsle_footer { display: none; }

.rootlevel_wrap:hover .image_container_underlay,
.rootlevel_wrap:hover .image_container_underlay .rootfolder { background: #006dd2; }


/* PLUGIN INFORMATIONS */

.plugin_inforow { display: table; visibility: hidden }
.pli_left { min-width: 430px; max-width: 430px; border-right: 1px solid #323438; padding-right: 80px; box-sizing: border-box; display: table-cell; }
.pli_right { display: table-cell; padding-left: 30px; width:100%;}
.pli_update_history { position: relative; display: block; width: 100%; height: 560px; overflow: hidden; margin-bottom:20px;}

.pli_update_history hr { display: none; }

.bugfix:before,
.change:before,
.newfeature:before {  font-family: 'Material Icons';font-weight: normal;font-style: normal;  display: inline-block;  text-transform: none;letter-spacing: normal;word-wrap: normal;white-space: nowrap;direction: ltr;vertical-align: top;font-feature-settings: 'liga';}


.pli_update_history .newfeature:before {font-family: 'Material Icons'; content:"star"; margin-right:20px;}
.pli_update_history .change:before {font-family: 'Material Icons'; content:"redo"; margin-right:20px;}
.pli_update_history .bugfix:before {font-family: 'Material Icons'; content:"bug_report"; margin-right:20px;}

.pli_update_history .change,
.pli_update_history .newfeature,
.pli_update_history .bugfix { color: #006dd2; font-size: 17px;  text-transform: capitalize; margin-top: 30px; font-weight: 500;}


.pli_update_history .change strong,
.pli_update_history .newfeature strong,
.pli_update_history .bugfix strong { font-weight: 400 !important }

.pli_update_history ul { padding-left: 20px; margin-bottom:30px;margin-top:20px;}
.pli_update_history li:before { display: block; float:left; content: " "; width: 5px; height: 5px; border-radius:3px; background: #006dd2; margin-right: 20px; position: absolute;left:17px; top: 7px; }

.system_requirement,
.pli_update_history li { position:relative; color: #b7bbc0; font-size: 15px; line-height: 20px; font-weight: 400; padding-left: 40px; margin-bottom: 7px; }

#system_requirements { border: 1px solid #323438; padding: 30px; box-sizing: border-box;position: relative }
.system_requirement { padding: 0px;margin-bottom: 10px; font-weight: 500; white-space: nowrap; position: relative; ;}

#rs_overview .system_requirement>i.material-icons.warning_icon { display: none }
#rs_overview .system_requirement>i.material-icons { font-size: 25px; color: #00b900; margin-right:10px;}
#rs_overview .system_requirement.warning>i.material-icons { color: #ffb818; }
#rs_overview .system_requirement.warning>i.material-icons.done_icon { display: none }
#rs_overview .system_requirement.warning>i.material-icons.warning_icon { display: inline-block }


.pli_twoline { display: inline-block; vertical-align: top;  }
.pli_title { font-size: 20px; color: #fff; font-weight: 500; line-height: 30px; padding: 0px; margin: 0px 0px 35px; }
.pli_subtitle,
.pli_update_history h3.version-number { font-size: 17px; color: #797b7e; font-weight: 500; line-height: 25px; padding: 0px; margin: 0px; }

.pli_update_history h3.version-number { margin-bottom:20px; }

.dynamicval { color: #b7bbc0; }


grayiconbox { width: 50px; height: 50px; display: inline-block; background:#2a2c2f; color:#62666a; text-align: center; line-height: 50px; font-size: 30px; margin-right:20px; vertical-align: top;}
blueiconbox { width: 50px; height: 50px; display: inline-block; background:#0051b2; color:#62666a; text-align: center; line-height: 50px; font-size: 30px; margin-right:20px; vertical-align: top;}
blueiconbox.blueiconongray { margin-left: -34px;margin-top: 20px; }

darkiconbox { cursor:pointer; width: 50px; height: 50px; display: inline-block; background:transparent; border:1px solid #323438; box-sizing:border-box; color:#62666a; text-align: center; line-height: 50px; font-size: 30px; vertical-align: top;}
darkiconbox:hover { background: #323438; }


bluebutton { display:block; background:#006dd2; width: 100%; text-align: center; line-height: 50px; color: #fff; font-weight: 400;  font-size:17px;  cursor: pointer}
purplebutton { display:block; background:#642fb4; width: 100%; text-align: center; line-height: 50px; color: #fff; font-weight: 400;  font-size:17px;  cursor: pointer; border-radius: 4px}

bluebutton,
purplebutton,
graybutton { display:block; background:#393e45; width: 100%; text-align: center; line-height: 50px; color: #fff; font-weight: 400;  font-size:17px;  cursor: pointer; border-radius: 4px}

bluebutton { background:#006dd2;}
purplebutton { background:#642fb4;}

bluebutton:hover,
graybutton:hover { filter: brightness(110%); }


grayiconbox.warning { background:#ffb818 !important; color:#000 !important} 
grayiconbox.warning i.material-icons { color: #000 !important; }

grayiconbox.cwt_youtube { background: url(../images/socials/youtube.png); background-size: contain; }
grayiconbox.cwt_twitter { background: url(../images/socials/twitter.png); background-size: contain; }
grayiconbox.cwt_facebook { background: url(../images/socials/facebook.png); background-size: contain; }
grayiconbox.cwt_googleplus { background: url(../images/socials/googleplus.png); background-size: contain; }
grayiconbox.cwt_instagram { background: url(../images/socials/instagram.png); background-size: contain; }
grayiconbox.cwt_dribbble { background: url(../images/socials/dribbble.png); background-size: contain; }

.system_requirement darkiconbox { width: 30px; height: 30px; line-height: 30px; font-size: 20px; position: absolute; right: 30px; top: 0px; }

#cwt_socials a,
#cwt_socials a:focus { display: block; outline: none; cursor: pointer; text-decoration: none !important}

.cwt_link { white-space: nowrap }

#cwt_socials a:hover .pli_subtitle { color: #fff !important; }

.activate_to_unlock { display: none; }


#rs_overview i.material-icons.reset_select { display: none; color: #62666a; cursor: pointer; margin-right:5px;}
#rs_overview i.material-icons.reset_select:hover { color: #fff; }

bluebutton.disabled { pointer-events: none; background: #2a2c2f; color: #62666a; }
bluebutton.halfdisabled { background: #2a2c2f; color: #62666a;  cursor: pointer}
bluebutton.halfdisabled:hover { color: #797b7e; }

purplebutton.normal,
bluebutton.normal,
graybutton.normal  { border-radius:4px; width: 200px; display: inline-block }


purplebutton .material-icons { font-size: 17px; margin-right: 10px; }

bluebutton.minimal,
graybutton.minimal { border-radius:4px;height: 30px; line-height: 30px; padding: 0px 30px; display: inline-block; width: auto; font-size: 13px; font-weight: 400 }
#plugin_history .rs__scrollbar-y-rail:hover { background: transparent !important; }

.timeline-Widget { background: #202224; }

/*
PURCHASE KEY
*/

.pkey_info { color: #797b7e; font-size: 15px; line-height: 20px; font-weight: 500; text-align: center; }
.pkey_info a,
.pkey_info a:focus { color: #797b7e; }
.pkey_info a:hover { color: #fff; }

.infobox { border: 1px solid #323438; padding: 30px; box-sizing: border-box; width:100%;}
.whitetitle { color: #fff; font-size: 17px;  line-height: 20px; margin-bottom:20px; font-weight: 500}
.bluetitle { color: #006dd2; font-size: 17px;  line-height: 20px; margin-bottom:20px; font-weight: 500}
.simpletext { color: #b7bbc0; line-height: 20px; font-size: 15px; font-weight: 400; }

.simpletext a,
.simpletext a:focus { color:#b7bbc0}

.simpletext a:hover { color: #fff; }

.simpletext.smalllink,
.simpletext.smalllink:visited { font-size: 13px  }

.simpletext.smalllink:hover,
.simpletext.smalllink:focus { color: #fff !important; }

#purchasekey_wrap { position: relative }
#hide_purchasekey { position: absolute; display:none; pointer-events: none; box-sizing:border-box; top:0px; left:0px; width:100%; font-size: 17px;color: #b7bbc0;background: none;border: 1px solid #323438;outline: none;box-shadow: none;font-weight: 500;line-height: 50px;padding: 0px 20px;width: 100%; }

#purchasekey_wrap.activated #hide_purchasekey { display: block; }
#purchasekey_wrap.activated #purchasekey    { visibility: hidden }

#purchasekey_wrap.activated:hover #purchasekey { visibility: visible; }
#purchasekey_wrap.activated:hover #hide_purchasekey { display: none; }

.rs_new { background: #f82c90; color: #fff; font-size: 13px; font-weight: 500; padding: 0px 5px; display: inline-block; margin-left: 10px; border-radius: 4px }


/*
FEATURE INFO BOX
*/
blueicon     { width: 50px;  position: absolute; left: 0px;top: 10px; background:transparent; color:#006dd2; text-align: center;  font-size: 30px; }
.features_wrapper { display: block; width: 100%; margin-bottom:40px;}
.featurebox  { display: inline-block; min-width:285px;   max-width:400px; width:50%; padding-right: 20px; box-sizing: border-box; position: relative; vertical-align: top;margin-bottom: 20px; }
.featureinfo { display: inline-block; padding-left:70px; }


a.graylink,
a.graylink:focus { background: #2a2c2f; color: #797b7e; font-size:15px;  padding:0px 20px; line-height: 30px; cursor: pointer;display: inline-block;text-decoration: none;}
a.graylink:hover { background: #006dd2; color: #fff; }


.warning { color: #ffb818; }


/* BREADCRUMBS IN CASE NEEDED */


.rsl_breadcrumb_wrap { display: block; width: 100%; margin-bottom: 45px; border-top: 1px solid #323438; padding-top:15px; }
.rsl_breadcrumb { display:inline-block; line-height:25px; vertical-align: top; color: #797b7e; font-size: 15px; margin-right:30px; cursor: pointer; font-weight: 500}
.rsl_breadcrumb i.material-icons { display:inline-block; line-height:25px !important; vertical-align: top;  font-size: 25px !important; margin-right: 10px;  }
.rsl_breadcrumb_div { display: inline-block; color: #323438; margin-right: 30px; font-size: 25px; line-height: 25px !important; vertical-align: top }

.rsl_breadcrumb:hover { color: #fff; }


/****************************
  -FULLPAGE INFO - 
****************************/
#fullpageinfo { position: fixed; background: rgba(50,52,56,0.85); width: 100%; height: 100%; top: 0px; left: 0px; z-index: 500000; color: #777c80;font-size: 14px; font-weight: 400; }
#fullpageinfo_zone { width: 800px; min-height: 450px; box-sizing: border-box; padding:0px 20px; transform:translateX(-50%) translateY(-50%); top:50%;left:50%; position: absolute;  text-align: left}

i.fullpage_main_icon.material-icons { color: #777c80; font-size: 50px !important; position: absolute;left: -50px;top: 0px; }
.fullpage_title { color: #fff; font-weight: 500; font-size: 17px;  line-height: 25px; margin-bottom:30px;}
#fullpageinfo b { font-weight: 500; color: #b7bbc0; }

.fullpage_content { margin-bottom: 15px; }

#fullpageinfo .inputtocopy {  border:none; box-shadow:none;line-height: 40px; font-size: 17px; color: #b7bbc0; font-weight: 500; padding: 0px 10px; background: #2a2c2f; border-radius: 0; outline: none; margin: 0px; display:block; width:100%;}
#fullpageinfo .inputrow { position: relative; display: block; }
#fullpageinfo .inputrow .basic_action_button { position: absolute; top: 0px; right: 0px; width: 40px; height: 40px; border-radius: 0px; line-height: 40px; font-size: 20px; background: #006dd2 }
#fullpageinfo .inputrow .basic_action_button i { color: #fff; }

/****************************
  - FILE DROP ZONE - 
****************************/
#filedrop{ position: fixed; background: rgba(50,52,56,0.85); width: 100%; height: 100%; top: 0px; left: 0px; z-index: 500000; }
#filedrop_zone { width: 800px; min-height: 450px; box-sizing: border-box; padding:100px 100px; border:2px dashed #62666a; transform:translateX(-50%) translateY(-50%); top:50%;left:50%; position: absolute; border-radius: 8px; text-align: center}

.editordrop #filedrop_zone { background: rgba(0,0,0,0.35);  border-color:#fff !important; border-radius: 0px;}
.editordrop #filedrop_zone.is-dragover,
.editordrop #filedrop_zone.is-processing { background:rgba(0,0,0,0.65) !important;}

.big_filedrop_icon { color:#777c80; font-size: 50px !important; line-height: 50px !important;margin-bottom: 30px !important;}


.editordrop .big_filedrop_icon { color: #fff; }
.editordrop .filedrop_state_idle,
.editordrop .filedrop_state_drop,
.editordrop .filedrop_state_process { transform: translateY(-50%); top: 50%; position: relative; color: #fff; }

#fullpage_close,
#filedrop_close { position: absolute; top: -30px;right: -30px; cursor: pointer;  }
@media (max-height: 715px){ #fullpage_close { top: -10px } }
.editordrop #filedrop_close { top: 15px;right: 15px;  }

#fullpage_close i.material-icons,
#filedrop_close i.material-icons { color:#fff; font-size: 30px !important; line-height: 30px !important;}

.filedrop_line_1 { color: #fff; font-size: 17px; line-height: 25px; font-weight: 600; margin-bottom:5px;}
.filedrop_line_2 { color: #777c80; font-size: 17px; line-height: 25px; font-weight: 600;margin-bottom:5px; }
.filedrop_clickbtn { color: #fff; font-size: 15px; line-height: 40px; padding:0px 30px; font-weight: 500;background: #006dd2; display: inline-block; cursor: pointer; }

.editordrop .filedrop_line_2  { color: #fff; }
#filedrop .uploadfileinput {
    width: 0.1px;
    height: 0.1px;
    opacity: 0;
    overflow: hidden;
    position: absolute;
    z-index: -1;
}

/* STATES */

.filedrop_state_process,
.filedrop_state_drop { display: none; pointer-events: none }

.filedrop_state_process .big_filedrop_icon.rotating {animation:rsrotating 1s linear infinite}
.filedrop_state_process #file_upload_processicon { color: #006dd2; }
.filedrop_state_process #file_upload_processicon.error { color: #ffb818; }
.filedrop_state_process #file_upload_processicon.done { color: #00b900; }

.fileupload_status.rotating { animation:rsrotating 1s linear infinite; color: #006dd2; }
.fileupload_status.doneupload { color: #00b900; }

@keyframes rsrotating {
  0% { transform: rotate(0deg); }
  100% { transform: rotate(360deg); }
}

.fileupload_message,
.fileupload_status.errorupload { color: #ffb818; }

.fileupload_message { margin-left: 10px; }
.fileupload_status { margin-left: 5px; }

.fileupload_status

.filedrop_state_process .big_filedrop_icon,
.filedrop_state_drop .big_filedrop_icon { color: #006dd2; }

#filedrop_zone.is-dragover { border-color: #fff; }


#filedrop_zone.is-dragover .filedrop_state_process,
#filedrop_zone.is-dragover .filedrop_state_idle { display: none; }
#filedrop_zone.is-dragover .filedrop_state_drop { display: block; }



#filedrop_zone.is-processing .filedrop_state_idle,
#filedrop_zone.is-processing .filedrop_state_drop { display: none; }
#filedrop_zone.is-processing .filedrop_state_process { display: block; }



/****************************
  - ICON SELECTOR CONTAINER -
****************************/
#rs_iconselector {   box-sizing: border-box; background:#2a2c2f; box-shadow: 0px 3px 10px rgba(0,0,0,0.25); z-index: 1000; position: absolute;  display:none; overflow:hidden;}
#text_button_layer_content_wrapper #rs_iconselector { width:280px; height:305px; top:20px; left:20px;}

#rs_iconselector_inner { overflow: hidden; width: 100%; height: 100%; box-sizing: border-box; position: absolute; top: 40px;  }
#text_button_layer_content_wrapper #rs_iconselector_inner { height:275px;}
.closers_iconselector { background:#2a2c2f; position: absolute; font-size: 20px; width: 40px; height: 40px; color: #777c80; cursor: pointer; right:0px;top:0px;    text-align: center;line-height: 40px !important; border-left:1px solid #323438;}
.closers_iconselector:hover { color: #fff; }

#rs_iconselector .font_icon_subcontainer { border-bottom: 1px solid #323438; }

#rs_iconselector .font_icon_subcontainer .font_icon_subcontainer_title { text-align: center; color: #777c80; font-size: 13px; font-weight: 900; line-height: 30px; border-bottom: 1px solid #323438;  text-transform: uppercase}
#rs_iconselector .font_icon_subcontainer i { color: #b7bbc0; font-size: 20px; line-height: 40px !important; width: 40px; height: 40px; display: inline-block; text-align: center; cursor: pointer}
#rs_iconselector .font_icon_subcontainer i:hover { background: #006dd2; color: #fff; }

.rs_iconselector_header { background: #2a2c2f; position: absolute; top: 0px; left: 0px; line-height: 40px; height: 40px; width: 100%; border-bottom: 1px solid #323438; }
#rb_tlw .rs_iconselector_header input[type=text] { line-height: 40px !important; margin: 0 !important;  width:100%; height:40px;}

/****************************
  - QUICK STYLE  CONTAINER -
****************************/

#quick_style {  position: fixed; top:0px; height:100%; right:0px; width:0px; box-sizing: border-box; z-index: 9500; padding-top:50px; display:none;overflow:hidden; box-shadow:-10px 20px 40px 0px rgba(0,0,0,0.35);}
#quick_style_inner {  position: absolute; width: 320px; min-height: 100%; top: 0px; left: -200px; box-sizing: border-box; }
#quick_style_menu { background: #202224;line-height: 50px; padding: 0px 20px; color: #777c80; font-size: 12px; font-weight: 400; border-bottom: 1px solid #2a2c2f; z-index: 20; position: relative}
.quick_style_menu_point { display: inline-block; margin-right:20px; cursor: pointer; text-transform: capitalize}
.quick_style_menu_point:hover,
.quick_style_menu_point.active { color: #fff; }


#quick_style_close { position: absolute; line-height: 50px; right: 0px; top: 0px; width: 50px; height: 50px; text-align: center; cursor: pointer }
#quick_style_close:hover { color: #fff; }

#quick_style_scrollable_wrap { width: 100%; height:100%; padding-top: 50px; position: absolute; box-sizing: border-box;top:0px; z-index: 5; overflow:hidden;}

#quick_style_scrollable { width: 100%; height:100%; position: relative; box-sizing: border-box;background: #202224;}

.quick_style_dep { line-height: 30px; border-bottom: 1px solid rgba(70,70,70,0.4); font-size: 11px; font-weight: 500; text-transform: uppercase; padding: 0px 20px; background: #1b1d1e; color: #777c80; }

.quick_style_example_wrap {  background: #202224; height: 100px; border-bottom:1px solid rgba(70,70,70,0.4);  position: relative; box-sizing:border-box; overflow: hidden; cursor: pointer; vertical-align: top}
.quick_style_example { padding:0px 20px; height:100%; position: relative;}

.quick_style_example_content { color: #fff;vertical-align: top; transform: translateY(-50%); top: 50%; position: absolute; box-sizing: border-box;overflow-wrap: break-word;word-wrap: break-word;hyphens: auto; max-width:285px;}
.quick_style_example_content.rev-btn { transform: translateY(-50%) translateX(-50%); left: 50%; white-space: nowrap; }


.quick_style_example_content * { color: inherit; }

.qsew_half { width: 50%; display: inline-block }
.qsew_third { width: 33.333%; display: inline-block }
.qsew_fourth { width: 25%; display: inline-block }

.qsew_half .quick_style_example_content,
.qsew_third .quick_style_example_content,
.qsew_fourth .quick_style_example_content { transform: translateX(-50%) translateY(-50%); top:50%; left:50%; white-space: nowrap;}

.qsec_info { background: #006dd2;color: #fff; font-size: 11px; font-weight: 500; text-transform: uppercase; line-height: 18px; padding: 0px 5px; position: absolute; top:0px; left:20px; z-index: 4; display: none}

.quick_style_example_wrap:hover { background: #2a2c2f; }
.quick_style_example:hover .qsec_info  { display:block;}

#quick_style_dep_headlines .quick_style_example:after { position: absolute;top: 0px; right: 0px; width: 40px; height:100%; content: " "; background: linear-gradient(to right, rgba(32,34,36,0) 0%,rgba(32,34,36,1) 75%); }
#quick_style_dep_headlines.dark .quick_style_example:after { background: linear-gradient(to right, rgba(255,255,255,0) 0%,rgba(255,255,255,1) 75%); }
#quick_style_dep_headlines.dark .quick_style_example_wrap { border-bottom-color: #b7bbc0; }


.qse_boxshadow {  width: 60px; height: 60px; background: #b7bbc0; padding: 0px; top: 20px; left: 50px; }
.qse_textshadow { font-size: 20px; font-family: roboto; font-weight: 500;   white-space: nowrap; color: #fff;  text-align: center; line-height: 100px}



/****************************
  - GLOBAL COLOR PICKER - 
****************************/
#rbm_colorskins { width: 390px; }
#rbm_colorskins .rbm_content { padding: 30px; }
#rbm_colorskins .mcg_page {display: none;width: 100%;height: 100%;position: absolute;top: 0px;left: 0px;box-sizing: border-box; padding:75px 120px;background-color:#212226;}
#rbm_colorskins .mcg_page.mcg_selected { display: block; }

#rb_tlw input[type=text].globalskin_alias { width: 170px; margin-right: 5px; }
#rb_tlw .revbuilder-colorpicker.visible-cp-input { width: 120px; }
#rb_tlw .revbuilder-colorpicker.visible-cp-input input { width: 90px;margin: -7px 0px;}

.modal_fields_title { font-size: 14px; line-height: 30px; vertical-align: top; margin-bottom: 15px; font-weight: 900; color: #b7bbc0; display: inline-block }

.global_sas_wrap { position:absolute; bottom:0px; left:0px; text-align: center;width: 100%; padding: 10px 0px 0px; border-top: 1px solid #3f4449; }


/****************************
  - CSS / JS  API - 
****************************/
#rbm_slider_api .rbm_header { z-index: 10; }
.modal_header_functions {     margin-left: 50px;display: inline-block;vertical-align: top;left: 50%;position: absolute;transform: translateX(-50%);top: 0px; }
.js_css_editor_tabs { display: inline-block; padding: 0px 10px; cursor: pointer;  vertical-align: top;}
.js_css_editor_tabs:hover { color: #fff; }
.js_css_editor_tabs.selected { background: #006dd2; color:#fff;}
.codes_css_js_inputs { width: 100% !important; height: 500px !important; margin: 0px !important; }
#rbm_slider_api .rbm_content { height: 500px; display: block; position: relative; z-index: 10; }

.emc_toggle_wrap { position: absolute; right: -40px; height: 100%; min-width: 30px;width: 350px; z-index: 1;  top:0px; height:551px;border-left:1px solid #000;  transition:right 0.5s}
.emc_toggle_wrap:after { content: ""; position: absolute; top: 0px;left: 0px; width: 100%; height: 50px; background: #2a2c2f; z-index:20;}
#emc_toggle { position: absolute; right: 0px; width: 40px; top: 280px; height: 40px; color: #b7bbc0; font-size: 20px; cursor: pointer; text-align: center;  z-index: 20; line-height: 40px !important}

.emc_toggle_info { position: absolute;font-size: 13px;color: #b7bbc0;line-height: 16px;top: 225px;left: auto;right: 0px;width: 40px;z-index: 100;text-align: center; }

.emc_toggle_inner { position: absolute; top: 0px; left: 0px; width: 350px; height: 551px; overflow: hidden; }

#emc_toggle:hover { color: #fff; }

#form_slidergeneral_advanced_api { padding: 0px; background: #3f444a; /*#323438;*/ padding-top: 70px;  }
#form_slidergeneral_advanced_api .form_inner_header { display: block;  background: transparent; height:50px; line-height: 50px; text-align: center; }
#form_slidergeneral_advanced_api .form_inner_header i { margin-right: 15px; }
#form_slidergeneral_advanced_api .collapsable { padding:30px; width: 280px; }

#rs_css_js_area .RevMirror { height: 500px !important; box-sizing: border-box !important; background: #323438 !important; padding-top:10px !important; line-height: 20px !important;}
#rs_css_js_area .cm-s-hopscotch .RevMirror-gutters { background: #323438 !important; padding-right:10px !important;  border-right: 1px solid #202224 !important; }
#rbm_slider_api i.rbm_close.material-icons { line-height: 50px !important; z-index: 30 !important; width: 40px !important;  background: #2a2c2f !important}


#rs_css_js_area .RevMirror .RevMirror-sizer { border-left: 10px solid transparent;}
#rs_css_js_area .RevMirror .RevMirror-gutter-wrapper { transform:translateX(-10px);}

#custom_css_hover_layer_area .RevMirror,
#custom_css_layer_area .RevMirror { height: 200px !important;box-sizing: border-box !important; background: #2a2c2f !important; padding-top:0px !important; line-height: 20px !important; }

#custom_css_hover_layer_area .RevMirror-lines,
#custom_css_layer_area .RevMirror-lines  { padding: 4px 10px; }
.custom_css_layer_area_pre { line-height: 20px;  color: #777c80; padding: 10px; font-size: 13px;   }
.css_opening_closing_bracket { line-height: 20px; color: #b7bbc0; padding: 5px 10px; font-size: 13px; background: #2a2c2f !important; font-weight: 600; }

#rs_css_js_area .RevMirror-linenumber { min-width:21px;}

.emc_toggle_wrap.open { right: -351px; }
.emc_toggle_wrap.open #emc_toggle { transform: scaleX(-1); }
.emc_toggle_wrap:hover #form_slidergeneral_advanced_api { background:#202224 }
.emc_toggle_wrap.open #form_slidergeneral_advanced_api { background: #202224; }


.show_more_toggle { margin: 12px 0px; position:relative; height:12px; width: 100%;}
.show_more_toggle .shmt_textmore,
.show_more_toggle .shmt_textless { position:absolute; right:20px; top:0px; background: #323438; padding:0px 10px; color:#b7bbc0; line-height: 12px; font-size: 12px; z-index:5; font-weight: 400; cursor: pointer;  }

.show_more_toggle.showlesson .shmt_textmore,
.show_more_toggle .shmt_textless { display: none; }
.show_more_toggle.showlesson .shmt_textless { display: block; }

.show_more_toggle .shmt_bar {background:#3f444a; position: absolute; top:6px; left:-20px; width:330px; height:1px; z-index:2;}
.show_more_toggle i.material-icons { font-size: 15px !important; margin-left: 5px; margin-top: 1px }


/****************************
  - NAVIGATION EDITOR - 
****************************/
#settings_sticky_info { display:none; width: 320px; height:50px; background:#202224; z-index: 500; position: absolute; top: 0px; left: 0px; padding:12px 15px; box-sizing: border-box;box-shadow: 0px 5px 10px 0px rgba(0,0,0,0.25);}


#settings_sticky_info.sticky_in_animation #settings_sticky_left.blue.purple { background: #5e35b1 !important; }


/****************************
  - NAVIGATION EDITOR - 
****************************/

#rbm_navigation_editor { width: 1200px; height: 800px; }
#rbm_navigation_editor .rbm_content { height: 750px; width: 100%; position: relative }
#rs_ne_left_wrap {  width: 260px; position: absolute;top: 0px; left: 0px; background: #323438; height: 100%;}
#rs_ne_right_wrap { width: 940px; height:100%; position: absolute; top: 0px; left: 260px; }
#rs_ne_preview_wrap { width: 940px; height: 220px; position: absolute; top: 0px; left: 0px; background:url(../images/light_pattern_2x.png); background-size:16px 16px; background-repeat:repeat; overflow: hidden;}
#rs_ne_ce_wrap { width: 690px; height: 530px; position: absolute;top: 220px; background: #212226 }
#rs_ne_helper_wrap { width: 250px; height: 530px; position: absolute;right: 0px;top: 220px; background:#333438;box-sizing: border-box; padding:30px 0px 30px 30px}
#rs_ne_navlist_wrap { width: 100%; height: 680px; position: absolute; overflow: hidden; }
#rs_ne_navlist { width: 100%; height: auto; position: relative }
.rs_ne_add_new_wrap {  width: 100%; padding: 20px; box-sizing: border-box }
#rs_ne_navlist_wrap .rs_ne_add_new_wrap { position: absolute; bottom: 0px; left: 0px; }
.rs_ne_header,
.rs_ne_navlist_header { font-size: 14px; font-weight: 900; color: #777c80; text-transform: uppercase; padding: 30px 20px 15px; line-height: 15px; border-bottom: 1px solid #3f444a; }
.rs_ne_header { padding-top: 0px; border: none; text-align: left; padding-bottom: 20px; padding-left: 0px; }

#rs_nav_css_js_area { position: absolute;top: 75px;left: 0px;width: 100%;height: 455px; padding: 20px;box-sizing: border-box; z-index: 1}

#rs_nav_css_js_area .RevMirror { height: 100%; background: transparent; }

#rs_nav_css_js_area .RevMirror.cm-s-hopscotch span.cm-error { background: transparent; color: #006dd2; }
#rs_nav_css_js_area .RevMirror.cm-s-hopscotch span.cm-tag { background: transparent; color: #b7bbc0; }


#rs_ne_horizontaltest { margin-left: 20px; }
#rs_ne_verticaltest { margin-left: 5px; }

#rs_ne_verticaltest.selected,
#rs_ne_horizontaltest.selected { background: #006dd2; color: #fff; }

#rs_ne_settings .bg_align_row { margin-bottom: 0px; }
#rs_ne_settings .bg_alignselector { width: 10px; height: 10px; }
#rs_ne_settings .bg_alignselector:nth-child(2) { left: 14px; }
#rs_ne_settings .bg_alignselector:nth-child(3) { left: 28px; }
#rs_ne_settings .bg_alignselector_wrap { margin-left: 15px; margin-top: -5px; }



/* ARROWS DEMO*/
#rs_ne_arrows { width: 100%; height: 100%; position: absolute; z-index: 2; }
#rs_ne_tp-rightarrow { right: 20px; top: 50%; transform: translateY(-50%); position: absolute }
#rs_ne_tp-leftarrow { left: 20px; top: 50%; transform: translateY(-50%); position: absolute }
#rs_ne_arrows .tp-arr-imgholder { background-position: center center; background-size: cover; background-repeat: no-repeat; background-image: url(../images/sources/gallery.png); }


/* BULLETS DEMO */
#rs_ne_bullets                    { position: absolute; }
#rs_ne_bullets.nav-pos-ver-top    { top: 30px;  bottom: auto;}
#rs_ne_bullets.nav-pos-ver-center { top: 50%;  bottom: auto; transform:translateY(-50%);}
#rs_ne_bullets.nav-pos-ver-bottom { bottom: 30px;  top: auto;}

#rs_ne_bullets.nav-pos-hor-left   { left: 30px;  right: auto;}
#rs_ne_bullets.nav-pos-hor-center { left: 50%;  right: auto; transform:translateX(-50%);}
#rs_ne_bullets.nav-pos-hor-right  { right: 30px;  left: auto;}




/* TABS DEMO */
#rs_ne_tabs                    { position: absolute; }
#rs_ne_tabs.nav-pos-ver-top    { top: 10px;  bottom: auto;}
#rs_ne_tabs.nav-pos-ver-center { top: 50%;  bottom: auto; transform:translateY(-50%);}
#rs_ne_tabs.nav-pos-ver-bottom { bottom: 10px;  top: auto;}

#rs_ne_tabs.nav-pos-hor-left   { left: 10px;  right: auto;}
#rs_ne_tabs.nav-pos-hor-center { left: 50%;  right: auto; transform:translateX(-50%);}
#rs_ne_tabs.nav-pos-hor-right  { right: 10px;  left: auto;}

#rs_ne_tabs.nav-pos-hor-center.nav-pos-ver-center { transform:translateY(-50%) translateX(-50%);}


/* THUMBS DEMO */
#rs_ne_thumbs                    { position: absolute; }
#rs_ne_thumbs.nav-pos-ver-top    { top: 10px;  bottom: auto;}
#rs_ne_thumbs.nav-pos-ver-center { top: 50%;  bottom: auto; transform:translateY(-50%);}
#rs_ne_thumbs.nav-pos-ver-bottom { bottom: 10px;  top: auto;}

#rs_ne_thumbs.nav-pos-hor-left   { left: 10px;  right: auto;}
#rs_ne_thumbs.nav-pos-hor-center { left: 50%;  right: auto; transform:translateX(-50%);}
#rs_ne_thumbs.nav-pos-hor-right  { right: 10px;  left: auto;}

#rs_ne_thumbs.nav-pos-hor-center.nav-pos-ver-center { transform:translateY(-50%) translateX(-50%);}


#rs_ne_bullets .tp-bullet-image { background-position: center center; background-size: cover; background-repeat: no-repeat; background-image: url(../images/sources/gallery.png); }
#rs_ne_tabs .tp-tab-image { background-position: center center; background-size: cover; background-repeat: no-repeat; background-image: url(../images/sources/gallery.png); }
#rs_ne_thumbs .tp-thumb-image { background-position: center center; background-size: cover; background-repeat: no-repeat; background-image: url(../images/sources/gallery.png); }

/* NAV MODE SELECTOR */
.rs_ne_selector { width: 50%; display: inline-block; background: #3a3e44; cursor: pointer; color: #b7bbc0; font-size: 13px; font-weight: 400; line-height: 40px; padding:0px 0px 0px 30px; box-sizing: border-box;}
.rs_ne_selector:first-child { border-right: 1px solid #333438; border-bottom: 1px solid #333438; }
.rs_ne_selector:nth-child(2) { border-bottom: 1px solid #333438; }
.rs_ne_selector:nth-child(3) { border-right: 1px solid #333438; }
.rs_ne_selector i.material-icons { font-size: 20px; margin-right:10px}
.rs_ne_selector.selected,
.rs_ne_selector:hover { color: #fff; }
.rs_ne_selector.selected { background: #006dd2; }

#rs_ne_settings { width: 100%; height: 30px; border-bottom: 1px solid #333438; padding:22px; line-height: 30px}

/* INPUT AND LABEL CHANGES */
#rb_tlw input[type="text"]#rs_ne_nav_classname { width: 120px;min-width: 120px; max-width: 120px; }
#rb_tlw input[type="text"]#rs_ne_nav_space,
#rb_tlw input[type="text"]#rs_ne_nav_width,
#rb_tlw input[type="text"]#rs_ne_nav_height     { width:60px !important;}
#rs_ne_cssmeta_config label_a { width: 60px !important; }

#rb_tlw #rs_ne_cssmeta_config .revbuilder-colorpicker.visible-cp-input,
#rb_tlw #rs_ne_cssmeta_config  input[type="text"] { width: 125px; }
#rb_tlw #rs_ne_cssmeta_config .revbuilder-colorpicker.visible-cp-input {margin-bottom:10px;}
#rb_tlw #rs_ne_cssmeta_config .revbuilder-colorpicker.visible-cp-input input { width: 97px;margin: -37px 0px 0px 20px; }

#rb_tlw .infactorymode  input[type="text"]#rs_ne_nav_width,
#rb_tlw .infactorymode  input[type="text"]#rs_ne_nav_height,
#rb_tlw .infactorymode  input[type="text"]#rs_ne_nav_classname { pointer-events: none; opacity: 0.5; }

#rs_ne_cssmeta_config .basic_action_button.onlyicon.autosize { width: 85px; }

#rs_ne_cssmeta_config .basic_action_button.onlyicon.autosize.disabled { opacity: 0.5; pointer-events: none; }

#rs_ne_def_meta_color_val_wrap,
#rs_ne_def_meta_color-rgba_val_wrap { display: none; }


.slide_anim_alternates { position: relative }
.remove_altslide.basic_action_button.leftbutton.onlyicon {
    float: none;
    position: absolute;
    left: -15px;
    background: none;
    display: none;
}

.slide_anim_alternates:hover  .remove_altslide.basic_action_button.leftbutton.onlyicon { display: block }





#rb_tlw #rs_ne_settings input[type="text"] { margin-bottom: 0px }


#rs_ne_markup_css_button_wrap { display: inline-block; position: absolute; right: 20px; top: 95px; background: #212226; z-index: 10; }
.rs_ne_markup_css_button { display: inline-block; cursor:pointer; border: 1px solid #333438; text-align: center; line-height: 28px; box-sizing: border-box; position: relative; width:100px; color:#b7bbc0; font-size:13px;}

.rsnmcb_left   { border-radius: 4px 0px 0px 4px; z-index: 1;}
.rsnmcb_right   { border-radius: 0px 4px 4px 0px; margin-left: -1px;z-index: 1}

.rs_ne_markup_css_button.selected { border-radius: 4px;  color:#fff; border-color:#3f444a; z-index: 2;}

#rs_ne_markup_css_button_wrap,
#rs_ne_settings,
#rs_ne_helper_wrap,
#rs_ne_css_meta,
#rs_ne_cssmeta_config { display: none; }

.rs_ne_meta_value_btn,
.rs_ne_markup_meta_btn        { color: #777c81; font-size: 14px; line-height: 30px; cursor: pointer; position: relative; }

.rs_ne_meta_value_btn:hover,
.rs_ne_markup_meta_btn:hover  {  color: #fff; }

#rs_ne_meta_values_inner { position: relative; }

/* TOOLBAR AND INPUT NAME */
.rs_ne_nav_skin { display: block; position: relative; line-height: 40px; border-bottom: 1px solid #3f444a; padding: 0px 20px; color:#b7bbc0; font-size: 14px; font-weight: 400; cursor: pointer; box-sizing: border-box;}

.rs_ne_nav_skin:hover,
.rs_ne_nav_skin.selected { background: #3a3e44; color: #fff; }

.rs_ne_nskin_message,
.rs_ne_nskin_title { display: block; width: 125px; position: relative; white-space: nowrap; overflow: hidden}
.rs_ne_nskin_message {display:none;}

#rb_tlw .rs_ne_nskin_title_input[type=text] { display: none; outline: none; box-shadow: none; border: none; width: 135px; line-height: 40px; height: 40px; margin: 0px; background: transparent;  padding: 0px; }

.rs_ne_nskin_tbar_yesno,
.rs_ne_nskin_tbar_basic { display:none;position: absolute; top:0px; right:0px; text-align: right; width: 110px;  }
#rs_ne_meta_values_inner .rs_ne_nskin_tbar_basic { right: 15px; }
.rs_ne_nskin_tbar_yesno i.material-icons,
.rs_ne_nskin_tbar_basic i.material-icons { margin-right:10px; font-size: 16px; color: #777c80; cursor: pointer;  }
.rs_ne_nskin_tbar_yesno i.material-icons:hover,
.rs_ne_nskin_tbar_basic i.material-icons:hover { color: #fff; }

.rs_ne_listelement:hover .rs_ne_nskin_tbar_basic { display: block; }

.rs_ne_listelement.rs_showmessage .rs_ne_nskin_message,
#rb_tlw .rs_ne_listelement.rs_changename .rs_ne_nskin_title_input[type=text],
.rs_ne_listelement.rs_showmessage .rs_ne_nskin_tbar_yesno,
.rs_ne_listelement.rs_changename .rs_ne_nskin_tbar_yesno { display: block !important; }


.rs_ne_listelement.rs_showmessage .rs_ne_nskin_title,
.rs_ne_listelement.rs_showmessage .rs_ne_nskin_tbar_basic,
.rs_ne_listelement.rs_changename .rs_ne_nskin_title,
.rs_ne_listelement.rs_changename .rs_ne_nskin_tbar_basic,
.rs_ne_listelement.rs_changename:hover .rs_ne_nskin_tbar_basic { display: none !important; }


.rs_ne_list_wrapper { position: relative; max-height: 250px; overflow: hidden; width: 100%; }

#rs_ne_factory_list,
#rs_ne_custom_list { position: relative }

/* NAVIGATION ICONS */
#rs_ne_icons { width: 140px; text-align: right; position: relative; display: block; margin-left:60px; margin-bottom:20px;}

.navpresetrow .font_icon_subcontainer i,
#rs_ne_icons .font_icon_subcontainer i {
    color: #b7bbc0;
    font-size: 17px;
    line-height: 26px !important;
    width: 26px;
    height: 26px;
    display: inline-block;
    text-align: center;
    cursor: pointer;
}

.navpresetrow .font_icon_subcontainer i:hover,
.navpresetrow .font_icon_subcontainer i.selected,
#rs_ne_icons .font_icon_subcontainer i:hover,
#rs_ne_icons .font_icon_subcontainer i.selected {
    background: #006dd2;
    color: #fff;
}


.navpresetrow .input_presets { width: 156px; }

#save_naveditor { display:none; width: 250px; height:50px; line-height:50px; color:#fff; font-size:15px; font-weight:500; position: absolute; bottom: 0px; right: 0px; text-align: center; z-index: 10000; background: #006dd2; cursor: pointer }
#save_naveditor:hover { background: #0a447a; }
#save_naveditor i { margin-right: 5px; line-height: 50px !important; font-size: 20px }

._lc_content_ rs-fcr    {width: 0;height: 0;border-left: 40px solid transparent;border-right: 0px solid transparent;border-top: 40px solid #00A8FF;position: absolute;right:100%;top:0px;}
._lc_content_ rs-fcrt   {width: 0;height: 0;border-left: 40px solid transparent;border-right: 0px solid transparent;border-bottom: 40px solid #00A8FF;position: absolute;right:100%;top:0px;}
._lc_content_ rs-bcr    {width: 0;height: 0;border-left: 0px solid transparent;border-right: 40px solid transparent;border-bottom: 40px solid #00A8FF;position: absolute;left:100%;top:0px;}
._lc_content_ rs-bcrt   {width: 0;height: 0;border-left: 0px solid transparent;border-right: 40px solid transparent;border-top: 40px solid #00A8FF;position: absolute;left:100%;top:0px;}

.tooltip_wrap {transform: rotateY(180deg)}

/****************************
  - MEDIA QUERY CHANGES - 
****************************/
@media only screen and (max-width : 1420px) {
  .help_wrap .toolbar_btn_txt,
  .quick_style_wrap .toolbar_btn_txt { display: none; }

  .help_wrap,
  .quick_style_wrap { padding: 0px; width:50px; text-align: center}

  .help_wrap.toolbar_btn>.material-icons,
  .quick_style_wrap.toolbar_btn>.material-icons { margin-right: 0px; }
}
@media only screen and (max-width : 1290px) {
  .toolbar_btn { padding: 0px; }
  .toolbar_btn_txt { display: none; }
  .toolbar_btn>.material-icons { margin-right: 0px; }
  .layertoolbar_wrap { position: relative; top: auto; left: auto; margin-left: 0px; }

  
  .rso_scrollmenuitem { margin-right: 20px; }

  .toolbar_rightoriented .tool_dd_wrap { margin-left: -160px; }
  .toolbar_rightoriented #toolkit_selector_wrap .tool_dd_wrap { margin-left: -130px; }
  .toolbar_rightoriented #main_screenselector .tool_dd_wrap { margin-left: -189px; }
}

@media only screen and (max-width : 1365px) {
    #add_layer_toolbar_wrap { margin-right: 10px; }
}
@media only screen and (max-width : 1350px) {
  .cwt_link .pli_subtitle { font-size: 15px }
  .pli_left { min-width: 320px; max-width: 320px; padding-right: 30px; }
  #activation_area row { display: block }
  #activation_area row onehalf { display: block; width: 100%; padding: 0px !important;margin-bottom: 10px; }


}

@media only screen and (max-width : 1175px) {
  .features_wrapper,
  .featurebox { width: 100%; display: block;  }  
}

@media only screen and (max-width : 980px) {
  .pli_update_history ul { padding-left: 0px; }
  .pli_update_history ul li { padding-left: 20px; }
  .pli_update_history li:before { left: 4px; } 
}

@media only screen and (max-width : 1165px) {
  
  #do_title_layer, #do_title_layer_not_selected,
  #do_title_slide, #do_title_layer_not_selected
  { font-size: 12px; width: 120px; }
  .toolbar_btn i.toptoolbaricon.material-icons,
  .toolbar_selector_icons .toptoolbaricon.material-icons {  font-size: 17px; }

  .help_wrap,
  .quick_style_wrap,
  #undo_redo_wrap,
  .toolbar_selector_icons .selected_placeholder { width: 40px; }

  .highlight_arrow  { left: 20px; }

  .layertoolbar_wrap { padding-left: 15px; }


}

@media only screen and (max-width : 1020px) {
    .rso_scrollmenuitem { margin-right: 20px;  font-size:14px;}

}

@media only screen and (max-width : 820px) {
  .pli_update_history { height: 300px }
  .rs_fh_right { float: left;  text-align: left;}
  .plugin_inforow { display: block; }
  .pli_left { display:block; min-width: none; border:none; width:100%;max-width: none; padding-right:0px;}
  .pli_right { display:block; min-width: none; padding-left:0px; margin-top:100px;width:100%;max-width: none;padding-left:0px;}
  #rs_overview .div75 { height: 100px; }
  #rs_overview .div150 { height: 100px; }
}



/* HIGH CONTRAST MODE */

.rs-high-contrast .slide_submodule_trigger, 
.rs-high-contrast .layer_submodule_trigger, 
.rs-high-contrast .general_submodule_trigger, 
.rs-high-contrast .nav_submodule_trigger,
.rs-high-contrast label_sub, 
.rs-high-contrast .label_sub, 
.rs-high-contrast label_short, 
.rs-high-contrast .label_short, 
.rs-high-contrast label_a_left, 
.rs-high-contrast .label_a_left, 
.rs-high-contrast label_a_right, 
.rs-high-contrast .label_a_right, 
.rs-high-contrast xy_label, 
.rs-high-contrast .xy_label, 
.rs-high-contrast label_full, 
.rs-high-contrast .label_full, 
.rs-high-contrast label_a, 
.rs-high-contrast .label_a,
.rs-high-contrast  #rb_tlw labelhalf .material-icons,
.rs-high-contrast .description, 
.rs-high-contrast label_info, 
.rs-high-contrast .label_info, 
.rs-high-contrast .function_info,
.rs-high-contrast .fake_onff_off, 
.rs-high-contrast .tponoff_off,
.rs-high-contrast .ale_i_environment, 
.rs-high-contrast #decmod_subtxt, 
.rs-high-contrast .ale_i_content,
.rs-high-contrast #revbuilder-cpicker,
.rs-high-contrast .main_mode_selector,
.rs-high-contrast #rs_overview .subtitle,
.rs-high-contrast .rso_scrollmenuitem,
.rs-high-contrast .action_button,
.rs-high-contrast .rsl_breadcrumb,
.rs-high-contrast grayiconbox,
.rs-high-contrast .pli_subtitle,
.rs-high-contrast .pli_update_history h3.version-number,
.rs-high-contrast darkiconbox,
.rs-high-contrast #general_frame_magnif_wrap .radiooption .shortcuttext,
.rs-high-contrast #quick_style_menu,
.rs-high-contrast .quick_style_dep,
.rs-high-contrast .ol_filter_listelement,
.rs-high-contrast #obj_fil_favorite, 
.rs-high-contrast #obj_updatefromserver, 
.rs-high-contrast #obj_addsliderasmodal,
.rs-high-contrast .rs_overview .ddTP_C .ddTP_S--single .ddTP_S__rendered,
.rs-high-contrast #rb_tlw .miniprevimage_wrap i.material-icons,
.rs-high-contrast #rs_copyright,    
.rs-high-contrast .page_button {
    color: #b7bbc0;
}



.rs-high-contrast .fake_onff_off:after, 
.rs-high-contrast .tponoff_off:after {
    background: #b7bbc0;
}
.rs-high-contrast .disablecontainer {
    opacity: 0.65;
}
 
.rs-high-contrast .revbuilder-cpicker-bright {
    color: #fff;
}
.rs-high-contrast #time_linear .rm_ms, 
.rs-high-contrast #time_linear .rm_sec, 
.rs-high-contrast #time_linear .rm_twosec {
    border-left: 1px solid #777c80;
    color: rgba(183,187,192,1);
}
.rs-high-contrast #ruler_left .rm_five, 
.rs-high-contrast #ruler_left .rm_ten, 
.rs-high-contrast #ruler_left .rm_hundred {
    border-top: 1px solid #777c80;
    color: rgba(183,187,192,1);
}

.rs-high-contrast #ruler_top .rm_five, 
.rs-high-contrast #ruler_top .rm_ten, 
.rs-high-contrast #ruler_top .rm_hundred {
    border-left: 1px solid #777c80;
    color: rgba(183,187,192,1);
}


.rs-high-contrast .multiple_layers_selected #do_background_layer, 
.rs-high-contrast .multiple_layers_selected #do_foreground_layer, 
.rs-high-contrast .no_layers_selected #do_background_layer, 
.rs-high-contrast .no_layers_selected #do_foreground_layer {
    opacity: 0.35;
}
 
.rs-high-contrast .basic_action_button.disabled,
.rs-high-contrast .basic_action_button.disabled i,
.rs-high-contrast .ts_wrapbrtn.notinuse, 
.rs-high-contrast .loop_wrapbrtn.notinuse {
    color: rgba(183,187,192,0.55);
}


.rs-high-contrast .rs_overview .ddTP_C .ddTP_S--single .ddTP_S__arrow b {
    border-color: #b7bbc0 transparent transparent transparent;
}


.rs-high-contrast .oc_gray {
    color: #b7bbc0;
    border: 1px solid #797b7e;
}
.rs-high-contrast i.olibrary_favorit.material-icons {
    color: rgba(255,255,255,0.35);
}

.rs-high-contrast .layer_submodule_trigger:hover, 
.rs-high-contrast .layer_submodule_trigger.selected, 
.rs-high-contrast .slide_submodule_trigger:hover, 
.rs-high-contrast .slide_submodule_trigger.selected, 
.rs-high-contrast .general_submodule_trigger:hover, 
.rs-high-contrast .general_submodule_trigger.selected, 
.rs-high-contrast .nav_submodule_trigger:hover, 
.rs-high-contrast .nav_submodule_trigger.selected,
.rs-high-contrast .ol_filter_listelement:hover, 
.rs-high-contrast .ol_filter_listelement.selected,
.rs-high-contrast #obj_fil_favorite:hover, 
.rs-high-contrast #obj_updatefromserver:hover, 
.rs-high-contrast #obj_fil_favorite.selected,
.rs-high-contrast i.olibrary_favorit.material-icons:hover, 
.rs-high-contrast i.olibrary_favorit.material-icons.selected,
.rs-high-contrast #rs_copyright:hover,
.rs-high-contrast .main_mode_selector:hover,
.rs-high-contrast .rso_scrollmenuitem.active, .rso_scrollmenuitem:hover,
.rs-high-contrast .action_button:hover {
    color: #fff;
}

.rs-high-contrast .page_button.selected, 
.rs-high-contrast .page_button:hover {
    background: #006dd2;
    color: #fff;
}

.rs-high-contrast .rsl_breadcrumb_div {
    color: #797b7e;
}


.rs-high-contrast #rs_overview .new_slider_block i.material-icons {
    color: #b7bbc0;
}
.rs-high-contrast .new_slider_block:hover {
    background: #006dd2;
    color: #fff;
}
.rs-high-contrast .box_with_icon:focus, 
.rs-high-contrast .box_with_icon {
    color: #b7bbc0;
}
.rs-high-contrast a.box_with_icon:hover {
    background: #006dd2;
    color: #fff;
}

.rs-high-contrast #rs_overview .new_slider_block:hover i.material-icons { color: #fff; }

.rs-high-contrast .rso_scrollmenuitem:hover i.material-icons { color: #fff; }

.rs-high-contrast .rso_scrollmenuitem.active i.material-icons,
.rs-high-contrast .rso_scrollmenuitem.active:hover i.material-icons { color: #006dd2; } 

